/*
    See the JupyterLab Developer Guide for useful CSS Patterns:

    https://jupyterlab.readthedocs.io/en/stable/developer/css.html
*/

dl {
  display: grid;
  grid-template-columns: 20% 50%; /* term 30%, definition takes the rest */
  gap: 0.5em 1em; /* row/column gaps */
  width: 100%;
}

dt {
  text-align: right;
  font-weight: bold;
}

dd {
  margin: 0; /* remove default indent */
}

progress {
  width: 100%;
}

.climb-stats {
  overflow: auto;
  height: 100%;
}

.card-body dl {
  margin-bottom: 0;
}
