"use strict";
(self["webpackChunkclimb_dashboard_gui_extension"] = self["webpackChunkclimb_dashboard_gui_extension"] || []).push([["vendors-node_modules_style-loader_dist_runtime_injectStylesIntoStyleTag_js-node_modules_style-12ea8e"],{

/***/ "./node_modules/css-loader/dist/cjs.js!./node_modules/climb-jupyter-base-component/dist/style.css"
/*!********************************************************************************************************!*\
  !*** ./node_modules/css-loader/dist/cjs.js!./node_modules/climb-jupyter-base-component/dist/style.css ***!
  \********************************************************************************************************/
(module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _css_loader_dist_runtime_sourceMaps_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../css-loader/dist/runtime/sourceMaps.js */ "./node_modules/css-loader/dist/runtime/sourceMaps.js");
/* harmony import */ var _css_loader_dist_runtime_sourceMaps_js__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_css_loader_dist_runtime_sourceMaps_js__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../css-loader/dist/runtime/api.js */ "./node_modules/css-loader/dist/runtime/api.js");
/* harmony import */ var _css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var _css_loader_dist_runtime_getUrl_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../css-loader/dist/runtime/getUrl.js */ "./node_modules/css-loader/dist/runtime/getUrl.js");
/* harmony import */ var _css_loader_dist_runtime_getUrl_js__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(_css_loader_dist_runtime_getUrl_js__WEBPACK_IMPORTED_MODULE_2__);
// Imports



var ___CSS_LOADER_URL_IMPORT_0___ = new URL(/* asset import */ __webpack_require__(/*! data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 16 16%27 fill=%27%23000%27%3e%3cpath d=%27M.293.293a1 1 0 0 1 1.414 0L8 6.586 14.293.293a1 1 0 1 1 1.414 1.414L9.414 8l6.293 6.293a1 1 0 0 1-1.414 1.414L8 9.414l-6.293 6.293a1 1 0 0 1-1.414-1.414L6.586 8 .293 1.707a1 1 0 0 1 0-1.414%27/%3e%3c/svg%3e */ "data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 16 16%27 fill=%27%23000%27%3e%3cpath d=%27M.293.293a1 1 0 0 1 1.414 0L8 6.586 14.293.293a1 1 0 1 1 1.414 1.414L9.414 8l6.293 6.293a1 1 0 0 1-1.414 1.414L8 9.414l-6.293 6.293a1 1 0 0 1-1.414-1.414L6.586 8 .293 1.707a1 1 0 0 1 0-1.414%27/%3e%3c/svg%3e"), __webpack_require__.b);
var ___CSS_LOADER_URL_IMPORT_1___ = new URL(/* asset import */ __webpack_require__(/*! data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 16 16%27%3e%3cpath fill=%27none%27 stroke=%27%23343a40%27 stroke-linecap=%27round%27 stroke-linejoin=%27round%27 stroke-width=%272%27 d=%27m2 5 6 6 6-6%27/%3e%3c/svg%3e */ "data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 16 16%27%3e%3cpath fill=%27none%27 stroke=%27%23343a40%27 stroke-linecap=%27round%27 stroke-linejoin=%27round%27 stroke-width=%272%27 d=%27m2 5 6 6 6-6%27/%3e%3c/svg%3e"), __webpack_require__.b);
var ___CSS_LOADER_URL_IMPORT_2___ = new URL(/* asset import */ __webpack_require__(/*! data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 16 16%27%3e%3cpath fill=%27none%27 stroke=%27%23dee2e6%27 stroke-linecap=%27round%27 stroke-linejoin=%27round%27 stroke-width=%272%27 d=%27m2 5 6 6 6-6%27/%3e%3c/svg%3e */ "data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 16 16%27%3e%3cpath fill=%27none%27 stroke=%27%23dee2e6%27 stroke-linecap=%27round%27 stroke-linejoin=%27round%27 stroke-width=%272%27 d=%27m2 5 6 6 6-6%27/%3e%3c/svg%3e"), __webpack_require__.b);
var ___CSS_LOADER_URL_IMPORT_3___ = new URL(/* asset import */ __webpack_require__(/*! data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 20 20%27%3e%3cpath fill=%27none%27 stroke=%27%23fff%27 stroke-linecap=%27round%27 stroke-linejoin=%27round%27 stroke-width=%273%27 d=%27m6 10 3 3 6-6%27/%3e%3c/svg%3e */ "data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 20 20%27%3e%3cpath fill=%27none%27 stroke=%27%23fff%27 stroke-linecap=%27round%27 stroke-linejoin=%27round%27 stroke-width=%273%27 d=%27m6 10 3 3 6-6%27/%3e%3c/svg%3e"), __webpack_require__.b);
var ___CSS_LOADER_URL_IMPORT_4___ = new URL(/* asset import */ __webpack_require__(/*! data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%27-4 -4 8 8%27%3e%3ccircle r=%272%27 fill=%27%23fff%27/%3e%3c/svg%3e */ "data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%27-4 -4 8 8%27%3e%3ccircle r=%272%27 fill=%27%23fff%27/%3e%3c/svg%3e"), __webpack_require__.b);
var ___CSS_LOADER_URL_IMPORT_5___ = new URL(/* asset import */ __webpack_require__(/*! data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 20 20%27%3e%3cpath fill=%27none%27 stroke=%27%23fff%27 stroke-linecap=%27round%27 stroke-linejoin=%27round%27 stroke-width=%273%27 d=%27M6 10h8%27/%3e%3c/svg%3e */ "data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 20 20%27%3e%3cpath fill=%27none%27 stroke=%27%23fff%27 stroke-linecap=%27round%27 stroke-linejoin=%27round%27 stroke-width=%273%27 d=%27M6 10h8%27/%3e%3c/svg%3e"), __webpack_require__.b);
var ___CSS_LOADER_URL_IMPORT_6___ = new URL(/* asset import */ __webpack_require__(/*! data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%27-4 -4 8 8%27%3e%3ccircle r=%273%27 fill=%27rgba%280, 0, 0, 0.25%29%27/%3e%3c/svg%3e */ "data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%27-4 -4 8 8%27%3e%3ccircle r=%273%27 fill=%27rgba%280, 0, 0, 0.25%29%27/%3e%3c/svg%3e"), __webpack_require__.b);
var ___CSS_LOADER_URL_IMPORT_7___ = new URL(/* asset import */ __webpack_require__(/*! data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%27-4 -4 8 8%27%3e%3ccircle r=%273%27 fill=%27rgb%28134, 182.5, 254%29%27/%3e%3c/svg%3e */ "data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%27-4 -4 8 8%27%3e%3ccircle r=%273%27 fill=%27rgb%28134, 182.5, 254%29%27/%3e%3c/svg%3e"), __webpack_require__.b);
var ___CSS_LOADER_URL_IMPORT_8___ = new URL(/* asset import */ __webpack_require__(/*! data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%27-4 -4 8 8%27%3e%3ccircle r=%273%27 fill=%27%23fff%27/%3e%3c/svg%3e */ "data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%27-4 -4 8 8%27%3e%3ccircle r=%273%27 fill=%27%23fff%27/%3e%3c/svg%3e"), __webpack_require__.b);
var ___CSS_LOADER_URL_IMPORT_9___ = new URL(/* asset import */ __webpack_require__(/*! data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%27-4 -4 8 8%27%3e%3ccircle r=%273%27 fill=%27rgba%28255, 255, 255, 0.25%29%27/%3e%3c/svg%3e */ "data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%27-4 -4 8 8%27%3e%3ccircle r=%273%27 fill=%27rgba%28255, 255, 255, 0.25%29%27/%3e%3c/svg%3e"), __webpack_require__.b);
var ___CSS_LOADER_URL_IMPORT_10___ = new URL(/* asset import */ __webpack_require__(/*! data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 8 8%27%3e%3cpath fill=%27%23198754%27 d=%27M2.3 6.73.6 4.53c-.4-1.04.46-1.4 1.1-.8l1.1 1.4 3.4-3.8c.6-.63 1.6-.27 1.2.7l-4 4.6c-.43.5-.8.4-1.1.1%27/%3e%3c/svg%3e */ "data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 8 8%27%3e%3cpath fill=%27%23198754%27 d=%27M2.3 6.73.6 4.53c-.4-1.04.46-1.4 1.1-.8l1.1 1.4 3.4-3.8c.6-.63 1.6-.27 1.2.7l-4 4.6c-.43.5-.8.4-1.1.1%27/%3e%3c/svg%3e"), __webpack_require__.b);
var ___CSS_LOADER_URL_IMPORT_11___ = new URL(/* asset import */ __webpack_require__(/*! data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 12 12%27 width=%2712%27 height=%2712%27 fill=%27none%27 stroke=%27%23dc3545%27%3e%3ccircle cx=%276%27 cy=%276%27 r=%274.5%27/%3e%3cpath stroke-linejoin=%27round%27 d=%27M5.8 3.6h.4L6 6.5z%27/%3e%3ccircle cx=%276%27 cy=%278.2%27 r=%27.6%27 fill=%27%23dc3545%27 stroke=%27none%27/%3e%3c/svg%3e */ "data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 12 12%27 width=%2712%27 height=%2712%27 fill=%27none%27 stroke=%27%23dc3545%27%3e%3ccircle cx=%276%27 cy=%276%27 r=%274.5%27/%3e%3cpath stroke-linejoin=%27round%27 d=%27M5.8 3.6h.4L6 6.5z%27/%3e%3ccircle cx=%276%27 cy=%278.2%27 r=%27.6%27 fill=%27%23dc3545%27 stroke=%27none%27/%3e%3c/svg%3e"), __webpack_require__.b);
var ___CSS_LOADER_URL_IMPORT_12___ = new URL(/* asset import */ __webpack_require__(/*! data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 30 30%27%3e%3cpath stroke=%27rgba%2833, 37, 41, 0.75%29%27 stroke-linecap=%27round%27 stroke-miterlimit=%2710%27 stroke-width=%272%27 d=%27M4 7h22M4 15h22M4 23h22%27/%3e%3c/svg%3e */ "data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 30 30%27%3e%3cpath stroke=%27rgba%2833, 37, 41, 0.75%29%27 stroke-linecap=%27round%27 stroke-miterlimit=%2710%27 stroke-width=%272%27 d=%27M4 7h22M4 15h22M4 23h22%27/%3e%3c/svg%3e"), __webpack_require__.b);
var ___CSS_LOADER_URL_IMPORT_13___ = new URL(/* asset import */ __webpack_require__(/*! data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 30 30%27%3e%3cpath stroke=%27rgba%28255, 255, 255, 0.55%29%27 stroke-linecap=%27round%27 stroke-miterlimit=%2710%27 stroke-width=%272%27 d=%27M4 7h22M4 15h22M4 23h22%27/%3e%3c/svg%3e */ "data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 30 30%27%3e%3cpath stroke=%27rgba%28255, 255, 255, 0.55%29%27 stroke-linecap=%27round%27 stroke-miterlimit=%2710%27 stroke-width=%272%27 d=%27M4 7h22M4 15h22M4 23h22%27/%3e%3c/svg%3e"), __webpack_require__.b);
var ___CSS_LOADER_URL_IMPORT_14___ = new URL(/* asset import */ __webpack_require__(/*! data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 16 16%27 fill=%27none%27 stroke=%27%23212529%27 stroke-linecap=%27round%27 stroke-linejoin=%27round%27%3e%3cpath d=%27m2 5 6 6 6-6%27/%3e%3c/svg%3e */ "data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 16 16%27 fill=%27none%27 stroke=%27%23212529%27 stroke-linecap=%27round%27 stroke-linejoin=%27round%27%3e%3cpath d=%27m2 5 6 6 6-6%27/%3e%3c/svg%3e"), __webpack_require__.b);
var ___CSS_LOADER_URL_IMPORT_15___ = new URL(/* asset import */ __webpack_require__(/*! data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 16 16%27 fill=%27none%27 stroke=%27rgb%285.2, 44, 101.2%29%27 stroke-linecap=%27round%27 stroke-linejoin=%27round%27%3e%3cpath d=%27m2 5 6 6 6-6%27/%3e%3c/svg%3e */ "data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 16 16%27 fill=%27none%27 stroke=%27rgb%285.2, 44, 101.2%29%27 stroke-linecap=%27round%27 stroke-linejoin=%27round%27%3e%3cpath d=%27m2 5 6 6 6-6%27/%3e%3c/svg%3e"), __webpack_require__.b);
var ___CSS_LOADER_URL_IMPORT_16___ = new URL(/* asset import */ __webpack_require__(/*! data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 16 16%27 fill=%27rgb%28109.8, 168, 253.8%29%27%3e%3cpath fill-rule=%27evenodd%27 d=%27M1.646 4.646a.5.5 0 0 1 .708 0L8 10.293l5.646-5.647a.5.5 0 0 1 .708.708l-6 6a.5.5 0 0 1-.708 0l-6-6a.5.5 0 0 1 0-.708%27/%3e%3c/svg%3e */ "data:image/svg+xml,%3csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 16 16%27 fill=%27rgb%28109.8, 168, 253.8%29%27%3e%3cpath fill-rule=%27evenodd%27 d=%27M1.646 4.646a.5.5 0 0 1 .708 0L8 10.293l5.646-5.647a.5.5 0 0 1 .708.708l-6 6a.5.5 0 0 1-.708 0l-6-6a.5.5 0 0 1 0-.708%27/%3e%3c/svg%3e"), __webpack_require__.b);
var ___CSS_LOADER_EXPORT___ = _css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1___default()((_css_loader_dist_runtime_sourceMaps_js__WEBPACK_IMPORTED_MODULE_0___default()));
var ___CSS_LOADER_URL_REPLACEMENT_0___ = _css_loader_dist_runtime_getUrl_js__WEBPACK_IMPORTED_MODULE_2___default()(___CSS_LOADER_URL_IMPORT_0___);
var ___CSS_LOADER_URL_REPLACEMENT_1___ = _css_loader_dist_runtime_getUrl_js__WEBPACK_IMPORTED_MODULE_2___default()(___CSS_LOADER_URL_IMPORT_1___);
var ___CSS_LOADER_URL_REPLACEMENT_2___ = _css_loader_dist_runtime_getUrl_js__WEBPACK_IMPORTED_MODULE_2___default()(___CSS_LOADER_URL_IMPORT_2___);
var ___CSS_LOADER_URL_REPLACEMENT_3___ = _css_loader_dist_runtime_getUrl_js__WEBPACK_IMPORTED_MODULE_2___default()(___CSS_LOADER_URL_IMPORT_3___);
var ___CSS_LOADER_URL_REPLACEMENT_4___ = _css_loader_dist_runtime_getUrl_js__WEBPACK_IMPORTED_MODULE_2___default()(___CSS_LOADER_URL_IMPORT_4___);
var ___CSS_LOADER_URL_REPLACEMENT_5___ = _css_loader_dist_runtime_getUrl_js__WEBPACK_IMPORTED_MODULE_2___default()(___CSS_LOADER_URL_IMPORT_5___);
var ___CSS_LOADER_URL_REPLACEMENT_6___ = _css_loader_dist_runtime_getUrl_js__WEBPACK_IMPORTED_MODULE_2___default()(___CSS_LOADER_URL_IMPORT_6___);
var ___CSS_LOADER_URL_REPLACEMENT_7___ = _css_loader_dist_runtime_getUrl_js__WEBPACK_IMPORTED_MODULE_2___default()(___CSS_LOADER_URL_IMPORT_7___);
var ___CSS_LOADER_URL_REPLACEMENT_8___ = _css_loader_dist_runtime_getUrl_js__WEBPACK_IMPORTED_MODULE_2___default()(___CSS_LOADER_URL_IMPORT_8___);
var ___CSS_LOADER_URL_REPLACEMENT_9___ = _css_loader_dist_runtime_getUrl_js__WEBPACK_IMPORTED_MODULE_2___default()(___CSS_LOADER_URL_IMPORT_9___);
var ___CSS_LOADER_URL_REPLACEMENT_10___ = _css_loader_dist_runtime_getUrl_js__WEBPACK_IMPORTED_MODULE_2___default()(___CSS_LOADER_URL_IMPORT_10___);
var ___CSS_LOADER_URL_REPLACEMENT_11___ = _css_loader_dist_runtime_getUrl_js__WEBPACK_IMPORTED_MODULE_2___default()(___CSS_LOADER_URL_IMPORT_11___);
var ___CSS_LOADER_URL_REPLACEMENT_12___ = _css_loader_dist_runtime_getUrl_js__WEBPACK_IMPORTED_MODULE_2___default()(___CSS_LOADER_URL_IMPORT_12___);
var ___CSS_LOADER_URL_REPLACEMENT_13___ = _css_loader_dist_runtime_getUrl_js__WEBPACK_IMPORTED_MODULE_2___default()(___CSS_LOADER_URL_IMPORT_13___);
var ___CSS_LOADER_URL_REPLACEMENT_14___ = _css_loader_dist_runtime_getUrl_js__WEBPACK_IMPORTED_MODULE_2___default()(___CSS_LOADER_URL_IMPORT_14___);
var ___CSS_LOADER_URL_REPLACEMENT_15___ = _css_loader_dist_runtime_getUrl_js__WEBPACK_IMPORTED_MODULE_2___default()(___CSS_LOADER_URL_IMPORT_15___);
var ___CSS_LOADER_URL_REPLACEMENT_16___ = _css_loader_dist_runtime_getUrl_js__WEBPACK_IMPORTED_MODULE_2___default()(___CSS_LOADER_URL_IMPORT_16___);
// Module
___CSS_LOADER_EXPORT___.push([module.id, `@charset "UTF-8";/*!
 * Bootstrap  v5.3.8 (https://getbootstrap.com/)
 * Copyright 2011-2025 The Bootstrap Authors
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
 */:root,[data-bs-theme=light]{--bs-blue: #0d6efd;--bs-indigo: #6610f2;--bs-purple: #6f42c1;--bs-pink: #d63384;--bs-red: #dc3545;--bs-orange: #fd7e14;--bs-yellow: #ffc107;--bs-green: #198754;--bs-teal: #20c997;--bs-cyan: #0dcaf0;--bs-black: #000;--bs-white: #fff;--bs-gray: #6c757d;--bs-gray-dark: #343a40;--bs-gray-100: #f8f9fa;--bs-gray-200: #e9ecef;--bs-gray-300: #dee2e6;--bs-gray-400: #ced4da;--bs-gray-500: #adb5bd;--bs-gray-600: #6c757d;--bs-gray-700: #495057;--bs-gray-800: #343a40;--bs-gray-900: #212529;--bs-primary: #0d6efd;--bs-secondary: #6c757d;--bs-success: #198754;--bs-info: #0dcaf0;--bs-warning: #ffc107;--bs-danger: #dc3545;--bs-light: #f8f9fa;--bs-dark: #212529;--bs-primary-rgb: 13, 110, 253;--bs-secondary-rgb: 108, 117, 125;--bs-success-rgb: 25, 135, 84;--bs-info-rgb: 13, 202, 240;--bs-warning-rgb: 255, 193, 7;--bs-danger-rgb: 220, 53, 69;--bs-light-rgb: 248, 249, 250;--bs-dark-rgb: 33, 37, 41;--bs-primary-text-emphasis: rgb(5.2, 44, 101.2);--bs-secondary-text-emphasis: rgb(43.2, 46.8, 50);--bs-success-text-emphasis: rgb(10, 54, 33.6);--bs-info-text-emphasis: rgb(5.2, 80.8, 96);--bs-warning-text-emphasis: rgb(102, 77.2, 2.8);--bs-danger-text-emphasis: rgb(88, 21.2, 27.6);--bs-light-text-emphasis: #495057;--bs-dark-text-emphasis: #495057;--bs-primary-bg-subtle: rgb(206.6, 226, 254.6);--bs-secondary-bg-subtle: rgb(225.6, 227.4, 229);--bs-success-bg-subtle: rgb(209, 231, 220.8);--bs-info-bg-subtle: rgb(206.6, 244.4, 252);--bs-warning-bg-subtle: rgb(255, 242.6, 205.4);--bs-danger-bg-subtle: rgb(248, 214.6, 217.8);--bs-light-bg-subtle: rgb(251.5, 252, 252.5);--bs-dark-bg-subtle: #ced4da;--bs-primary-border-subtle: rgb(158.2, 197, 254.2);--bs-secondary-border-subtle: rgb(196.2, 199.8, 203);--bs-success-border-subtle: rgb(163, 207, 186.6);--bs-info-border-subtle: rgb(158.2, 233.8, 249);--bs-warning-border-subtle: rgb(255, 230.2, 155.8);--bs-danger-border-subtle: rgb(241, 174.2, 180.6);--bs-light-border-subtle: #e9ecef;--bs-dark-border-subtle: #adb5bd;--bs-white-rgb: 255, 255, 255;--bs-black-rgb: 0, 0, 0;--bs-font-sans-serif: system-ui, -apple-system, "Segoe UI", Roboto, "Helvetica Neue", "Noto Sans", "Liberation Sans", Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol", "Noto Color Emoji";--bs-font-monospace: SFMono-Regular, Menlo, Monaco, Consolas, "Liberation Mono", "Courier New", monospace;--bs-gradient: linear-gradient(180deg, rgba(255, 255, 255, .15), rgba(255, 255, 255, 0));--bs-body-font-family: var(--bs-font-sans-serif);--bs-body-font-size: 1rem;--bs-body-font-weight: 400;--bs-body-line-height: 1.5;--bs-body-color: #212529;--bs-body-color-rgb: 33, 37, 41;--bs-body-bg: #fff;--bs-body-bg-rgb: 255, 255, 255;--bs-emphasis-color: #000;--bs-emphasis-color-rgb: 0, 0, 0;--bs-secondary-color: rgba(33, 37, 41, .75);--bs-secondary-color-rgb: 33, 37, 41;--bs-secondary-bg: #e9ecef;--bs-secondary-bg-rgb: 233, 236, 239;--bs-tertiary-color: rgba(33, 37, 41, .5);--bs-tertiary-color-rgb: 33, 37, 41;--bs-tertiary-bg: #f8f9fa;--bs-tertiary-bg-rgb: 248, 249, 250;--bs-heading-color: inherit;--bs-link-color: #0d6efd;--bs-link-color-rgb: 13, 110, 253;--bs-link-decoration: underline;--bs-link-hover-color: rgb(10.4, 88, 202.4);--bs-link-hover-color-rgb: 10, 88, 202;--bs-code-color: #d63384;--bs-highlight-color: #212529;--bs-highlight-bg: rgb(255, 242.6, 205.4);--bs-border-width: 1px;--bs-border-style: solid;--bs-border-color: #dee2e6;--bs-border-color-translucent: rgba(0, 0, 0, .175);--bs-border-radius: .375rem;--bs-border-radius-sm: .25rem;--bs-border-radius-lg: .5rem;--bs-border-radius-xl: 1rem;--bs-border-radius-xxl: 2rem;--bs-border-radius-2xl: var(--bs-border-radius-xxl);--bs-border-radius-pill: 50rem;--bs-box-shadow: 0 .5rem 1rem rgba(0, 0, 0, .15);--bs-box-shadow-sm: 0 .125rem .25rem rgba(0, 0, 0, .075);--bs-box-shadow-lg: 0 1rem 3rem rgba(0, 0, 0, .175);--bs-box-shadow-inset: inset 0 1px 2px rgba(0, 0, 0, .075);--bs-focus-ring-width: .25rem;--bs-focus-ring-opacity: .25;--bs-focus-ring-color: rgba(13, 110, 253, .25);--bs-form-valid-color: #198754;--bs-form-valid-border-color: #198754;--bs-form-invalid-color: #dc3545;--bs-form-invalid-border-color: #dc3545}[data-bs-theme=dark]{color-scheme:dark;--bs-body-color: #dee2e6;--bs-body-color-rgb: 222, 226, 230;--bs-body-bg: #212529;--bs-body-bg-rgb: 33, 37, 41;--bs-emphasis-color: #fff;--bs-emphasis-color-rgb: 255, 255, 255;--bs-secondary-color: rgba(222, 226, 230, .75);--bs-secondary-color-rgb: 222, 226, 230;--bs-secondary-bg: #343a40;--bs-secondary-bg-rgb: 52, 58, 64;--bs-tertiary-color: rgba(222, 226, 230, .5);--bs-tertiary-color-rgb: 222, 226, 230;--bs-tertiary-bg: rgb(42.5, 47.5, 52.5);--bs-tertiary-bg-rgb: 43, 48, 53;--bs-primary-text-emphasis: rgb(109.8, 168, 253.8);--bs-secondary-text-emphasis: rgb(166.8, 172.2, 177);--bs-success-text-emphasis: rgb(117, 183, 152.4);--bs-info-text-emphasis: rgb(109.8, 223.2, 246);--bs-warning-text-emphasis: rgb(255, 217.8, 106.2);--bs-danger-text-emphasis: rgb(234, 133.8, 143.4);--bs-light-text-emphasis: #f8f9fa;--bs-dark-text-emphasis: #dee2e6;--bs-primary-bg-subtle: rgb(2.6, 22, 50.6);--bs-secondary-bg-subtle: rgb(21.6, 23.4, 25);--bs-success-bg-subtle: rgb(5, 27, 16.8);--bs-info-bg-subtle: rgb(2.6, 40.4, 48);--bs-warning-bg-subtle: rgb(51, 38.6, 1.4);--bs-danger-bg-subtle: rgb(44, 10.6, 13.8);--bs-light-bg-subtle: #343a40;--bs-dark-bg-subtle: #1a1d20;--bs-primary-border-subtle: rgb(7.8, 66, 151.8);--bs-secondary-border-subtle: rgb(64.8, 70.2, 75);--bs-success-border-subtle: rgb(15, 81, 50.4);--bs-info-border-subtle: rgb(7.8, 121.2, 144);--bs-warning-border-subtle: rgb(153, 115.8, 4.2);--bs-danger-border-subtle: rgb(132, 31.8, 41.4);--bs-light-border-subtle: #495057;--bs-dark-border-subtle: #343a40;--bs-heading-color: inherit;--bs-link-color: rgb(109.8, 168, 253.8);--bs-link-hover-color: rgb(138.84, 185.4, 254.04);--bs-link-color-rgb: 110, 168, 254;--bs-link-hover-color-rgb: 139, 185, 254;--bs-code-color: rgb(230.4, 132.6, 181.2);--bs-highlight-color: #dee2e6;--bs-highlight-bg: rgb(102, 77.2, 2.8);--bs-border-color: #495057;--bs-border-color-translucent: rgba(255, 255, 255, .15);--bs-form-valid-color: rgb(117, 183, 152.4);--bs-form-valid-border-color: rgb(117, 183, 152.4);--bs-form-invalid-color: rgb(234, 133.8, 143.4);--bs-form-invalid-border-color: rgb(234, 133.8, 143.4)}.btn-close{--bs-btn-close-color: #000;--bs-btn-close-bg: url(${___CSS_LOADER_URL_REPLACEMENT_0___});--bs-btn-close-opacity: .5;--bs-btn-close-hover-opacity: .75;--bs-btn-close-focus-shadow: 0 0 0 .25rem rgba(13, 110, 253, .25);--bs-btn-close-focus-opacity: 1;--bs-btn-close-disabled-opacity: .25;box-sizing:content-box;width:1em;height:1em;padding:.25em;color:var(--bs-btn-close-color);background:transparent var(--bs-btn-close-bg) center/1em auto no-repeat;filter:var(--bs-btn-close-filter);border:0;border-radius:.375rem;opacity:var(--bs-btn-close-opacity)}.btn-close:hover{color:var(--bs-btn-close-color);text-decoration:none;opacity:var(--bs-btn-close-hover-opacity)}.btn-close:focus{outline:0;box-shadow:var(--bs-btn-close-focus-shadow);opacity:var(--bs-btn-close-focus-opacity)}.btn-close:disabled,.btn-close.disabled{pointer-events:none;-webkit-user-select:none;user-select:none;opacity:var(--bs-btn-close-disabled-opacity)}.btn-close-white{--bs-btn-close-filter: invert(1) grayscale(100%) brightness(200%)}:root,[data-bs-theme=light]{--bs-btn-close-filter: }[data-bs-theme=dark]{--bs-btn-close-filter: invert(1) grayscale(100%) brightness(200%)}.climb-jupyter *,.climb-jupyter *:before,.climb-jupyter *:after{box-sizing:border-box}@media (prefers-reduced-motion: no-preference){.climb-jupyter :root{scroll-behavior:smooth}}.climb-jupyter body{margin:0;font-family:var(--bs-body-font-family);font-size:var(--bs-body-font-size);font-weight:var(--bs-body-font-weight);line-height:var(--bs-body-line-height);color:var(--bs-body-color);text-align:var(--bs-body-text-align);background-color:var(--bs-body-bg);-webkit-text-size-adjust:100%;-webkit-tap-highlight-color:rgba(0,0,0,0)}.climb-jupyter hr{margin:1rem 0;color:inherit;border:0;border-top:var(--bs-border-width) solid;opacity:.25}.climb-jupyter h6,.climb-jupyter .h6,.climb-jupyter h5,.climb-jupyter .h5,.climb-jupyter h4,.climb-jupyter .h4,.climb-jupyter h3,.climb-jupyter .h3,.climb-jupyter h2,.climb-jupyter .h2,.climb-jupyter h1,.climb-jupyter .h1{margin-top:0;margin-bottom:.5rem;font-weight:500;line-height:1.2;color:var(--bs-heading-color)}.climb-jupyter h1,.climb-jupyter .h1{font-size:calc(1.375rem + 1.5vw)}@media (min-width: 1200px){.climb-jupyter h1,.climb-jupyter .h1{font-size:2.5rem}}.climb-jupyter h2,.climb-jupyter .h2{font-size:calc(1.325rem + .9vw)}@media (min-width: 1200px){.climb-jupyter h2,.climb-jupyter .h2{font-size:2rem}}.climb-jupyter h3,.climb-jupyter .h3{font-size:calc(1.3rem + .6vw)}@media (min-width: 1200px){.climb-jupyter h3,.climb-jupyter .h3{font-size:1.75rem}}.climb-jupyter h4,.climb-jupyter .h4{font-size:calc(1.275rem + .3vw)}@media (min-width: 1200px){.climb-jupyter h4,.climb-jupyter .h4{font-size:1.5rem}}.climb-jupyter h5,.climb-jupyter .h5{font-size:1.25rem}.climb-jupyter h6,.climb-jupyter .h6{font-size:1rem}.climb-jupyter p{margin-top:0;margin-bottom:1rem}.climb-jupyter abbr[title]{text-decoration:underline dotted;cursor:help;text-decoration-skip-ink:none}.climb-jupyter address{margin-bottom:1rem;font-style:normal;line-height:inherit}.climb-jupyter ol,.climb-jupyter ul{padding-left:2rem}.climb-jupyter ol,.climb-jupyter ul,.climb-jupyter dl{margin-top:0;margin-bottom:1rem}.climb-jupyter ol ol,.climb-jupyter ul ul,.climb-jupyter ol ul,.climb-jupyter ul ol{margin-bottom:0}.climb-jupyter dt{font-weight:700}.climb-jupyter dd{margin-bottom:.5rem;margin-left:0}.climb-jupyter blockquote{margin:0 0 1rem}.climb-jupyter b,.climb-jupyter strong{font-weight:bolder}.climb-jupyter small,.climb-jupyter .small{font-size:.875em}.climb-jupyter mark,.climb-jupyter .mark{padding:.1875em;color:var(--bs-highlight-color);background-color:var(--bs-highlight-bg)}.climb-jupyter sub,.climb-jupyter sup{position:relative;font-size:.75em;line-height:0;vertical-align:baseline}.climb-jupyter sub{bottom:-.25em}.climb-jupyter sup{top:-.5em}.climb-jupyter a{color:rgba(var(--bs-link-color-rgb),var(--bs-link-opacity, 1));text-decoration:underline}.climb-jupyter a:hover{--bs-link-color-rgb: var(--bs-link-hover-color-rgb)}.climb-jupyter a:not([href]):not([class]),.climb-jupyter a:not([href]):not([class]):hover{color:inherit;text-decoration:none}.climb-jupyter pre,.climb-jupyter code,.climb-jupyter kbd,.climb-jupyter samp{font-family:var(--bs-font-monospace);font-size:1em}.climb-jupyter pre{display:block;margin-top:0;margin-bottom:1rem;overflow:auto;font-size:.875em}.climb-jupyter pre code{font-size:inherit;color:inherit;word-break:normal}.climb-jupyter code{font-size:.875em;color:var(--bs-code-color);word-wrap:break-word}a>.climb-jupyter code{color:inherit}.climb-jupyter kbd{padding:.1875rem .375rem;font-size:.875em;color:var(--bs-body-bg);background-color:var(--bs-body-color);border-radius:.25rem}.climb-jupyter kbd kbd{padding:0;font-size:1em}.climb-jupyter figure{margin:0 0 1rem}.climb-jupyter img,.climb-jupyter svg{vertical-align:middle}.climb-jupyter table{caption-side:bottom;border-collapse:collapse}.climb-jupyter caption{padding-top:.5rem;padding-bottom:.5rem;color:var(--bs-secondary-color);text-align:left}.climb-jupyter th{text-align:inherit;text-align:-webkit-match-parent}.climb-jupyter thead,.climb-jupyter tbody,.climb-jupyter tfoot,.climb-jupyter tr,.climb-jupyter td,.climb-jupyter th{border-color:inherit;border-style:solid;border-width:0}.climb-jupyter label{display:inline-block}.climb-jupyter button{border-radius:0}.climb-jupyter button:focus:not(:focus-visible){outline:0}.climb-jupyter input,.climb-jupyter button,.climb-jupyter select,.climb-jupyter optgroup,.climb-jupyter textarea{margin:0;font-family:inherit;font-size:inherit;line-height:inherit}.climb-jupyter button,.climb-jupyter select{text-transform:none}.climb-jupyter [role=button]{cursor:pointer}.climb-jupyter select{word-wrap:normal}.climb-jupyter select:disabled{opacity:1}.climb-jupyter [list]:not([type=date]):not([type=datetime-local]):not([type=month]):not([type=week]):not([type=time])::-webkit-calendar-picker-indicator{display:none!important}.climb-jupyter button,.climb-jupyter [type=button],.climb-jupyter [type=reset],.climb-jupyter [type=submit]{-webkit-appearance:button}.climb-jupyter button:not(:disabled),.climb-jupyter [type=button]:not(:disabled),.climb-jupyter [type=reset]:not(:disabled),.climb-jupyter [type=submit]:not(:disabled){cursor:pointer}.climb-jupyter ::-moz-focus-inner{padding:0;border-style:none}.climb-jupyter textarea{resize:vertical}.climb-jupyter fieldset{min-width:0;padding:0;margin:0;border:0}.climb-jupyter legend{float:left;width:100%;padding:0;margin-bottom:.5rem;line-height:inherit;font-size:calc(1.275rem + .3vw)}@media (min-width: 1200px){.climb-jupyter legend{font-size:1.5rem}}.climb-jupyter legend+*{clear:left}.climb-jupyter ::-webkit-datetime-edit-fields-wrapper,.climb-jupyter ::-webkit-datetime-edit-text,.climb-jupyter ::-webkit-datetime-edit-minute,.climb-jupyter ::-webkit-datetime-edit-hour-field,.climb-jupyter ::-webkit-datetime-edit-day-field,.climb-jupyter ::-webkit-datetime-edit-month-field,.climb-jupyter ::-webkit-datetime-edit-year-field{padding:0}.climb-jupyter ::-webkit-inner-spin-button{height:auto}.climb-jupyter [type=search]{-webkit-appearance:textfield;outline-offset:-2px}.climb-jupyter [type=search]::-webkit-search-cancel-button{cursor:pointer;filter:grayscale(1)}.climb-jupyter ::-webkit-search-decoration{-webkit-appearance:none}.climb-jupyter ::-webkit-color-swatch-wrapper{padding:0}.climb-jupyter ::file-selector-button{font:inherit;-webkit-appearance:button}.climb-jupyter output{display:inline-block}.climb-jupyter iframe{border:0}.climb-jupyter summary{display:list-item;cursor:pointer}.climb-jupyter progress{vertical-align:baseline}.climb-jupyter [hidden]{display:none!important}.climb-jupyter .lead{font-size:1.25rem;font-weight:300}.climb-jupyter .display-1{font-weight:300;line-height:1.2;font-size:calc(1.625rem + 4.5vw)}@media (min-width: 1200px){.climb-jupyter .display-1{font-size:5rem}}.climb-jupyter .display-2{font-weight:300;line-height:1.2;font-size:calc(1.575rem + 3.9vw)}@media (min-width: 1200px){.climb-jupyter .display-2{font-size:4.5rem}}.climb-jupyter .display-3{font-weight:300;line-height:1.2;font-size:calc(1.525rem + 3.3vw)}@media (min-width: 1200px){.climb-jupyter .display-3{font-size:4rem}}.climb-jupyter .display-4{font-weight:300;line-height:1.2;font-size:calc(1.475rem + 2.7vw)}@media (min-width: 1200px){.climb-jupyter .display-4{font-size:3.5rem}}.climb-jupyter .display-5{font-weight:300;line-height:1.2;font-size:calc(1.425rem + 2.1vw)}@media (min-width: 1200px){.climb-jupyter .display-5{font-size:3rem}}.climb-jupyter .display-6{font-weight:300;line-height:1.2;font-size:calc(1.375rem + 1.5vw)}@media (min-width: 1200px){.climb-jupyter .display-6{font-size:2.5rem}}.climb-jupyter .list-unstyled,.climb-jupyter .list-inline{padding-left:0;list-style:none}.climb-jupyter .list-inline-item{display:inline-block}.climb-jupyter .list-inline-item:not(:last-child){margin-right:.5rem}.climb-jupyter .initialism{font-size:.875em;text-transform:uppercase}.climb-jupyter .blockquote{margin-bottom:1rem;font-size:1.25rem}.climb-jupyter .blockquote>:last-child{margin-bottom:0}.climb-jupyter .blockquote-footer{margin-top:-1rem;margin-bottom:1rem;font-size:.875em;color:#6c757d}.climb-jupyter .blockquote-footer:before{content:"— "}.climb-jupyter .container,.climb-jupyter .container-fluid,.climb-jupyter .container-xxl,.climb-jupyter .container-xl,.climb-jupyter .container-lg,.climb-jupyter .container-md,.climb-jupyter .container-sm{--bs-gutter-x: 1.5rem;--bs-gutter-y: 0;width:100%;padding-right:calc(var(--bs-gutter-x) * .5);padding-left:calc(var(--bs-gutter-x) * .5);margin-right:auto;margin-left:auto}@media (min-width: 576px){.climb-jupyter .container-sm,.climb-jupyter .container{max-width:540px}}@media (min-width: 768px){.climb-jupyter .container-md,.climb-jupyter .container-sm,.climb-jupyter .container{max-width:720px}}@media (min-width: 992px){.climb-jupyter .container-lg,.climb-jupyter .container-md,.climb-jupyter .container-sm,.climb-jupyter .container{max-width:960px}}@media (min-width: 1200px){.climb-jupyter .container-xl,.climb-jupyter .container-lg,.climb-jupyter .container-md,.climb-jupyter .container-sm,.climb-jupyter .container{max-width:1140px}}@media (min-width: 1400px){.climb-jupyter .container-xxl,.climb-jupyter .container-xl,.climb-jupyter .container-lg,.climb-jupyter .container-md,.climb-jupyter .container-sm,.climb-jupyter .container{max-width:1320px}}.climb-jupyter :root{--bs-breakpoint-xs: 0;--bs-breakpoint-sm: 576px;--bs-breakpoint-md: 768px;--bs-breakpoint-lg: 992px;--bs-breakpoint-xl: 1200px;--bs-breakpoint-xxl: 1400px}.climb-jupyter .row{--bs-gutter-x: 1.5rem;--bs-gutter-y: 0;display:flex;flex-wrap:wrap;margin-top:calc(-1 * var(--bs-gutter-y));margin-right:calc(-.5 * var(--bs-gutter-x));margin-left:calc(-.5 * var(--bs-gutter-x))}.climb-jupyter .row>*{flex-shrink:0;width:100%;max-width:100%;padding-right:calc(var(--bs-gutter-x) * .5);padding-left:calc(var(--bs-gutter-x) * .5);margin-top:var(--bs-gutter-y)}.climb-jupyter .col{flex:1 0 0}.climb-jupyter .row-cols-auto>*{flex:0 0 auto;width:auto}.climb-jupyter .row-cols-1>*{flex:0 0 auto;width:100%}.climb-jupyter .row-cols-2>*{flex:0 0 auto;width:50%}.climb-jupyter .row-cols-3>*{flex:0 0 auto;width:33.33333333%}.climb-jupyter .row-cols-4>*{flex:0 0 auto;width:25%}.climb-jupyter .row-cols-5>*{flex:0 0 auto;width:20%}.climb-jupyter .row-cols-6>*{flex:0 0 auto;width:16.66666667%}.climb-jupyter .col-auto{flex:0 0 auto;width:auto}.climb-jupyter .col-1{flex:0 0 auto;width:8.33333333%}.climb-jupyter .col-2{flex:0 0 auto;width:16.66666667%}.climb-jupyter .col-3{flex:0 0 auto;width:25%}.climb-jupyter .col-4{flex:0 0 auto;width:33.33333333%}.climb-jupyter .col-5{flex:0 0 auto;width:41.66666667%}.climb-jupyter .col-6{flex:0 0 auto;width:50%}.climb-jupyter .col-7{flex:0 0 auto;width:58.33333333%}.climb-jupyter .col-8{flex:0 0 auto;width:66.66666667%}.climb-jupyter .col-9{flex:0 0 auto;width:75%}.climb-jupyter .col-10{flex:0 0 auto;width:83.33333333%}.climb-jupyter .col-11{flex:0 0 auto;width:91.66666667%}.climb-jupyter .col-12{flex:0 0 auto;width:100%}.climb-jupyter .offset-1{margin-left:8.33333333%}.climb-jupyter .offset-2{margin-left:16.66666667%}.climb-jupyter .offset-3{margin-left:25%}.climb-jupyter .offset-4{margin-left:33.33333333%}.climb-jupyter .offset-5{margin-left:41.66666667%}.climb-jupyter .offset-6{margin-left:50%}.climb-jupyter .offset-7{margin-left:58.33333333%}.climb-jupyter .offset-8{margin-left:66.66666667%}.climb-jupyter .offset-9{margin-left:75%}.climb-jupyter .offset-10{margin-left:83.33333333%}.climb-jupyter .offset-11{margin-left:91.66666667%}.climb-jupyter .g-0,.climb-jupyter .gx-0{--bs-gutter-x: 0}.climb-jupyter .g-0,.climb-jupyter .gy-0{--bs-gutter-y: 0}.climb-jupyter .g-1,.climb-jupyter .gx-1{--bs-gutter-x: .25rem}.climb-jupyter .g-1,.climb-jupyter .gy-1{--bs-gutter-y: .25rem}.climb-jupyter .g-2,.climb-jupyter .gx-2{--bs-gutter-x: .5rem}.climb-jupyter .g-2,.climb-jupyter .gy-2{--bs-gutter-y: .5rem}.climb-jupyter .g-3,.climb-jupyter .gx-3{--bs-gutter-x: 1rem}.climb-jupyter .g-3,.climb-jupyter .gy-3{--bs-gutter-y: 1rem}.climb-jupyter .g-4,.climb-jupyter .gx-4{--bs-gutter-x: 1.5rem}.climb-jupyter .g-4,.climb-jupyter .gy-4{--bs-gutter-y: 1.5rem}.climb-jupyter .g-5,.climb-jupyter .gx-5{--bs-gutter-x: 3rem}.climb-jupyter .g-5,.climb-jupyter .gy-5{--bs-gutter-y: 3rem}@media (min-width: 576px){.climb-jupyter .col-sm{flex:1 0 0}.climb-jupyter .row-cols-sm-auto>*{flex:0 0 auto;width:auto}.climb-jupyter .row-cols-sm-1>*{flex:0 0 auto;width:100%}.climb-jupyter .row-cols-sm-2>*{flex:0 0 auto;width:50%}.climb-jupyter .row-cols-sm-3>*{flex:0 0 auto;width:33.33333333%}.climb-jupyter .row-cols-sm-4>*{flex:0 0 auto;width:25%}.climb-jupyter .row-cols-sm-5>*{flex:0 0 auto;width:20%}.climb-jupyter .row-cols-sm-6>*{flex:0 0 auto;width:16.66666667%}.climb-jupyter .col-sm-auto{flex:0 0 auto;width:auto}.climb-jupyter .col-sm-1{flex:0 0 auto;width:8.33333333%}.climb-jupyter .col-sm-2{flex:0 0 auto;width:16.66666667%}.climb-jupyter .col-sm-3{flex:0 0 auto;width:25%}.climb-jupyter .col-sm-4{flex:0 0 auto;width:33.33333333%}.climb-jupyter .col-sm-5{flex:0 0 auto;width:41.66666667%}.climb-jupyter .col-sm-6{flex:0 0 auto;width:50%}.climb-jupyter .col-sm-7{flex:0 0 auto;width:58.33333333%}.climb-jupyter .col-sm-8{flex:0 0 auto;width:66.66666667%}.climb-jupyter .col-sm-9{flex:0 0 auto;width:75%}.climb-jupyter .col-sm-10{flex:0 0 auto;width:83.33333333%}.climb-jupyter .col-sm-11{flex:0 0 auto;width:91.66666667%}.climb-jupyter .col-sm-12{flex:0 0 auto;width:100%}.climb-jupyter .offset-sm-0{margin-left:0}.climb-jupyter .offset-sm-1{margin-left:8.33333333%}.climb-jupyter .offset-sm-2{margin-left:16.66666667%}.climb-jupyter .offset-sm-3{margin-left:25%}.climb-jupyter .offset-sm-4{margin-left:33.33333333%}.climb-jupyter .offset-sm-5{margin-left:41.66666667%}.climb-jupyter .offset-sm-6{margin-left:50%}.climb-jupyter .offset-sm-7{margin-left:58.33333333%}.climb-jupyter .offset-sm-8{margin-left:66.66666667%}.climb-jupyter .offset-sm-9{margin-left:75%}.climb-jupyter .offset-sm-10{margin-left:83.33333333%}.climb-jupyter .offset-sm-11{margin-left:91.66666667%}.climb-jupyter .g-sm-0,.climb-jupyter .gx-sm-0{--bs-gutter-x: 0}.climb-jupyter .g-sm-0,.climb-jupyter .gy-sm-0{--bs-gutter-y: 0}.climb-jupyter .g-sm-1,.climb-jupyter .gx-sm-1{--bs-gutter-x: .25rem}.climb-jupyter .g-sm-1,.climb-jupyter .gy-sm-1{--bs-gutter-y: .25rem}.climb-jupyter .g-sm-2,.climb-jupyter .gx-sm-2{--bs-gutter-x: .5rem}.climb-jupyter .g-sm-2,.climb-jupyter .gy-sm-2{--bs-gutter-y: .5rem}.climb-jupyter .g-sm-3,.climb-jupyter .gx-sm-3{--bs-gutter-x: 1rem}.climb-jupyter .g-sm-3,.climb-jupyter .gy-sm-3{--bs-gutter-y: 1rem}.climb-jupyter .g-sm-4,.climb-jupyter .gx-sm-4{--bs-gutter-x: 1.5rem}.climb-jupyter .g-sm-4,.climb-jupyter .gy-sm-4{--bs-gutter-y: 1.5rem}.climb-jupyter .g-sm-5,.climb-jupyter .gx-sm-5{--bs-gutter-x: 3rem}.climb-jupyter .g-sm-5,.climb-jupyter .gy-sm-5{--bs-gutter-y: 3rem}}@media (min-width: 768px){.climb-jupyter .col-md{flex:1 0 0}.climb-jupyter .row-cols-md-auto>*{flex:0 0 auto;width:auto}.climb-jupyter .row-cols-md-1>*{flex:0 0 auto;width:100%}.climb-jupyter .row-cols-md-2>*{flex:0 0 auto;width:50%}.climb-jupyter .row-cols-md-3>*{flex:0 0 auto;width:33.33333333%}.climb-jupyter .row-cols-md-4>*{flex:0 0 auto;width:25%}.climb-jupyter .row-cols-md-5>*{flex:0 0 auto;width:20%}.climb-jupyter .row-cols-md-6>*{flex:0 0 auto;width:16.66666667%}.climb-jupyter .col-md-auto{flex:0 0 auto;width:auto}.climb-jupyter .col-md-1{flex:0 0 auto;width:8.33333333%}.climb-jupyter .col-md-2{flex:0 0 auto;width:16.66666667%}.climb-jupyter .col-md-3{flex:0 0 auto;width:25%}.climb-jupyter .col-md-4{flex:0 0 auto;width:33.33333333%}.climb-jupyter .col-md-5{flex:0 0 auto;width:41.66666667%}.climb-jupyter .col-md-6{flex:0 0 auto;width:50%}.climb-jupyter .col-md-7{flex:0 0 auto;width:58.33333333%}.climb-jupyter .col-md-8{flex:0 0 auto;width:66.66666667%}.climb-jupyter .col-md-9{flex:0 0 auto;width:75%}.climb-jupyter .col-md-10{flex:0 0 auto;width:83.33333333%}.climb-jupyter .col-md-11{flex:0 0 auto;width:91.66666667%}.climb-jupyter .col-md-12{flex:0 0 auto;width:100%}.climb-jupyter .offset-md-0{margin-left:0}.climb-jupyter .offset-md-1{margin-left:8.33333333%}.climb-jupyter .offset-md-2{margin-left:16.66666667%}.climb-jupyter .offset-md-3{margin-left:25%}.climb-jupyter .offset-md-4{margin-left:33.33333333%}.climb-jupyter .offset-md-5{margin-left:41.66666667%}.climb-jupyter .offset-md-6{margin-left:50%}.climb-jupyter .offset-md-7{margin-left:58.33333333%}.climb-jupyter .offset-md-8{margin-left:66.66666667%}.climb-jupyter .offset-md-9{margin-left:75%}.climb-jupyter .offset-md-10{margin-left:83.33333333%}.climb-jupyter .offset-md-11{margin-left:91.66666667%}.climb-jupyter .g-md-0,.climb-jupyter .gx-md-0{--bs-gutter-x: 0}.climb-jupyter .g-md-0,.climb-jupyter .gy-md-0{--bs-gutter-y: 0}.climb-jupyter .g-md-1,.climb-jupyter .gx-md-1{--bs-gutter-x: .25rem}.climb-jupyter .g-md-1,.climb-jupyter .gy-md-1{--bs-gutter-y: .25rem}.climb-jupyter .g-md-2,.climb-jupyter .gx-md-2{--bs-gutter-x: .5rem}.climb-jupyter .g-md-2,.climb-jupyter .gy-md-2{--bs-gutter-y: .5rem}.climb-jupyter .g-md-3,.climb-jupyter .gx-md-3{--bs-gutter-x: 1rem}.climb-jupyter .g-md-3,.climb-jupyter .gy-md-3{--bs-gutter-y: 1rem}.climb-jupyter .g-md-4,.climb-jupyter .gx-md-4{--bs-gutter-x: 1.5rem}.climb-jupyter .g-md-4,.climb-jupyter .gy-md-4{--bs-gutter-y: 1.5rem}.climb-jupyter .g-md-5,.climb-jupyter .gx-md-5{--bs-gutter-x: 3rem}.climb-jupyter .g-md-5,.climb-jupyter .gy-md-5{--bs-gutter-y: 3rem}}@media (min-width: 992px){.climb-jupyter .col-lg{flex:1 0 0}.climb-jupyter .row-cols-lg-auto>*{flex:0 0 auto;width:auto}.climb-jupyter .row-cols-lg-1>*{flex:0 0 auto;width:100%}.climb-jupyter .row-cols-lg-2>*{flex:0 0 auto;width:50%}.climb-jupyter .row-cols-lg-3>*{flex:0 0 auto;width:33.33333333%}.climb-jupyter .row-cols-lg-4>*{flex:0 0 auto;width:25%}.climb-jupyter .row-cols-lg-5>*{flex:0 0 auto;width:20%}.climb-jupyter .row-cols-lg-6>*{flex:0 0 auto;width:16.66666667%}.climb-jupyter .col-lg-auto{flex:0 0 auto;width:auto}.climb-jupyter .col-lg-1{flex:0 0 auto;width:8.33333333%}.climb-jupyter .col-lg-2{flex:0 0 auto;width:16.66666667%}.climb-jupyter .col-lg-3{flex:0 0 auto;width:25%}.climb-jupyter .col-lg-4{flex:0 0 auto;width:33.33333333%}.climb-jupyter .col-lg-5{flex:0 0 auto;width:41.66666667%}.climb-jupyter .col-lg-6{flex:0 0 auto;width:50%}.climb-jupyter .col-lg-7{flex:0 0 auto;width:58.33333333%}.climb-jupyter .col-lg-8{flex:0 0 auto;width:66.66666667%}.climb-jupyter .col-lg-9{flex:0 0 auto;width:75%}.climb-jupyter .col-lg-10{flex:0 0 auto;width:83.33333333%}.climb-jupyter .col-lg-11{flex:0 0 auto;width:91.66666667%}.climb-jupyter .col-lg-12{flex:0 0 auto;width:100%}.climb-jupyter .offset-lg-0{margin-left:0}.climb-jupyter .offset-lg-1{margin-left:8.33333333%}.climb-jupyter .offset-lg-2{margin-left:16.66666667%}.climb-jupyter .offset-lg-3{margin-left:25%}.climb-jupyter .offset-lg-4{margin-left:33.33333333%}.climb-jupyter .offset-lg-5{margin-left:41.66666667%}.climb-jupyter .offset-lg-6{margin-left:50%}.climb-jupyter .offset-lg-7{margin-left:58.33333333%}.climb-jupyter .offset-lg-8{margin-left:66.66666667%}.climb-jupyter .offset-lg-9{margin-left:75%}.climb-jupyter .offset-lg-10{margin-left:83.33333333%}.climb-jupyter .offset-lg-11{margin-left:91.66666667%}.climb-jupyter .g-lg-0,.climb-jupyter .gx-lg-0{--bs-gutter-x: 0}.climb-jupyter .g-lg-0,.climb-jupyter .gy-lg-0{--bs-gutter-y: 0}.climb-jupyter .g-lg-1,.climb-jupyter .gx-lg-1{--bs-gutter-x: .25rem}.climb-jupyter .g-lg-1,.climb-jupyter .gy-lg-1{--bs-gutter-y: .25rem}.climb-jupyter .g-lg-2,.climb-jupyter .gx-lg-2{--bs-gutter-x: .5rem}.climb-jupyter .g-lg-2,.climb-jupyter .gy-lg-2{--bs-gutter-y: .5rem}.climb-jupyter .g-lg-3,.climb-jupyter .gx-lg-3{--bs-gutter-x: 1rem}.climb-jupyter .g-lg-3,.climb-jupyter .gy-lg-3{--bs-gutter-y: 1rem}.climb-jupyter .g-lg-4,.climb-jupyter .gx-lg-4{--bs-gutter-x: 1.5rem}.climb-jupyter .g-lg-4,.climb-jupyter .gy-lg-4{--bs-gutter-y: 1.5rem}.climb-jupyter .g-lg-5,.climb-jupyter .gx-lg-5{--bs-gutter-x: 3rem}.climb-jupyter .g-lg-5,.climb-jupyter .gy-lg-5{--bs-gutter-y: 3rem}}@media (min-width: 1200px){.climb-jupyter .col-xl{flex:1 0 0}.climb-jupyter .row-cols-xl-auto>*{flex:0 0 auto;width:auto}.climb-jupyter .row-cols-xl-1>*{flex:0 0 auto;width:100%}.climb-jupyter .row-cols-xl-2>*{flex:0 0 auto;width:50%}.climb-jupyter .row-cols-xl-3>*{flex:0 0 auto;width:33.33333333%}.climb-jupyter .row-cols-xl-4>*{flex:0 0 auto;width:25%}.climb-jupyter .row-cols-xl-5>*{flex:0 0 auto;width:20%}.climb-jupyter .row-cols-xl-6>*{flex:0 0 auto;width:16.66666667%}.climb-jupyter .col-xl-auto{flex:0 0 auto;width:auto}.climb-jupyter .col-xl-1{flex:0 0 auto;width:8.33333333%}.climb-jupyter .col-xl-2{flex:0 0 auto;width:16.66666667%}.climb-jupyter .col-xl-3{flex:0 0 auto;width:25%}.climb-jupyter .col-xl-4{flex:0 0 auto;width:33.33333333%}.climb-jupyter .col-xl-5{flex:0 0 auto;width:41.66666667%}.climb-jupyter .col-xl-6{flex:0 0 auto;width:50%}.climb-jupyter .col-xl-7{flex:0 0 auto;width:58.33333333%}.climb-jupyter .col-xl-8{flex:0 0 auto;width:66.66666667%}.climb-jupyter .col-xl-9{flex:0 0 auto;width:75%}.climb-jupyter .col-xl-10{flex:0 0 auto;width:83.33333333%}.climb-jupyter .col-xl-11{flex:0 0 auto;width:91.66666667%}.climb-jupyter .col-xl-12{flex:0 0 auto;width:100%}.climb-jupyter .offset-xl-0{margin-left:0}.climb-jupyter .offset-xl-1{margin-left:8.33333333%}.climb-jupyter .offset-xl-2{margin-left:16.66666667%}.climb-jupyter .offset-xl-3{margin-left:25%}.climb-jupyter .offset-xl-4{margin-left:33.33333333%}.climb-jupyter .offset-xl-5{margin-left:41.66666667%}.climb-jupyter .offset-xl-6{margin-left:50%}.climb-jupyter .offset-xl-7{margin-left:58.33333333%}.climb-jupyter .offset-xl-8{margin-left:66.66666667%}.climb-jupyter .offset-xl-9{margin-left:75%}.climb-jupyter .offset-xl-10{margin-left:83.33333333%}.climb-jupyter .offset-xl-11{margin-left:91.66666667%}.climb-jupyter .g-xl-0,.climb-jupyter .gx-xl-0{--bs-gutter-x: 0}.climb-jupyter .g-xl-0,.climb-jupyter .gy-xl-0{--bs-gutter-y: 0}.climb-jupyter .g-xl-1,.climb-jupyter .gx-xl-1{--bs-gutter-x: .25rem}.climb-jupyter .g-xl-1,.climb-jupyter .gy-xl-1{--bs-gutter-y: .25rem}.climb-jupyter .g-xl-2,.climb-jupyter .gx-xl-2{--bs-gutter-x: .5rem}.climb-jupyter .g-xl-2,.climb-jupyter .gy-xl-2{--bs-gutter-y: .5rem}.climb-jupyter .g-xl-3,.climb-jupyter .gx-xl-3{--bs-gutter-x: 1rem}.climb-jupyter .g-xl-3,.climb-jupyter .gy-xl-3{--bs-gutter-y: 1rem}.climb-jupyter .g-xl-4,.climb-jupyter .gx-xl-4{--bs-gutter-x: 1.5rem}.climb-jupyter .g-xl-4,.climb-jupyter .gy-xl-4{--bs-gutter-y: 1.5rem}.climb-jupyter .g-xl-5,.climb-jupyter .gx-xl-5{--bs-gutter-x: 3rem}.climb-jupyter .g-xl-5,.climb-jupyter .gy-xl-5{--bs-gutter-y: 3rem}}@media (min-width: 1400px){.climb-jupyter .col-xxl{flex:1 0 0}.climb-jupyter .row-cols-xxl-auto>*{flex:0 0 auto;width:auto}.climb-jupyter .row-cols-xxl-1>*{flex:0 0 auto;width:100%}.climb-jupyter .row-cols-xxl-2>*{flex:0 0 auto;width:50%}.climb-jupyter .row-cols-xxl-3>*{flex:0 0 auto;width:33.33333333%}.climb-jupyter .row-cols-xxl-4>*{flex:0 0 auto;width:25%}.climb-jupyter .row-cols-xxl-5>*{flex:0 0 auto;width:20%}.climb-jupyter .row-cols-xxl-6>*{flex:0 0 auto;width:16.66666667%}.climb-jupyter .col-xxl-auto{flex:0 0 auto;width:auto}.climb-jupyter .col-xxl-1{flex:0 0 auto;width:8.33333333%}.climb-jupyter .col-xxl-2{flex:0 0 auto;width:16.66666667%}.climb-jupyter .col-xxl-3{flex:0 0 auto;width:25%}.climb-jupyter .col-xxl-4{flex:0 0 auto;width:33.33333333%}.climb-jupyter .col-xxl-5{flex:0 0 auto;width:41.66666667%}.climb-jupyter .col-xxl-6{flex:0 0 auto;width:50%}.climb-jupyter .col-xxl-7{flex:0 0 auto;width:58.33333333%}.climb-jupyter .col-xxl-8{flex:0 0 auto;width:66.66666667%}.climb-jupyter .col-xxl-9{flex:0 0 auto;width:75%}.climb-jupyter .col-xxl-10{flex:0 0 auto;width:83.33333333%}.climb-jupyter .col-xxl-11{flex:0 0 auto;width:91.66666667%}.climb-jupyter .col-xxl-12{flex:0 0 auto;width:100%}.climb-jupyter .offset-xxl-0{margin-left:0}.climb-jupyter .offset-xxl-1{margin-left:8.33333333%}.climb-jupyter .offset-xxl-2{margin-left:16.66666667%}.climb-jupyter .offset-xxl-3{margin-left:25%}.climb-jupyter .offset-xxl-4{margin-left:33.33333333%}.climb-jupyter .offset-xxl-5{margin-left:41.66666667%}.climb-jupyter .offset-xxl-6{margin-left:50%}.climb-jupyter .offset-xxl-7{margin-left:58.33333333%}.climb-jupyter .offset-xxl-8{margin-left:66.66666667%}.climb-jupyter .offset-xxl-9{margin-left:75%}.climb-jupyter .offset-xxl-10{margin-left:83.33333333%}.climb-jupyter .offset-xxl-11{margin-left:91.66666667%}.climb-jupyter .g-xxl-0,.climb-jupyter .gx-xxl-0{--bs-gutter-x: 0}.climb-jupyter .g-xxl-0,.climb-jupyter .gy-xxl-0{--bs-gutter-y: 0}.climb-jupyter .g-xxl-1,.climb-jupyter .gx-xxl-1{--bs-gutter-x: .25rem}.climb-jupyter .g-xxl-1,.climb-jupyter .gy-xxl-1{--bs-gutter-y: .25rem}.climb-jupyter .g-xxl-2,.climb-jupyter .gx-xxl-2{--bs-gutter-x: .5rem}.climb-jupyter .g-xxl-2,.climb-jupyter .gy-xxl-2{--bs-gutter-y: .5rem}.climb-jupyter .g-xxl-3,.climb-jupyter .gx-xxl-3{--bs-gutter-x: 1rem}.climb-jupyter .g-xxl-3,.climb-jupyter .gy-xxl-3{--bs-gutter-y: 1rem}.climb-jupyter .g-xxl-4,.climb-jupyter .gx-xxl-4{--bs-gutter-x: 1.5rem}.climb-jupyter .g-xxl-4,.climb-jupyter .gy-xxl-4{--bs-gutter-y: 1.5rem}.climb-jupyter .g-xxl-5,.climb-jupyter .gx-xxl-5{--bs-gutter-x: 3rem}.climb-jupyter .g-xxl-5,.climb-jupyter .gy-xxl-5{--bs-gutter-y: 3rem}}.climb-jupyter .form-label{margin-bottom:.5rem}.climb-jupyter .col-form-label{padding-top:calc(.375rem + var(--bs-border-width));padding-bottom:calc(.375rem + var(--bs-border-width));margin-bottom:0;font-size:inherit;line-height:1.5}.climb-jupyter .col-form-label-lg{padding-top:calc(.5rem + var(--bs-border-width));padding-bottom:calc(.5rem + var(--bs-border-width));font-size:1.25rem}.climb-jupyter .col-form-label-sm{padding-top:calc(.25rem + var(--bs-border-width));padding-bottom:calc(.25rem + var(--bs-border-width));font-size:.875rem}.climb-jupyter .form-text{margin-top:.25rem;font-size:.875em;color:var(--bs-secondary-color)}.climb-jupyter .form-control{display:block;width:100%;padding:.375rem .75rem;font-size:1rem;font-weight:400;line-height:1.5;color:var(--bs-body-color);-webkit-appearance:none;-moz-appearance:none;appearance:none;background-color:var(--bs-body-bg);background-clip:padding-box;border:var(--bs-border-width) solid var(--bs-border-color);border-radius:var(--bs-border-radius);transition:border-color .15s ease-in-out,box-shadow .15s ease-in-out}@media (prefers-reduced-motion: reduce){.climb-jupyter .form-control{transition:none}}.climb-jupyter .form-control[type=file]{overflow:hidden}.climb-jupyter .form-control[type=file]:not(:disabled):not([readonly]){cursor:pointer}.climb-jupyter .form-control:focus{color:var(--bs-body-color);background-color:var(--bs-body-bg);border-color:#86b7fe;outline:0;box-shadow:0 0 0 .25rem #0d6efd40}.climb-jupyter .form-control::-webkit-date-and-time-value{min-width:85px;height:1.5em;margin:0}.climb-jupyter .form-control::-webkit-datetime-edit{display:block;padding:0}.climb-jupyter .form-control::placeholder{color:var(--bs-secondary-color);opacity:1}.climb-jupyter .form-control:disabled{background-color:var(--bs-secondary-bg);opacity:1}.climb-jupyter .form-control::file-selector-button{padding:.375rem .75rem;margin:-.375rem -.75rem;margin-inline-end:.75rem;color:var(--bs-body-color);background-color:var(--bs-tertiary-bg);pointer-events:none;border-color:inherit;border-style:solid;border-width:0;border-inline-end-width:var(--bs-border-width);border-radius:0;transition:color .15s ease-in-out,background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out}@media (prefers-reduced-motion: reduce){.climb-jupyter .form-control::file-selector-button{transition:none}}.climb-jupyter .form-control:hover:not(:disabled):not([readonly])::file-selector-button{background-color:var(--bs-secondary-bg)}.climb-jupyter .form-control-plaintext{display:block;width:100%;padding:.375rem 0;margin-bottom:0;line-height:1.5;color:var(--bs-body-color);background-color:transparent;border:solid transparent;border-width:var(--bs-border-width) 0}.climb-jupyter .form-control-plaintext:focus{outline:0}.climb-jupyter .form-control-plaintext.form-control-sm,.climb-jupyter .form-control-plaintext.form-control-lg{padding-right:0;padding-left:0}.climb-jupyter .form-control-sm{min-height:calc(1.5em + .5rem + calc(var(--bs-border-width) * 2));padding:.25rem .5rem;font-size:.875rem;border-radius:var(--bs-border-radius-sm)}.climb-jupyter .form-control-sm::file-selector-button{padding:.25rem .5rem;margin:-.25rem -.5rem;margin-inline-end:.5rem}.climb-jupyter .form-control-lg{min-height:calc(1.5em + 1rem + calc(var(--bs-border-width) * 2));padding:.5rem 1rem;font-size:1.25rem;border-radius:var(--bs-border-radius-lg)}.climb-jupyter .form-control-lg::file-selector-button{padding:.5rem 1rem;margin:-.5rem -1rem;margin-inline-end:1rem}.climb-jupyter textarea.form-control{min-height:calc(1.5em + .75rem + calc(var(--bs-border-width) * 2))}.climb-jupyter textarea.form-control-sm{min-height:calc(1.5em + .5rem + calc(var(--bs-border-width) * 2))}.climb-jupyter textarea.form-control-lg{min-height:calc(1.5em + 1rem + calc(var(--bs-border-width) * 2))}.climb-jupyter .form-control-color{width:3rem;height:calc(1.5em + .75rem + calc(var(--bs-border-width) * 2));padding:.375rem}.climb-jupyter .form-control-color:not(:disabled):not([readonly]){cursor:pointer}.climb-jupyter .form-control-color::-moz-color-swatch{border:0!important;border-radius:var(--bs-border-radius)}.climb-jupyter .form-control-color::-webkit-color-swatch{border:0!important;border-radius:var(--bs-border-radius)}.climb-jupyter .form-control-color.form-control-sm{height:calc(1.5em + .5rem + calc(var(--bs-border-width) * 2))}.climb-jupyter .form-control-color.form-control-lg{height:calc(1.5em + 1rem + calc(var(--bs-border-width) * 2))}.climb-jupyter .form-select{--bs-form-select-bg-img: url(${___CSS_LOADER_URL_REPLACEMENT_1___});display:block;width:100%;padding:.375rem 2.25rem .375rem .75rem;font-size:1rem;font-weight:400;line-height:1.5;color:var(--bs-body-color);-webkit-appearance:none;-moz-appearance:none;appearance:none;background-color:var(--bs-body-bg);background-image:var(--bs-form-select-bg-img),var(--bs-form-select-bg-icon, none);background-repeat:no-repeat;background-position:right .75rem center;background-size:16px 12px;border:var(--bs-border-width) solid var(--bs-border-color);border-radius:var(--bs-border-radius);transition:border-color .15s ease-in-out,box-shadow .15s ease-in-out}@media (prefers-reduced-motion: reduce){.climb-jupyter .form-select{transition:none}}.climb-jupyter .form-select:focus{border-color:#86b7fe;outline:0;box-shadow:0 0 0 .25rem #0d6efd40}.climb-jupyter .form-select[multiple],.climb-jupyter .form-select[size]:not([size="1"]){padding-right:.75rem;background-image:none}.climb-jupyter .form-select:disabled{background-color:var(--bs-secondary-bg)}.climb-jupyter .form-select:-moz-focusring{color:transparent;text-shadow:0 0 0 var(--bs-body-color)}.climb-jupyter .form-select-sm{padding-top:.25rem;padding-bottom:.25rem;padding-left:.5rem;font-size:.875rem;border-radius:var(--bs-border-radius-sm)}.climb-jupyter .form-select-lg{padding-top:.5rem;padding-bottom:.5rem;padding-left:1rem;font-size:1.25rem;border-radius:var(--bs-border-radius-lg)}.climb-jupyter [data-bs-theme=dark] .form-select{--bs-form-select-bg-img: url(${___CSS_LOADER_URL_REPLACEMENT_2___})}.climb-jupyter .form-check{display:block;min-height:1.5rem;padding-left:1.5em;margin-bottom:.125rem}.climb-jupyter .form-check .form-check-input{float:left;margin-left:-1.5em}.climb-jupyter .form-check-reverse{padding-right:1.5em;padding-left:0;text-align:right}.climb-jupyter .form-check-reverse .form-check-input{float:right;margin-right:-1.5em;margin-left:0}.climb-jupyter .form-check-input{--bs-form-check-bg: var(--bs-body-bg);flex-shrink:0;width:1em;height:1em;margin-top:.25em;vertical-align:top;-webkit-appearance:none;-moz-appearance:none;appearance:none;background-color:var(--bs-form-check-bg);background-image:var(--bs-form-check-bg-image);background-repeat:no-repeat;background-position:center;background-size:contain;border:var(--bs-border-width) solid var(--bs-border-color);-webkit-print-color-adjust:exact;print-color-adjust:exact}.climb-jupyter .form-check-input[type=checkbox]{border-radius:.25em}.climb-jupyter .form-check-input[type=radio]{border-radius:50%}.climb-jupyter .form-check-input:active{filter:brightness(90%)}.climb-jupyter .form-check-input:focus{border-color:#86b7fe;outline:0;box-shadow:0 0 0 .25rem #0d6efd40}.climb-jupyter .form-check-input:checked{background-color:#0d6efd;border-color:#0d6efd}.climb-jupyter .form-check-input:checked[type=checkbox]{--bs-form-check-bg-image: url(${___CSS_LOADER_URL_REPLACEMENT_3___})}.climb-jupyter .form-check-input:checked[type=radio]{--bs-form-check-bg-image: url(${___CSS_LOADER_URL_REPLACEMENT_4___})}.climb-jupyter .form-check-input[type=checkbox]:indeterminate{background-color:#0d6efd;border-color:#0d6efd;--bs-form-check-bg-image: url(${___CSS_LOADER_URL_REPLACEMENT_5___})}.climb-jupyter .form-check-input:disabled{pointer-events:none;filter:none;opacity:.5}.climb-jupyter .form-check-input[disabled]~.form-check-label,.climb-jupyter .form-check-input:disabled~.form-check-label{cursor:default;opacity:.5}.climb-jupyter .form-switch{padding-left:2.5em}.climb-jupyter .form-switch .form-check-input{--bs-form-switch-bg: url(${___CSS_LOADER_URL_REPLACEMENT_6___});width:2em;margin-left:-2.5em;background-image:var(--bs-form-switch-bg);background-position:left center;border-radius:2em;transition:background-position .15s ease-in-out}@media (prefers-reduced-motion: reduce){.climb-jupyter .form-switch .form-check-input{transition:none}}.climb-jupyter .form-switch .form-check-input:focus{--bs-form-switch-bg: url(${___CSS_LOADER_URL_REPLACEMENT_7___})}.climb-jupyter .form-switch .form-check-input:checked{background-position:right center;--bs-form-switch-bg: url(${___CSS_LOADER_URL_REPLACEMENT_8___})}.climb-jupyter .form-switch.form-check-reverse{padding-right:2.5em;padding-left:0}.climb-jupyter .form-switch.form-check-reverse .form-check-input{margin-right:-2.5em;margin-left:0}.climb-jupyter .form-check-inline{display:inline-block;margin-right:1rem}.climb-jupyter .btn-check{position:absolute;clip:rect(0,0,0,0);pointer-events:none}.climb-jupyter .btn-check[disabled]+.btn,.climb-jupyter .btn-check:disabled+.btn{pointer-events:none;filter:none;opacity:.65}.climb-jupyter [data-bs-theme=dark] .form-switch .form-check-input:not(:checked):not(:focus){--bs-form-switch-bg: url(${___CSS_LOADER_URL_REPLACEMENT_9___})}.climb-jupyter .form-range{width:100%;height:1.5rem;padding:0;-webkit-appearance:none;-moz-appearance:none;appearance:none;background-color:transparent}.climb-jupyter .form-range:focus{outline:0}.climb-jupyter .form-range:focus::-webkit-slider-thumb{box-shadow:0 0 0 1px #fff,0 0 0 .25rem #0d6efd40}.climb-jupyter .form-range:focus::-moz-range-thumb{box-shadow:0 0 0 1px #fff,0 0 0 .25rem #0d6efd40}.climb-jupyter .form-range::-moz-focus-outer{border:0}.climb-jupyter .form-range::-webkit-slider-thumb{width:1rem;height:1rem;margin-top:-.25rem;-webkit-appearance:none;-moz-appearance:none;appearance:none;background-color:#0d6efd;border:0;border-radius:1rem;transition:background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out}@media (prefers-reduced-motion: reduce){.climb-jupyter .form-range::-webkit-slider-thumb{transition:none}}.climb-jupyter .form-range::-webkit-slider-thumb:active{background-color:#b6d4fe}.climb-jupyter .form-range::-webkit-slider-runnable-track{width:100%;height:.5rem;color:transparent;cursor:pointer;background-color:var(--bs-secondary-bg);border-color:transparent;border-radius:1rem}.climb-jupyter .form-range::-moz-range-thumb{width:1rem;height:1rem;-webkit-appearance:none;-moz-appearance:none;appearance:none;background-color:#0d6efd;border:0;border-radius:1rem;transition:background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out}@media (prefers-reduced-motion: reduce){.climb-jupyter .form-range::-moz-range-thumb{transition:none}}.climb-jupyter .form-range::-moz-range-thumb:active{background-color:#b6d4fe}.climb-jupyter .form-range::-moz-range-track{width:100%;height:.5rem;color:transparent;cursor:pointer;background-color:var(--bs-secondary-bg);border-color:transparent;border-radius:1rem}.climb-jupyter .form-range:disabled{pointer-events:none}.climb-jupyter .form-range:disabled::-webkit-slider-thumb{background-color:var(--bs-secondary-color)}.climb-jupyter .form-range:disabled::-moz-range-thumb{background-color:var(--bs-secondary-color)}.climb-jupyter .form-floating{position:relative}.climb-jupyter .form-floating>.form-control,.climb-jupyter .form-floating>.form-control-plaintext,.climb-jupyter .form-floating>.form-select{height:calc(3.5rem + calc(var(--bs-border-width) * 2));min-height:calc(3.5rem + calc(var(--bs-border-width) * 2));line-height:1.25}.climb-jupyter .form-floating>label{position:absolute;top:0;left:0;z-index:2;max-width:100%;height:100%;padding:1rem .75rem;overflow:hidden;color:rgba(var(--bs-body-color-rgb),.65);text-align:start;text-overflow:ellipsis;white-space:nowrap;pointer-events:none;border:var(--bs-border-width) solid transparent;transform-origin:0 0;transition:opacity .1s ease-in-out,transform .1s ease-in-out}@media (prefers-reduced-motion: reduce){.climb-jupyter .form-floating>label{transition:none}}.climb-jupyter .form-floating>.form-control,.climb-jupyter .form-floating>.form-control-plaintext{padding:1rem .75rem}.climb-jupyter .form-floating>.form-control::placeholder,.climb-jupyter .form-floating>.form-control-plaintext::placeholder{color:transparent}.climb-jupyter .form-floating>.form-control:focus,.climb-jupyter .form-floating>.form-control:not(:placeholder-shown),.climb-jupyter .form-floating>.form-control-plaintext:focus,.climb-jupyter .form-floating>.form-control-plaintext:not(:placeholder-shown){padding-top:1.625rem;padding-bottom:.625rem}.climb-jupyter .form-floating>.form-control:-webkit-autofill,.climb-jupyter .form-floating>.form-control-plaintext:-webkit-autofill{padding-top:1.625rem;padding-bottom:.625rem}.climb-jupyter .form-floating>.form-select{padding-top:1.625rem;padding-bottom:.625rem;padding-left:.75rem}.climb-jupyter .form-floating>.form-control:focus~label,.climb-jupyter .form-floating>.form-control:not(:placeholder-shown)~label,.climb-jupyter .form-floating>.form-control-plaintext~label,.climb-jupyter .form-floating>.form-select~label{transform:scale(.85) translateY(-.5rem) translate(.15rem)}.climb-jupyter .form-floating>.form-control:-webkit-autofill~label{transform:scale(.85) translateY(-.5rem) translate(.15rem)}.climb-jupyter .form-floating>textarea:focus~label:after,.climb-jupyter .form-floating>textarea:not(:placeholder-shown)~label:after{position:absolute;top:1rem;right:.375rem;bottom:1rem;left:.375rem;z-index:-1;height:1.5em;content:"";background-color:var(--bs-body-bg);border-radius:var(--bs-border-radius)}.climb-jupyter .form-floating>textarea:disabled~label:after{background-color:var(--bs-secondary-bg)}.climb-jupyter .form-floating>.form-control-plaintext~label{border-width:var(--bs-border-width) 0}.climb-jupyter .form-floating>:disabled~label,.climb-jupyter .form-floating>.form-control:disabled~label{color:#6c757d}.climb-jupyter .input-group{position:relative;display:flex;flex-wrap:wrap;align-items:stretch;width:100%}.climb-jupyter .input-group>.form-control,.climb-jupyter .input-group>.form-select,.climb-jupyter .input-group>.form-floating{position:relative;flex:1 1 auto;width:1%;min-width:0}.climb-jupyter .input-group>.form-control:focus,.climb-jupyter .input-group>.form-select:focus,.climb-jupyter .input-group>.form-floating:focus-within{z-index:5}.climb-jupyter .input-group .btn{position:relative;z-index:2}.climb-jupyter .input-group .btn:focus{z-index:5}.climb-jupyter .input-group-text{display:flex;align-items:center;padding:.375rem .75rem;font-size:1rem;font-weight:400;line-height:1.5;color:var(--bs-body-color);text-align:center;white-space:nowrap;background-color:var(--bs-tertiary-bg);border:var(--bs-border-width) solid var(--bs-border-color);border-radius:var(--bs-border-radius)}.climb-jupyter .input-group-lg>.form-control,.climb-jupyter .input-group-lg>.form-select,.climb-jupyter .input-group-lg>.input-group-text,.climb-jupyter .input-group-lg>.btn{padding:.5rem 1rem;font-size:1.25rem;border-radius:var(--bs-border-radius-lg)}.climb-jupyter .input-group-sm>.form-control,.climb-jupyter .input-group-sm>.form-select,.climb-jupyter .input-group-sm>.input-group-text,.climb-jupyter .input-group-sm>.btn{padding:.25rem .5rem;font-size:.875rem;border-radius:var(--bs-border-radius-sm)}.climb-jupyter .input-group-lg>.form-select,.climb-jupyter .input-group-sm>.form-select{padding-right:3rem}.climb-jupyter .input-group:not(.has-validation)>:not(:last-child):not(.dropdown-toggle):not(.dropdown-menu):not(.form-floating),.climb-jupyter .input-group:not(.has-validation)>.dropdown-toggle:nth-last-child(n+3),.climb-jupyter .input-group:not(.has-validation)>.form-floating:not(:last-child)>.form-control,.climb-jupyter .input-group:not(.has-validation)>.form-floating:not(:last-child)>.form-select{border-top-right-radius:0;border-bottom-right-radius:0}.climb-jupyter .input-group.has-validation>:nth-last-child(n+3):not(.dropdown-toggle):not(.dropdown-menu):not(.form-floating),.climb-jupyter .input-group.has-validation>.dropdown-toggle:nth-last-child(n+4),.climb-jupyter .input-group.has-validation>.form-floating:nth-last-child(n+3)>.form-control,.climb-jupyter .input-group.has-validation>.form-floating:nth-last-child(n+3)>.form-select{border-top-right-radius:0;border-bottom-right-radius:0}.climb-jupyter .input-group>:not(:first-child):not(.dropdown-menu):not(.valid-tooltip):not(.valid-feedback):not(.invalid-tooltip):not(.invalid-feedback){margin-left:calc(-1 * var(--bs-border-width));border-top-left-radius:0;border-bottom-left-radius:0}.climb-jupyter .input-group>.form-floating:not(:first-child)>.form-control,.climb-jupyter .input-group>.form-floating:not(:first-child)>.form-select{border-top-left-radius:0;border-bottom-left-radius:0}.climb-jupyter .valid-feedback{display:none;width:100%;margin-top:.25rem;font-size:.875em;color:var(--bs-form-valid-color)}.climb-jupyter .valid-tooltip{position:absolute;top:100%;z-index:5;display:none;max-width:100%;padding:.25rem .5rem;margin-top:.1rem;font-size:.875rem;color:#fff;background-color:var(--bs-success);border-radius:var(--bs-border-radius)}.was-validated .climb-jupyter:valid~.valid-feedback,.was-validated .climb-jupyter:valid~.valid-tooltip,.climb-jupyter.is-valid~.valid-feedback,.climb-jupyter.is-valid~.valid-tooltip{display:block}.was-validated .climb-jupyter .form-control:valid,.climb-jupyter .form-control.is-valid{border-color:var(--bs-form-valid-border-color);padding-right:calc(1.5em + .75rem);background-image:url(${___CSS_LOADER_URL_REPLACEMENT_10___});background-repeat:no-repeat;background-position:right calc(.375em + .1875rem) center;background-size:calc(.75em + .375rem) calc(.75em + .375rem)}.was-validated .climb-jupyter .form-control:valid:focus,.climb-jupyter .form-control.is-valid:focus{border-color:var(--bs-form-valid-border-color);box-shadow:0 0 0 .25rem rgba(var(--bs-success-rgb),.25)}.was-validated .climb-jupyter textarea.form-control:valid,.climb-jupyter textarea.form-control.is-valid{padding-right:calc(1.5em + .75rem);background-position:top calc(.375em + .1875rem) right calc(.375em + .1875rem)}.was-validated .climb-jupyter .form-select:valid,.climb-jupyter .form-select.is-valid{border-color:var(--bs-form-valid-border-color)}.was-validated .climb-jupyter .form-select:valid:not([multiple]):not([size]),.was-validated .climb-jupyter .form-select:valid:not([multiple])[size="1"],.climb-jupyter .form-select.is-valid:not([multiple]):not([size]),.climb-jupyter .form-select.is-valid:not([multiple])[size="1"]{--bs-form-select-bg-icon: url(${___CSS_LOADER_URL_REPLACEMENT_10___});padding-right:4.125rem;background-position:right .75rem center,center right 2.25rem;background-size:16px 12px,calc(.75em + .375rem) calc(.75em + .375rem)}.was-validated .climb-jupyter .form-select:valid:focus,.climb-jupyter .form-select.is-valid:focus{border-color:var(--bs-form-valid-border-color);box-shadow:0 0 0 .25rem rgba(var(--bs-success-rgb),.25)}.was-validated .climb-jupyter .form-control-color:valid,.climb-jupyter .form-control-color.is-valid{width:calc(3.75rem + 1.5em)}.was-validated .climb-jupyter .form-check-input:valid,.climb-jupyter .form-check-input.is-valid{border-color:var(--bs-form-valid-border-color)}.was-validated .climb-jupyter .form-check-input:valid:checked,.climb-jupyter .form-check-input.is-valid:checked{background-color:var(--bs-form-valid-color)}.was-validated .climb-jupyter .form-check-input:valid:focus,.climb-jupyter .form-check-input.is-valid:focus{box-shadow:0 0 0 .25rem rgba(var(--bs-success-rgb),.25)}.was-validated .climb-jupyter .form-check-input:valid~.form-check-label,.climb-jupyter .form-check-input.is-valid~.form-check-label{color:var(--bs-form-valid-color)}.climb-jupyter .form-check-inline .form-check-input~.valid-feedback{margin-left:.5em}.was-validated .climb-jupyter .input-group>.form-control:not(:focus):valid,.climb-jupyter .input-group>.form-control:not(:focus).is-valid,.was-validated .climb-jupyter .input-group>.form-select:not(:focus):valid,.climb-jupyter .input-group>.form-select:not(:focus).is-valid,.was-validated .climb-jupyter .input-group>.form-floating:not(:focus-within):valid,.climb-jupyter .input-group>.form-floating:not(:focus-within).is-valid{z-index:3}.climb-jupyter .invalid-feedback{display:none;width:100%;margin-top:.25rem;font-size:.875em;color:var(--bs-form-invalid-color)}.climb-jupyter .invalid-tooltip{position:absolute;top:100%;z-index:5;display:none;max-width:100%;padding:.25rem .5rem;margin-top:.1rem;font-size:.875rem;color:#fff;background-color:var(--bs-danger);border-radius:var(--bs-border-radius)}.was-validated .climb-jupyter:invalid~.invalid-feedback,.was-validated .climb-jupyter:invalid~.invalid-tooltip,.climb-jupyter.is-invalid~.invalid-feedback,.climb-jupyter.is-invalid~.invalid-tooltip{display:block}.was-validated .climb-jupyter .form-control:invalid,.climb-jupyter .form-control.is-invalid{border-color:var(--bs-form-invalid-border-color);padding-right:calc(1.5em + .75rem);background-image:url(${___CSS_LOADER_URL_REPLACEMENT_11___});background-repeat:no-repeat;background-position:right calc(.375em + .1875rem) center;background-size:calc(.75em + .375rem) calc(.75em + .375rem)}.was-validated .climb-jupyter .form-control:invalid:focus,.climb-jupyter .form-control.is-invalid:focus{border-color:var(--bs-form-invalid-border-color);box-shadow:0 0 0 .25rem rgba(var(--bs-danger-rgb),.25)}.was-validated .climb-jupyter textarea.form-control:invalid,.climb-jupyter textarea.form-control.is-invalid{padding-right:calc(1.5em + .75rem);background-position:top calc(.375em + .1875rem) right calc(.375em + .1875rem)}.was-validated .climb-jupyter .form-select:invalid,.climb-jupyter .form-select.is-invalid{border-color:var(--bs-form-invalid-border-color)}.was-validated .climb-jupyter .form-select:invalid:not([multiple]):not([size]),.was-validated .climb-jupyter .form-select:invalid:not([multiple])[size="1"],.climb-jupyter .form-select.is-invalid:not([multiple]):not([size]),.climb-jupyter .form-select.is-invalid:not([multiple])[size="1"]{--bs-form-select-bg-icon: url(${___CSS_LOADER_URL_REPLACEMENT_11___});padding-right:4.125rem;background-position:right .75rem center,center right 2.25rem;background-size:16px 12px,calc(.75em + .375rem) calc(.75em + .375rem)}.was-validated .climb-jupyter .form-select:invalid:focus,.climb-jupyter .form-select.is-invalid:focus{border-color:var(--bs-form-invalid-border-color);box-shadow:0 0 0 .25rem rgba(var(--bs-danger-rgb),.25)}.was-validated .climb-jupyter .form-control-color:invalid,.climb-jupyter .form-control-color.is-invalid{width:calc(3.75rem + 1.5em)}.was-validated .climb-jupyter .form-check-input:invalid,.climb-jupyter .form-check-input.is-invalid{border-color:var(--bs-form-invalid-border-color)}.was-validated .climb-jupyter .form-check-input:invalid:checked,.climb-jupyter .form-check-input.is-invalid:checked{background-color:var(--bs-form-invalid-color)}.was-validated .climb-jupyter .form-check-input:invalid:focus,.climb-jupyter .form-check-input.is-invalid:focus{box-shadow:0 0 0 .25rem rgba(var(--bs-danger-rgb),.25)}.was-validated .climb-jupyter .form-check-input:invalid~.form-check-label,.climb-jupyter .form-check-input.is-invalid~.form-check-label{color:var(--bs-form-invalid-color)}.climb-jupyter .form-check-inline .form-check-input~.invalid-feedback{margin-left:.5em}.was-validated .climb-jupyter .input-group>.form-control:not(:focus):invalid,.climb-jupyter .input-group>.form-control:not(:focus).is-invalid,.was-validated .climb-jupyter .input-group>.form-select:not(:focus):invalid,.climb-jupyter .input-group>.form-select:not(:focus).is-invalid,.was-validated .climb-jupyter .input-group>.form-floating:not(:focus-within):invalid,.climb-jupyter .input-group>.form-floating:not(:focus-within).is-invalid{z-index:4}.climb-jupyter .btn{--bs-btn-padding-x: .75rem;--bs-btn-padding-y: .375rem;--bs-btn-font-family: ;--bs-btn-font-size: 1rem;--bs-btn-font-weight: 400;--bs-btn-line-height: 1.5;--bs-btn-color: var(--bs-body-color);--bs-btn-bg: transparent;--bs-btn-border-width: var(--bs-border-width);--bs-btn-border-color: transparent;--bs-btn-border-radius: var(--bs-border-radius);--bs-btn-hover-border-color: transparent;--bs-btn-box-shadow: inset 0 1px 0 rgba(255, 255, 255, .15), 0 1px 1px rgba(0, 0, 0, .075);--bs-btn-disabled-opacity: .65;--bs-btn-focus-box-shadow: 0 0 0 .25rem rgba(var(--bs-btn-focus-shadow-rgb), .5);display:inline-block;padding:var(--bs-btn-padding-y) var(--bs-btn-padding-x);font-family:var(--bs-btn-font-family);font-size:var(--bs-btn-font-size);font-weight:var(--bs-btn-font-weight);line-height:var(--bs-btn-line-height);color:var(--bs-btn-color);text-align:center;text-decoration:none;vertical-align:middle;cursor:pointer;-webkit-user-select:none;user-select:none;border:var(--bs-btn-border-width) solid var(--bs-btn-border-color);border-radius:var(--bs-btn-border-radius);background-color:var(--bs-btn-bg);transition:color .15s ease-in-out,background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out}@media (prefers-reduced-motion: reduce){.climb-jupyter .btn{transition:none}}.climb-jupyter .btn:hover{color:var(--bs-btn-hover-color);background-color:var(--bs-btn-hover-bg);border-color:var(--bs-btn-hover-border-color)}.btn-check+.climb-jupyter .btn:hover{color:var(--bs-btn-color);background-color:var(--bs-btn-bg);border-color:var(--bs-btn-border-color)}.climb-jupyter .btn:focus-visible{color:var(--bs-btn-hover-color);background-color:var(--bs-btn-hover-bg);border-color:var(--bs-btn-hover-border-color);outline:0;box-shadow:var(--bs-btn-focus-box-shadow)}.btn-check:focus-visible+.climb-jupyter .btn{border-color:var(--bs-btn-hover-border-color);outline:0;box-shadow:var(--bs-btn-focus-box-shadow)}.btn-check:checked+.climb-jupyter .btn,:not(.btn-check)+.climb-jupyter .btn:active,.climb-jupyter .btn:first-child:active,.climb-jupyter .btn.active,.climb-jupyter .btn.show{color:var(--bs-btn-active-color);background-color:var(--bs-btn-active-bg);border-color:var(--bs-btn-active-border-color)}.btn-check:checked+.climb-jupyter .btn:focus-visible,:not(.btn-check)+.climb-jupyter .btn:active:focus-visible,.climb-jupyter .btn:first-child:active:focus-visible,.climb-jupyter .btn.active:focus-visible,.climb-jupyter .btn.show:focus-visible{box-shadow:var(--bs-btn-focus-box-shadow)}.btn-check:checked:focus-visible+.climb-jupyter .btn{box-shadow:var(--bs-btn-focus-box-shadow)}.climb-jupyter .btn:disabled,.climb-jupyter .btn.disabled,fieldset:disabled .climb-jupyter .btn{color:var(--bs-btn-disabled-color);pointer-events:none;background-color:var(--bs-btn-disabled-bg);border-color:var(--bs-btn-disabled-border-color);opacity:var(--bs-btn-disabled-opacity)}.climb-jupyter .btn-primary{--bs-btn-color: #fff;--bs-btn-bg: #0d6efd;--bs-btn-border-color: #0d6efd;--bs-btn-hover-color: #fff;--bs-btn-hover-bg: rgb(11.05, 93.5, 215.05);--bs-btn-hover-border-color: rgb(10.4, 88, 202.4);--bs-btn-focus-shadow-rgb: 49, 132, 253;--bs-btn-active-color: #fff;--bs-btn-active-bg: rgb(10.4, 88, 202.4);--bs-btn-active-border-color: rgb(9.75, 82.5, 189.75);--bs-btn-active-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);--bs-btn-disabled-color: #fff;--bs-btn-disabled-bg: #0d6efd;--bs-btn-disabled-border-color: #0d6efd}.climb-jupyter .btn-secondary{--bs-btn-color: #fff;--bs-btn-bg: #6c757d;--bs-btn-border-color: #6c757d;--bs-btn-hover-color: #fff;--bs-btn-hover-bg: rgb(91.8, 99.45, 106.25);--bs-btn-hover-border-color: rgb(86.4, 93.6, 100);--bs-btn-focus-shadow-rgb: 130, 138, 145;--bs-btn-active-color: #fff;--bs-btn-active-bg: rgb(86.4, 93.6, 100);--bs-btn-active-border-color: rgb(81, 87.75, 93.75);--bs-btn-active-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);--bs-btn-disabled-color: #fff;--bs-btn-disabled-bg: #6c757d;--bs-btn-disabled-border-color: #6c757d}.climb-jupyter .btn-success{--bs-btn-color: #fff;--bs-btn-bg: #198754;--bs-btn-border-color: #198754;--bs-btn-hover-color: #fff;--bs-btn-hover-bg: rgb(21.25, 114.75, 71.4);--bs-btn-hover-border-color: rgb(20, 108, 67.2);--bs-btn-focus-shadow-rgb: 60, 153, 110;--bs-btn-active-color: #fff;--bs-btn-active-bg: rgb(20, 108, 67.2);--bs-btn-active-border-color: rgb(18.75, 101.25, 63);--bs-btn-active-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);--bs-btn-disabled-color: #fff;--bs-btn-disabled-bg: #198754;--bs-btn-disabled-border-color: #198754}.climb-jupyter .btn-info{--bs-btn-color: #000;--bs-btn-bg: #0dcaf0;--bs-btn-border-color: #0dcaf0;--bs-btn-hover-color: #000;--bs-btn-hover-bg: rgb(49.3, 209.95, 242.25);--bs-btn-hover-border-color: rgb(37.2, 207.3, 241.5);--bs-btn-focus-shadow-rgb: 11, 172, 204;--bs-btn-active-color: #000;--bs-btn-active-bg: rgb(61.4, 212.6, 243);--bs-btn-active-border-color: rgb(37.2, 207.3, 241.5);--bs-btn-active-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);--bs-btn-disabled-color: #000;--bs-btn-disabled-bg: #0dcaf0;--bs-btn-disabled-border-color: #0dcaf0}.climb-jupyter .btn-warning{--bs-btn-color: #000;--bs-btn-bg: #ffc107;--bs-btn-border-color: #ffc107;--bs-btn-hover-color: #000;--bs-btn-hover-bg: rgb(255, 202.3, 44.2);--bs-btn-hover-border-color: rgb(255, 199.2, 31.8);--bs-btn-focus-shadow-rgb: 217, 164, 6;--bs-btn-active-color: #000;--bs-btn-active-bg: rgb(255, 205.4, 56.6);--bs-btn-active-border-color: rgb(255, 199.2, 31.8);--bs-btn-active-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);--bs-btn-disabled-color: #000;--bs-btn-disabled-bg: #ffc107;--bs-btn-disabled-border-color: #ffc107}.climb-jupyter .btn-danger{--bs-btn-color: #fff;--bs-btn-bg: #dc3545;--bs-btn-border-color: #dc3545;--bs-btn-hover-color: #fff;--bs-btn-hover-bg: rgb(187, 45.05, 58.65);--bs-btn-hover-border-color: rgb(176, 42.4, 55.2);--bs-btn-focus-shadow-rgb: 225, 83, 97;--bs-btn-active-color: #fff;--bs-btn-active-bg: rgb(176, 42.4, 55.2);--bs-btn-active-border-color: rgb(165, 39.75, 51.75);--bs-btn-active-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);--bs-btn-disabled-color: #fff;--bs-btn-disabled-bg: #dc3545;--bs-btn-disabled-border-color: #dc3545}.climb-jupyter .btn-light{--bs-btn-color: #000;--bs-btn-bg: #f8f9fa;--bs-btn-border-color: #f8f9fa;--bs-btn-hover-color: #000;--bs-btn-hover-bg: rgb(210.8, 211.65, 212.5);--bs-btn-hover-border-color: rgb(198.4, 199.2, 200);--bs-btn-focus-shadow-rgb: 211, 212, 213;--bs-btn-active-color: #000;--bs-btn-active-bg: rgb(198.4, 199.2, 200);--bs-btn-active-border-color: rgb(186, 186.75, 187.5);--bs-btn-active-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);--bs-btn-disabled-color: #000;--bs-btn-disabled-bg: #f8f9fa;--bs-btn-disabled-border-color: #f8f9fa}.climb-jupyter .btn-dark{--bs-btn-color: #fff;--bs-btn-bg: #212529;--bs-btn-border-color: #212529;--bs-btn-hover-color: #fff;--bs-btn-hover-bg: rgb(66.3, 69.7, 73.1);--bs-btn-hover-border-color: rgb(55.2, 58.8, 62.4);--bs-btn-focus-shadow-rgb: 66, 70, 73;--bs-btn-active-color: #fff;--bs-btn-active-bg: rgb(77.4, 80.6, 83.8);--bs-btn-active-border-color: rgb(55.2, 58.8, 62.4);--bs-btn-active-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);--bs-btn-disabled-color: #fff;--bs-btn-disabled-bg: #212529;--bs-btn-disabled-border-color: #212529}.climb-jupyter .btn-outline-primary{--bs-btn-color: #0d6efd;--bs-btn-border-color: #0d6efd;--bs-btn-hover-color: #fff;--bs-btn-hover-bg: #0d6efd;--bs-btn-hover-border-color: #0d6efd;--bs-btn-focus-shadow-rgb: 13, 110, 253;--bs-btn-active-color: #fff;--bs-btn-active-bg: #0d6efd;--bs-btn-active-border-color: #0d6efd;--bs-btn-active-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);--bs-btn-disabled-color: #0d6efd;--bs-btn-disabled-bg: transparent;--bs-btn-disabled-border-color: #0d6efd;--bs-gradient: none}.climb-jupyter .btn-outline-secondary{--bs-btn-color: #6c757d;--bs-btn-border-color: #6c757d;--bs-btn-hover-color: #fff;--bs-btn-hover-bg: #6c757d;--bs-btn-hover-border-color: #6c757d;--bs-btn-focus-shadow-rgb: 108, 117, 125;--bs-btn-active-color: #fff;--bs-btn-active-bg: #6c757d;--bs-btn-active-border-color: #6c757d;--bs-btn-active-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);--bs-btn-disabled-color: #6c757d;--bs-btn-disabled-bg: transparent;--bs-btn-disabled-border-color: #6c757d;--bs-gradient: none}.climb-jupyter .btn-outline-success{--bs-btn-color: #198754;--bs-btn-border-color: #198754;--bs-btn-hover-color: #fff;--bs-btn-hover-bg: #198754;--bs-btn-hover-border-color: #198754;--bs-btn-focus-shadow-rgb: 25, 135, 84;--bs-btn-active-color: #fff;--bs-btn-active-bg: #198754;--bs-btn-active-border-color: #198754;--bs-btn-active-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);--bs-btn-disabled-color: #198754;--bs-btn-disabled-bg: transparent;--bs-btn-disabled-border-color: #198754;--bs-gradient: none}.climb-jupyter .btn-outline-info{--bs-btn-color: #0dcaf0;--bs-btn-border-color: #0dcaf0;--bs-btn-hover-color: #000;--bs-btn-hover-bg: #0dcaf0;--bs-btn-hover-border-color: #0dcaf0;--bs-btn-focus-shadow-rgb: 13, 202, 240;--bs-btn-active-color: #000;--bs-btn-active-bg: #0dcaf0;--bs-btn-active-border-color: #0dcaf0;--bs-btn-active-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);--bs-btn-disabled-color: #0dcaf0;--bs-btn-disabled-bg: transparent;--bs-btn-disabled-border-color: #0dcaf0;--bs-gradient: none}.climb-jupyter .btn-outline-warning{--bs-btn-color: #ffc107;--bs-btn-border-color: #ffc107;--bs-btn-hover-color: #000;--bs-btn-hover-bg: #ffc107;--bs-btn-hover-border-color: #ffc107;--bs-btn-focus-shadow-rgb: 255, 193, 7;--bs-btn-active-color: #000;--bs-btn-active-bg: #ffc107;--bs-btn-active-border-color: #ffc107;--bs-btn-active-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);--bs-btn-disabled-color: #ffc107;--bs-btn-disabled-bg: transparent;--bs-btn-disabled-border-color: #ffc107;--bs-gradient: none}.climb-jupyter .btn-outline-danger{--bs-btn-color: #dc3545;--bs-btn-border-color: #dc3545;--bs-btn-hover-color: #fff;--bs-btn-hover-bg: #dc3545;--bs-btn-hover-border-color: #dc3545;--bs-btn-focus-shadow-rgb: 220, 53, 69;--bs-btn-active-color: #fff;--bs-btn-active-bg: #dc3545;--bs-btn-active-border-color: #dc3545;--bs-btn-active-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);--bs-btn-disabled-color: #dc3545;--bs-btn-disabled-bg: transparent;--bs-btn-disabled-border-color: #dc3545;--bs-gradient: none}.climb-jupyter .btn-outline-light{--bs-btn-color: #f8f9fa;--bs-btn-border-color: #f8f9fa;--bs-btn-hover-color: #000;--bs-btn-hover-bg: #f8f9fa;--bs-btn-hover-border-color: #f8f9fa;--bs-btn-focus-shadow-rgb: 248, 249, 250;--bs-btn-active-color: #000;--bs-btn-active-bg: #f8f9fa;--bs-btn-active-border-color: #f8f9fa;--bs-btn-active-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);--bs-btn-disabled-color: #f8f9fa;--bs-btn-disabled-bg: transparent;--bs-btn-disabled-border-color: #f8f9fa;--bs-gradient: none}.climb-jupyter .btn-outline-dark{--bs-btn-color: #212529;--bs-btn-border-color: #212529;--bs-btn-hover-color: #fff;--bs-btn-hover-bg: #212529;--bs-btn-hover-border-color: #212529;--bs-btn-focus-shadow-rgb: 33, 37, 41;--bs-btn-active-color: #fff;--bs-btn-active-bg: #212529;--bs-btn-active-border-color: #212529;--bs-btn-active-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);--bs-btn-disabled-color: #212529;--bs-btn-disabled-bg: transparent;--bs-btn-disabled-border-color: #212529;--bs-gradient: none}.climb-jupyter .btn-link{--bs-btn-font-weight: 400;--bs-btn-color: var(--bs-link-color);--bs-btn-bg: transparent;--bs-btn-border-color: transparent;--bs-btn-hover-color: var(--bs-link-hover-color);--bs-btn-hover-border-color: transparent;--bs-btn-active-color: var(--bs-link-hover-color);--bs-btn-active-border-color: transparent;--bs-btn-disabled-color: #6c757d;--bs-btn-disabled-border-color: transparent;--bs-btn-box-shadow: 0 0 0 #000;--bs-btn-focus-shadow-rgb: 49, 132, 253;text-decoration:underline}.climb-jupyter .btn-link:focus-visible{color:var(--bs-btn-color)}.climb-jupyter .btn-link:hover{color:var(--bs-btn-hover-color)}.climb-jupyter .btn-lg,.climb-jupyter .btn-group-lg>.btn{--bs-btn-padding-y: .5rem;--bs-btn-padding-x: 1rem;--bs-btn-font-size: 1.25rem;--bs-btn-border-radius: var(--bs-border-radius-lg)}.climb-jupyter .btn-sm,.climb-jupyter .btn-group-sm>.btn{--bs-btn-padding-y: .25rem;--bs-btn-padding-x: .5rem;--bs-btn-font-size: .875rem;--bs-btn-border-radius: var(--bs-border-radius-sm)}.climb-jupyter .fade{transition:opacity .15s linear}@media (prefers-reduced-motion: reduce){.climb-jupyter .fade{transition:none}}.climb-jupyter .fade:not(.show){opacity:0}.climb-jupyter .collapse:not(.show){display:none}.climb-jupyter .collapsing{height:0;overflow:hidden;transition:height .35s ease}@media (prefers-reduced-motion: reduce){.climb-jupyter .collapsing{transition:none}}.climb-jupyter .collapsing.collapse-horizontal{width:0;height:auto;transition:width .35s ease}@media (prefers-reduced-motion: reduce){.climb-jupyter .collapsing.collapse-horizontal{transition:none}}.climb-jupyter .dropup,.climb-jupyter .dropend,.climb-jupyter .dropdown,.climb-jupyter .dropstart,.climb-jupyter .dropup-center,.climb-jupyter .dropdown-center{position:relative}.climb-jupyter .dropdown-toggle{white-space:nowrap}.climb-jupyter .dropdown-toggle:after{display:inline-block;margin-left:.255em;vertical-align:.255em;content:"";border-top:.3em solid;border-right:.3em solid transparent;border-bottom:0;border-left:.3em solid transparent}.climb-jupyter .dropdown-toggle:empty:after{margin-left:0}.climb-jupyter .dropdown-menu{--bs-dropdown-zindex: 1000;--bs-dropdown-min-width: 10rem;--bs-dropdown-padding-x: 0;--bs-dropdown-padding-y: .5rem;--bs-dropdown-spacer: .125rem;--bs-dropdown-font-size: 1rem;--bs-dropdown-color: var(--bs-body-color);--bs-dropdown-bg: var(--bs-body-bg);--bs-dropdown-border-color: var(--bs-border-color-translucent);--bs-dropdown-border-radius: var(--bs-border-radius);--bs-dropdown-border-width: var(--bs-border-width);--bs-dropdown-inner-border-radius: calc(var(--bs-border-radius) - var(--bs-border-width));--bs-dropdown-divider-bg: var(--bs-border-color-translucent);--bs-dropdown-divider-margin-y: .5rem;--bs-dropdown-box-shadow: var(--bs-box-shadow);--bs-dropdown-link-color: var(--bs-body-color);--bs-dropdown-link-hover-color: var(--bs-body-color);--bs-dropdown-link-hover-bg: var(--bs-tertiary-bg);--bs-dropdown-link-active-color: #fff;--bs-dropdown-link-active-bg: #0d6efd;--bs-dropdown-link-disabled-color: var(--bs-tertiary-color);--bs-dropdown-item-padding-x: 1rem;--bs-dropdown-item-padding-y: .25rem;--bs-dropdown-header-color: #6c757d;--bs-dropdown-header-padding-x: 1rem;--bs-dropdown-header-padding-y: .5rem;position:absolute;z-index:var(--bs-dropdown-zindex);display:none;min-width:var(--bs-dropdown-min-width);padding:var(--bs-dropdown-padding-y) var(--bs-dropdown-padding-x);margin:0;font-size:var(--bs-dropdown-font-size);color:var(--bs-dropdown-color);text-align:left;list-style:none;background-color:var(--bs-dropdown-bg);background-clip:padding-box;border:var(--bs-dropdown-border-width) solid var(--bs-dropdown-border-color);border-radius:var(--bs-dropdown-border-radius)}.climb-jupyter .dropdown-menu[data-bs-popper]{top:100%;left:0;margin-top:var(--bs-dropdown-spacer)}.climb-jupyter .dropdown-menu-start{--bs-position: start}.climb-jupyter .dropdown-menu-start[data-bs-popper]{right:auto;left:0}.climb-jupyter .dropdown-menu-end{--bs-position: end}.climb-jupyter .dropdown-menu-end[data-bs-popper]{right:0;left:auto}@media (min-width: 576px){.climb-jupyter .dropdown-menu-sm-start{--bs-position: start}.climb-jupyter .dropdown-menu-sm-start[data-bs-popper]{right:auto;left:0}.climb-jupyter .dropdown-menu-sm-end{--bs-position: end}.climb-jupyter .dropdown-menu-sm-end[data-bs-popper]{right:0;left:auto}}@media (min-width: 768px){.climb-jupyter .dropdown-menu-md-start{--bs-position: start}.climb-jupyter .dropdown-menu-md-start[data-bs-popper]{right:auto;left:0}.climb-jupyter .dropdown-menu-md-end{--bs-position: end}.climb-jupyter .dropdown-menu-md-end[data-bs-popper]{right:0;left:auto}}@media (min-width: 992px){.climb-jupyter .dropdown-menu-lg-start{--bs-position: start}.climb-jupyter .dropdown-menu-lg-start[data-bs-popper]{right:auto;left:0}.climb-jupyter .dropdown-menu-lg-end{--bs-position: end}.climb-jupyter .dropdown-menu-lg-end[data-bs-popper]{right:0;left:auto}}@media (min-width: 1200px){.climb-jupyter .dropdown-menu-xl-start{--bs-position: start}.climb-jupyter .dropdown-menu-xl-start[data-bs-popper]{right:auto;left:0}.climb-jupyter .dropdown-menu-xl-end{--bs-position: end}.climb-jupyter .dropdown-menu-xl-end[data-bs-popper]{right:0;left:auto}}@media (min-width: 1400px){.climb-jupyter .dropdown-menu-xxl-start{--bs-position: start}.climb-jupyter .dropdown-menu-xxl-start[data-bs-popper]{right:auto;left:0}.climb-jupyter .dropdown-menu-xxl-end{--bs-position: end}.climb-jupyter .dropdown-menu-xxl-end[data-bs-popper]{right:0;left:auto}}.climb-jupyter .dropup .dropdown-menu[data-bs-popper]{top:auto;bottom:100%;margin-top:0;margin-bottom:var(--bs-dropdown-spacer)}.climb-jupyter .dropup .dropdown-toggle:after{display:inline-block;margin-left:.255em;vertical-align:.255em;content:"";border-top:0;border-right:.3em solid transparent;border-bottom:.3em solid;border-left:.3em solid transparent}.climb-jupyter .dropup .dropdown-toggle:empty:after{margin-left:0}.climb-jupyter .dropend .dropdown-menu[data-bs-popper]{top:0;right:auto;left:100%;margin-top:0;margin-left:var(--bs-dropdown-spacer)}.climb-jupyter .dropend .dropdown-toggle:after{display:inline-block;margin-left:.255em;vertical-align:.255em;content:"";border-top:.3em solid transparent;border-right:0;border-bottom:.3em solid transparent;border-left:.3em solid}.climb-jupyter .dropend .dropdown-toggle:empty:after{margin-left:0}.climb-jupyter .dropend .dropdown-toggle:after{vertical-align:0}.climb-jupyter .dropstart .dropdown-menu[data-bs-popper]{top:0;right:100%;left:auto;margin-top:0;margin-right:var(--bs-dropdown-spacer)}.climb-jupyter .dropstart .dropdown-toggle:after{display:inline-block;margin-left:.255em;vertical-align:.255em;content:""}.climb-jupyter .dropstart .dropdown-toggle:after{display:none}.climb-jupyter .dropstart .dropdown-toggle:before{display:inline-block;margin-right:.255em;vertical-align:.255em;content:"";border-top:.3em solid transparent;border-right:.3em solid;border-bottom:.3em solid transparent}.climb-jupyter .dropstart .dropdown-toggle:empty:after{margin-left:0}.climb-jupyter .dropstart .dropdown-toggle:before{vertical-align:0}.climb-jupyter .dropdown-divider{height:0;margin:var(--bs-dropdown-divider-margin-y) 0;overflow:hidden;border-top:1px solid var(--bs-dropdown-divider-bg);opacity:1}.climb-jupyter .dropdown-item{display:block;width:100%;padding:var(--bs-dropdown-item-padding-y) var(--bs-dropdown-item-padding-x);clear:both;font-weight:400;color:var(--bs-dropdown-link-color);text-align:inherit;text-decoration:none;white-space:nowrap;background-color:transparent;border:0;border-radius:var(--bs-dropdown-item-border-radius, 0)}.climb-jupyter .dropdown-item:hover,.climb-jupyter .dropdown-item:focus{color:var(--bs-dropdown-link-hover-color);background-color:var(--bs-dropdown-link-hover-bg)}.climb-jupyter .dropdown-item.active,.climb-jupyter .dropdown-item:active{color:var(--bs-dropdown-link-active-color);text-decoration:none;background-color:var(--bs-dropdown-link-active-bg)}.climb-jupyter .dropdown-item.disabled,.climb-jupyter .dropdown-item:disabled{color:var(--bs-dropdown-link-disabled-color);pointer-events:none;background-color:transparent}.climb-jupyter .dropdown-menu.show{display:block}.climb-jupyter .dropdown-header{display:block;padding:var(--bs-dropdown-header-padding-y) var(--bs-dropdown-header-padding-x);margin-bottom:0;font-size:.875rem;color:var(--bs-dropdown-header-color);white-space:nowrap}.climb-jupyter .dropdown-item-text{display:block;padding:var(--bs-dropdown-item-padding-y) var(--bs-dropdown-item-padding-x);color:var(--bs-dropdown-link-color)}.climb-jupyter .dropdown-menu-dark{--bs-dropdown-color: #dee2e6;--bs-dropdown-bg: #343a40;--bs-dropdown-border-color: var(--bs-border-color-translucent);--bs-dropdown-box-shadow: ;--bs-dropdown-link-color: #dee2e6;--bs-dropdown-link-hover-color: #fff;--bs-dropdown-divider-bg: var(--bs-border-color-translucent);--bs-dropdown-link-hover-bg: rgba(255, 255, 255, .15);--bs-dropdown-link-active-color: #fff;--bs-dropdown-link-active-bg: #0d6efd;--bs-dropdown-link-disabled-color: #adb5bd;--bs-dropdown-header-color: #adb5bd}.climb-jupyter .btn-group,.climb-jupyter .btn-group-vertical{position:relative;display:inline-flex;vertical-align:middle}.climb-jupyter .btn-group>.btn,.climb-jupyter .btn-group-vertical>.btn{position:relative;flex:1 1 auto}.climb-jupyter .btn-group>.btn-check:checked+.btn,.climb-jupyter .btn-group>.btn-check:focus+.btn,.climb-jupyter .btn-group>.btn:hover,.climb-jupyter .btn-group>.btn:focus,.climb-jupyter .btn-group>.btn:active,.climb-jupyter .btn-group>.btn.active,.climb-jupyter .btn-group-vertical>.btn-check:checked+.btn,.climb-jupyter .btn-group-vertical>.btn-check:focus+.btn,.climb-jupyter .btn-group-vertical>.btn:hover,.climb-jupyter .btn-group-vertical>.btn:focus,.climb-jupyter .btn-group-vertical>.btn:active,.climb-jupyter .btn-group-vertical>.btn.active{z-index:1}.climb-jupyter .btn-toolbar{display:flex;flex-wrap:wrap;justify-content:flex-start}.climb-jupyter .btn-toolbar .input-group{width:auto}.climb-jupyter .btn-group{border-radius:var(--bs-border-radius)}.climb-jupyter .btn-group>:not(.btn-check:first-child)+.btn,.climb-jupyter .btn-group>.btn-group:not(:first-child){margin-left:calc(-1 * var(--bs-border-width))}.climb-jupyter .btn-group>.btn:not(:last-child):not(.dropdown-toggle),.climb-jupyter .btn-group>.btn.dropdown-toggle-split:first-child,.climb-jupyter .btn-group>.btn-group:not(:last-child)>.btn{border-top-right-radius:0;border-bottom-right-radius:0}.climb-jupyter .btn-group>.btn:nth-child(n+3),.climb-jupyter .btn-group>:not(.btn-check)+.btn,.climb-jupyter .btn-group>.btn-group:not(:first-child)>.btn{border-top-left-radius:0;border-bottom-left-radius:0}.climb-jupyter .dropdown-toggle-split{padding-right:.5625rem;padding-left:.5625rem}.climb-jupyter .dropdown-toggle-split:after,.dropup .climb-jupyter .dropdown-toggle-split:after,.dropend .climb-jupyter .dropdown-toggle-split:after{margin-left:0}.dropstart .climb-jupyter .dropdown-toggle-split:before{margin-right:0}.climb-jupyter .btn-sm+.dropdown-toggle-split,.climb-jupyter .btn-group-sm>.btn+.dropdown-toggle-split{padding-right:.375rem;padding-left:.375rem}.climb-jupyter .btn-lg+.dropdown-toggle-split,.climb-jupyter .btn-group-lg>.btn+.dropdown-toggle-split{padding-right:.75rem;padding-left:.75rem}.climb-jupyter .btn-group-vertical{flex-direction:column;align-items:flex-start;justify-content:center}.climb-jupyter .btn-group-vertical>.btn,.climb-jupyter .btn-group-vertical>.btn-group{width:100%}.climb-jupyter .btn-group-vertical>.btn:not(:first-child),.climb-jupyter .btn-group-vertical>.btn-group:not(:first-child){margin-top:calc(-1 * var(--bs-border-width))}.climb-jupyter .btn-group-vertical>.btn:not(:last-child):not(.dropdown-toggle),.climb-jupyter .btn-group-vertical>.btn-group:not(:last-child)>.btn{border-bottom-right-radius:0;border-bottom-left-radius:0}.climb-jupyter .btn-group-vertical>.btn:nth-child(n+3),.climb-jupyter .btn-group-vertical>:not(.btn-check)+.btn,.climb-jupyter .btn-group-vertical>.btn-group:not(:first-child)>.btn{border-top-left-radius:0;border-top-right-radius:0}.climb-jupyter .nav{--bs-nav-link-padding-x: 1rem;--bs-nav-link-padding-y: .5rem;--bs-nav-link-font-weight: ;--bs-nav-link-color: var(--bs-link-color);--bs-nav-link-hover-color: var(--bs-link-hover-color);--bs-nav-link-disabled-color: var(--bs-secondary-color);display:flex;flex-wrap:wrap;padding-left:0;margin-bottom:0;list-style:none}.climb-jupyter .nav-link{display:block;padding:var(--bs-nav-link-padding-y) var(--bs-nav-link-padding-x);font-size:var(--bs-nav-link-font-size);font-weight:var(--bs-nav-link-font-weight);color:var(--bs-nav-link-color);text-decoration:none;background:none;border:0;transition:color .15s ease-in-out,background-color .15s ease-in-out,border-color .15s ease-in-out}@media (prefers-reduced-motion: reduce){.climb-jupyter .nav-link{transition:none}}.climb-jupyter .nav-link:hover,.climb-jupyter .nav-link:focus{color:var(--bs-nav-link-hover-color)}.climb-jupyter .nav-link:focus-visible{outline:0;box-shadow:0 0 0 .25rem #0d6efd40}.climb-jupyter .nav-link.disabled,.climb-jupyter .nav-link:disabled{color:var(--bs-nav-link-disabled-color);pointer-events:none;cursor:default}.climb-jupyter .nav-tabs{--bs-nav-tabs-border-width: var(--bs-border-width);--bs-nav-tabs-border-color: var(--bs-border-color);--bs-nav-tabs-border-radius: var(--bs-border-radius);--bs-nav-tabs-link-hover-border-color: var(--bs-secondary-bg) var(--bs-secondary-bg) var(--bs-border-color);--bs-nav-tabs-link-active-color: var(--bs-emphasis-color);--bs-nav-tabs-link-active-bg: var(--bs-body-bg);--bs-nav-tabs-link-active-border-color: var(--bs-border-color) var(--bs-border-color) var(--bs-body-bg);border-bottom:var(--bs-nav-tabs-border-width) solid var(--bs-nav-tabs-border-color)}.climb-jupyter .nav-tabs .nav-link{margin-bottom:calc(-1 * var(--bs-nav-tabs-border-width));border:var(--bs-nav-tabs-border-width) solid transparent;border-top-left-radius:var(--bs-nav-tabs-border-radius);border-top-right-radius:var(--bs-nav-tabs-border-radius)}.climb-jupyter .nav-tabs .nav-link:hover,.climb-jupyter .nav-tabs .nav-link:focus{isolation:isolate;border-color:var(--bs-nav-tabs-link-hover-border-color)}.climb-jupyter .nav-tabs .nav-link.active,.climb-jupyter .nav-tabs .nav-item.show .nav-link{color:var(--bs-nav-tabs-link-active-color);background-color:var(--bs-nav-tabs-link-active-bg);border-color:var(--bs-nav-tabs-link-active-border-color)}.climb-jupyter .nav-tabs .dropdown-menu{margin-top:calc(-1 * var(--bs-nav-tabs-border-width));border-top-left-radius:0;border-top-right-radius:0}.climb-jupyter .nav-pills{--bs-nav-pills-border-radius: var(--bs-border-radius);--bs-nav-pills-link-active-color: #fff;--bs-nav-pills-link-active-bg: #0d6efd}.climb-jupyter .nav-pills .nav-link{border-radius:var(--bs-nav-pills-border-radius)}.climb-jupyter .nav-pills .nav-link.active,.climb-jupyter .nav-pills .show>.nav-link{color:var(--bs-nav-pills-link-active-color);background-color:var(--bs-nav-pills-link-active-bg)}.climb-jupyter .nav-underline{--bs-nav-underline-gap: 1rem;--bs-nav-underline-border-width: .125rem;--bs-nav-underline-link-active-color: var(--bs-emphasis-color);gap:var(--bs-nav-underline-gap)}.climb-jupyter .nav-underline .nav-link{padding-right:0;padding-left:0;border-bottom:var(--bs-nav-underline-border-width) solid transparent}.climb-jupyter .nav-underline .nav-link:hover,.climb-jupyter .nav-underline .nav-link:focus{border-bottom-color:currentcolor}.climb-jupyter .nav-underline .nav-link.active,.climb-jupyter .nav-underline .show>.nav-link{font-weight:700;color:var(--bs-nav-underline-link-active-color);border-bottom-color:currentcolor}.climb-jupyter .nav-fill>.nav-link,.climb-jupyter .nav-fill .nav-item{flex:1 1 auto;text-align:center}.climb-jupyter .nav-justified>.nav-link,.climb-jupyter .nav-justified .nav-item{flex-grow:1;flex-basis:0;text-align:center}.climb-jupyter .nav-fill .nav-item .nav-link,.climb-jupyter .nav-justified .nav-item .nav-link{width:100%}.climb-jupyter .tab-content>.tab-pane{display:none}.climb-jupyter .tab-content>.active{display:block}.climb-jupyter .navbar{--bs-navbar-padding-x: 0;--bs-navbar-padding-y: .5rem;--bs-navbar-color: rgba(var(--bs-emphasis-color-rgb), .65);--bs-navbar-hover-color: rgba(var(--bs-emphasis-color-rgb), .8);--bs-navbar-disabled-color: rgba(var(--bs-emphasis-color-rgb), .3);--bs-navbar-active-color: rgba(var(--bs-emphasis-color-rgb), 1);--bs-navbar-brand-padding-y: .3125rem;--bs-navbar-brand-margin-end: 1rem;--bs-navbar-brand-font-size: 1.25rem;--bs-navbar-brand-color: rgba(var(--bs-emphasis-color-rgb), 1);--bs-navbar-brand-hover-color: rgba(var(--bs-emphasis-color-rgb), 1);--bs-navbar-nav-link-padding-x: .5rem;--bs-navbar-toggler-padding-y: .25rem;--bs-navbar-toggler-padding-x: .75rem;--bs-navbar-toggler-font-size: 1.25rem;--bs-navbar-toggler-icon-bg: url(${___CSS_LOADER_URL_REPLACEMENT_12___});--bs-navbar-toggler-border-color: rgba(var(--bs-emphasis-color-rgb), .15);--bs-navbar-toggler-border-radius: var(--bs-border-radius);--bs-navbar-toggler-focus-width: .25rem;--bs-navbar-toggler-transition: box-shadow .15s ease-in-out;position:relative;display:flex;flex-wrap:wrap;align-items:center;justify-content:space-between;padding:var(--bs-navbar-padding-y) var(--bs-navbar-padding-x)}.climb-jupyter .navbar>.container,.climb-jupyter .navbar>.container-fluid,.climb-jupyter .navbar>.container-sm,.climb-jupyter .navbar>.container-md,.climb-jupyter .navbar>.container-lg,.climb-jupyter .navbar>.container-xl,.climb-jupyter .navbar>.container-xxl{display:flex;flex-wrap:inherit;align-items:center;justify-content:space-between}.climb-jupyter .navbar-brand{padding-top:var(--bs-navbar-brand-padding-y);padding-bottom:var(--bs-navbar-brand-padding-y);margin-right:var(--bs-navbar-brand-margin-end);font-size:var(--bs-navbar-brand-font-size);color:var(--bs-navbar-brand-color);text-decoration:none;white-space:nowrap}.climb-jupyter .navbar-brand:hover,.climb-jupyter .navbar-brand:focus{color:var(--bs-navbar-brand-hover-color)}.climb-jupyter .navbar-nav{--bs-nav-link-padding-x: 0;--bs-nav-link-padding-y: .5rem;--bs-nav-link-font-weight: ;--bs-nav-link-color: var(--bs-navbar-color);--bs-nav-link-hover-color: var(--bs-navbar-hover-color);--bs-nav-link-disabled-color: var(--bs-navbar-disabled-color);display:flex;flex-direction:column;padding-left:0;margin-bottom:0;list-style:none}.climb-jupyter .navbar-nav .nav-link.active,.climb-jupyter .navbar-nav .nav-link.show{color:var(--bs-navbar-active-color)}.climb-jupyter .navbar-nav .dropdown-menu{position:static}.climb-jupyter .navbar-text{padding-top:.5rem;padding-bottom:.5rem;color:var(--bs-navbar-color)}.climb-jupyter .navbar-text a,.climb-jupyter .navbar-text a:hover,.climb-jupyter .navbar-text a:focus{color:var(--bs-navbar-active-color)}.climb-jupyter .navbar-collapse{flex-grow:1;flex-basis:100%;align-items:center}.climb-jupyter .navbar-toggler{padding:var(--bs-navbar-toggler-padding-y) var(--bs-navbar-toggler-padding-x);font-size:var(--bs-navbar-toggler-font-size);line-height:1;color:var(--bs-navbar-color);background-color:transparent;border:var(--bs-border-width) solid var(--bs-navbar-toggler-border-color);border-radius:var(--bs-navbar-toggler-border-radius);transition:var(--bs-navbar-toggler-transition)}@media (prefers-reduced-motion: reduce){.climb-jupyter .navbar-toggler{transition:none}}.climb-jupyter .navbar-toggler:hover{text-decoration:none}.climb-jupyter .navbar-toggler:focus{text-decoration:none;outline:0;box-shadow:0 0 0 var(--bs-navbar-toggler-focus-width)}.climb-jupyter .navbar-toggler-icon{display:inline-block;width:1.5em;height:1.5em;vertical-align:middle;background-image:var(--bs-navbar-toggler-icon-bg);background-repeat:no-repeat;background-position:center;background-size:100%}.climb-jupyter .navbar-nav-scroll{max-height:var(--bs-scroll-height, 75vh);overflow-y:auto}@media (min-width: 576px){.climb-jupyter .navbar-expand-sm{flex-wrap:nowrap;justify-content:flex-start}.climb-jupyter .navbar-expand-sm .navbar-nav{flex-direction:row}.climb-jupyter .navbar-expand-sm .navbar-nav .dropdown-menu{position:absolute}.climb-jupyter .navbar-expand-sm .navbar-nav .nav-link{padding-right:var(--bs-navbar-nav-link-padding-x);padding-left:var(--bs-navbar-nav-link-padding-x)}.climb-jupyter .navbar-expand-sm .navbar-nav-scroll{overflow:visible}.climb-jupyter .navbar-expand-sm .navbar-collapse{display:flex!important;flex-basis:auto}.climb-jupyter .navbar-expand-sm .navbar-toggler{display:none}.climb-jupyter .navbar-expand-sm .offcanvas{position:static;z-index:auto;flex-grow:1;width:auto!important;height:auto!important;visibility:visible!important;background-color:transparent!important;border:0!important;transform:none!important;transition:none}.climb-jupyter .navbar-expand-sm .offcanvas .offcanvas-header{display:none}.climb-jupyter .navbar-expand-sm .offcanvas .offcanvas-body{display:flex;flex-grow:0;padding:0;overflow-y:visible}}@media (min-width: 768px){.climb-jupyter .navbar-expand-md{flex-wrap:nowrap;justify-content:flex-start}.climb-jupyter .navbar-expand-md .navbar-nav{flex-direction:row}.climb-jupyter .navbar-expand-md .navbar-nav .dropdown-menu{position:absolute}.climb-jupyter .navbar-expand-md .navbar-nav .nav-link{padding-right:var(--bs-navbar-nav-link-padding-x);padding-left:var(--bs-navbar-nav-link-padding-x)}.climb-jupyter .navbar-expand-md .navbar-nav-scroll{overflow:visible}.climb-jupyter .navbar-expand-md .navbar-collapse{display:flex!important;flex-basis:auto}.climb-jupyter .navbar-expand-md .navbar-toggler{display:none}.climb-jupyter .navbar-expand-md .offcanvas{position:static;z-index:auto;flex-grow:1;width:auto!important;height:auto!important;visibility:visible!important;background-color:transparent!important;border:0!important;transform:none!important;transition:none}.climb-jupyter .navbar-expand-md .offcanvas .offcanvas-header{display:none}.climb-jupyter .navbar-expand-md .offcanvas .offcanvas-body{display:flex;flex-grow:0;padding:0;overflow-y:visible}}@media (min-width: 992px){.climb-jupyter .navbar-expand-lg{flex-wrap:nowrap;justify-content:flex-start}.climb-jupyter .navbar-expand-lg .navbar-nav{flex-direction:row}.climb-jupyter .navbar-expand-lg .navbar-nav .dropdown-menu{position:absolute}.climb-jupyter .navbar-expand-lg .navbar-nav .nav-link{padding-right:var(--bs-navbar-nav-link-padding-x);padding-left:var(--bs-navbar-nav-link-padding-x)}.climb-jupyter .navbar-expand-lg .navbar-nav-scroll{overflow:visible}.climb-jupyter .navbar-expand-lg .navbar-collapse{display:flex!important;flex-basis:auto}.climb-jupyter .navbar-expand-lg .navbar-toggler{display:none}.climb-jupyter .navbar-expand-lg .offcanvas{position:static;z-index:auto;flex-grow:1;width:auto!important;height:auto!important;visibility:visible!important;background-color:transparent!important;border:0!important;transform:none!important;transition:none}.climb-jupyter .navbar-expand-lg .offcanvas .offcanvas-header{display:none}.climb-jupyter .navbar-expand-lg .offcanvas .offcanvas-body{display:flex;flex-grow:0;padding:0;overflow-y:visible}}@media (min-width: 1200px){.climb-jupyter .navbar-expand-xl{flex-wrap:nowrap;justify-content:flex-start}.climb-jupyter .navbar-expand-xl .navbar-nav{flex-direction:row}.climb-jupyter .navbar-expand-xl .navbar-nav .dropdown-menu{position:absolute}.climb-jupyter .navbar-expand-xl .navbar-nav .nav-link{padding-right:var(--bs-navbar-nav-link-padding-x);padding-left:var(--bs-navbar-nav-link-padding-x)}.climb-jupyter .navbar-expand-xl .navbar-nav-scroll{overflow:visible}.climb-jupyter .navbar-expand-xl .navbar-collapse{display:flex!important;flex-basis:auto}.climb-jupyter .navbar-expand-xl .navbar-toggler{display:none}.climb-jupyter .navbar-expand-xl .offcanvas{position:static;z-index:auto;flex-grow:1;width:auto!important;height:auto!important;visibility:visible!important;background-color:transparent!important;border:0!important;transform:none!important;transition:none}.climb-jupyter .navbar-expand-xl .offcanvas .offcanvas-header{display:none}.climb-jupyter .navbar-expand-xl .offcanvas .offcanvas-body{display:flex;flex-grow:0;padding:0;overflow-y:visible}}@media (min-width: 1400px){.climb-jupyter .navbar-expand-xxl{flex-wrap:nowrap;justify-content:flex-start}.climb-jupyter .navbar-expand-xxl .navbar-nav{flex-direction:row}.climb-jupyter .navbar-expand-xxl .navbar-nav .dropdown-menu{position:absolute}.climb-jupyter .navbar-expand-xxl .navbar-nav .nav-link{padding-right:var(--bs-navbar-nav-link-padding-x);padding-left:var(--bs-navbar-nav-link-padding-x)}.climb-jupyter .navbar-expand-xxl .navbar-nav-scroll{overflow:visible}.climb-jupyter .navbar-expand-xxl .navbar-collapse{display:flex!important;flex-basis:auto}.climb-jupyter .navbar-expand-xxl .navbar-toggler{display:none}.climb-jupyter .navbar-expand-xxl .offcanvas{position:static;z-index:auto;flex-grow:1;width:auto!important;height:auto!important;visibility:visible!important;background-color:transparent!important;border:0!important;transform:none!important;transition:none}.climb-jupyter .navbar-expand-xxl .offcanvas .offcanvas-header{display:none}.climb-jupyter .navbar-expand-xxl .offcanvas .offcanvas-body{display:flex;flex-grow:0;padding:0;overflow-y:visible}}.climb-jupyter .navbar-expand{flex-wrap:nowrap;justify-content:flex-start}.climb-jupyter .navbar-expand .navbar-nav{flex-direction:row}.climb-jupyter .navbar-expand .navbar-nav .dropdown-menu{position:absolute}.climb-jupyter .navbar-expand .navbar-nav .nav-link{padding-right:var(--bs-navbar-nav-link-padding-x);padding-left:var(--bs-navbar-nav-link-padding-x)}.climb-jupyter .navbar-expand .navbar-nav-scroll{overflow:visible}.climb-jupyter .navbar-expand .navbar-collapse{display:flex!important;flex-basis:auto}.climb-jupyter .navbar-expand .navbar-toggler{display:none}.climb-jupyter .navbar-expand .offcanvas{position:static;z-index:auto;flex-grow:1;width:auto!important;height:auto!important;visibility:visible!important;background-color:transparent!important;border:0!important;transform:none!important;transition:none}.climb-jupyter .navbar-expand .offcanvas .offcanvas-header{display:none}.climb-jupyter .navbar-expand .offcanvas .offcanvas-body{display:flex;flex-grow:0;padding:0;overflow-y:visible}.climb-jupyter .navbar-dark,.climb-jupyter .navbar[data-bs-theme=dark]{--bs-navbar-color: rgba(255, 255, 255, .55);--bs-navbar-hover-color: rgba(255, 255, 255, .75);--bs-navbar-disabled-color: rgba(255, 255, 255, .25);--bs-navbar-active-color: #fff;--bs-navbar-brand-color: #fff;--bs-navbar-brand-hover-color: #fff;--bs-navbar-toggler-border-color: rgba(255, 255, 255, .1);--bs-navbar-toggler-icon-bg: url(${___CSS_LOADER_URL_REPLACEMENT_13___})}.climb-jupyter [data-bs-theme=dark] .navbar-toggler-icon{--bs-navbar-toggler-icon-bg: url(${___CSS_LOADER_URL_REPLACEMENT_13___})}.climb-jupyter .card{--bs-card-spacer-y: 1rem;--bs-card-spacer-x: 1rem;--bs-card-title-spacer-y: .5rem;--bs-card-title-color: ;--bs-card-subtitle-color: ;--bs-card-border-width: var(--bs-border-width);--bs-card-border-color: var(--bs-border-color-translucent);--bs-card-border-radius: var(--bs-border-radius);--bs-card-box-shadow: ;--bs-card-inner-border-radius: calc(var(--bs-border-radius) - (var(--bs-border-width)));--bs-card-cap-padding-y: .5rem;--bs-card-cap-padding-x: 1rem;--bs-card-cap-bg: rgba(var(--bs-body-color-rgb), .03);--bs-card-cap-color: ;--bs-card-height: ;--bs-card-color: ;--bs-card-bg: var(--bs-body-bg);--bs-card-img-overlay-padding: 1rem;--bs-card-group-margin: .75rem;position:relative;display:flex;flex-direction:column;min-width:0;height:var(--bs-card-height);color:var(--bs-body-color);word-wrap:break-word;background-color:var(--bs-card-bg);background-clip:border-box;border:var(--bs-card-border-width) solid var(--bs-card-border-color);border-radius:var(--bs-card-border-radius)}.climb-jupyter .card>hr{margin-right:0;margin-left:0}.climb-jupyter .card>.list-group{border-top:inherit;border-bottom:inherit}.climb-jupyter .card>.list-group:first-child{border-top-width:0;border-top-left-radius:var(--bs-card-inner-border-radius);border-top-right-radius:var(--bs-card-inner-border-radius)}.climb-jupyter .card>.list-group:last-child{border-bottom-width:0;border-bottom-right-radius:var(--bs-card-inner-border-radius);border-bottom-left-radius:var(--bs-card-inner-border-radius)}.climb-jupyter .card>.card-header+.list-group,.climb-jupyter .card>.list-group+.card-footer{border-top:0}.climb-jupyter .card-body{flex:1 1 auto;padding:var(--bs-card-spacer-y) var(--bs-card-spacer-x);color:var(--bs-card-color)}.climb-jupyter .card-title{margin-bottom:var(--bs-card-title-spacer-y);color:var(--bs-card-title-color)}.climb-jupyter .card-subtitle{margin-top:calc(-.5 * var(--bs-card-title-spacer-y));margin-bottom:0;color:var(--bs-card-subtitle-color)}.climb-jupyter .card-text:last-child{margin-bottom:0}.climb-jupyter .card-link+.card-link{margin-left:var(--bs-card-spacer-x)}.climb-jupyter .card-header{padding:var(--bs-card-cap-padding-y) var(--bs-card-cap-padding-x);margin-bottom:0;color:var(--bs-card-cap-color);background-color:var(--bs-card-cap-bg);border-bottom:var(--bs-card-border-width) solid var(--bs-card-border-color)}.climb-jupyter .card-header:first-child{border-radius:var(--bs-card-inner-border-radius) var(--bs-card-inner-border-radius) 0 0}.climb-jupyter .card-footer{padding:var(--bs-card-cap-padding-y) var(--bs-card-cap-padding-x);color:var(--bs-card-cap-color);background-color:var(--bs-card-cap-bg);border-top:var(--bs-card-border-width) solid var(--bs-card-border-color)}.climb-jupyter .card-footer:last-child{border-radius:0 0 var(--bs-card-inner-border-radius) var(--bs-card-inner-border-radius)}.climb-jupyter .card-header-tabs{margin-right:calc(-.5 * var(--bs-card-cap-padding-x));margin-bottom:calc(-1 * var(--bs-card-cap-padding-y));margin-left:calc(-.5 * var(--bs-card-cap-padding-x));border-bottom:0}.climb-jupyter .card-header-tabs .nav-link.active{background-color:var(--bs-card-bg);border-bottom-color:var(--bs-card-bg)}.climb-jupyter .card-header-pills{margin-right:calc(-.5 * var(--bs-card-cap-padding-x));margin-left:calc(-.5 * var(--bs-card-cap-padding-x))}.climb-jupyter .card-img-overlay{position:absolute;top:0;right:0;bottom:0;left:0;padding:var(--bs-card-img-overlay-padding);border-radius:var(--bs-card-inner-border-radius)}.climb-jupyter .card-img,.climb-jupyter .card-img-top,.climb-jupyter .card-img-bottom{width:100%}.climb-jupyter .card-img,.climb-jupyter .card-img-top{border-top-left-radius:var(--bs-card-inner-border-radius);border-top-right-radius:var(--bs-card-inner-border-radius)}.climb-jupyter .card-img,.climb-jupyter .card-img-bottom{border-bottom-right-radius:var(--bs-card-inner-border-radius);border-bottom-left-radius:var(--bs-card-inner-border-radius)}.climb-jupyter .card-group>.card{margin-bottom:var(--bs-card-group-margin)}@media (min-width: 576px){.climb-jupyter .card-group{display:flex;flex-flow:row wrap}.climb-jupyter .card-group>.card{flex:1 0 0;margin-bottom:0}.climb-jupyter .card-group>.card+.card{margin-left:0;border-left:0}.climb-jupyter .card-group>.card:not(:last-child){border-top-right-radius:0;border-bottom-right-radius:0}.climb-jupyter .card-group>.card:not(:last-child)>.card-img-top,.climb-jupyter .card-group>.card:not(:last-child)>.card-header{border-top-right-radius:0}.climb-jupyter .card-group>.card:not(:last-child)>.card-img-bottom,.climb-jupyter .card-group>.card:not(:last-child)>.card-footer{border-bottom-right-radius:0}.climb-jupyter .card-group>.card:not(:first-child){border-top-left-radius:0;border-bottom-left-radius:0}.climb-jupyter .card-group>.card:not(:first-child)>.card-img-top,.climb-jupyter .card-group>.card:not(:first-child)>.card-header{border-top-left-radius:0}.climb-jupyter .card-group>.card:not(:first-child)>.card-img-bottom,.climb-jupyter .card-group>.card:not(:first-child)>.card-footer{border-bottom-left-radius:0}}.climb-jupyter .accordion{--bs-accordion-color: var(--bs-body-color);--bs-accordion-bg: var(--bs-body-bg);--bs-accordion-transition: color .15s ease-in-out, background-color .15s ease-in-out, border-color .15s ease-in-out, box-shadow .15s ease-in-out, border-radius .15s ease;--bs-accordion-border-color: var(--bs-border-color);--bs-accordion-border-width: var(--bs-border-width);--bs-accordion-border-radius: var(--bs-border-radius);--bs-accordion-inner-border-radius: calc(var(--bs-border-radius) - (var(--bs-border-width)));--bs-accordion-btn-padding-x: 1.25rem;--bs-accordion-btn-padding-y: 1rem;--bs-accordion-btn-color: var(--bs-body-color);--bs-accordion-btn-bg: var(--bs-accordion-bg);--bs-accordion-btn-icon: url(${___CSS_LOADER_URL_REPLACEMENT_14___});--bs-accordion-btn-icon-width: 1.25rem;--bs-accordion-btn-icon-transform: rotate(-180deg);--bs-accordion-btn-icon-transition: transform .2s ease-in-out;--bs-accordion-btn-active-icon: url(${___CSS_LOADER_URL_REPLACEMENT_15___});--bs-accordion-btn-focus-box-shadow: 0 0 0 .25rem rgba(13, 110, 253, .25);--bs-accordion-body-padding-x: 1.25rem;--bs-accordion-body-padding-y: 1rem;--bs-accordion-active-color: var(--bs-primary-text-emphasis);--bs-accordion-active-bg: var(--bs-primary-bg-subtle)}.climb-jupyter .accordion-button{position:relative;display:flex;align-items:center;width:100%;padding:var(--bs-accordion-btn-padding-y) var(--bs-accordion-btn-padding-x);font-size:1rem;color:var(--bs-accordion-btn-color);text-align:left;background-color:var(--bs-accordion-btn-bg);border:0;border-radius:0;overflow-anchor:none;transition:var(--bs-accordion-transition)}@media (prefers-reduced-motion: reduce){.climb-jupyter .accordion-button{transition:none}}.climb-jupyter .accordion-button:not(.collapsed){color:var(--bs-accordion-active-color);background-color:var(--bs-accordion-active-bg);box-shadow:inset 0 calc(-1 * var(--bs-accordion-border-width)) 0 var(--bs-accordion-border-color)}.climb-jupyter .accordion-button:not(.collapsed):after{background-image:var(--bs-accordion-btn-active-icon);transform:var(--bs-accordion-btn-icon-transform)}.climb-jupyter .accordion-button:after{flex-shrink:0;width:var(--bs-accordion-btn-icon-width);height:var(--bs-accordion-btn-icon-width);margin-left:auto;content:"";background-image:var(--bs-accordion-btn-icon);background-repeat:no-repeat;background-size:var(--bs-accordion-btn-icon-width);transition:var(--bs-accordion-btn-icon-transition)}@media (prefers-reduced-motion: reduce){.climb-jupyter .accordion-button:after{transition:none}}.climb-jupyter .accordion-button:hover{z-index:2}.climb-jupyter .accordion-button:focus{z-index:3;outline:0;box-shadow:var(--bs-accordion-btn-focus-box-shadow)}.climb-jupyter .accordion-header{margin-bottom:0}.climb-jupyter .accordion-item{color:var(--bs-accordion-color);background-color:var(--bs-accordion-bg);border:var(--bs-accordion-border-width) solid var(--bs-accordion-border-color)}.climb-jupyter .accordion-item:first-of-type{border-top-left-radius:var(--bs-accordion-border-radius);border-top-right-radius:var(--bs-accordion-border-radius)}.climb-jupyter .accordion-item:first-of-type>.accordion-header .accordion-button{border-top-left-radius:var(--bs-accordion-inner-border-radius);border-top-right-radius:var(--bs-accordion-inner-border-radius)}.climb-jupyter .accordion-item:not(:first-of-type){border-top:0}.climb-jupyter .accordion-item:last-of-type{border-bottom-right-radius:var(--bs-accordion-border-radius);border-bottom-left-radius:var(--bs-accordion-border-radius)}.climb-jupyter .accordion-item:last-of-type>.accordion-header .accordion-button.collapsed{border-bottom-right-radius:var(--bs-accordion-inner-border-radius);border-bottom-left-radius:var(--bs-accordion-inner-border-radius)}.climb-jupyter .accordion-item:last-of-type>.accordion-collapse{border-bottom-right-radius:var(--bs-accordion-border-radius);border-bottom-left-radius:var(--bs-accordion-border-radius)}.climb-jupyter .accordion-body{padding:var(--bs-accordion-body-padding-y) var(--bs-accordion-body-padding-x)}.climb-jupyter .accordion-flush>.accordion-item{border-right:0;border-left:0;border-radius:0}.climb-jupyter .accordion-flush>.accordion-item:first-child{border-top:0}.climb-jupyter .accordion-flush>.accordion-item:last-child{border-bottom:0}.climb-jupyter .accordion-flush>.accordion-item>.accordion-collapse,.climb-jupyter .accordion-flush>.accordion-item>.accordion-header .accordion-button,.climb-jupyter .accordion-flush>.accordion-item>.accordion-header .accordion-button.collapsed{border-radius:0}.climb-jupyter [data-bs-theme=dark] .accordion-button:after{--bs-accordion-btn-icon: url(${___CSS_LOADER_URL_REPLACEMENT_16___});--bs-accordion-btn-active-icon: url(${___CSS_LOADER_URL_REPLACEMENT_16___})}.climb-jupyter .pagination{--bs-pagination-padding-x: .75rem;--bs-pagination-padding-y: .375rem;--bs-pagination-font-size: 1rem;--bs-pagination-color: var(--bs-link-color);--bs-pagination-bg: var(--bs-body-bg);--bs-pagination-border-width: var(--bs-border-width);--bs-pagination-border-color: var(--bs-border-color);--bs-pagination-border-radius: var(--bs-border-radius);--bs-pagination-hover-color: var(--bs-link-hover-color);--bs-pagination-hover-bg: var(--bs-tertiary-bg);--bs-pagination-hover-border-color: var(--bs-border-color);--bs-pagination-focus-color: var(--bs-link-hover-color);--bs-pagination-focus-bg: var(--bs-secondary-bg);--bs-pagination-focus-box-shadow: 0 0 0 .25rem rgba(13, 110, 253, .25);--bs-pagination-active-color: #fff;--bs-pagination-active-bg: #0d6efd;--bs-pagination-active-border-color: #0d6efd;--bs-pagination-disabled-color: var(--bs-secondary-color);--bs-pagination-disabled-bg: var(--bs-secondary-bg);--bs-pagination-disabled-border-color: var(--bs-border-color);display:flex;padding-left:0;list-style:none}.climb-jupyter .page-link{position:relative;display:block;padding:var(--bs-pagination-padding-y) var(--bs-pagination-padding-x);font-size:var(--bs-pagination-font-size);color:var(--bs-pagination-color);text-decoration:none;background-color:var(--bs-pagination-bg);border:var(--bs-pagination-border-width) solid var(--bs-pagination-border-color);transition:color .15s ease-in-out,background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out}@media (prefers-reduced-motion: reduce){.climb-jupyter .page-link{transition:none}}.climb-jupyter .page-link:hover{z-index:2;color:var(--bs-pagination-hover-color);background-color:var(--bs-pagination-hover-bg);border-color:var(--bs-pagination-hover-border-color)}.climb-jupyter .page-link:focus{z-index:3;color:var(--bs-pagination-focus-color);background-color:var(--bs-pagination-focus-bg);outline:0;box-shadow:var(--bs-pagination-focus-box-shadow)}.climb-jupyter .page-link.active,.active>.climb-jupyter .page-link{z-index:3;color:var(--bs-pagination-active-color);background-color:var(--bs-pagination-active-bg);border-color:var(--bs-pagination-active-border-color)}.climb-jupyter .page-link.disabled,.disabled>.climb-jupyter .page-link{color:var(--bs-pagination-disabled-color);pointer-events:none;background-color:var(--bs-pagination-disabled-bg);border-color:var(--bs-pagination-disabled-border-color)}.climb-jupyter .page-item:not(:first-child) .page-link{margin-left:calc(-1 * var(--bs-border-width))}.climb-jupyter .page-item:first-child .page-link{border-top-left-radius:var(--bs-pagination-border-radius);border-bottom-left-radius:var(--bs-pagination-border-radius)}.climb-jupyter .page-item:last-child .page-link{border-top-right-radius:var(--bs-pagination-border-radius);border-bottom-right-radius:var(--bs-pagination-border-radius)}.climb-jupyter .pagination-lg{--bs-pagination-padding-x: 1.5rem;--bs-pagination-padding-y: .75rem;--bs-pagination-font-size: 1.25rem;--bs-pagination-border-radius: var(--bs-border-radius-lg)}.climb-jupyter .pagination-sm{--bs-pagination-padding-x: .5rem;--bs-pagination-padding-y: .25rem;--bs-pagination-font-size: .875rem;--bs-pagination-border-radius: var(--bs-border-radius-sm)}.climb-jupyter .badge{--bs-badge-padding-x: .65em;--bs-badge-padding-y: .35em;--bs-badge-font-size: .75em;--bs-badge-font-weight: 700;--bs-badge-color: #fff;--bs-badge-border-radius: var(--bs-border-radius);display:inline-block;padding:var(--bs-badge-padding-y) var(--bs-badge-padding-x);font-size:var(--bs-badge-font-size);font-weight:var(--bs-badge-font-weight);line-height:1;color:var(--bs-badge-color);text-align:center;white-space:nowrap;vertical-align:baseline;border-radius:var(--bs-badge-border-radius)}.climb-jupyter .badge:empty{display:none}.climb-jupyter .btn .badge{position:relative;top:-1px}.climb-jupyter .alert{--bs-alert-bg: transparent;--bs-alert-padding-x: 1rem;--bs-alert-padding-y: 1rem;--bs-alert-margin-bottom: 1rem;--bs-alert-color: inherit;--bs-alert-border-color: transparent;--bs-alert-border: var(--bs-border-width) solid var(--bs-alert-border-color);--bs-alert-border-radius: var(--bs-border-radius);--bs-alert-link-color: inherit;position:relative;padding:var(--bs-alert-padding-y) var(--bs-alert-padding-x);margin-bottom:var(--bs-alert-margin-bottom);color:var(--bs-alert-color);background-color:var(--bs-alert-bg);border:var(--bs-alert-border);border-radius:var(--bs-alert-border-radius)}.climb-jupyter .alert-heading{color:inherit}.climb-jupyter .alert-link{font-weight:700;color:var(--bs-alert-link-color)}.climb-jupyter .alert-dismissible{padding-right:3rem}.climb-jupyter .alert-dismissible .btn-close{position:absolute;top:0;right:0;z-index:2;padding:1.25rem 1rem}.climb-jupyter .alert-primary{--bs-alert-color: var(--bs-primary-text-emphasis);--bs-alert-bg: var(--bs-primary-bg-subtle);--bs-alert-border-color: var(--bs-primary-border-subtle);--bs-alert-link-color: var(--bs-primary-text-emphasis)}.climb-jupyter .alert-secondary{--bs-alert-color: var(--bs-secondary-text-emphasis);--bs-alert-bg: var(--bs-secondary-bg-subtle);--bs-alert-border-color: var(--bs-secondary-border-subtle);--bs-alert-link-color: var(--bs-secondary-text-emphasis)}.climb-jupyter .alert-success{--bs-alert-color: var(--bs-success-text-emphasis);--bs-alert-bg: var(--bs-success-bg-subtle);--bs-alert-border-color: var(--bs-success-border-subtle);--bs-alert-link-color: var(--bs-success-text-emphasis)}.climb-jupyter .alert-info{--bs-alert-color: var(--bs-info-text-emphasis);--bs-alert-bg: var(--bs-info-bg-subtle);--bs-alert-border-color: var(--bs-info-border-subtle);--bs-alert-link-color: var(--bs-info-text-emphasis)}.climb-jupyter .alert-warning{--bs-alert-color: var(--bs-warning-text-emphasis);--bs-alert-bg: var(--bs-warning-bg-subtle);--bs-alert-border-color: var(--bs-warning-border-subtle);--bs-alert-link-color: var(--bs-warning-text-emphasis)}.climb-jupyter .alert-danger{--bs-alert-color: var(--bs-danger-text-emphasis);--bs-alert-bg: var(--bs-danger-bg-subtle);--bs-alert-border-color: var(--bs-danger-border-subtle);--bs-alert-link-color: var(--bs-danger-text-emphasis)}.climb-jupyter .alert-light{--bs-alert-color: var(--bs-light-text-emphasis);--bs-alert-bg: var(--bs-light-bg-subtle);--bs-alert-border-color: var(--bs-light-border-subtle);--bs-alert-link-color: var(--bs-light-text-emphasis)}.climb-jupyter .alert-dark{--bs-alert-color: var(--bs-dark-text-emphasis);--bs-alert-bg: var(--bs-dark-bg-subtle);--bs-alert-border-color: var(--bs-dark-border-subtle);--bs-alert-link-color: var(--bs-dark-text-emphasis)}@keyframes progress-bar-stripes{0%{background-position-x:var(--bs-progress-height)}}.climb-jupyter .progress,.climb-jupyter .progress-stacked{--bs-progress-height: 1rem;--bs-progress-font-size: .75rem;--bs-progress-bg: var(--bs-secondary-bg);--bs-progress-border-radius: var(--bs-border-radius);--bs-progress-box-shadow: var(--bs-box-shadow-inset);--bs-progress-bar-color: #fff;--bs-progress-bar-bg: #0d6efd;--bs-progress-bar-transition: width .6s ease;display:flex;height:var(--bs-progress-height);overflow:hidden;font-size:var(--bs-progress-font-size);background-color:var(--bs-progress-bg);border-radius:var(--bs-progress-border-radius)}.climb-jupyter .progress-bar{display:flex;flex-direction:column;justify-content:center;overflow:hidden;color:var(--bs-progress-bar-color);text-align:center;white-space:nowrap;background-color:var(--bs-progress-bar-bg);transition:var(--bs-progress-bar-transition)}@media (prefers-reduced-motion: reduce){.climb-jupyter .progress-bar{transition:none}}.climb-jupyter .progress-bar-striped{background-image:linear-gradient(45deg,rgba(255,255,255,.15) 25%,transparent 25%,transparent 50%,rgba(255,255,255,.15) 50%,rgba(255,255,255,.15) 75%,transparent 75%,transparent);background-size:var(--bs-progress-height) var(--bs-progress-height)}.climb-jupyter .progress-stacked>.progress{overflow:visible}.climb-jupyter .progress-stacked>.progress>.progress-bar{width:100%}.climb-jupyter .progress-bar-animated{animation:1s linear infinite progress-bar-stripes}@media (prefers-reduced-motion: reduce){.climb-jupyter .progress-bar-animated{animation:none}}.climb-jupyter .modal{--bs-modal-zindex: 1055;--bs-modal-width: 500px;--bs-modal-padding: 1rem;--bs-modal-margin: .5rem;--bs-modal-color: var(--bs-body-color);--bs-modal-bg: var(--bs-body-bg);--bs-modal-border-color: var(--bs-border-color-translucent);--bs-modal-border-width: var(--bs-border-width);--bs-modal-border-radius: var(--bs-border-radius-lg);--bs-modal-box-shadow: var(--bs-box-shadow-sm);--bs-modal-inner-border-radius: calc(var(--bs-border-radius-lg) - (var(--bs-border-width)));--bs-modal-header-padding-x: 1rem;--bs-modal-header-padding-y: 1rem;--bs-modal-header-padding: 1rem 1rem;--bs-modal-header-border-color: var(--bs-border-color);--bs-modal-header-border-width: var(--bs-border-width);--bs-modal-title-line-height: 1.5;--bs-modal-footer-gap: .5rem;--bs-modal-footer-bg: ;--bs-modal-footer-border-color: var(--bs-border-color);--bs-modal-footer-border-width: var(--bs-border-width);position:fixed;top:0;left:0;z-index:var(--bs-modal-zindex);display:none;width:100%;height:100%;overflow-x:hidden;overflow-y:auto;outline:0}.climb-jupyter .modal-dialog{position:relative;width:auto;margin:var(--bs-modal-margin);pointer-events:none}.modal.fade .climb-jupyter .modal-dialog{transform:translateY(-50px);transition:transform .3s ease-out}@media (prefers-reduced-motion: reduce){.modal.fade .climb-jupyter .modal-dialog{transition:none}}.modal.show .climb-jupyter .modal-dialog{transform:none}.modal.modal-static .climb-jupyter .modal-dialog{transform:scale(1.02)}.climb-jupyter .modal-dialog-scrollable{height:calc(100% - var(--bs-modal-margin) * 2)}.climb-jupyter .modal-dialog-scrollable .modal-content{max-height:100%;overflow:hidden}.climb-jupyter .modal-dialog-scrollable .modal-body{overflow-y:auto}.climb-jupyter .modal-dialog-centered{display:flex;align-items:center;min-height:calc(100% - var(--bs-modal-margin) * 2)}.climb-jupyter .modal-content{position:relative;display:flex;flex-direction:column;width:100%;color:var(--bs-modal-color);pointer-events:auto;background-color:var(--bs-modal-bg);background-clip:padding-box;border:var(--bs-modal-border-width) solid var(--bs-modal-border-color);border-radius:var(--bs-modal-border-radius);outline:0}.climb-jupyter .modal-backdrop{--bs-backdrop-zindex: 1050;--bs-backdrop-bg: #000;--bs-backdrop-opacity: .5;position:fixed;top:0;left:0;z-index:var(--bs-backdrop-zindex);width:100vw;height:100vh;background-color:var(--bs-backdrop-bg)}.climb-jupyter .modal-backdrop.fade{opacity:0}.climb-jupyter .modal-backdrop.show{opacity:var(--bs-backdrop-opacity)}.climb-jupyter .modal-header{display:flex;flex-shrink:0;align-items:center;padding:var(--bs-modal-header-padding);border-bottom:var(--bs-modal-header-border-width) solid var(--bs-modal-header-border-color);border-top-left-radius:var(--bs-modal-inner-border-radius);border-top-right-radius:var(--bs-modal-inner-border-radius)}.climb-jupyter .modal-header .btn-close{padding:calc(var(--bs-modal-header-padding-y) * .5) calc(var(--bs-modal-header-padding-x) * .5);margin-top:calc(-.5 * var(--bs-modal-header-padding-y));margin-right:calc(-.5 * var(--bs-modal-header-padding-x));margin-bottom:calc(-.5 * var(--bs-modal-header-padding-y));margin-left:auto}.climb-jupyter .modal-title{margin-bottom:0;line-height:var(--bs-modal-title-line-height)}.climb-jupyter .modal-body{position:relative;flex:1 1 auto;padding:var(--bs-modal-padding)}.climb-jupyter .modal-footer{display:flex;flex-shrink:0;flex-wrap:wrap;align-items:center;justify-content:flex-end;padding:calc(var(--bs-modal-padding) - var(--bs-modal-footer-gap) * .5);background-color:var(--bs-modal-footer-bg);border-top:var(--bs-modal-footer-border-width) solid var(--bs-modal-footer-border-color);border-bottom-right-radius:var(--bs-modal-inner-border-radius);border-bottom-left-radius:var(--bs-modal-inner-border-radius)}.climb-jupyter .modal-footer>*{margin:calc(var(--bs-modal-footer-gap) * .5)}@media (min-width: 576px){.climb-jupyter .modal{--bs-modal-margin: 1.75rem;--bs-modal-box-shadow: var(--bs-box-shadow)}.climb-jupyter .modal-dialog{max-width:var(--bs-modal-width);margin-right:auto;margin-left:auto}.climb-jupyter .modal-sm{--bs-modal-width: 300px}}@media (min-width: 992px){.climb-jupyter .modal-lg,.climb-jupyter .modal-xl{--bs-modal-width: 800px}}@media (min-width: 1200px){.climb-jupyter .modal-xl{--bs-modal-width: 1140px}}.climb-jupyter .modal-fullscreen{width:100vw;max-width:none;height:100%;margin:0}.climb-jupyter .modal-fullscreen .modal-content{height:100%;border:0;border-radius:0}.climb-jupyter .modal-fullscreen .modal-header,.climb-jupyter .modal-fullscreen .modal-footer{border-radius:0}.climb-jupyter .modal-fullscreen .modal-body{overflow-y:auto}@media (max-width: 575.98px){.climb-jupyter .modal-fullscreen-sm-down{width:100vw;max-width:none;height:100%;margin:0}.climb-jupyter .modal-fullscreen-sm-down .modal-content{height:100%;border:0;border-radius:0}.climb-jupyter .modal-fullscreen-sm-down .modal-header,.climb-jupyter .modal-fullscreen-sm-down .modal-footer{border-radius:0}.climb-jupyter .modal-fullscreen-sm-down .modal-body{overflow-y:auto}}@media (max-width: 767.98px){.climb-jupyter .modal-fullscreen-md-down{width:100vw;max-width:none;height:100%;margin:0}.climb-jupyter .modal-fullscreen-md-down .modal-content{height:100%;border:0;border-radius:0}.climb-jupyter .modal-fullscreen-md-down .modal-header,.climb-jupyter .modal-fullscreen-md-down .modal-footer{border-radius:0}.climb-jupyter .modal-fullscreen-md-down .modal-body{overflow-y:auto}}@media (max-width: 991.98px){.climb-jupyter .modal-fullscreen-lg-down{width:100vw;max-width:none;height:100%;margin:0}.climb-jupyter .modal-fullscreen-lg-down .modal-content{height:100%;border:0;border-radius:0}.climb-jupyter .modal-fullscreen-lg-down .modal-header,.climb-jupyter .modal-fullscreen-lg-down .modal-footer{border-radius:0}.climb-jupyter .modal-fullscreen-lg-down .modal-body{overflow-y:auto}}@media (max-width: 1199.98px){.climb-jupyter .modal-fullscreen-xl-down{width:100vw;max-width:none;height:100%;margin:0}.climb-jupyter .modal-fullscreen-xl-down .modal-content{height:100%;border:0;border-radius:0}.climb-jupyter .modal-fullscreen-xl-down .modal-header,.climb-jupyter .modal-fullscreen-xl-down .modal-footer{border-radius:0}.climb-jupyter .modal-fullscreen-xl-down .modal-body{overflow-y:auto}}@media (max-width: 1399.98px){.climb-jupyter .modal-fullscreen-xxl-down{width:100vw;max-width:none;height:100%;margin:0}.climb-jupyter .modal-fullscreen-xxl-down .modal-content{height:100%;border:0;border-radius:0}.climb-jupyter .modal-fullscreen-xxl-down .modal-header,.climb-jupyter .modal-fullscreen-xxl-down .modal-footer{border-radius:0}.climb-jupyter .modal-fullscreen-xxl-down .modal-body{overflow-y:auto}}.climb-jupyter .spinner-grow,.climb-jupyter .spinner-border{display:inline-block;flex-shrink:0;width:var(--bs-spinner-width);height:var(--bs-spinner-height);vertical-align:var(--bs-spinner-vertical-align);border-radius:50%;animation:var(--bs-spinner-animation-speed) linear infinite var(--bs-spinner-animation-name)}@keyframes spinner-border{to{transform:rotate(360deg)}}.climb-jupyter .spinner-border{--bs-spinner-width: 2rem;--bs-spinner-height: 2rem;--bs-spinner-vertical-align: -.125em;--bs-spinner-border-width: .25em;--bs-spinner-animation-speed: .75s;--bs-spinner-animation-name: spinner-border;border:var(--bs-spinner-border-width) solid currentcolor;border-right-color:transparent}.climb-jupyter .spinner-border-sm{--bs-spinner-width: 1rem;--bs-spinner-height: 1rem;--bs-spinner-border-width: .2em}@keyframes spinner-grow{0%{transform:scale(0)}50%{opacity:1;transform:none}}.climb-jupyter .spinner-grow{--bs-spinner-width: 2rem;--bs-spinner-height: 2rem;--bs-spinner-vertical-align: -.125em;--bs-spinner-animation-speed: .75s;--bs-spinner-animation-name: spinner-grow;background-color:currentcolor;opacity:0}.climb-jupyter .spinner-grow-sm{--bs-spinner-width: 1rem;--bs-spinner-height: 1rem}@media (prefers-reduced-motion: reduce){.climb-jupyter .spinner-border,.climb-jupyter .spinner-grow{--bs-spinner-animation-speed: 1.5s}}.climb-jupyter .page-item.disabled .page-link{color:var(--bs-pagination-disabled-color)!important;pointer-events:none!important;background-color:var(--bs-pagination-disabled-bg)!important;border-color:var(--bs-pagination-disabled-border-color)!important}.climb-jupyter .modal-backdrop{position:fixed;top:0;left:0;width:100%;height:100%}.climb-jupyter{font-family:var(--bs-body-font-family);font-size:var(--bs-body-font-size);font-weight:var(--bs-body-font-weight);line-height:var(--bs-body-line-height);color:var(--bs-body-color);text-align:var(--bs-body-text-align);background-color:var(--bs-body-bg);-webkit-text-size-adjust:100%;-webkit-tap-highlight-color:rgba(0,0,0,0);display:flex;flex-direction:column;height:100%}.clearfix:after{display:block;clear:both;content:""}.text-bg-primary{color:#fff!important;background-color:RGBA(var(--bs-primary-rgb),var(--bs-bg-opacity, 1))!important}.text-bg-secondary{color:#fff!important;background-color:RGBA(var(--bs-secondary-rgb),var(--bs-bg-opacity, 1))!important}.text-bg-success{color:#fff!important;background-color:RGBA(var(--bs-success-rgb),var(--bs-bg-opacity, 1))!important}.text-bg-info{color:#000!important;background-color:RGBA(var(--bs-info-rgb),var(--bs-bg-opacity, 1))!important}.text-bg-warning{color:#000!important;background-color:RGBA(var(--bs-warning-rgb),var(--bs-bg-opacity, 1))!important}.text-bg-danger{color:#fff!important;background-color:RGBA(var(--bs-danger-rgb),var(--bs-bg-opacity, 1))!important}.text-bg-light{color:#000!important;background-color:RGBA(var(--bs-light-rgb),var(--bs-bg-opacity, 1))!important}.text-bg-dark{color:#fff!important;background-color:RGBA(var(--bs-dark-rgb),var(--bs-bg-opacity, 1))!important}.link-primary{color:RGBA(var(--bs-primary-rgb),var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(var(--bs-primary-rgb),var(--bs-link-underline-opacity, 1))!important}.link-primary:hover,.link-primary:focus{color:RGBA(10,88,202,var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(10,88,202,var(--bs-link-underline-opacity, 1))!important}.link-secondary{color:RGBA(var(--bs-secondary-rgb),var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(var(--bs-secondary-rgb),var(--bs-link-underline-opacity, 1))!important}.link-secondary:hover,.link-secondary:focus{color:RGBA(86,94,100,var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(86,94,100,var(--bs-link-underline-opacity, 1))!important}.link-success{color:RGBA(var(--bs-success-rgb),var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(var(--bs-success-rgb),var(--bs-link-underline-opacity, 1))!important}.link-success:hover,.link-success:focus{color:RGBA(20,108,67,var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(20,108,67,var(--bs-link-underline-opacity, 1))!important}.link-info{color:RGBA(var(--bs-info-rgb),var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(var(--bs-info-rgb),var(--bs-link-underline-opacity, 1))!important}.link-info:hover,.link-info:focus{color:RGBA(61,213,243,var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(61,213,243,var(--bs-link-underline-opacity, 1))!important}.link-warning{color:RGBA(var(--bs-warning-rgb),var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(var(--bs-warning-rgb),var(--bs-link-underline-opacity, 1))!important}.link-warning:hover,.link-warning:focus{color:RGBA(255,205,57,var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(255,205,57,var(--bs-link-underline-opacity, 1))!important}.link-danger{color:RGBA(var(--bs-danger-rgb),var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(var(--bs-danger-rgb),var(--bs-link-underline-opacity, 1))!important}.link-danger:hover,.link-danger:focus{color:RGBA(176,42,55,var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(176,42,55,var(--bs-link-underline-opacity, 1))!important}.link-light{color:RGBA(var(--bs-light-rgb),var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(var(--bs-light-rgb),var(--bs-link-underline-opacity, 1))!important}.link-light:hover,.link-light:focus{color:RGBA(249,250,251,var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(249,250,251,var(--bs-link-underline-opacity, 1))!important}.link-dark{color:RGBA(var(--bs-dark-rgb),var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(var(--bs-dark-rgb),var(--bs-link-underline-opacity, 1))!important}.link-dark:hover,.link-dark:focus{color:RGBA(26,30,33,var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(26,30,33,var(--bs-link-underline-opacity, 1))!important}.link-body-emphasis{color:RGBA(var(--bs-emphasis-color-rgb),var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(var(--bs-emphasis-color-rgb),var(--bs-link-underline-opacity, 1))!important}.link-body-emphasis:hover,.link-body-emphasis:focus{color:RGBA(var(--bs-emphasis-color-rgb),var(--bs-link-opacity, .75))!important;text-decoration-color:RGBA(var(--bs-emphasis-color-rgb),var(--bs-link-underline-opacity, .75))!important}.focus-ring:focus{outline:0;box-shadow:var(--bs-focus-ring-x, 0) var(--bs-focus-ring-y, 0) var(--bs-focus-ring-blur, 0) var(--bs-focus-ring-width) var(--bs-focus-ring-color)}.icon-link{display:inline-flex;gap:.375rem;align-items:center;text-decoration-color:rgba(var(--bs-link-color-rgb),var(--bs-link-opacity, .5));text-underline-offset:.25em;backface-visibility:hidden}.icon-link>.bi{flex-shrink:0;width:1em;height:1em;fill:currentcolor;transition:.2s ease-in-out transform}@media (prefers-reduced-motion: reduce){.icon-link>.bi{transition:none}}.icon-link-hover:hover>.bi,.icon-link-hover:focus-visible>.bi{transform:var(--bs-icon-link-transform, translate3d(.25em, 0, 0))}.ratio{position:relative;width:100%}.ratio:before{display:block;padding-top:var(--bs-aspect-ratio);content:""}.ratio>*{position:absolute;top:0;left:0;width:100%;height:100%}.ratio-1x1{--bs-aspect-ratio: 100%}.ratio-4x3{--bs-aspect-ratio: 75%}.ratio-16x9{--bs-aspect-ratio: 56.25%}.ratio-21x9{--bs-aspect-ratio: 42.8571428571%}.fixed-top{position:fixed;top:0;right:0;left:0;z-index:1030}.fixed-bottom{position:fixed;right:0;bottom:0;left:0;z-index:1030}.sticky-top{position:sticky;top:0;z-index:1020}.sticky-bottom{position:sticky;bottom:0;z-index:1020}@media (min-width: 576px){.sticky-sm-top{position:sticky;top:0;z-index:1020}.sticky-sm-bottom{position:sticky;bottom:0;z-index:1020}}@media (min-width: 768px){.sticky-md-top{position:sticky;top:0;z-index:1020}.sticky-md-bottom{position:sticky;bottom:0;z-index:1020}}@media (min-width: 992px){.sticky-lg-top{position:sticky;top:0;z-index:1020}.sticky-lg-bottom{position:sticky;bottom:0;z-index:1020}}@media (min-width: 1200px){.sticky-xl-top{position:sticky;top:0;z-index:1020}.sticky-xl-bottom{position:sticky;bottom:0;z-index:1020}}@media (min-width: 1400px){.sticky-xxl-top{position:sticky;top:0;z-index:1020}.sticky-xxl-bottom{position:sticky;bottom:0;z-index:1020}}.hstack{display:flex;flex-direction:row;align-items:center;align-self:stretch}.vstack{display:flex;flex:1 1 auto;flex-direction:column;align-self:stretch}.visually-hidden,.visually-hidden-focusable:not(:focus):not(:focus-within){width:1px!important;height:1px!important;padding:0!important;margin:-1px!important;overflow:hidden!important;clip:rect(0,0,0,0)!important;white-space:nowrap!important;border:0!important}.visually-hidden:not(caption),.visually-hidden-focusable:not(:focus):not(:focus-within):not(caption){position:absolute!important}.visually-hidden *,.visually-hidden-focusable:not(:focus):not(:focus-within) *{overflow:hidden!important}.stretched-link:after{position:absolute;top:0;right:0;bottom:0;left:0;z-index:1;content:""}.text-truncate{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.vr{display:inline-block;align-self:stretch;width:var(--bs-border-width);min-height:1em;background-color:currentcolor;opacity:.25}.align-baseline{vertical-align:baseline!important}.align-top{vertical-align:top!important}.align-middle{vertical-align:middle!important}.align-bottom{vertical-align:bottom!important}.align-text-bottom{vertical-align:text-bottom!important}.align-text-top{vertical-align:text-top!important}.float-start{float:left!important}.float-end{float:right!important}.float-none{float:none!important}.object-fit-contain{object-fit:contain!important}.object-fit-cover{object-fit:cover!important}.object-fit-fill{object-fit:fill!important}.object-fit-scale{object-fit:scale-down!important}.object-fit-none{object-fit:none!important}.opacity-0{opacity:0!important}.opacity-25{opacity:.25!important}.opacity-50{opacity:.5!important}.opacity-75{opacity:.75!important}.opacity-100{opacity:1!important}.overflow-auto{overflow:auto!important}.overflow-hidden{overflow:hidden!important}.overflow-visible{overflow:visible!important}.overflow-scroll{overflow:scroll!important}.overflow-x-auto{overflow-x:auto!important}.overflow-x-hidden{overflow-x:hidden!important}.overflow-x-visible{overflow-x:visible!important}.overflow-x-scroll{overflow-x:scroll!important}.overflow-y-auto{overflow-y:auto!important}.overflow-y-hidden{overflow-y:hidden!important}.overflow-y-visible{overflow-y:visible!important}.overflow-y-scroll{overflow-y:scroll!important}.d-inline{display:inline!important}.d-inline-block{display:inline-block!important}.d-block{display:block!important}.d-grid{display:grid!important}.d-inline-grid{display:inline-grid!important}.d-table{display:table!important}.d-table-row{display:table-row!important}.d-table-cell{display:table-cell!important}.d-flex{display:flex!important}.d-inline-flex{display:inline-flex!important}.d-none{display:none!important}.shadow{box-shadow:var(--bs-box-shadow)!important}.shadow-sm{box-shadow:var(--bs-box-shadow-sm)!important}.shadow-lg{box-shadow:var(--bs-box-shadow-lg)!important}.shadow-none{box-shadow:none!important}.focus-ring-primary{--bs-focus-ring-color: rgba(var(--bs-primary-rgb), var(--bs-focus-ring-opacity))}.focus-ring-secondary{--bs-focus-ring-color: rgba(var(--bs-secondary-rgb), var(--bs-focus-ring-opacity))}.focus-ring-success{--bs-focus-ring-color: rgba(var(--bs-success-rgb), var(--bs-focus-ring-opacity))}.focus-ring-info{--bs-focus-ring-color: rgba(var(--bs-info-rgb), var(--bs-focus-ring-opacity))}.focus-ring-warning{--bs-focus-ring-color: rgba(var(--bs-warning-rgb), var(--bs-focus-ring-opacity))}.focus-ring-danger{--bs-focus-ring-color: rgba(var(--bs-danger-rgb), var(--bs-focus-ring-opacity))}.focus-ring-light{--bs-focus-ring-color: rgba(var(--bs-light-rgb), var(--bs-focus-ring-opacity))}.focus-ring-dark{--bs-focus-ring-color: rgba(var(--bs-dark-rgb), var(--bs-focus-ring-opacity))}.position-static{position:static!important}.position-relative{position:relative!important}.position-absolute{position:absolute!important}.position-fixed{position:fixed!important}.position-sticky{position:sticky!important}.top-0{top:0!important}.top-50{top:50%!important}.top-100{top:100%!important}.bottom-0{bottom:0!important}.bottom-50{bottom:50%!important}.bottom-100{bottom:100%!important}.start-0{left:0!important}.start-50{left:50%!important}.start-100{left:100%!important}.end-0{right:0!important}.end-50{right:50%!important}.end-100{right:100%!important}.translate-middle{transform:translate(-50%,-50%)!important}.translate-middle-x{transform:translate(-50%)!important}.translate-middle-y{transform:translateY(-50%)!important}.border{border:var(--bs-border-width) var(--bs-border-style) var(--bs-border-color)!important}.border-0{border:0!important}.border-top{border-top:var(--bs-border-width) var(--bs-border-style) var(--bs-border-color)!important}.border-top-0{border-top:0!important}.border-end{border-right:var(--bs-border-width) var(--bs-border-style) var(--bs-border-color)!important}.border-end-0{border-right:0!important}.border-bottom{border-bottom:var(--bs-border-width) var(--bs-border-style) var(--bs-border-color)!important}.border-bottom-0{border-bottom:0!important}.border-start{border-left:var(--bs-border-width) var(--bs-border-style) var(--bs-border-color)!important}.border-start-0{border-left:0!important}.border-primary{--bs-border-opacity: 1;border-color:rgba(var(--bs-primary-rgb),var(--bs-border-opacity))!important}.border-secondary{--bs-border-opacity: 1;border-color:rgba(var(--bs-secondary-rgb),var(--bs-border-opacity))!important}.border-success{--bs-border-opacity: 1;border-color:rgba(var(--bs-success-rgb),var(--bs-border-opacity))!important}.border-info{--bs-border-opacity: 1;border-color:rgba(var(--bs-info-rgb),var(--bs-border-opacity))!important}.border-warning{--bs-border-opacity: 1;border-color:rgba(var(--bs-warning-rgb),var(--bs-border-opacity))!important}.border-danger{--bs-border-opacity: 1;border-color:rgba(var(--bs-danger-rgb),var(--bs-border-opacity))!important}.border-light{--bs-border-opacity: 1;border-color:rgba(var(--bs-light-rgb),var(--bs-border-opacity))!important}.border-dark{--bs-border-opacity: 1;border-color:rgba(var(--bs-dark-rgb),var(--bs-border-opacity))!important}.border-black{--bs-border-opacity: 1;border-color:rgba(var(--bs-black-rgb),var(--bs-border-opacity))!important}.border-white{--bs-border-opacity: 1;border-color:rgba(var(--bs-white-rgb),var(--bs-border-opacity))!important}.border-primary-subtle{border-color:var(--bs-primary-border-subtle)!important}.border-secondary-subtle{border-color:var(--bs-secondary-border-subtle)!important}.border-success-subtle{border-color:var(--bs-success-border-subtle)!important}.border-info-subtle{border-color:var(--bs-info-border-subtle)!important}.border-warning-subtle{border-color:var(--bs-warning-border-subtle)!important}.border-danger-subtle{border-color:var(--bs-danger-border-subtle)!important}.border-light-subtle{border-color:var(--bs-light-border-subtle)!important}.border-dark-subtle{border-color:var(--bs-dark-border-subtle)!important}.border-1{border-width:1px!important}.border-2{border-width:2px!important}.border-3{border-width:3px!important}.border-4{border-width:4px!important}.border-5{border-width:5px!important}.border-opacity-10{--bs-border-opacity: .1}.border-opacity-25{--bs-border-opacity: .25}.border-opacity-50{--bs-border-opacity: .5}.border-opacity-75{--bs-border-opacity: .75}.border-opacity-100{--bs-border-opacity: 1}.w-25{width:25%!important}.w-50{width:50%!important}.w-75{width:75%!important}.w-100{width:100%!important}.w-auto{width:auto!important}.mw-100{max-width:100%!important}.vw-100{width:100vw!important}.min-vw-100{min-width:100vw!important}.h-25{height:25%!important}.h-50{height:50%!important}.h-75{height:75%!important}.h-100{height:100%!important}.h-auto{height:auto!important}.mh-100{max-height:100%!important}.vh-100{height:100vh!important}.min-vh-100{min-height:100vh!important}.flex-fill{flex:1 1 auto!important}.flex-row{flex-direction:row!important}.flex-column{flex-direction:column!important}.flex-row-reverse{flex-direction:row-reverse!important}.flex-column-reverse{flex-direction:column-reverse!important}.flex-grow-0{flex-grow:0!important}.flex-grow-1{flex-grow:1!important}.flex-shrink-0{flex-shrink:0!important}.flex-shrink-1{flex-shrink:1!important}.flex-wrap{flex-wrap:wrap!important}.flex-nowrap{flex-wrap:nowrap!important}.flex-wrap-reverse{flex-wrap:wrap-reverse!important}.justify-content-start{justify-content:flex-start!important}.justify-content-end{justify-content:flex-end!important}.justify-content-center{justify-content:center!important}.justify-content-between{justify-content:space-between!important}.justify-content-around{justify-content:space-around!important}.justify-content-evenly{justify-content:space-evenly!important}.align-items-start{align-items:flex-start!important}.align-items-end{align-items:flex-end!important}.align-items-center{align-items:center!important}.align-items-baseline{align-items:baseline!important}.align-items-stretch{align-items:stretch!important}.align-content-start{align-content:flex-start!important}.align-content-end{align-content:flex-end!important}.align-content-center{align-content:center!important}.align-content-between{align-content:space-between!important}.align-content-around{align-content:space-around!important}.align-content-stretch{align-content:stretch!important}.align-self-auto{align-self:auto!important}.align-self-start{align-self:flex-start!important}.align-self-end{align-self:flex-end!important}.align-self-center{align-self:center!important}.align-self-baseline{align-self:baseline!important}.align-self-stretch{align-self:stretch!important}.order-first{order:-1!important}.order-0{order:0!important}.order-1{order:1!important}.order-2{order:2!important}.order-3{order:3!important}.order-4{order:4!important}.order-5{order:5!important}.order-last{order:6!important}.m-0{margin:0!important}.m-1{margin:.25rem!important}.m-2{margin:.5rem!important}.m-3{margin:1rem!important}.m-4{margin:1.5rem!important}.m-5{margin:3rem!important}.m-auto{margin:auto!important}.mx-0{margin-right:0!important;margin-left:0!important}.mx-1{margin-right:.25rem!important;margin-left:.25rem!important}.mx-2{margin-right:.5rem!important;margin-left:.5rem!important}.mx-3{margin-right:1rem!important;margin-left:1rem!important}.mx-4{margin-right:1.5rem!important;margin-left:1.5rem!important}.mx-5{margin-right:3rem!important;margin-left:3rem!important}.mx-auto{margin-right:auto!important;margin-left:auto!important}.my-0{margin-top:0!important;margin-bottom:0!important}.my-1{margin-top:.25rem!important;margin-bottom:.25rem!important}.my-2{margin-top:.5rem!important;margin-bottom:.5rem!important}.my-3{margin-top:1rem!important;margin-bottom:1rem!important}.my-4{margin-top:1.5rem!important;margin-bottom:1.5rem!important}.my-5{margin-top:3rem!important;margin-bottom:3rem!important}.my-auto{margin-top:auto!important;margin-bottom:auto!important}.mt-0{margin-top:0!important}.mt-1{margin-top:.25rem!important}.mt-2{margin-top:.5rem!important}.mt-3{margin-top:1rem!important}.mt-4{margin-top:1.5rem!important}.mt-5{margin-top:3rem!important}.mt-auto{margin-top:auto!important}.me-0{margin-right:0!important}.me-1{margin-right:.25rem!important}.me-2{margin-right:.5rem!important}.me-3{margin-right:1rem!important}.me-4{margin-right:1.5rem!important}.me-5{margin-right:3rem!important}.me-auto{margin-right:auto!important}.mb-0{margin-bottom:0!important}.mb-1{margin-bottom:.25rem!important}.mb-2{margin-bottom:.5rem!important}.mb-3{margin-bottom:1rem!important}.mb-4{margin-bottom:1.5rem!important}.mb-5{margin-bottom:3rem!important}.mb-auto{margin-bottom:auto!important}.ms-0{margin-left:0!important}.ms-1{margin-left:.25rem!important}.ms-2{margin-left:.5rem!important}.ms-3{margin-left:1rem!important}.ms-4{margin-left:1.5rem!important}.ms-5{margin-left:3rem!important}.ms-auto{margin-left:auto!important}.p-0{padding:0!important}.p-1{padding:.25rem!important}.p-2{padding:.5rem!important}.p-3{padding:1rem!important}.p-4{padding:1.5rem!important}.p-5{padding:3rem!important}.px-0{padding-right:0!important;padding-left:0!important}.px-1{padding-right:.25rem!important;padding-left:.25rem!important}.px-2{padding-right:.5rem!important;padding-left:.5rem!important}.px-3{padding-right:1rem!important;padding-left:1rem!important}.px-4{padding-right:1.5rem!important;padding-left:1.5rem!important}.px-5{padding-right:3rem!important;padding-left:3rem!important}.py-0{padding-top:0!important;padding-bottom:0!important}.py-1{padding-top:.25rem!important;padding-bottom:.25rem!important}.py-2{padding-top:.5rem!important;padding-bottom:.5rem!important}.py-3{padding-top:1rem!important;padding-bottom:1rem!important}.py-4{padding-top:1.5rem!important;padding-bottom:1.5rem!important}.py-5{padding-top:3rem!important;padding-bottom:3rem!important}.pt-0{padding-top:0!important}.pt-1{padding-top:.25rem!important}.pt-2{padding-top:.5rem!important}.pt-3{padding-top:1rem!important}.pt-4{padding-top:1.5rem!important}.pt-5{padding-top:3rem!important}.pe-0{padding-right:0!important}.pe-1{padding-right:.25rem!important}.pe-2{padding-right:.5rem!important}.pe-3{padding-right:1rem!important}.pe-4{padding-right:1.5rem!important}.pe-5{padding-right:3rem!important}.pb-0{padding-bottom:0!important}.pb-1{padding-bottom:.25rem!important}.pb-2{padding-bottom:.5rem!important}.pb-3{padding-bottom:1rem!important}.pb-4{padding-bottom:1.5rem!important}.pb-5{padding-bottom:3rem!important}.ps-0{padding-left:0!important}.ps-1{padding-left:.25rem!important}.ps-2{padding-left:.5rem!important}.ps-3{padding-left:1rem!important}.ps-4{padding-left:1.5rem!important}.ps-5{padding-left:3rem!important}.gap-0{gap:0!important}.gap-1{gap:.25rem!important}.gap-2{gap:.5rem!important}.gap-3{gap:1rem!important}.gap-4{gap:1.5rem!important}.gap-5{gap:3rem!important}.row-gap-0{row-gap:0!important}.row-gap-1{row-gap:.25rem!important}.row-gap-2{row-gap:.5rem!important}.row-gap-3{row-gap:1rem!important}.row-gap-4{row-gap:1.5rem!important}.row-gap-5{row-gap:3rem!important}.column-gap-0{column-gap:0!important}.column-gap-1{column-gap:.25rem!important}.column-gap-2{column-gap:.5rem!important}.column-gap-3{column-gap:1rem!important}.column-gap-4{column-gap:1.5rem!important}.column-gap-5{column-gap:3rem!important}.font-monospace{font-family:var(--bs-font-monospace)!important}.fs-1{font-size:calc(1.375rem + 1.5vw)!important}.fs-2{font-size:calc(1.325rem + .9vw)!important}.fs-3{font-size:calc(1.3rem + .6vw)!important}.fs-4{font-size:calc(1.275rem + .3vw)!important}.fs-5{font-size:1.25rem!important}.fs-6{font-size:1rem!important}.fst-italic{font-style:italic!important}.fst-normal{font-style:normal!important}.fw-lighter{font-weight:lighter!important}.fw-light{font-weight:300!important}.fw-normal{font-weight:400!important}.fw-medium{font-weight:500!important}.fw-semibold{font-weight:600!important}.fw-bold{font-weight:700!important}.fw-bolder{font-weight:bolder!important}.lh-1{line-height:1!important}.lh-sm{line-height:1.25!important}.lh-base{line-height:1.5!important}.lh-lg{line-height:2!important}.text-start{text-align:left!important}.text-end{text-align:right!important}.text-center{text-align:center!important}.text-decoration-none{text-decoration:none!important}.text-decoration-underline{text-decoration:underline!important}.text-decoration-line-through{text-decoration:line-through!important}.text-lowercase{text-transform:lowercase!important}.text-uppercase{text-transform:uppercase!important}.text-capitalize{text-transform:capitalize!important}.text-wrap{white-space:normal!important}.text-nowrap{white-space:nowrap!important}.text-break{word-wrap:break-word!important;word-break:break-word!important}.text-primary{--bs-text-opacity: 1;color:rgba(var(--bs-primary-rgb),var(--bs-text-opacity))!important}.text-secondary{--bs-text-opacity: 1;color:rgba(var(--bs-secondary-rgb),var(--bs-text-opacity))!important}.text-success{--bs-text-opacity: 1;color:rgba(var(--bs-success-rgb),var(--bs-text-opacity))!important}.text-info{--bs-text-opacity: 1;color:rgba(var(--bs-info-rgb),var(--bs-text-opacity))!important}.text-warning{--bs-text-opacity: 1;color:rgba(var(--bs-warning-rgb),var(--bs-text-opacity))!important}.text-danger{--bs-text-opacity: 1;color:rgba(var(--bs-danger-rgb),var(--bs-text-opacity))!important}.text-light{--bs-text-opacity: 1;color:rgba(var(--bs-light-rgb),var(--bs-text-opacity))!important}.text-dark{--bs-text-opacity: 1;color:rgba(var(--bs-dark-rgb),var(--bs-text-opacity))!important}.text-black{--bs-text-opacity: 1;color:rgba(var(--bs-black-rgb),var(--bs-text-opacity))!important}.text-white{--bs-text-opacity: 1;color:rgba(var(--bs-white-rgb),var(--bs-text-opacity))!important}.text-body{--bs-text-opacity: 1;color:rgba(var(--bs-body-color-rgb),var(--bs-text-opacity))!important}.text-muted{--bs-text-opacity: 1;color:var(--bs-secondary-color)!important}.text-black-50{--bs-text-opacity: 1;color:#00000080!important}.text-white-50{--bs-text-opacity: 1;color:#ffffff80!important}.text-body-secondary{--bs-text-opacity: 1;color:var(--bs-secondary-color)!important}.text-body-tertiary{--bs-text-opacity: 1;color:var(--bs-tertiary-color)!important}.text-body-emphasis{--bs-text-opacity: 1;color:var(--bs-emphasis-color)!important}.text-reset{--bs-text-opacity: 1;color:inherit!important}.text-opacity-25{--bs-text-opacity: .25}.text-opacity-50{--bs-text-opacity: .5}.text-opacity-75{--bs-text-opacity: .75}.text-opacity-100{--bs-text-opacity: 1}.text-primary-emphasis{color:var(--bs-primary-text-emphasis)!important}.text-secondary-emphasis{color:var(--bs-secondary-text-emphasis)!important}.text-success-emphasis{color:var(--bs-success-text-emphasis)!important}.text-info-emphasis{color:var(--bs-info-text-emphasis)!important}.text-warning-emphasis{color:var(--bs-warning-text-emphasis)!important}.text-danger-emphasis{color:var(--bs-danger-text-emphasis)!important}.text-light-emphasis{color:var(--bs-light-text-emphasis)!important}.text-dark-emphasis{color:var(--bs-dark-text-emphasis)!important}.link-opacity-10,.link-opacity-10-hover:hover{--bs-link-opacity: .1}.link-opacity-25,.link-opacity-25-hover:hover{--bs-link-opacity: .25}.link-opacity-50,.link-opacity-50-hover:hover{--bs-link-opacity: .5}.link-opacity-75,.link-opacity-75-hover:hover{--bs-link-opacity: .75}.link-opacity-100,.link-opacity-100-hover:hover{--bs-link-opacity: 1}.link-offset-1,.link-offset-1-hover:hover{text-underline-offset:.125em!important}.link-offset-2,.link-offset-2-hover:hover{text-underline-offset:.25em!important}.link-offset-3,.link-offset-3-hover:hover{text-underline-offset:.375em!important}.link-underline-primary{--bs-link-underline-opacity: 1;text-decoration-color:rgba(var(--bs-primary-rgb),var(--bs-link-underline-opacity))!important}.link-underline-secondary{--bs-link-underline-opacity: 1;text-decoration-color:rgba(var(--bs-secondary-rgb),var(--bs-link-underline-opacity))!important}.link-underline-success{--bs-link-underline-opacity: 1;text-decoration-color:rgba(var(--bs-success-rgb),var(--bs-link-underline-opacity))!important}.link-underline-info{--bs-link-underline-opacity: 1;text-decoration-color:rgba(var(--bs-info-rgb),var(--bs-link-underline-opacity))!important}.link-underline-warning{--bs-link-underline-opacity: 1;text-decoration-color:rgba(var(--bs-warning-rgb),var(--bs-link-underline-opacity))!important}.link-underline-danger{--bs-link-underline-opacity: 1;text-decoration-color:rgba(var(--bs-danger-rgb),var(--bs-link-underline-opacity))!important}.link-underline-light{--bs-link-underline-opacity: 1;text-decoration-color:rgba(var(--bs-light-rgb),var(--bs-link-underline-opacity))!important}.link-underline-dark{--bs-link-underline-opacity: 1;text-decoration-color:rgba(var(--bs-dark-rgb),var(--bs-link-underline-opacity))!important}.link-underline{--bs-link-underline-opacity: 1;text-decoration-color:rgba(var(--bs-link-color-rgb),var(--bs-link-underline-opacity, 1))!important}.link-underline-opacity-0,.link-underline-opacity-0-hover:hover{--bs-link-underline-opacity: 0}.link-underline-opacity-10,.link-underline-opacity-10-hover:hover{--bs-link-underline-opacity: .1}.link-underline-opacity-25,.link-underline-opacity-25-hover:hover{--bs-link-underline-opacity: .25}.link-underline-opacity-50,.link-underline-opacity-50-hover:hover{--bs-link-underline-opacity: .5}.link-underline-opacity-75,.link-underline-opacity-75-hover:hover{--bs-link-underline-opacity: .75}.link-underline-opacity-100,.link-underline-opacity-100-hover:hover{--bs-link-underline-opacity: 1}.bg-primary{--bs-bg-opacity: 1;background-color:rgba(var(--bs-primary-rgb),var(--bs-bg-opacity))!important}.bg-secondary{--bs-bg-opacity: 1;background-color:rgba(var(--bs-secondary-rgb),var(--bs-bg-opacity))!important}.bg-success{--bs-bg-opacity: 1;background-color:rgba(var(--bs-success-rgb),var(--bs-bg-opacity))!important}.bg-info{--bs-bg-opacity: 1;background-color:rgba(var(--bs-info-rgb),var(--bs-bg-opacity))!important}.bg-warning{--bs-bg-opacity: 1;background-color:rgba(var(--bs-warning-rgb),var(--bs-bg-opacity))!important}.bg-danger{--bs-bg-opacity: 1;background-color:rgba(var(--bs-danger-rgb),var(--bs-bg-opacity))!important}.bg-light{--bs-bg-opacity: 1;background-color:rgba(var(--bs-light-rgb),var(--bs-bg-opacity))!important}.bg-dark{--bs-bg-opacity: 1;background-color:rgba(var(--bs-dark-rgb),var(--bs-bg-opacity))!important}.bg-black{--bs-bg-opacity: 1;background-color:rgba(var(--bs-black-rgb),var(--bs-bg-opacity))!important}.bg-white{--bs-bg-opacity: 1;background-color:rgba(var(--bs-white-rgb),var(--bs-bg-opacity))!important}.bg-body{--bs-bg-opacity: 1;background-color:rgba(var(--bs-body-bg-rgb),var(--bs-bg-opacity))!important}.bg-transparent{--bs-bg-opacity: 1;background-color:transparent!important}.bg-body-secondary{--bs-bg-opacity: 1;background-color:rgba(var(--bs-secondary-bg-rgb),var(--bs-bg-opacity))!important}.bg-body-tertiary{--bs-bg-opacity: 1;background-color:rgba(var(--bs-tertiary-bg-rgb),var(--bs-bg-opacity))!important}.bg-opacity-10{--bs-bg-opacity: .1}.bg-opacity-25{--bs-bg-opacity: .25}.bg-opacity-50{--bs-bg-opacity: .5}.bg-opacity-75{--bs-bg-opacity: .75}.bg-opacity-100{--bs-bg-opacity: 1}.bg-primary-subtle{background-color:var(--bs-primary-bg-subtle)!important}.bg-secondary-subtle{background-color:var(--bs-secondary-bg-subtle)!important}.bg-success-subtle{background-color:var(--bs-success-bg-subtle)!important}.bg-info-subtle{background-color:var(--bs-info-bg-subtle)!important}.bg-warning-subtle{background-color:var(--bs-warning-bg-subtle)!important}.bg-danger-subtle{background-color:var(--bs-danger-bg-subtle)!important}.bg-light-subtle{background-color:var(--bs-light-bg-subtle)!important}.bg-dark-subtle{background-color:var(--bs-dark-bg-subtle)!important}.bg-gradient{background-image:var(--bs-gradient)!important}.user-select-all{-webkit-user-select:all!important;user-select:all!important}.user-select-auto{-webkit-user-select:auto!important;user-select:auto!important}.user-select-none{-webkit-user-select:none!important;user-select:none!important}.pe-none{pointer-events:none!important}.pe-auto{pointer-events:auto!important}.rounded{border-radius:var(--bs-border-radius)!important}.rounded-0{border-radius:0!important}.rounded-1{border-radius:var(--bs-border-radius-sm)!important}.rounded-2{border-radius:var(--bs-border-radius)!important}.rounded-3{border-radius:var(--bs-border-radius-lg)!important}.rounded-4{border-radius:var(--bs-border-radius-xl)!important}.rounded-5{border-radius:var(--bs-border-radius-xxl)!important}.rounded-circle{border-radius:50%!important}.rounded-pill{border-radius:var(--bs-border-radius-pill)!important}.rounded-top{border-top-left-radius:var(--bs-border-radius)!important;border-top-right-radius:var(--bs-border-radius)!important}.rounded-top-0{border-top-left-radius:0!important;border-top-right-radius:0!important}.rounded-top-1{border-top-left-radius:var(--bs-border-radius-sm)!important;border-top-right-radius:var(--bs-border-radius-sm)!important}.rounded-top-2{border-top-left-radius:var(--bs-border-radius)!important;border-top-right-radius:var(--bs-border-radius)!important}.rounded-top-3{border-top-left-radius:var(--bs-border-radius-lg)!important;border-top-right-radius:var(--bs-border-radius-lg)!important}.rounded-top-4{border-top-left-radius:var(--bs-border-radius-xl)!important;border-top-right-radius:var(--bs-border-radius-xl)!important}.rounded-top-5{border-top-left-radius:var(--bs-border-radius-xxl)!important;border-top-right-radius:var(--bs-border-radius-xxl)!important}.rounded-top-circle{border-top-left-radius:50%!important;border-top-right-radius:50%!important}.rounded-top-pill{border-top-left-radius:var(--bs-border-radius-pill)!important;border-top-right-radius:var(--bs-border-radius-pill)!important}.rounded-end{border-top-right-radius:var(--bs-border-radius)!important;border-bottom-right-radius:var(--bs-border-radius)!important}.rounded-end-0{border-top-right-radius:0!important;border-bottom-right-radius:0!important}.rounded-end-1{border-top-right-radius:var(--bs-border-radius-sm)!important;border-bottom-right-radius:var(--bs-border-radius-sm)!important}.rounded-end-2{border-top-right-radius:var(--bs-border-radius)!important;border-bottom-right-radius:var(--bs-border-radius)!important}.rounded-end-3{border-top-right-radius:var(--bs-border-radius-lg)!important;border-bottom-right-radius:var(--bs-border-radius-lg)!important}.rounded-end-4{border-top-right-radius:var(--bs-border-radius-xl)!important;border-bottom-right-radius:var(--bs-border-radius-xl)!important}.rounded-end-5{border-top-right-radius:var(--bs-border-radius-xxl)!important;border-bottom-right-radius:var(--bs-border-radius-xxl)!important}.rounded-end-circle{border-top-right-radius:50%!important;border-bottom-right-radius:50%!important}.rounded-end-pill{border-top-right-radius:var(--bs-border-radius-pill)!important;border-bottom-right-radius:var(--bs-border-radius-pill)!important}.rounded-bottom{border-bottom-right-radius:var(--bs-border-radius)!important;border-bottom-left-radius:var(--bs-border-radius)!important}.rounded-bottom-0{border-bottom-right-radius:0!important;border-bottom-left-radius:0!important}.rounded-bottom-1{border-bottom-right-radius:var(--bs-border-radius-sm)!important;border-bottom-left-radius:var(--bs-border-radius-sm)!important}.rounded-bottom-2{border-bottom-right-radius:var(--bs-border-radius)!important;border-bottom-left-radius:var(--bs-border-radius)!important}.rounded-bottom-3{border-bottom-right-radius:var(--bs-border-radius-lg)!important;border-bottom-left-radius:var(--bs-border-radius-lg)!important}.rounded-bottom-4{border-bottom-right-radius:var(--bs-border-radius-xl)!important;border-bottom-left-radius:var(--bs-border-radius-xl)!important}.rounded-bottom-5{border-bottom-right-radius:var(--bs-border-radius-xxl)!important;border-bottom-left-radius:var(--bs-border-radius-xxl)!important}.rounded-bottom-circle{border-bottom-right-radius:50%!important;border-bottom-left-radius:50%!important}.rounded-bottom-pill{border-bottom-right-radius:var(--bs-border-radius-pill)!important;border-bottom-left-radius:var(--bs-border-radius-pill)!important}.rounded-start{border-bottom-left-radius:var(--bs-border-radius)!important;border-top-left-radius:var(--bs-border-radius)!important}.rounded-start-0{border-bottom-left-radius:0!important;border-top-left-radius:0!important}.rounded-start-1{border-bottom-left-radius:var(--bs-border-radius-sm)!important;border-top-left-radius:var(--bs-border-radius-sm)!important}.rounded-start-2{border-bottom-left-radius:var(--bs-border-radius)!important;border-top-left-radius:var(--bs-border-radius)!important}.rounded-start-3{border-bottom-left-radius:var(--bs-border-radius-lg)!important;border-top-left-radius:var(--bs-border-radius-lg)!important}.rounded-start-4{border-bottom-left-radius:var(--bs-border-radius-xl)!important;border-top-left-radius:var(--bs-border-radius-xl)!important}.rounded-start-5{border-bottom-left-radius:var(--bs-border-radius-xxl)!important;border-top-left-radius:var(--bs-border-radius-xxl)!important}.rounded-start-circle{border-bottom-left-radius:50%!important;border-top-left-radius:50%!important}.rounded-start-pill{border-bottom-left-radius:var(--bs-border-radius-pill)!important;border-top-left-radius:var(--bs-border-radius-pill)!important}.visible{visibility:visible!important}.invisible{visibility:hidden!important}.z-n1{z-index:-1!important}.z-0{z-index:0!important}.z-1{z-index:1!important}.z-2{z-index:2!important}.z-3{z-index:3!important}@media (min-width: 576px){.float-sm-start{float:left!important}.float-sm-end{float:right!important}.float-sm-none{float:none!important}.object-fit-sm-contain{object-fit:contain!important}.object-fit-sm-cover{object-fit:cover!important}.object-fit-sm-fill{object-fit:fill!important}.object-fit-sm-scale{object-fit:scale-down!important}.object-fit-sm-none{object-fit:none!important}.d-sm-inline{display:inline!important}.d-sm-inline-block{display:inline-block!important}.d-sm-block{display:block!important}.d-sm-grid{display:grid!important}.d-sm-inline-grid{display:inline-grid!important}.d-sm-table{display:table!important}.d-sm-table-row{display:table-row!important}.d-sm-table-cell{display:table-cell!important}.d-sm-flex{display:flex!important}.d-sm-inline-flex{display:inline-flex!important}.d-sm-none{display:none!important}.flex-sm-fill{flex:1 1 auto!important}.flex-sm-row{flex-direction:row!important}.flex-sm-column{flex-direction:column!important}.flex-sm-row-reverse{flex-direction:row-reverse!important}.flex-sm-column-reverse{flex-direction:column-reverse!important}.flex-sm-grow-0{flex-grow:0!important}.flex-sm-grow-1{flex-grow:1!important}.flex-sm-shrink-0{flex-shrink:0!important}.flex-sm-shrink-1{flex-shrink:1!important}.flex-sm-wrap{flex-wrap:wrap!important}.flex-sm-nowrap{flex-wrap:nowrap!important}.flex-sm-wrap-reverse{flex-wrap:wrap-reverse!important}.justify-content-sm-start{justify-content:flex-start!important}.justify-content-sm-end{justify-content:flex-end!important}.justify-content-sm-center{justify-content:center!important}.justify-content-sm-between{justify-content:space-between!important}.justify-content-sm-around{justify-content:space-around!important}.justify-content-sm-evenly{justify-content:space-evenly!important}.align-items-sm-start{align-items:flex-start!important}.align-items-sm-end{align-items:flex-end!important}.align-items-sm-center{align-items:center!important}.align-items-sm-baseline{align-items:baseline!important}.align-items-sm-stretch{align-items:stretch!important}.align-content-sm-start{align-content:flex-start!important}.align-content-sm-end{align-content:flex-end!important}.align-content-sm-center{align-content:center!important}.align-content-sm-between{align-content:space-between!important}.align-content-sm-around{align-content:space-around!important}.align-content-sm-stretch{align-content:stretch!important}.align-self-sm-auto{align-self:auto!important}.align-self-sm-start{align-self:flex-start!important}.align-self-sm-end{align-self:flex-end!important}.align-self-sm-center{align-self:center!important}.align-self-sm-baseline{align-self:baseline!important}.align-self-sm-stretch{align-self:stretch!important}.order-sm-first{order:-1!important}.order-sm-0{order:0!important}.order-sm-1{order:1!important}.order-sm-2{order:2!important}.order-sm-3{order:3!important}.order-sm-4{order:4!important}.order-sm-5{order:5!important}.order-sm-last{order:6!important}.m-sm-0{margin:0!important}.m-sm-1{margin:.25rem!important}.m-sm-2{margin:.5rem!important}.m-sm-3{margin:1rem!important}.m-sm-4{margin:1.5rem!important}.m-sm-5{margin:3rem!important}.m-sm-auto{margin:auto!important}.mx-sm-0{margin-right:0!important;margin-left:0!important}.mx-sm-1{margin-right:.25rem!important;margin-left:.25rem!important}.mx-sm-2{margin-right:.5rem!important;margin-left:.5rem!important}.mx-sm-3{margin-right:1rem!important;margin-left:1rem!important}.mx-sm-4{margin-right:1.5rem!important;margin-left:1.5rem!important}.mx-sm-5{margin-right:3rem!important;margin-left:3rem!important}.mx-sm-auto{margin-right:auto!important;margin-left:auto!important}.my-sm-0{margin-top:0!important;margin-bottom:0!important}.my-sm-1{margin-top:.25rem!important;margin-bottom:.25rem!important}.my-sm-2{margin-top:.5rem!important;margin-bottom:.5rem!important}.my-sm-3{margin-top:1rem!important;margin-bottom:1rem!important}.my-sm-4{margin-top:1.5rem!important;margin-bottom:1.5rem!important}.my-sm-5{margin-top:3rem!important;margin-bottom:3rem!important}.my-sm-auto{margin-top:auto!important;margin-bottom:auto!important}.mt-sm-0{margin-top:0!important}.mt-sm-1{margin-top:.25rem!important}.mt-sm-2{margin-top:.5rem!important}.mt-sm-3{margin-top:1rem!important}.mt-sm-4{margin-top:1.5rem!important}.mt-sm-5{margin-top:3rem!important}.mt-sm-auto{margin-top:auto!important}.me-sm-0{margin-right:0!important}.me-sm-1{margin-right:.25rem!important}.me-sm-2{margin-right:.5rem!important}.me-sm-3{margin-right:1rem!important}.me-sm-4{margin-right:1.5rem!important}.me-sm-5{margin-right:3rem!important}.me-sm-auto{margin-right:auto!important}.mb-sm-0{margin-bottom:0!important}.mb-sm-1{margin-bottom:.25rem!important}.mb-sm-2{margin-bottom:.5rem!important}.mb-sm-3{margin-bottom:1rem!important}.mb-sm-4{margin-bottom:1.5rem!important}.mb-sm-5{margin-bottom:3rem!important}.mb-sm-auto{margin-bottom:auto!important}.ms-sm-0{margin-left:0!important}.ms-sm-1{margin-left:.25rem!important}.ms-sm-2{margin-left:.5rem!important}.ms-sm-3{margin-left:1rem!important}.ms-sm-4{margin-left:1.5rem!important}.ms-sm-5{margin-left:3rem!important}.ms-sm-auto{margin-left:auto!important}.p-sm-0{padding:0!important}.p-sm-1{padding:.25rem!important}.p-sm-2{padding:.5rem!important}.p-sm-3{padding:1rem!important}.p-sm-4{padding:1.5rem!important}.p-sm-5{padding:3rem!important}.px-sm-0{padding-right:0!important;padding-left:0!important}.px-sm-1{padding-right:.25rem!important;padding-left:.25rem!important}.px-sm-2{padding-right:.5rem!important;padding-left:.5rem!important}.px-sm-3{padding-right:1rem!important;padding-left:1rem!important}.px-sm-4{padding-right:1.5rem!important;padding-left:1.5rem!important}.px-sm-5{padding-right:3rem!important;padding-left:3rem!important}.py-sm-0{padding-top:0!important;padding-bottom:0!important}.py-sm-1{padding-top:.25rem!important;padding-bottom:.25rem!important}.py-sm-2{padding-top:.5rem!important;padding-bottom:.5rem!important}.py-sm-3{padding-top:1rem!important;padding-bottom:1rem!important}.py-sm-4{padding-top:1.5rem!important;padding-bottom:1.5rem!important}.py-sm-5{padding-top:3rem!important;padding-bottom:3rem!important}.pt-sm-0{padding-top:0!important}.pt-sm-1{padding-top:.25rem!important}.pt-sm-2{padding-top:.5rem!important}.pt-sm-3{padding-top:1rem!important}.pt-sm-4{padding-top:1.5rem!important}.pt-sm-5{padding-top:3rem!important}.pe-sm-0{padding-right:0!important}.pe-sm-1{padding-right:.25rem!important}.pe-sm-2{padding-right:.5rem!important}.pe-sm-3{padding-right:1rem!important}.pe-sm-4{padding-right:1.5rem!important}.pe-sm-5{padding-right:3rem!important}.pb-sm-0{padding-bottom:0!important}.pb-sm-1{padding-bottom:.25rem!important}.pb-sm-2{padding-bottom:.5rem!important}.pb-sm-3{padding-bottom:1rem!important}.pb-sm-4{padding-bottom:1.5rem!important}.pb-sm-5{padding-bottom:3rem!important}.ps-sm-0{padding-left:0!important}.ps-sm-1{padding-left:.25rem!important}.ps-sm-2{padding-left:.5rem!important}.ps-sm-3{padding-left:1rem!important}.ps-sm-4{padding-left:1.5rem!important}.ps-sm-5{padding-left:3rem!important}.gap-sm-0{gap:0!important}.gap-sm-1{gap:.25rem!important}.gap-sm-2{gap:.5rem!important}.gap-sm-3{gap:1rem!important}.gap-sm-4{gap:1.5rem!important}.gap-sm-5{gap:3rem!important}.row-gap-sm-0{row-gap:0!important}.row-gap-sm-1{row-gap:.25rem!important}.row-gap-sm-2{row-gap:.5rem!important}.row-gap-sm-3{row-gap:1rem!important}.row-gap-sm-4{row-gap:1.5rem!important}.row-gap-sm-5{row-gap:3rem!important}.column-gap-sm-0{column-gap:0!important}.column-gap-sm-1{column-gap:.25rem!important}.column-gap-sm-2{column-gap:.5rem!important}.column-gap-sm-3{column-gap:1rem!important}.column-gap-sm-4{column-gap:1.5rem!important}.column-gap-sm-5{column-gap:3rem!important}.text-sm-start{text-align:left!important}.text-sm-end{text-align:right!important}.text-sm-center{text-align:center!important}}@media (min-width: 768px){.float-md-start{float:left!important}.float-md-end{float:right!important}.float-md-none{float:none!important}.object-fit-md-contain{object-fit:contain!important}.object-fit-md-cover{object-fit:cover!important}.object-fit-md-fill{object-fit:fill!important}.object-fit-md-scale{object-fit:scale-down!important}.object-fit-md-none{object-fit:none!important}.d-md-inline{display:inline!important}.d-md-inline-block{display:inline-block!important}.d-md-block{display:block!important}.d-md-grid{display:grid!important}.d-md-inline-grid{display:inline-grid!important}.d-md-table{display:table!important}.d-md-table-row{display:table-row!important}.d-md-table-cell{display:table-cell!important}.d-md-flex{display:flex!important}.d-md-inline-flex{display:inline-flex!important}.d-md-none{display:none!important}.flex-md-fill{flex:1 1 auto!important}.flex-md-row{flex-direction:row!important}.flex-md-column{flex-direction:column!important}.flex-md-row-reverse{flex-direction:row-reverse!important}.flex-md-column-reverse{flex-direction:column-reverse!important}.flex-md-grow-0{flex-grow:0!important}.flex-md-grow-1{flex-grow:1!important}.flex-md-shrink-0{flex-shrink:0!important}.flex-md-shrink-1{flex-shrink:1!important}.flex-md-wrap{flex-wrap:wrap!important}.flex-md-nowrap{flex-wrap:nowrap!important}.flex-md-wrap-reverse{flex-wrap:wrap-reverse!important}.justify-content-md-start{justify-content:flex-start!important}.justify-content-md-end{justify-content:flex-end!important}.justify-content-md-center{justify-content:center!important}.justify-content-md-between{justify-content:space-between!important}.justify-content-md-around{justify-content:space-around!important}.justify-content-md-evenly{justify-content:space-evenly!important}.align-items-md-start{align-items:flex-start!important}.align-items-md-end{align-items:flex-end!important}.align-items-md-center{align-items:center!important}.align-items-md-baseline{align-items:baseline!important}.align-items-md-stretch{align-items:stretch!important}.align-content-md-start{align-content:flex-start!important}.align-content-md-end{align-content:flex-end!important}.align-content-md-center{align-content:center!important}.align-content-md-between{align-content:space-between!important}.align-content-md-around{align-content:space-around!important}.align-content-md-stretch{align-content:stretch!important}.align-self-md-auto{align-self:auto!important}.align-self-md-start{align-self:flex-start!important}.align-self-md-end{align-self:flex-end!important}.align-self-md-center{align-self:center!important}.align-self-md-baseline{align-self:baseline!important}.align-self-md-stretch{align-self:stretch!important}.order-md-first{order:-1!important}.order-md-0{order:0!important}.order-md-1{order:1!important}.order-md-2{order:2!important}.order-md-3{order:3!important}.order-md-4{order:4!important}.order-md-5{order:5!important}.order-md-last{order:6!important}.m-md-0{margin:0!important}.m-md-1{margin:.25rem!important}.m-md-2{margin:.5rem!important}.m-md-3{margin:1rem!important}.m-md-4{margin:1.5rem!important}.m-md-5{margin:3rem!important}.m-md-auto{margin:auto!important}.mx-md-0{margin-right:0!important;margin-left:0!important}.mx-md-1{margin-right:.25rem!important;margin-left:.25rem!important}.mx-md-2{margin-right:.5rem!important;margin-left:.5rem!important}.mx-md-3{margin-right:1rem!important;margin-left:1rem!important}.mx-md-4{margin-right:1.5rem!important;margin-left:1.5rem!important}.mx-md-5{margin-right:3rem!important;margin-left:3rem!important}.mx-md-auto{margin-right:auto!important;margin-left:auto!important}.my-md-0{margin-top:0!important;margin-bottom:0!important}.my-md-1{margin-top:.25rem!important;margin-bottom:.25rem!important}.my-md-2{margin-top:.5rem!important;margin-bottom:.5rem!important}.my-md-3{margin-top:1rem!important;margin-bottom:1rem!important}.my-md-4{margin-top:1.5rem!important;margin-bottom:1.5rem!important}.my-md-5{margin-top:3rem!important;margin-bottom:3rem!important}.my-md-auto{margin-top:auto!important;margin-bottom:auto!important}.mt-md-0{margin-top:0!important}.mt-md-1{margin-top:.25rem!important}.mt-md-2{margin-top:.5rem!important}.mt-md-3{margin-top:1rem!important}.mt-md-4{margin-top:1.5rem!important}.mt-md-5{margin-top:3rem!important}.mt-md-auto{margin-top:auto!important}.me-md-0{margin-right:0!important}.me-md-1{margin-right:.25rem!important}.me-md-2{margin-right:.5rem!important}.me-md-3{margin-right:1rem!important}.me-md-4{margin-right:1.5rem!important}.me-md-5{margin-right:3rem!important}.me-md-auto{margin-right:auto!important}.mb-md-0{margin-bottom:0!important}.mb-md-1{margin-bottom:.25rem!important}.mb-md-2{margin-bottom:.5rem!important}.mb-md-3{margin-bottom:1rem!important}.mb-md-4{margin-bottom:1.5rem!important}.mb-md-5{margin-bottom:3rem!important}.mb-md-auto{margin-bottom:auto!important}.ms-md-0{margin-left:0!important}.ms-md-1{margin-left:.25rem!important}.ms-md-2{margin-left:.5rem!important}.ms-md-3{margin-left:1rem!important}.ms-md-4{margin-left:1.5rem!important}.ms-md-5{margin-left:3rem!important}.ms-md-auto{margin-left:auto!important}.p-md-0{padding:0!important}.p-md-1{padding:.25rem!important}.p-md-2{padding:.5rem!important}.p-md-3{padding:1rem!important}.p-md-4{padding:1.5rem!important}.p-md-5{padding:3rem!important}.px-md-0{padding-right:0!important;padding-left:0!important}.px-md-1{padding-right:.25rem!important;padding-left:.25rem!important}.px-md-2{padding-right:.5rem!important;padding-left:.5rem!important}.px-md-3{padding-right:1rem!important;padding-left:1rem!important}.px-md-4{padding-right:1.5rem!important;padding-left:1.5rem!important}.px-md-5{padding-right:3rem!important;padding-left:3rem!important}.py-md-0{padding-top:0!important;padding-bottom:0!important}.py-md-1{padding-top:.25rem!important;padding-bottom:.25rem!important}.py-md-2{padding-top:.5rem!important;padding-bottom:.5rem!important}.py-md-3{padding-top:1rem!important;padding-bottom:1rem!important}.py-md-4{padding-top:1.5rem!important;padding-bottom:1.5rem!important}.py-md-5{padding-top:3rem!important;padding-bottom:3rem!important}.pt-md-0{padding-top:0!important}.pt-md-1{padding-top:.25rem!important}.pt-md-2{padding-top:.5rem!important}.pt-md-3{padding-top:1rem!important}.pt-md-4{padding-top:1.5rem!important}.pt-md-5{padding-top:3rem!important}.pe-md-0{padding-right:0!important}.pe-md-1{padding-right:.25rem!important}.pe-md-2{padding-right:.5rem!important}.pe-md-3{padding-right:1rem!important}.pe-md-4{padding-right:1.5rem!important}.pe-md-5{padding-right:3rem!important}.pb-md-0{padding-bottom:0!important}.pb-md-1{padding-bottom:.25rem!important}.pb-md-2{padding-bottom:.5rem!important}.pb-md-3{padding-bottom:1rem!important}.pb-md-4{padding-bottom:1.5rem!important}.pb-md-5{padding-bottom:3rem!important}.ps-md-0{padding-left:0!important}.ps-md-1{padding-left:.25rem!important}.ps-md-2{padding-left:.5rem!important}.ps-md-3{padding-left:1rem!important}.ps-md-4{padding-left:1.5rem!important}.ps-md-5{padding-left:3rem!important}.gap-md-0{gap:0!important}.gap-md-1{gap:.25rem!important}.gap-md-2{gap:.5rem!important}.gap-md-3{gap:1rem!important}.gap-md-4{gap:1.5rem!important}.gap-md-5{gap:3rem!important}.row-gap-md-0{row-gap:0!important}.row-gap-md-1{row-gap:.25rem!important}.row-gap-md-2{row-gap:.5rem!important}.row-gap-md-3{row-gap:1rem!important}.row-gap-md-4{row-gap:1.5rem!important}.row-gap-md-5{row-gap:3rem!important}.column-gap-md-0{column-gap:0!important}.column-gap-md-1{column-gap:.25rem!important}.column-gap-md-2{column-gap:.5rem!important}.column-gap-md-3{column-gap:1rem!important}.column-gap-md-4{column-gap:1.5rem!important}.column-gap-md-5{column-gap:3rem!important}.text-md-start{text-align:left!important}.text-md-end{text-align:right!important}.text-md-center{text-align:center!important}}@media (min-width: 992px){.float-lg-start{float:left!important}.float-lg-end{float:right!important}.float-lg-none{float:none!important}.object-fit-lg-contain{object-fit:contain!important}.object-fit-lg-cover{object-fit:cover!important}.object-fit-lg-fill{object-fit:fill!important}.object-fit-lg-scale{object-fit:scale-down!important}.object-fit-lg-none{object-fit:none!important}.d-lg-inline{display:inline!important}.d-lg-inline-block{display:inline-block!important}.d-lg-block{display:block!important}.d-lg-grid{display:grid!important}.d-lg-inline-grid{display:inline-grid!important}.d-lg-table{display:table!important}.d-lg-table-row{display:table-row!important}.d-lg-table-cell{display:table-cell!important}.d-lg-flex{display:flex!important}.d-lg-inline-flex{display:inline-flex!important}.d-lg-none{display:none!important}.flex-lg-fill{flex:1 1 auto!important}.flex-lg-row{flex-direction:row!important}.flex-lg-column{flex-direction:column!important}.flex-lg-row-reverse{flex-direction:row-reverse!important}.flex-lg-column-reverse{flex-direction:column-reverse!important}.flex-lg-grow-0{flex-grow:0!important}.flex-lg-grow-1{flex-grow:1!important}.flex-lg-shrink-0{flex-shrink:0!important}.flex-lg-shrink-1{flex-shrink:1!important}.flex-lg-wrap{flex-wrap:wrap!important}.flex-lg-nowrap{flex-wrap:nowrap!important}.flex-lg-wrap-reverse{flex-wrap:wrap-reverse!important}.justify-content-lg-start{justify-content:flex-start!important}.justify-content-lg-end{justify-content:flex-end!important}.justify-content-lg-center{justify-content:center!important}.justify-content-lg-between{justify-content:space-between!important}.justify-content-lg-around{justify-content:space-around!important}.justify-content-lg-evenly{justify-content:space-evenly!important}.align-items-lg-start{align-items:flex-start!important}.align-items-lg-end{align-items:flex-end!important}.align-items-lg-center{align-items:center!important}.align-items-lg-baseline{align-items:baseline!important}.align-items-lg-stretch{align-items:stretch!important}.align-content-lg-start{align-content:flex-start!important}.align-content-lg-end{align-content:flex-end!important}.align-content-lg-center{align-content:center!important}.align-content-lg-between{align-content:space-between!important}.align-content-lg-around{align-content:space-around!important}.align-content-lg-stretch{align-content:stretch!important}.align-self-lg-auto{align-self:auto!important}.align-self-lg-start{align-self:flex-start!important}.align-self-lg-end{align-self:flex-end!important}.align-self-lg-center{align-self:center!important}.align-self-lg-baseline{align-self:baseline!important}.align-self-lg-stretch{align-self:stretch!important}.order-lg-first{order:-1!important}.order-lg-0{order:0!important}.order-lg-1{order:1!important}.order-lg-2{order:2!important}.order-lg-3{order:3!important}.order-lg-4{order:4!important}.order-lg-5{order:5!important}.order-lg-last{order:6!important}.m-lg-0{margin:0!important}.m-lg-1{margin:.25rem!important}.m-lg-2{margin:.5rem!important}.m-lg-3{margin:1rem!important}.m-lg-4{margin:1.5rem!important}.m-lg-5{margin:3rem!important}.m-lg-auto{margin:auto!important}.mx-lg-0{margin-right:0!important;margin-left:0!important}.mx-lg-1{margin-right:.25rem!important;margin-left:.25rem!important}.mx-lg-2{margin-right:.5rem!important;margin-left:.5rem!important}.mx-lg-3{margin-right:1rem!important;margin-left:1rem!important}.mx-lg-4{margin-right:1.5rem!important;margin-left:1.5rem!important}.mx-lg-5{margin-right:3rem!important;margin-left:3rem!important}.mx-lg-auto{margin-right:auto!important;margin-left:auto!important}.my-lg-0{margin-top:0!important;margin-bottom:0!important}.my-lg-1{margin-top:.25rem!important;margin-bottom:.25rem!important}.my-lg-2{margin-top:.5rem!important;margin-bottom:.5rem!important}.my-lg-3{margin-top:1rem!important;margin-bottom:1rem!important}.my-lg-4{margin-top:1.5rem!important;margin-bottom:1.5rem!important}.my-lg-5{margin-top:3rem!important;margin-bottom:3rem!important}.my-lg-auto{margin-top:auto!important;margin-bottom:auto!important}.mt-lg-0{margin-top:0!important}.mt-lg-1{margin-top:.25rem!important}.mt-lg-2{margin-top:.5rem!important}.mt-lg-3{margin-top:1rem!important}.mt-lg-4{margin-top:1.5rem!important}.mt-lg-5{margin-top:3rem!important}.mt-lg-auto{margin-top:auto!important}.me-lg-0{margin-right:0!important}.me-lg-1{margin-right:.25rem!important}.me-lg-2{margin-right:.5rem!important}.me-lg-3{margin-right:1rem!important}.me-lg-4{margin-right:1.5rem!important}.me-lg-5{margin-right:3rem!important}.me-lg-auto{margin-right:auto!important}.mb-lg-0{margin-bottom:0!important}.mb-lg-1{margin-bottom:.25rem!important}.mb-lg-2{margin-bottom:.5rem!important}.mb-lg-3{margin-bottom:1rem!important}.mb-lg-4{margin-bottom:1.5rem!important}.mb-lg-5{margin-bottom:3rem!important}.mb-lg-auto{margin-bottom:auto!important}.ms-lg-0{margin-left:0!important}.ms-lg-1{margin-left:.25rem!important}.ms-lg-2{margin-left:.5rem!important}.ms-lg-3{margin-left:1rem!important}.ms-lg-4{margin-left:1.5rem!important}.ms-lg-5{margin-left:3rem!important}.ms-lg-auto{margin-left:auto!important}.p-lg-0{padding:0!important}.p-lg-1{padding:.25rem!important}.p-lg-2{padding:.5rem!important}.p-lg-3{padding:1rem!important}.p-lg-4{padding:1.5rem!important}.p-lg-5{padding:3rem!important}.px-lg-0{padding-right:0!important;padding-left:0!important}.px-lg-1{padding-right:.25rem!important;padding-left:.25rem!important}.px-lg-2{padding-right:.5rem!important;padding-left:.5rem!important}.px-lg-3{padding-right:1rem!important;padding-left:1rem!important}.px-lg-4{padding-right:1.5rem!important;padding-left:1.5rem!important}.px-lg-5{padding-right:3rem!important;padding-left:3rem!important}.py-lg-0{padding-top:0!important;padding-bottom:0!important}.py-lg-1{padding-top:.25rem!important;padding-bottom:.25rem!important}.py-lg-2{padding-top:.5rem!important;padding-bottom:.5rem!important}.py-lg-3{padding-top:1rem!important;padding-bottom:1rem!important}.py-lg-4{padding-top:1.5rem!important;padding-bottom:1.5rem!important}.py-lg-5{padding-top:3rem!important;padding-bottom:3rem!important}.pt-lg-0{padding-top:0!important}.pt-lg-1{padding-top:.25rem!important}.pt-lg-2{padding-top:.5rem!important}.pt-lg-3{padding-top:1rem!important}.pt-lg-4{padding-top:1.5rem!important}.pt-lg-5{padding-top:3rem!important}.pe-lg-0{padding-right:0!important}.pe-lg-1{padding-right:.25rem!important}.pe-lg-2{padding-right:.5rem!important}.pe-lg-3{padding-right:1rem!important}.pe-lg-4{padding-right:1.5rem!important}.pe-lg-5{padding-right:3rem!important}.pb-lg-0{padding-bottom:0!important}.pb-lg-1{padding-bottom:.25rem!important}.pb-lg-2{padding-bottom:.5rem!important}.pb-lg-3{padding-bottom:1rem!important}.pb-lg-4{padding-bottom:1.5rem!important}.pb-lg-5{padding-bottom:3rem!important}.ps-lg-0{padding-left:0!important}.ps-lg-1{padding-left:.25rem!important}.ps-lg-2{padding-left:.5rem!important}.ps-lg-3{padding-left:1rem!important}.ps-lg-4{padding-left:1.5rem!important}.ps-lg-5{padding-left:3rem!important}.gap-lg-0{gap:0!important}.gap-lg-1{gap:.25rem!important}.gap-lg-2{gap:.5rem!important}.gap-lg-3{gap:1rem!important}.gap-lg-4{gap:1.5rem!important}.gap-lg-5{gap:3rem!important}.row-gap-lg-0{row-gap:0!important}.row-gap-lg-1{row-gap:.25rem!important}.row-gap-lg-2{row-gap:.5rem!important}.row-gap-lg-3{row-gap:1rem!important}.row-gap-lg-4{row-gap:1.5rem!important}.row-gap-lg-5{row-gap:3rem!important}.column-gap-lg-0{column-gap:0!important}.column-gap-lg-1{column-gap:.25rem!important}.column-gap-lg-2{column-gap:.5rem!important}.column-gap-lg-3{column-gap:1rem!important}.column-gap-lg-4{column-gap:1.5rem!important}.column-gap-lg-5{column-gap:3rem!important}.text-lg-start{text-align:left!important}.text-lg-end{text-align:right!important}.text-lg-center{text-align:center!important}}@media (min-width: 1200px){.float-xl-start{float:left!important}.float-xl-end{float:right!important}.float-xl-none{float:none!important}.object-fit-xl-contain{object-fit:contain!important}.object-fit-xl-cover{object-fit:cover!important}.object-fit-xl-fill{object-fit:fill!important}.object-fit-xl-scale{object-fit:scale-down!important}.object-fit-xl-none{object-fit:none!important}.d-xl-inline{display:inline!important}.d-xl-inline-block{display:inline-block!important}.d-xl-block{display:block!important}.d-xl-grid{display:grid!important}.d-xl-inline-grid{display:inline-grid!important}.d-xl-table{display:table!important}.d-xl-table-row{display:table-row!important}.d-xl-table-cell{display:table-cell!important}.d-xl-flex{display:flex!important}.d-xl-inline-flex{display:inline-flex!important}.d-xl-none{display:none!important}.flex-xl-fill{flex:1 1 auto!important}.flex-xl-row{flex-direction:row!important}.flex-xl-column{flex-direction:column!important}.flex-xl-row-reverse{flex-direction:row-reverse!important}.flex-xl-column-reverse{flex-direction:column-reverse!important}.flex-xl-grow-0{flex-grow:0!important}.flex-xl-grow-1{flex-grow:1!important}.flex-xl-shrink-0{flex-shrink:0!important}.flex-xl-shrink-1{flex-shrink:1!important}.flex-xl-wrap{flex-wrap:wrap!important}.flex-xl-nowrap{flex-wrap:nowrap!important}.flex-xl-wrap-reverse{flex-wrap:wrap-reverse!important}.justify-content-xl-start{justify-content:flex-start!important}.justify-content-xl-end{justify-content:flex-end!important}.justify-content-xl-center{justify-content:center!important}.justify-content-xl-between{justify-content:space-between!important}.justify-content-xl-around{justify-content:space-around!important}.justify-content-xl-evenly{justify-content:space-evenly!important}.align-items-xl-start{align-items:flex-start!important}.align-items-xl-end{align-items:flex-end!important}.align-items-xl-center{align-items:center!important}.align-items-xl-baseline{align-items:baseline!important}.align-items-xl-stretch{align-items:stretch!important}.align-content-xl-start{align-content:flex-start!important}.align-content-xl-end{align-content:flex-end!important}.align-content-xl-center{align-content:center!important}.align-content-xl-between{align-content:space-between!important}.align-content-xl-around{align-content:space-around!important}.align-content-xl-stretch{align-content:stretch!important}.align-self-xl-auto{align-self:auto!important}.align-self-xl-start{align-self:flex-start!important}.align-self-xl-end{align-self:flex-end!important}.align-self-xl-center{align-self:center!important}.align-self-xl-baseline{align-self:baseline!important}.align-self-xl-stretch{align-self:stretch!important}.order-xl-first{order:-1!important}.order-xl-0{order:0!important}.order-xl-1{order:1!important}.order-xl-2{order:2!important}.order-xl-3{order:3!important}.order-xl-4{order:4!important}.order-xl-5{order:5!important}.order-xl-last{order:6!important}.m-xl-0{margin:0!important}.m-xl-1{margin:.25rem!important}.m-xl-2{margin:.5rem!important}.m-xl-3{margin:1rem!important}.m-xl-4{margin:1.5rem!important}.m-xl-5{margin:3rem!important}.m-xl-auto{margin:auto!important}.mx-xl-0{margin-right:0!important;margin-left:0!important}.mx-xl-1{margin-right:.25rem!important;margin-left:.25rem!important}.mx-xl-2{margin-right:.5rem!important;margin-left:.5rem!important}.mx-xl-3{margin-right:1rem!important;margin-left:1rem!important}.mx-xl-4{margin-right:1.5rem!important;margin-left:1.5rem!important}.mx-xl-5{margin-right:3rem!important;margin-left:3rem!important}.mx-xl-auto{margin-right:auto!important;margin-left:auto!important}.my-xl-0{margin-top:0!important;margin-bottom:0!important}.my-xl-1{margin-top:.25rem!important;margin-bottom:.25rem!important}.my-xl-2{margin-top:.5rem!important;margin-bottom:.5rem!important}.my-xl-3{margin-top:1rem!important;margin-bottom:1rem!important}.my-xl-4{margin-top:1.5rem!important;margin-bottom:1.5rem!important}.my-xl-5{margin-top:3rem!important;margin-bottom:3rem!important}.my-xl-auto{margin-top:auto!important;margin-bottom:auto!important}.mt-xl-0{margin-top:0!important}.mt-xl-1{margin-top:.25rem!important}.mt-xl-2{margin-top:.5rem!important}.mt-xl-3{margin-top:1rem!important}.mt-xl-4{margin-top:1.5rem!important}.mt-xl-5{margin-top:3rem!important}.mt-xl-auto{margin-top:auto!important}.me-xl-0{margin-right:0!important}.me-xl-1{margin-right:.25rem!important}.me-xl-2{margin-right:.5rem!important}.me-xl-3{margin-right:1rem!important}.me-xl-4{margin-right:1.5rem!important}.me-xl-5{margin-right:3rem!important}.me-xl-auto{margin-right:auto!important}.mb-xl-0{margin-bottom:0!important}.mb-xl-1{margin-bottom:.25rem!important}.mb-xl-2{margin-bottom:.5rem!important}.mb-xl-3{margin-bottom:1rem!important}.mb-xl-4{margin-bottom:1.5rem!important}.mb-xl-5{margin-bottom:3rem!important}.mb-xl-auto{margin-bottom:auto!important}.ms-xl-0{margin-left:0!important}.ms-xl-1{margin-left:.25rem!important}.ms-xl-2{margin-left:.5rem!important}.ms-xl-3{margin-left:1rem!important}.ms-xl-4{margin-left:1.5rem!important}.ms-xl-5{margin-left:3rem!important}.ms-xl-auto{margin-left:auto!important}.p-xl-0{padding:0!important}.p-xl-1{padding:.25rem!important}.p-xl-2{padding:.5rem!important}.p-xl-3{padding:1rem!important}.p-xl-4{padding:1.5rem!important}.p-xl-5{padding:3rem!important}.px-xl-0{padding-right:0!important;padding-left:0!important}.px-xl-1{padding-right:.25rem!important;padding-left:.25rem!important}.px-xl-2{padding-right:.5rem!important;padding-left:.5rem!important}.px-xl-3{padding-right:1rem!important;padding-left:1rem!important}.px-xl-4{padding-right:1.5rem!important;padding-left:1.5rem!important}.px-xl-5{padding-right:3rem!important;padding-left:3rem!important}.py-xl-0{padding-top:0!important;padding-bottom:0!important}.py-xl-1{padding-top:.25rem!important;padding-bottom:.25rem!important}.py-xl-2{padding-top:.5rem!important;padding-bottom:.5rem!important}.py-xl-3{padding-top:1rem!important;padding-bottom:1rem!important}.py-xl-4{padding-top:1.5rem!important;padding-bottom:1.5rem!important}.py-xl-5{padding-top:3rem!important;padding-bottom:3rem!important}.pt-xl-0{padding-top:0!important}.pt-xl-1{padding-top:.25rem!important}.pt-xl-2{padding-top:.5rem!important}.pt-xl-3{padding-top:1rem!important}.pt-xl-4{padding-top:1.5rem!important}.pt-xl-5{padding-top:3rem!important}.pe-xl-0{padding-right:0!important}.pe-xl-1{padding-right:.25rem!important}.pe-xl-2{padding-right:.5rem!important}.pe-xl-3{padding-right:1rem!important}.pe-xl-4{padding-right:1.5rem!important}.pe-xl-5{padding-right:3rem!important}.pb-xl-0{padding-bottom:0!important}.pb-xl-1{padding-bottom:.25rem!important}.pb-xl-2{padding-bottom:.5rem!important}.pb-xl-3{padding-bottom:1rem!important}.pb-xl-4{padding-bottom:1.5rem!important}.pb-xl-5{padding-bottom:3rem!important}.ps-xl-0{padding-left:0!important}.ps-xl-1{padding-left:.25rem!important}.ps-xl-2{padding-left:.5rem!important}.ps-xl-3{padding-left:1rem!important}.ps-xl-4{padding-left:1.5rem!important}.ps-xl-5{padding-left:3rem!important}.gap-xl-0{gap:0!important}.gap-xl-1{gap:.25rem!important}.gap-xl-2{gap:.5rem!important}.gap-xl-3{gap:1rem!important}.gap-xl-4{gap:1.5rem!important}.gap-xl-5{gap:3rem!important}.row-gap-xl-0{row-gap:0!important}.row-gap-xl-1{row-gap:.25rem!important}.row-gap-xl-2{row-gap:.5rem!important}.row-gap-xl-3{row-gap:1rem!important}.row-gap-xl-4{row-gap:1.5rem!important}.row-gap-xl-5{row-gap:3rem!important}.column-gap-xl-0{column-gap:0!important}.column-gap-xl-1{column-gap:.25rem!important}.column-gap-xl-2{column-gap:.5rem!important}.column-gap-xl-3{column-gap:1rem!important}.column-gap-xl-4{column-gap:1.5rem!important}.column-gap-xl-5{column-gap:3rem!important}.text-xl-start{text-align:left!important}.text-xl-end{text-align:right!important}.text-xl-center{text-align:center!important}}@media (min-width: 1400px){.float-xxl-start{float:left!important}.float-xxl-end{float:right!important}.float-xxl-none{float:none!important}.object-fit-xxl-contain{object-fit:contain!important}.object-fit-xxl-cover{object-fit:cover!important}.object-fit-xxl-fill{object-fit:fill!important}.object-fit-xxl-scale{object-fit:scale-down!important}.object-fit-xxl-none{object-fit:none!important}.d-xxl-inline{display:inline!important}.d-xxl-inline-block{display:inline-block!important}.d-xxl-block{display:block!important}.d-xxl-grid{display:grid!important}.d-xxl-inline-grid{display:inline-grid!important}.d-xxl-table{display:table!important}.d-xxl-table-row{display:table-row!important}.d-xxl-table-cell{display:table-cell!important}.d-xxl-flex{display:flex!important}.d-xxl-inline-flex{display:inline-flex!important}.d-xxl-none{display:none!important}.flex-xxl-fill{flex:1 1 auto!important}.flex-xxl-row{flex-direction:row!important}.flex-xxl-column{flex-direction:column!important}.flex-xxl-row-reverse{flex-direction:row-reverse!important}.flex-xxl-column-reverse{flex-direction:column-reverse!important}.flex-xxl-grow-0{flex-grow:0!important}.flex-xxl-grow-1{flex-grow:1!important}.flex-xxl-shrink-0{flex-shrink:0!important}.flex-xxl-shrink-1{flex-shrink:1!important}.flex-xxl-wrap{flex-wrap:wrap!important}.flex-xxl-nowrap{flex-wrap:nowrap!important}.flex-xxl-wrap-reverse{flex-wrap:wrap-reverse!important}.justify-content-xxl-start{justify-content:flex-start!important}.justify-content-xxl-end{justify-content:flex-end!important}.justify-content-xxl-center{justify-content:center!important}.justify-content-xxl-between{justify-content:space-between!important}.justify-content-xxl-around{justify-content:space-around!important}.justify-content-xxl-evenly{justify-content:space-evenly!important}.align-items-xxl-start{align-items:flex-start!important}.align-items-xxl-end{align-items:flex-end!important}.align-items-xxl-center{align-items:center!important}.align-items-xxl-baseline{align-items:baseline!important}.align-items-xxl-stretch{align-items:stretch!important}.align-content-xxl-start{align-content:flex-start!important}.align-content-xxl-end{align-content:flex-end!important}.align-content-xxl-center{align-content:center!important}.align-content-xxl-between{align-content:space-between!important}.align-content-xxl-around{align-content:space-around!important}.align-content-xxl-stretch{align-content:stretch!important}.align-self-xxl-auto{align-self:auto!important}.align-self-xxl-start{align-self:flex-start!important}.align-self-xxl-end{align-self:flex-end!important}.align-self-xxl-center{align-self:center!important}.align-self-xxl-baseline{align-self:baseline!important}.align-self-xxl-stretch{align-self:stretch!important}.order-xxl-first{order:-1!important}.order-xxl-0{order:0!important}.order-xxl-1{order:1!important}.order-xxl-2{order:2!important}.order-xxl-3{order:3!important}.order-xxl-4{order:4!important}.order-xxl-5{order:5!important}.order-xxl-last{order:6!important}.m-xxl-0{margin:0!important}.m-xxl-1{margin:.25rem!important}.m-xxl-2{margin:.5rem!important}.m-xxl-3{margin:1rem!important}.m-xxl-4{margin:1.5rem!important}.m-xxl-5{margin:3rem!important}.m-xxl-auto{margin:auto!important}.mx-xxl-0{margin-right:0!important;margin-left:0!important}.mx-xxl-1{margin-right:.25rem!important;margin-left:.25rem!important}.mx-xxl-2{margin-right:.5rem!important;margin-left:.5rem!important}.mx-xxl-3{margin-right:1rem!important;margin-left:1rem!important}.mx-xxl-4{margin-right:1.5rem!important;margin-left:1.5rem!important}.mx-xxl-5{margin-right:3rem!important;margin-left:3rem!important}.mx-xxl-auto{margin-right:auto!important;margin-left:auto!important}.my-xxl-0{margin-top:0!important;margin-bottom:0!important}.my-xxl-1{margin-top:.25rem!important;margin-bottom:.25rem!important}.my-xxl-2{margin-top:.5rem!important;margin-bottom:.5rem!important}.my-xxl-3{margin-top:1rem!important;margin-bottom:1rem!important}.my-xxl-4{margin-top:1.5rem!important;margin-bottom:1.5rem!important}.my-xxl-5{margin-top:3rem!important;margin-bottom:3rem!important}.my-xxl-auto{margin-top:auto!important;margin-bottom:auto!important}.mt-xxl-0{margin-top:0!important}.mt-xxl-1{margin-top:.25rem!important}.mt-xxl-2{margin-top:.5rem!important}.mt-xxl-3{margin-top:1rem!important}.mt-xxl-4{margin-top:1.5rem!important}.mt-xxl-5{margin-top:3rem!important}.mt-xxl-auto{margin-top:auto!important}.me-xxl-0{margin-right:0!important}.me-xxl-1{margin-right:.25rem!important}.me-xxl-2{margin-right:.5rem!important}.me-xxl-3{margin-right:1rem!important}.me-xxl-4{margin-right:1.5rem!important}.me-xxl-5{margin-right:3rem!important}.me-xxl-auto{margin-right:auto!important}.mb-xxl-0{margin-bottom:0!important}.mb-xxl-1{margin-bottom:.25rem!important}.mb-xxl-2{margin-bottom:.5rem!important}.mb-xxl-3{margin-bottom:1rem!important}.mb-xxl-4{margin-bottom:1.5rem!important}.mb-xxl-5{margin-bottom:3rem!important}.mb-xxl-auto{margin-bottom:auto!important}.ms-xxl-0{margin-left:0!important}.ms-xxl-1{margin-left:.25rem!important}.ms-xxl-2{margin-left:.5rem!important}.ms-xxl-3{margin-left:1rem!important}.ms-xxl-4{margin-left:1.5rem!important}.ms-xxl-5{margin-left:3rem!important}.ms-xxl-auto{margin-left:auto!important}.p-xxl-0{padding:0!important}.p-xxl-1{padding:.25rem!important}.p-xxl-2{padding:.5rem!important}.p-xxl-3{padding:1rem!important}.p-xxl-4{padding:1.5rem!important}.p-xxl-5{padding:3rem!important}.px-xxl-0{padding-right:0!important;padding-left:0!important}.px-xxl-1{padding-right:.25rem!important;padding-left:.25rem!important}.px-xxl-2{padding-right:.5rem!important;padding-left:.5rem!important}.px-xxl-3{padding-right:1rem!important;padding-left:1rem!important}.px-xxl-4{padding-right:1.5rem!important;padding-left:1.5rem!important}.px-xxl-5{padding-right:3rem!important;padding-left:3rem!important}.py-xxl-0{padding-top:0!important;padding-bottom:0!important}.py-xxl-1{padding-top:.25rem!important;padding-bottom:.25rem!important}.py-xxl-2{padding-top:.5rem!important;padding-bottom:.5rem!important}.py-xxl-3{padding-top:1rem!important;padding-bottom:1rem!important}.py-xxl-4{padding-top:1.5rem!important;padding-bottom:1.5rem!important}.py-xxl-5{padding-top:3rem!important;padding-bottom:3rem!important}.pt-xxl-0{padding-top:0!important}.pt-xxl-1{padding-top:.25rem!important}.pt-xxl-2{padding-top:.5rem!important}.pt-xxl-3{padding-top:1rem!important}.pt-xxl-4{padding-top:1.5rem!important}.pt-xxl-5{padding-top:3rem!important}.pe-xxl-0{padding-right:0!important}.pe-xxl-1{padding-right:.25rem!important}.pe-xxl-2{padding-right:.5rem!important}.pe-xxl-3{padding-right:1rem!important}.pe-xxl-4{padding-right:1.5rem!important}.pe-xxl-5{padding-right:3rem!important}.pb-xxl-0{padding-bottom:0!important}.pb-xxl-1{padding-bottom:.25rem!important}.pb-xxl-2{padding-bottom:.5rem!important}.pb-xxl-3{padding-bottom:1rem!important}.pb-xxl-4{padding-bottom:1.5rem!important}.pb-xxl-5{padding-bottom:3rem!important}.ps-xxl-0{padding-left:0!important}.ps-xxl-1{padding-left:.25rem!important}.ps-xxl-2{padding-left:.5rem!important}.ps-xxl-3{padding-left:1rem!important}.ps-xxl-4{padding-left:1.5rem!important}.ps-xxl-5{padding-left:3rem!important}.gap-xxl-0{gap:0!important}.gap-xxl-1{gap:.25rem!important}.gap-xxl-2{gap:.5rem!important}.gap-xxl-3{gap:1rem!important}.gap-xxl-4{gap:1.5rem!important}.gap-xxl-5{gap:3rem!important}.row-gap-xxl-0{row-gap:0!important}.row-gap-xxl-1{row-gap:.25rem!important}.row-gap-xxl-2{row-gap:.5rem!important}.row-gap-xxl-3{row-gap:1rem!important}.row-gap-xxl-4{row-gap:1.5rem!important}.row-gap-xxl-5{row-gap:3rem!important}.column-gap-xxl-0{column-gap:0!important}.column-gap-xxl-1{column-gap:.25rem!important}.column-gap-xxl-2{column-gap:.5rem!important}.column-gap-xxl-3{column-gap:1rem!important}.column-gap-xxl-4{column-gap:1.5rem!important}.column-gap-xxl-5{column-gap:3rem!important}.text-xxl-start{text-align:left!important}.text-xxl-end{text-align:right!important}.text-xxl-center{text-align:center!important}}@media (min-width: 1200px){.fs-1{font-size:2.5rem!important}.fs-2{font-size:2rem!important}.fs-3{font-size:1.75rem!important}.fs-4{font-size:1.5rem!important}}@media print{.d-print-inline{display:inline!important}.d-print-inline-block{display:inline-block!important}.d-print-block{display:block!important}.d-print-grid{display:grid!important}.d-print-inline-grid{display:inline-grid!important}.d-print-table{display:table!important}.d-print-table-row{display:table-row!important}.d-print-table-cell{display:table-cell!important}.d-print-flex{display:flex!important}.d-print-inline-flex{display:inline-flex!important}.d-print-none{display:none!important}}
`, "",{"version":3,"sources":["webpack://./node_modules/climb-jupyter-base-component/dist/style.css"],"names":[],"mappings":"AAAA,gBAAgB,CAAC;;;;EAIf,CAAC,4BAA4B,kBAAkB,CAAC,oBAAoB,CAAC,oBAAoB,CAAC,kBAAkB,CAAC,iBAAiB,CAAC,oBAAoB,CAAC,oBAAoB,CAAC,mBAAmB,CAAC,kBAAkB,CAAC,kBAAkB,CAAC,gBAAgB,CAAC,gBAAgB,CAAC,kBAAkB,CAAC,uBAAuB,CAAC,sBAAsB,CAAC,sBAAsB,CAAC,sBAAsB,CAAC,sBAAsB,CAAC,sBAAsB,CAAC,sBAAsB,CAAC,sBAAsB,CAAC,sBAAsB,CAAC,sBAAsB,CAAC,qBAAqB,CAAC,uBAAuB,CAAC,qBAAqB,CAAC,kBAAkB,CAAC,qBAAqB,CAAC,oBAAoB,CAAC,mBAAmB,CAAC,kBAAkB,CAAC,8BAA8B,CAAC,iCAAiC,CAAC,6BAA6B,CAAC,2BAA2B,CAAC,6BAA6B,CAAC,4BAA4B,CAAC,6BAA6B,CAAC,yBAAyB,CAAC,+CAA+C,CAAC,iDAAiD,CAAC,6CAA6C,CAAC,2CAA2C,CAAC,+CAA+C,CAAC,8CAA8C,CAAC,iCAAiC,CAAC,gCAAgC,CAAC,8CAA8C,CAAC,gDAAgD,CAAC,4CAA4C,CAAC,2CAA2C,CAAC,8CAA8C,CAAC,6CAA6C,CAAC,4CAA4C,CAAC,4BAA4B,CAAC,kDAAkD,CAAC,oDAAoD,CAAC,gDAAgD,CAAC,+CAA+C,CAAC,kDAAkD,CAAC,iDAAiD,CAAC,iCAAiC,CAAC,gCAAgC,CAAC,6BAA6B,CAAC,uBAAuB,CAAC,qNAAqN,CAAC,yGAAyG,CAAC,wFAAwF,CAAC,gDAAgD,CAAC,yBAAyB,CAAC,0BAA0B,CAAC,0BAA0B,CAAC,wBAAwB,CAAC,+BAA+B,CAAC,kBAAkB,CAAC,+BAA+B,CAAC,yBAAyB,CAAC,gCAAgC,CAAC,2CAA2C,CAAC,oCAAoC,CAAC,0BAA0B,CAAC,oCAAoC,CAAC,yCAAyC,CAAC,mCAAmC,CAAC,yBAAyB,CAAC,mCAAmC,CAAC,2BAA2B,CAAC,wBAAwB,CAAC,iCAAiC,CAAC,+BAA+B,CAAC,2CAA2C,CAAC,sCAAsC,CAAC,wBAAwB,CAAC,6BAA6B,CAAC,yCAAyC,CAAC,sBAAsB,CAAC,wBAAwB,CAAC,0BAA0B,CAAC,kDAAkD,CAAC,2BAA2B,CAAC,6BAA6B,CAAC,4BAA4B,CAAC,2BAA2B,CAAC,4BAA4B,CAAC,mDAAmD,CAAC,8BAA8B,CAAC,gDAAgD,CAAC,wDAAwD,CAAC,mDAAmD,CAAC,0DAA0D,CAAC,6BAA6B,CAAC,4BAA4B,CAAC,8CAA8C,CAAC,8BAA8B,CAAC,qCAAqC,CAAC,gCAAgC,CAAC,uCAAuC,CAAC,qBAAqB,iBAAiB,CAAC,wBAAwB,CAAC,kCAAkC,CAAC,qBAAqB,CAAC,4BAA4B,CAAC,yBAAyB,CAAC,sCAAsC,CAAC,8CAA8C,CAAC,uCAAuC,CAAC,0BAA0B,CAAC,iCAAiC,CAAC,4CAA4C,CAAC,sCAAsC,CAAC,uCAAuC,CAAC,gCAAgC,CAAC,kDAAkD,CAAC,oDAAoD,CAAC,gDAAgD,CAAC,+CAA+C,CAAC,kDAAkD,CAAC,iDAAiD,CAAC,iCAAiC,CAAC,gCAAgC,CAAC,0CAA0C,CAAC,6CAA6C,CAAC,wCAAwC,CAAC,uCAAuC,CAAC,0CAA0C,CAAC,0CAA0C,CAAC,6BAA6B,CAAC,4BAA4B,CAAC,+CAA+C,CAAC,iDAAiD,CAAC,6CAA6C,CAAC,6CAA6C,CAAC,gDAAgD,CAAC,+CAA+C,CAAC,iCAAiC,CAAC,gCAAgC,CAAC,2BAA2B,CAAC,uCAAuC,CAAC,iDAAiD,CAAC,kCAAkC,CAAC,wCAAwC,CAAC,yCAAyC,CAAC,6BAA6B,CAAC,sCAAsC,CAAC,0BAA0B,CAAC,uDAAuD,CAAC,2CAA2C,CAAC,kDAAkD,CAAC,+CAA+C,CAAC,sDAAsD,CAAC,WAAW,0BAA0B,CAAC,0DAAmV,CAAC,0BAA0B,CAAC,iCAAiC,CAAC,iEAAiE,CAAC,+BAA+B,CAAC,oCAAoC,CAAC,sBAAsB,CAAC,SAAS,CAAC,UAAU,CAAC,aAAa,CAAC,+BAA+B,CAAC,uEAAuE,CAAC,iCAAiC,CAAC,QAAQ,CAAC,qBAAqB,CAAC,mCAAmC,CAAC,iBAAiB,+BAA+B,CAAC,oBAAoB,CAAC,yCAAyC,CAAC,iBAAiB,SAAS,CAAC,2CAA2C,CAAC,yCAAyC,CAAC,wCAAwC,mBAAmB,CAAC,wBAAwB,CAAC,gBAAgB,CAAC,4CAA4C,CAAC,iBAAiB,iEAAiE,CAAC,4BAA4B,uBAAuB,CAAC,qBAAqB,iEAAiE,CAAC,gEAAgE,qBAAqB,CAAC,+CAA+C,qBAAqB,sBAAsB,CAAC,CAAC,oBAAoB,QAAQ,CAAC,sCAAsC,CAAC,kCAAkC,CAAC,sCAAsC,CAAC,sCAAsC,CAAC,0BAA0B,CAAC,oCAAoC,CAAC,kCAAkC,CAAC,6BAA6B,CAAC,yCAAyC,CAAC,kBAAkB,aAAa,CAAC,aAAa,CAAC,QAAQ,CAAC,uCAAuC,CAAC,WAAW,CAAC,8NAA8N,YAAY,CAAC,mBAAmB,CAAC,eAAe,CAAC,eAAe,CAAC,6BAA6B,CAAC,qCAAqC,gCAAgC,CAAC,2BAA2B,qCAAqC,gBAAgB,CAAC,CAAC,qCAAqC,+BAA+B,CAAC,2BAA2B,qCAAqC,cAAc,CAAC,CAAC,qCAAqC,6BAA6B,CAAC,2BAA2B,qCAAqC,iBAAiB,CAAC,CAAC,qCAAqC,+BAA+B,CAAC,2BAA2B,qCAAqC,gBAAgB,CAAC,CAAC,qCAAqC,iBAAiB,CAAC,qCAAqC,cAAc,CAAC,iBAAiB,YAAY,CAAC,kBAAkB,CAAC,2BAA2B,gCAAgC,CAAC,WAAW,CAAC,6BAA6B,CAAC,uBAAuB,kBAAkB,CAAC,iBAAiB,CAAC,mBAAmB,CAAC,oCAAoC,iBAAiB,CAAC,sDAAsD,YAAY,CAAC,kBAAkB,CAAC,oFAAoF,eAAe,CAAC,kBAAkB,eAAe,CAAC,kBAAkB,mBAAmB,CAAC,aAAa,CAAC,0BAA0B,eAAe,CAAC,uCAAuC,kBAAkB,CAAC,2CAA2C,gBAAgB,CAAC,yCAAyC,eAAe,CAAC,+BAA+B,CAAC,uCAAuC,CAAC,sCAAsC,iBAAiB,CAAC,eAAe,CAAC,aAAa,CAAC,uBAAuB,CAAC,mBAAmB,aAAa,CAAC,mBAAmB,SAAS,CAAC,iBAAiB,8DAA8D,CAAC,yBAAyB,CAAC,uBAAuB,mDAAmD,CAAC,0FAA0F,aAAa,CAAC,oBAAoB,CAAC,8EAA8E,oCAAoC,CAAC,aAAa,CAAC,mBAAmB,aAAa,CAAC,YAAY,CAAC,kBAAkB,CAAC,aAAa,CAAC,gBAAgB,CAAC,wBAAwB,iBAAiB,CAAC,aAAa,CAAC,iBAAiB,CAAC,oBAAoB,gBAAgB,CAAC,0BAA0B,CAAC,oBAAoB,CAAC,sBAAsB,aAAa,CAAC,mBAAmB,wBAAwB,CAAC,gBAAgB,CAAC,uBAAuB,CAAC,qCAAqC,CAAC,oBAAoB,CAAC,uBAAuB,SAAS,CAAC,aAAa,CAAC,sBAAsB,eAAe,CAAC,sCAAsC,qBAAqB,CAAC,qBAAqB,mBAAmB,CAAC,wBAAwB,CAAC,uBAAuB,iBAAiB,CAAC,oBAAoB,CAAC,+BAA+B,CAAC,eAAe,CAAC,kBAAkB,kBAAkB,CAAC,+BAA+B,CAAC,qHAAqH,oBAAoB,CAAC,kBAAkB,CAAC,cAAc,CAAC,qBAAqB,oBAAoB,CAAC,sBAAsB,eAAe,CAAC,gDAAgD,SAAS,CAAC,iHAAiH,QAAQ,CAAC,mBAAmB,CAAC,iBAAiB,CAAC,mBAAmB,CAAC,4CAA4C,mBAAmB,CAAC,6BAA6B,cAAc,CAAC,sBAAsB,gBAAgB,CAAC,+BAA+B,SAAS,CAAC,yJAAyJ,sBAAsB,CAAC,4GAA4G,yBAAyB,CAAC,wKAAwK,cAAc,CAAC,kCAAkC,SAAS,CAAC,iBAAiB,CAAC,wBAAwB,eAAe,CAAC,wBAAwB,WAAW,CAAC,SAAS,CAAC,QAAQ,CAAC,QAAQ,CAAC,sBAAsB,UAAU,CAAC,UAAU,CAAC,SAAS,CAAC,mBAAmB,CAAC,mBAAmB,CAAC,+BAA+B,CAAC,2BAA2B,sBAAsB,gBAAgB,CAAC,CAAC,wBAAwB,UAAU,CAAC,wVAAwV,SAAS,CAAC,2CAA2C,WAAW,CAAC,6BAA6B,4BAA4B,CAAC,mBAAmB,CAAC,2DAA2D,cAAc,CAAC,mBAAmB,CAAC,2CAA2C,uBAAuB,CAAC,8CAA8C,SAAS,CAAC,sCAAsC,YAAY,CAAC,yBAAyB,CAAC,sBAAsB,oBAAoB,CAAC,sBAAsB,QAAQ,CAAC,uBAAuB,iBAAiB,CAAC,cAAc,CAAC,wBAAwB,uBAAuB,CAAC,wBAAwB,sBAAsB,CAAC,qBAAqB,iBAAiB,CAAC,eAAe,CAAC,0BAA0B,eAAe,CAAC,eAAe,CAAC,gCAAgC,CAAC,2BAA2B,0BAA0B,cAAc,CAAC,CAAC,0BAA0B,eAAe,CAAC,eAAe,CAAC,gCAAgC,CAAC,2BAA2B,0BAA0B,gBAAgB,CAAC,CAAC,0BAA0B,eAAe,CAAC,eAAe,CAAC,gCAAgC,CAAC,2BAA2B,0BAA0B,cAAc,CAAC,CAAC,0BAA0B,eAAe,CAAC,eAAe,CAAC,gCAAgC,CAAC,2BAA2B,0BAA0B,gBAAgB,CAAC,CAAC,0BAA0B,eAAe,CAAC,eAAe,CAAC,gCAAgC,CAAC,2BAA2B,0BAA0B,cAAc,CAAC,CAAC,0BAA0B,eAAe,CAAC,eAAe,CAAC,gCAAgC,CAAC,2BAA2B,0BAA0B,gBAAgB,CAAC,CAAC,0DAA0D,cAAc,CAAC,eAAe,CAAC,iCAAiC,oBAAoB,CAAC,kDAAkD,kBAAkB,CAAC,2BAA2B,gBAAgB,CAAC,wBAAwB,CAAC,2BAA2B,kBAAkB,CAAC,iBAAiB,CAAC,uCAAuC,eAAe,CAAC,kCAAkC,gBAAgB,CAAC,kBAAkB,CAAC,gBAAgB,CAAC,aAAa,CAAC,yCAAyC,YAAY,CAAC,4MAA4M,qBAAqB,CAAC,gBAAgB,CAAC,UAAU,CAAC,2CAA2C,CAAC,0CAA0C,CAAC,iBAAiB,CAAC,gBAAgB,CAAC,0BAA0B,uDAAuD,eAAe,CAAC,CAAC,0BAA0B,oFAAoF,eAAe,CAAC,CAAC,0BAA0B,iHAAiH,eAAe,CAAC,CAAC,2BAA2B,8IAA8I,gBAAgB,CAAC,CAAC,2BAA2B,4KAA4K,gBAAgB,CAAC,CAAC,qBAAqB,qBAAqB,CAAC,yBAAyB,CAAC,yBAAyB,CAAC,yBAAyB,CAAC,0BAA0B,CAAC,2BAA2B,CAAC,oBAAoB,qBAAqB,CAAC,gBAAgB,CAAC,YAAY,CAAC,cAAc,CAAC,wCAAwC,CAAC,2CAA2C,CAAC,0CAA0C,CAAC,sBAAsB,aAAa,CAAC,UAAU,CAAC,cAAc,CAAC,2CAA2C,CAAC,0CAA0C,CAAC,6BAA6B,CAAC,oBAAoB,UAAU,CAAC,gCAAgC,aAAa,CAAC,UAAU,CAAC,6BAA6B,aAAa,CAAC,UAAU,CAAC,6BAA6B,aAAa,CAAC,SAAS,CAAC,6BAA6B,aAAa,CAAC,kBAAkB,CAAC,6BAA6B,aAAa,CAAC,SAAS,CAAC,6BAA6B,aAAa,CAAC,SAAS,CAAC,6BAA6B,aAAa,CAAC,kBAAkB,CAAC,yBAAyB,aAAa,CAAC,UAAU,CAAC,sBAAsB,aAAa,CAAC,iBAAiB,CAAC,sBAAsB,aAAa,CAAC,kBAAkB,CAAC,sBAAsB,aAAa,CAAC,SAAS,CAAC,sBAAsB,aAAa,CAAC,kBAAkB,CAAC,sBAAsB,aAAa,CAAC,kBAAkB,CAAC,sBAAsB,aAAa,CAAC,SAAS,CAAC,sBAAsB,aAAa,CAAC,kBAAkB,CAAC,sBAAsB,aAAa,CAAC,kBAAkB,CAAC,sBAAsB,aAAa,CAAC,SAAS,CAAC,uBAAuB,aAAa,CAAC,kBAAkB,CAAC,uBAAuB,aAAa,CAAC,kBAAkB,CAAC,uBAAuB,aAAa,CAAC,UAAU,CAAC,yBAAyB,uBAAuB,CAAC,yBAAyB,wBAAwB,CAAC,yBAAyB,eAAe,CAAC,yBAAyB,wBAAwB,CAAC,yBAAyB,wBAAwB,CAAC,yBAAyB,eAAe,CAAC,yBAAyB,wBAAwB,CAAC,yBAAyB,wBAAwB,CAAC,yBAAyB,eAAe,CAAC,0BAA0B,wBAAwB,CAAC,0BAA0B,wBAAwB,CAAC,yCAAyC,gBAAgB,CAAC,yCAAyC,gBAAgB,CAAC,yCAAyC,qBAAqB,CAAC,yCAAyC,qBAAqB,CAAC,yCAAyC,oBAAoB,CAAC,yCAAyC,oBAAoB,CAAC,yCAAyC,mBAAmB,CAAC,yCAAyC,mBAAmB,CAAC,yCAAyC,qBAAqB,CAAC,yCAAyC,qBAAqB,CAAC,yCAAyC,mBAAmB,CAAC,yCAAyC,mBAAmB,CAAC,0BAA0B,uBAAuB,UAAU,CAAC,mCAAmC,aAAa,CAAC,UAAU,CAAC,gCAAgC,aAAa,CAAC,UAAU,CAAC,gCAAgC,aAAa,CAAC,SAAS,CAAC,gCAAgC,aAAa,CAAC,kBAAkB,CAAC,gCAAgC,aAAa,CAAC,SAAS,CAAC,gCAAgC,aAAa,CAAC,SAAS,CAAC,gCAAgC,aAAa,CAAC,kBAAkB,CAAC,4BAA4B,aAAa,CAAC,UAAU,CAAC,yBAAyB,aAAa,CAAC,iBAAiB,CAAC,yBAAyB,aAAa,CAAC,kBAAkB,CAAC,yBAAyB,aAAa,CAAC,SAAS,CAAC,yBAAyB,aAAa,CAAC,kBAAkB,CAAC,yBAAyB,aAAa,CAAC,kBAAkB,CAAC,yBAAyB,aAAa,CAAC,SAAS,CAAC,yBAAyB,aAAa,CAAC,kBAAkB,CAAC,yBAAyB,aAAa,CAAC,kBAAkB,CAAC,yBAAyB,aAAa,CAAC,SAAS,CAAC,0BAA0B,aAAa,CAAC,kBAAkB,CAAC,0BAA0B,aAAa,CAAC,kBAAkB,CAAC,0BAA0B,aAAa,CAAC,UAAU,CAAC,4BAA4B,aAAa,CAAC,4BAA4B,uBAAuB,CAAC,4BAA4B,wBAAwB,CAAC,4BAA4B,eAAe,CAAC,4BAA4B,wBAAwB,CAAC,4BAA4B,wBAAwB,CAAC,4BAA4B,eAAe,CAAC,4BAA4B,wBAAwB,CAAC,4BAA4B,wBAAwB,CAAC,4BAA4B,eAAe,CAAC,6BAA6B,wBAAwB,CAAC,6BAA6B,wBAAwB,CAAC,+CAA+C,gBAAgB,CAAC,+CAA+C,gBAAgB,CAAC,+CAA+C,qBAAqB,CAAC,+CAA+C,qBAAqB,CAAC,+CAA+C,oBAAoB,CAAC,+CAA+C,oBAAoB,CAAC,+CAA+C,mBAAmB,CAAC,+CAA+C,mBAAmB,CAAC,+CAA+C,qBAAqB,CAAC,+CAA+C,qBAAqB,CAAC,+CAA+C,mBAAmB,CAAC,+CAA+C,mBAAmB,CAAC,CAAC,0BAA0B,uBAAuB,UAAU,CAAC,mCAAmC,aAAa,CAAC,UAAU,CAAC,gCAAgC,aAAa,CAAC,UAAU,CAAC,gCAAgC,aAAa,CAAC,SAAS,CAAC,gCAAgC,aAAa,CAAC,kBAAkB,CAAC,gCAAgC,aAAa,CAAC,SAAS,CAAC,gCAAgC,aAAa,CAAC,SAAS,CAAC,gCAAgC,aAAa,CAAC,kBAAkB,CAAC,4BAA4B,aAAa,CAAC,UAAU,CAAC,yBAAyB,aAAa,CAAC,iBAAiB,CAAC,yBAAyB,aAAa,CAAC,kBAAkB,CAAC,yBAAyB,aAAa,CAAC,SAAS,CAAC,yBAAyB,aAAa,CAAC,kBAAkB,CAAC,yBAAyB,aAAa,CAAC,kBAAkB,CAAC,yBAAyB,aAAa,CAAC,SAAS,CAAC,yBAAyB,aAAa,CAAC,kBAAkB,CAAC,yBAAyB,aAAa,CAAC,kBAAkB,CAAC,yBAAyB,aAAa,CAAC,SAAS,CAAC,0BAA0B,aAAa,CAAC,kBAAkB,CAAC,0BAA0B,aAAa,CAAC,kBAAkB,CAAC,0BAA0B,aAAa,CAAC,UAAU,CAAC,4BAA4B,aAAa,CAAC,4BAA4B,uBAAuB,CAAC,4BAA4B,wBAAwB,CAAC,4BAA4B,eAAe,CAAC,4BAA4B,wBAAwB,CAAC,4BAA4B,wBAAwB,CAAC,4BAA4B,eAAe,CAAC,4BAA4B,wBAAwB,CAAC,4BAA4B,wBAAwB,CAAC,4BAA4B,eAAe,CAAC,6BAA6B,wBAAwB,CAAC,6BAA6B,wBAAwB,CAAC,+CAA+C,gBAAgB,CAAC,+CAA+C,gBAAgB,CAAC,+CAA+C,qBAAqB,CAAC,+CAA+C,qBAAqB,CAAC,+CAA+C,oBAAoB,CAAC,+CAA+C,oBAAoB,CAAC,+CAA+C,mBAAmB,CAAC,+CAA+C,mBAAmB,CAAC,+CAA+C,qBAAqB,CAAC,+CAA+C,qBAAqB,CAAC,+CAA+C,mBAAmB,CAAC,+CAA+C,mBAAmB,CAAC,CAAC,0BAA0B,uBAAuB,UAAU,CAAC,mCAAmC,aAAa,CAAC,UAAU,CAAC,gCAAgC,aAAa,CAAC,UAAU,CAAC,gCAAgC,aAAa,CAAC,SAAS,CAAC,gCAAgC,aAAa,CAAC,kBAAkB,CAAC,gCAAgC,aAAa,CAAC,SAAS,CAAC,gCAAgC,aAAa,CAAC,SAAS,CAAC,gCAAgC,aAAa,CAAC,kBAAkB,CAAC,4BAA4B,aAAa,CAAC,UAAU,CAAC,yBAAyB,aAAa,CAAC,iBAAiB,CAAC,yBAAyB,aAAa,CAAC,kBAAkB,CAAC,yBAAyB,aAAa,CAAC,SAAS,CAAC,yBAAyB,aAAa,CAAC,kBAAkB,CAAC,yBAAyB,aAAa,CAAC,kBAAkB,CAAC,yBAAyB,aAAa,CAAC,SAAS,CAAC,yBAAyB,aAAa,CAAC,kBAAkB,CAAC,yBAAyB,aAAa,CAAC,kBAAkB,CAAC,yBAAyB,aAAa,CAAC,SAAS,CAAC,0BAA0B,aAAa,CAAC,kBAAkB,CAAC,0BAA0B,aAAa,CAAC,kBAAkB,CAAC,0BAA0B,aAAa,CAAC,UAAU,CAAC,4BAA4B,aAAa,CAAC,4BAA4B,uBAAuB,CAAC,4BAA4B,wBAAwB,CAAC,4BAA4B,eAAe,CAAC,4BAA4B,wBAAwB,CAAC,4BAA4B,wBAAwB,CAAC,4BAA4B,eAAe,CAAC,4BAA4B,wBAAwB,CAAC,4BAA4B,wBAAwB,CAAC,4BAA4B,eAAe,CAAC,6BAA6B,wBAAwB,CAAC,6BAA6B,wBAAwB,CAAC,+CAA+C,gBAAgB,CAAC,+CAA+C,gBAAgB,CAAC,+CAA+C,qBAAqB,CAAC,+CAA+C,qBAAqB,CAAC,+CAA+C,oBAAoB,CAAC,+CAA+C,oBAAoB,CAAC,+CAA+C,mBAAmB,CAAC,+CAA+C,mBAAmB,CAAC,+CAA+C,qBAAqB,CAAC,+CAA+C,qBAAqB,CAAC,+CAA+C,mBAAmB,CAAC,+CAA+C,mBAAmB,CAAC,CAAC,2BAA2B,uBAAuB,UAAU,CAAC,mCAAmC,aAAa,CAAC,UAAU,CAAC,gCAAgC,aAAa,CAAC,UAAU,CAAC,gCAAgC,aAAa,CAAC,SAAS,CAAC,gCAAgC,aAAa,CAAC,kBAAkB,CAAC,gCAAgC,aAAa,CAAC,SAAS,CAAC,gCAAgC,aAAa,CAAC,SAAS,CAAC,gCAAgC,aAAa,CAAC,kBAAkB,CAAC,4BAA4B,aAAa,CAAC,UAAU,CAAC,yBAAyB,aAAa,CAAC,iBAAiB,CAAC,yBAAyB,aAAa,CAAC,kBAAkB,CAAC,yBAAyB,aAAa,CAAC,SAAS,CAAC,yBAAyB,aAAa,CAAC,kBAAkB,CAAC,yBAAyB,aAAa,CAAC,kBAAkB,CAAC,yBAAyB,aAAa,CAAC,SAAS,CAAC,yBAAyB,aAAa,CAAC,kBAAkB,CAAC,yBAAyB,aAAa,CAAC,kBAAkB,CAAC,yBAAyB,aAAa,CAAC,SAAS,CAAC,0BAA0B,aAAa,CAAC,kBAAkB,CAAC,0BAA0B,aAAa,CAAC,kBAAkB,CAAC,0BAA0B,aAAa,CAAC,UAAU,CAAC,4BAA4B,aAAa,CAAC,4BAA4B,uBAAuB,CAAC,4BAA4B,wBAAwB,CAAC,4BAA4B,eAAe,CAAC,4BAA4B,wBAAwB,CAAC,4BAA4B,wBAAwB,CAAC,4BAA4B,eAAe,CAAC,4BAA4B,wBAAwB,CAAC,4BAA4B,wBAAwB,CAAC,4BAA4B,eAAe,CAAC,6BAA6B,wBAAwB,CAAC,6BAA6B,wBAAwB,CAAC,+CAA+C,gBAAgB,CAAC,+CAA+C,gBAAgB,CAAC,+CAA+C,qBAAqB,CAAC,+CAA+C,qBAAqB,CAAC,+CAA+C,oBAAoB,CAAC,+CAA+C,oBAAoB,CAAC,+CAA+C,mBAAmB,CAAC,+CAA+C,mBAAmB,CAAC,+CAA+C,qBAAqB,CAAC,+CAA+C,qBAAqB,CAAC,+CAA+C,mBAAmB,CAAC,+CAA+C,mBAAmB,CAAC,CAAC,2BAA2B,wBAAwB,UAAU,CAAC,oCAAoC,aAAa,CAAC,UAAU,CAAC,iCAAiC,aAAa,CAAC,UAAU,CAAC,iCAAiC,aAAa,CAAC,SAAS,CAAC,iCAAiC,aAAa,CAAC,kBAAkB,CAAC,iCAAiC,aAAa,CAAC,SAAS,CAAC,iCAAiC,aAAa,CAAC,SAAS,CAAC,iCAAiC,aAAa,CAAC,kBAAkB,CAAC,6BAA6B,aAAa,CAAC,UAAU,CAAC,0BAA0B,aAAa,CAAC,iBAAiB,CAAC,0BAA0B,aAAa,CAAC,kBAAkB,CAAC,0BAA0B,aAAa,CAAC,SAAS,CAAC,0BAA0B,aAAa,CAAC,kBAAkB,CAAC,0BAA0B,aAAa,CAAC,kBAAkB,CAAC,0BAA0B,aAAa,CAAC,SAAS,CAAC,0BAA0B,aAAa,CAAC,kBAAkB,CAAC,0BAA0B,aAAa,CAAC,kBAAkB,CAAC,0BAA0B,aAAa,CAAC,SAAS,CAAC,2BAA2B,aAAa,CAAC,kBAAkB,CAAC,2BAA2B,aAAa,CAAC,kBAAkB,CAAC,2BAA2B,aAAa,CAAC,UAAU,CAAC,6BAA6B,aAAa,CAAC,6BAA6B,uBAAuB,CAAC,6BAA6B,wBAAwB,CAAC,6BAA6B,eAAe,CAAC,6BAA6B,wBAAwB,CAAC,6BAA6B,wBAAwB,CAAC,6BAA6B,eAAe,CAAC,6BAA6B,wBAAwB,CAAC,6BAA6B,wBAAwB,CAAC,6BAA6B,eAAe,CAAC,8BAA8B,wBAAwB,CAAC,8BAA8B,wBAAwB,CAAC,iDAAiD,gBAAgB,CAAC,iDAAiD,gBAAgB,CAAC,iDAAiD,qBAAqB,CAAC,iDAAiD,qBAAqB,CAAC,iDAAiD,oBAAoB,CAAC,iDAAiD,oBAAoB,CAAC,iDAAiD,mBAAmB,CAAC,iDAAiD,mBAAmB,CAAC,iDAAiD,qBAAqB,CAAC,iDAAiD,qBAAqB,CAAC,iDAAiD,mBAAmB,CAAC,iDAAiD,mBAAmB,CAAC,CAAC,2BAA2B,mBAAmB,CAAC,+BAA+B,kDAAkD,CAAC,qDAAqD,CAAC,eAAe,CAAC,iBAAiB,CAAC,eAAe,CAAC,kCAAkC,gDAAgD,CAAC,mDAAmD,CAAC,iBAAiB,CAAC,kCAAkC,iDAAiD,CAAC,oDAAoD,CAAC,iBAAiB,CAAC,0BAA0B,iBAAiB,CAAC,gBAAgB,CAAC,+BAA+B,CAAC,6BAA6B,aAAa,CAAC,UAAU,CAAC,sBAAsB,CAAC,cAAc,CAAC,eAAe,CAAC,eAAe,CAAC,0BAA0B,CAAC,uBAAuB,CAAC,oBAAoB,CAAC,eAAe,CAAC,kCAAkC,CAAC,2BAA2B,CAAC,0DAA0D,CAAC,qCAAqC,CAAC,oEAAoE,CAAC,wCAAwC,6BAA6B,eAAe,CAAC,CAAC,wCAAwC,eAAe,CAAC,uEAAuE,cAAc,CAAC,mCAAmC,0BAA0B,CAAC,kCAAkC,CAAC,oBAAoB,CAAC,SAAS,CAAC,iCAAiC,CAAC,0DAA0D,cAAc,CAAC,YAAY,CAAC,QAAQ,CAAC,oDAAoD,aAAa,CAAC,SAAS,CAAC,0CAA0C,+BAA+B,CAAC,SAAS,CAAC,sCAAsC,uCAAuC,CAAC,SAAS,CAAC,mDAAmD,sBAAsB,CAAC,uBAAuB,CAAC,wBAAwB,CAAC,0BAA0B,CAAC,sCAAsC,CAAC,mBAAmB,CAAC,oBAAoB,CAAC,kBAAkB,CAAC,cAAc,CAAC,8CAA8C,CAAC,eAAe,CAAC,6HAA6H,CAAC,wCAAwC,mDAAmD,eAAe,CAAC,CAAC,wFAAwF,uCAAuC,CAAC,uCAAuC,aAAa,CAAC,UAAU,CAAC,iBAAiB,CAAC,eAAe,CAAC,eAAe,CAAC,0BAA0B,CAAC,4BAA4B,CAAC,wBAAwB,CAAC,qCAAqC,CAAC,6CAA6C,SAAS,CAAC,8GAA8G,eAAe,CAAC,cAAc,CAAC,gCAAgC,iEAAiE,CAAC,oBAAoB,CAAC,iBAAiB,CAAC,wCAAwC,CAAC,sDAAsD,oBAAoB,CAAC,qBAAqB,CAAC,uBAAuB,CAAC,gCAAgC,gEAAgE,CAAC,kBAAkB,CAAC,iBAAiB,CAAC,wCAAwC,CAAC,sDAAsD,kBAAkB,CAAC,mBAAmB,CAAC,sBAAsB,CAAC,qCAAqC,kEAAkE,CAAC,wCAAwC,iEAAiE,CAAC,wCAAwC,gEAAgE,CAAC,mCAAmC,UAAU,CAAC,8DAA8D,CAAC,eAAe,CAAC,kEAAkE,cAAc,CAAC,sDAAsD,kBAAkB,CAAC,qCAAqC,CAAC,yDAAyD,kBAAkB,CAAC,qCAAqC,CAAC,mDAAmD,6DAA6D,CAAC,mDAAmD,4DAA4D,CAAC,4BAA4B,gEAAwP,CAAC,aAAa,CAAC,UAAU,CAAC,sCAAsC,CAAC,cAAc,CAAC,eAAe,CAAC,eAAe,CAAC,0BAA0B,CAAC,uBAAuB,CAAC,oBAAoB,CAAC,eAAe,CAAC,kCAAkC,CAAC,iFAAiF,CAAC,2BAA2B,CAAC,uCAAuC,CAAC,yBAAyB,CAAC,0DAA0D,CAAC,qCAAqC,CAAC,oEAAoE,CAAC,wCAAwC,4BAA4B,eAAe,CAAC,CAAC,kCAAkC,oBAAoB,CAAC,SAAS,CAAC,iCAAiC,CAAC,wFAAwF,oBAAoB,CAAC,qBAAqB,CAAC,qCAAqC,uCAAuC,CAAC,2CAA2C,iBAAiB,CAAC,sCAAsC,CAAC,+BAA+B,kBAAkB,CAAC,qBAAqB,CAAC,kBAAkB,CAAC,iBAAiB,CAAC,wCAAwC,CAAC,+BAA+B,iBAAiB,CAAC,oBAAoB,CAAC,iBAAiB,CAAC,iBAAiB,CAAC,wCAAwC,CAAC,iDAAiD,gEAAwP,CAAC,2BAA2B,aAAa,CAAC,iBAAiB,CAAC,kBAAkB,CAAC,qBAAqB,CAAC,6CAA6C,UAAU,CAAC,kBAAkB,CAAC,mCAAmC,mBAAmB,CAAC,cAAc,CAAC,gBAAgB,CAAC,qDAAqD,WAAW,CAAC,mBAAmB,CAAC,aAAa,CAAC,iCAAiC,qCAAqC,CAAC,aAAa,CAAC,SAAS,CAAC,UAAU,CAAC,gBAAgB,CAAC,kBAAkB,CAAC,uBAAuB,CAAC,oBAAoB,CAAC,eAAe,CAAC,wCAAwC,CAAC,8CAA8C,CAAC,2BAA2B,CAAC,0BAA0B,CAAC,uBAAuB,CAAC,0DAA0D,CAAC,gCAAgC,CAAC,wBAAwB,CAAC,gDAAgD,mBAAmB,CAAC,6CAA6C,iBAAiB,CAAC,wCAAwC,sBAAsB,CAAC,uCAAuC,oBAAoB,CAAC,SAAS,CAAC,iCAAiC,CAAC,yCAAyC,wBAAwB,CAAC,oBAAoB,CAAC,wDAAwD,iEAAuP,CAAC,qDAAqD,iEAA+J,CAAC,8DAA8D,wBAAwB,CAAC,oBAAoB,CAAC,iEAAiP,CAAC,0CAA0C,mBAAmB,CAAC,WAAW,CAAC,UAAU,CAAC,yHAAyH,cAAc,CAAC,UAAU,CAAC,4BAA4B,kBAAkB,CAAC,8CAA8C,4DAA2K,CAAC,SAAS,CAAC,kBAAkB,CAAC,yCAAyC,CAAC,+BAA+B,CAAC,iBAAiB,CAAC,+CAA+C,CAAC,wCAAwC,8CAA8C,eAAe,CAAC,CAAC,oDAAoD,4DAA4K,CAAC,sDAAsD,gCAAgC,CAAC,4DAA0J,CAAC,+CAA+C,mBAAmB,CAAC,cAAc,CAAC,iEAAiE,mBAAmB,CAAC,aAAa,CAAC,kCAAkC,oBAAoB,CAAC,iBAAiB,CAAC,0BAA0B,iBAAiB,CAAC,kBAAkB,CAAC,mBAAmB,CAAC,iFAAiF,mBAAmB,CAAC,WAAW,CAAC,WAAW,CAAC,6FAA6F,4DAAiL,CAAC,2BAA2B,UAAU,CAAC,aAAa,CAAC,SAAS,CAAC,uBAAuB,CAAC,oBAAoB,CAAC,eAAe,CAAC,4BAA4B,CAAC,iCAAiC,SAAS,CAAC,uDAAuD,gDAAgD,CAAC,mDAAmD,gDAAgD,CAAC,6CAA6C,QAAQ,CAAC,iDAAiD,UAAU,CAAC,WAAW,CAAC,kBAAkB,CAAC,uBAAuB,CAAC,oBAAoB,CAAC,eAAe,CAAC,wBAAwB,CAAC,QAAQ,CAAC,kBAAkB,CAAC,sGAAsG,CAAC,wCAAwC,iDAAiD,eAAe,CAAC,CAAC,wDAAwD,wBAAwB,CAAC,0DAA0D,UAAU,CAAC,YAAY,CAAC,iBAAiB,CAAC,cAAc,CAAC,uCAAuC,CAAC,wBAAwB,CAAC,kBAAkB,CAAC,6CAA6C,UAAU,CAAC,WAAW,CAAC,uBAAuB,CAAC,oBAAoB,CAAC,eAAe,CAAC,wBAAwB,CAAC,QAAQ,CAAC,kBAAkB,CAAC,sGAAsG,CAAC,wCAAwC,6CAA6C,eAAe,CAAC,CAAC,oDAAoD,wBAAwB,CAAC,6CAA6C,UAAU,CAAC,YAAY,CAAC,iBAAiB,CAAC,cAAc,CAAC,uCAAuC,CAAC,wBAAwB,CAAC,kBAAkB,CAAC,oCAAoC,mBAAmB,CAAC,0DAA0D,0CAA0C,CAAC,sDAAsD,0CAA0C,CAAC,8BAA8B,iBAAiB,CAAC,6IAA6I,sDAAsD,CAAC,0DAA0D,CAAC,gBAAgB,CAAC,oCAAoC,iBAAiB,CAAC,KAAK,CAAC,MAAM,CAAC,SAAS,CAAC,cAAc,CAAC,WAAW,CAAC,mBAAmB,CAAC,eAAe,CAAC,wCAAwC,CAAC,gBAAgB,CAAC,sBAAsB,CAAC,kBAAkB,CAAC,mBAAmB,CAAC,+CAA+C,CAAC,oBAAoB,CAAC,4DAA4D,CAAC,wCAAwC,oCAAoC,eAAe,CAAC,CAAC,kGAAkG,mBAAmB,CAAC,4HAA4H,iBAAiB,CAAC,gQAAgQ,oBAAoB,CAAC,sBAAsB,CAAC,oIAAoI,oBAAoB,CAAC,sBAAsB,CAAC,2CAA2C,oBAAoB,CAAC,sBAAsB,CAAC,mBAAmB,CAAC,+OAA+O,yDAAyD,CAAC,mEAAmE,yDAAyD,CAAC,oIAAoI,iBAAiB,CAAC,QAAQ,CAAC,aAAa,CAAC,WAAW,CAAC,YAAY,CAAC,UAAU,CAAC,YAAY,CAAC,UAAU,CAAC,kCAAkC,CAAC,qCAAqC,CAAC,4DAA4D,uCAAuC,CAAC,4DAA4D,qCAAqC,CAAC,yGAAyG,aAAa,CAAC,4BAA4B,iBAAiB,CAAC,YAAY,CAAC,cAAc,CAAC,mBAAmB,CAAC,UAAU,CAAC,8HAA8H,iBAAiB,CAAC,aAAa,CAAC,QAAQ,CAAC,WAAW,CAAC,uJAAuJ,SAAS,CAAC,iCAAiC,iBAAiB,CAAC,SAAS,CAAC,uCAAuC,SAAS,CAAC,iCAAiC,YAAY,CAAC,kBAAkB,CAAC,sBAAsB,CAAC,cAAc,CAAC,eAAe,CAAC,eAAe,CAAC,0BAA0B,CAAC,iBAAiB,CAAC,kBAAkB,CAAC,sCAAsC,CAAC,0DAA0D,CAAC,qCAAqC,CAAC,8KAA8K,kBAAkB,CAAC,iBAAiB,CAAC,wCAAwC,CAAC,8KAA8K,oBAAoB,CAAC,iBAAiB,CAAC,wCAAwC,CAAC,wFAAwF,kBAAkB,CAAC,oZAAoZ,yBAAyB,CAAC,4BAA4B,CAAC,qYAAqY,yBAAyB,CAAC,4BAA4B,CAAC,yJAAyJ,6CAA6C,CAAC,wBAAwB,CAAC,2BAA2B,CAAC,qJAAqJ,wBAAwB,CAAC,2BAA2B,CAAC,+BAA+B,YAAY,CAAC,UAAU,CAAC,iBAAiB,CAAC,gBAAgB,CAAC,gCAAgC,CAAC,8BAA8B,iBAAiB,CAAC,QAAQ,CAAC,SAAS,CAAC,YAAY,CAAC,cAAc,CAAC,oBAAoB,CAAC,gBAAgB,CAAC,iBAAiB,CAAC,UAAU,CAAC,kCAAkC,CAAC,qCAAqC,CAAC,sLAAsL,aAAa,CAAC,wFAAwF,8CAA8C,CAAC,kCAAkC,CAAC,yDAAyP,CAAC,2BAA2B,CAAC,wDAAwD,CAAC,2DAA2D,CAAC,oGAAoG,8CAA8C,CAAC,uDAAuD,CAAC,wGAAwG,kCAAkC,CAAC,6EAA6E,CAAC,sFAAsF,8CAA8C,CAAC,wRAAwR,kEAAkQ,CAAC,sBAAsB,CAAC,4DAA4D,CAAC,qEAAqE,CAAC,kGAAkG,8CAA8C,CAAC,uDAAuD,CAAC,oGAAoG,2BAA2B,CAAC,gGAAgG,8CAA8C,CAAC,gHAAgH,2CAA2C,CAAC,4GAA4G,uDAAuD,CAAC,oIAAoI,gCAAgC,CAAC,oEAAoE,gBAAgB,CAAC,4aAA4a,SAAS,CAAC,iCAAiC,YAAY,CAAC,UAAU,CAAC,iBAAiB,CAAC,gBAAgB,CAAC,kCAAkC,CAAC,gCAAgC,iBAAiB,CAAC,QAAQ,CAAC,SAAS,CAAC,YAAY,CAAC,cAAc,CAAC,oBAAoB,CAAC,gBAAgB,CAAC,iBAAiB,CAAC,UAAU,CAAC,iCAAiC,CAAC,qCAAqC,CAAC,sMAAsM,aAAa,CAAC,4FAA4F,gDAAgD,CAAC,kCAAkC,CAAC,yDAA2U,CAAC,2BAA2B,CAAC,wDAAwD,CAAC,2DAA2D,CAAC,wGAAwG,gDAAgD,CAAC,sDAAsD,CAAC,4GAA4G,kCAAkC,CAAC,6EAA6E,CAAC,0FAA0F,gDAAgD,CAAC,gSAAgS,kEAAoV,CAAC,sBAAsB,CAAC,4DAA4D,CAAC,qEAAqE,CAAC,sGAAsG,gDAAgD,CAAC,sDAAsD,CAAC,wGAAwG,2BAA2B,CAAC,oGAAoG,gDAAgD,CAAC,oHAAoH,6CAA6C,CAAC,gHAAgH,sDAAsD,CAAC,wIAAwI,kCAAkC,CAAC,sEAAsE,gBAAgB,CAAC,wbAAwb,SAAS,CAAC,oBAAoB,0BAA0B,CAAC,2BAA2B,CAAC,sBAAsB,CAAC,wBAAwB,CAAC,yBAAyB,CAAC,yBAAyB,CAAC,oCAAoC,CAAC,wBAAwB,CAAC,6CAA6C,CAAC,kCAAkC,CAAC,+CAA+C,CAAC,wCAAwC,CAAC,0FAA0F,CAAC,8BAA8B,CAAC,gFAAgF,CAAC,oBAAoB,CAAC,uDAAuD,CAAC,qCAAqC,CAAC,iCAAiC,CAAC,qCAAqC,CAAC,qCAAqC,CAAC,yBAAyB,CAAC,iBAAiB,CAAC,oBAAoB,CAAC,qBAAqB,CAAC,cAAc,CAAC,wBAAwB,CAAC,gBAAgB,CAAC,kEAAkE,CAAC,yCAAyC,CAAC,iCAAiC,CAAC,6HAA6H,CAAC,wCAAwC,oBAAoB,eAAe,CAAC,CAAC,0BAA0B,+BAA+B,CAAC,uCAAuC,CAAC,6CAA6C,CAAC,qCAAqC,yBAAyB,CAAC,iCAAiC,CAAC,uCAAuC,CAAC,kCAAkC,+BAA+B,CAAC,uCAAuC,CAAC,6CAA6C,CAAC,SAAS,CAAC,yCAAyC,CAAC,6CAA6C,6CAA6C,CAAC,SAAS,CAAC,yCAAyC,CAAC,8KAA8K,gCAAgC,CAAC,wCAAwC,CAAC,8CAA8C,CAAC,oPAAoP,yCAAyC,CAAC,qDAAqD,yCAAyC,CAAC,gGAAgG,kCAAkC,CAAC,mBAAmB,CAAC,0CAA0C,CAAC,gDAAgD,CAAC,sCAAsC,CAAC,4BAA4B,oBAAoB,CAAC,oBAAoB,CAAC,8BAA8B,CAAC,0BAA0B,CAAC,2CAA2C,CAAC,iDAAiD,CAAC,uCAAuC,CAAC,2BAA2B,CAAC,wCAAwC,CAAC,qDAAqD,CAAC,2DAA2D,CAAC,6BAA6B,CAAC,6BAA6B,CAAC,uCAAuC,CAAC,8BAA8B,oBAAoB,CAAC,oBAAoB,CAAC,8BAA8B,CAAC,0BAA0B,CAAC,2CAA2C,CAAC,iDAAiD,CAAC,wCAAwC,CAAC,2BAA2B,CAAC,wCAAwC,CAAC,mDAAmD,CAAC,2DAA2D,CAAC,6BAA6B,CAAC,6BAA6B,CAAC,uCAAuC,CAAC,4BAA4B,oBAAoB,CAAC,oBAAoB,CAAC,8BAA8B,CAAC,0BAA0B,CAAC,2CAA2C,CAAC,+CAA+C,CAAC,uCAAuC,CAAC,2BAA2B,CAAC,sCAAsC,CAAC,oDAAoD,CAAC,2DAA2D,CAAC,6BAA6B,CAAC,6BAA6B,CAAC,uCAAuC,CAAC,yBAAyB,oBAAoB,CAAC,oBAAoB,CAAC,8BAA8B,CAAC,0BAA0B,CAAC,4CAA4C,CAAC,oDAAoD,CAAC,uCAAuC,CAAC,2BAA2B,CAAC,yCAAyC,CAAC,qDAAqD,CAAC,2DAA2D,CAAC,6BAA6B,CAAC,6BAA6B,CAAC,uCAAuC,CAAC,4BAA4B,oBAAoB,CAAC,oBAAoB,CAAC,8BAA8B,CAAC,0BAA0B,CAAC,wCAAwC,CAAC,kDAAkD,CAAC,sCAAsC,CAAC,2BAA2B,CAAC,yCAAyC,CAAC,mDAAmD,CAAC,2DAA2D,CAAC,6BAA6B,CAAC,6BAA6B,CAAC,uCAAuC,CAAC,2BAA2B,oBAAoB,CAAC,oBAAoB,CAAC,8BAA8B,CAAC,0BAA0B,CAAC,yCAAyC,CAAC,iDAAiD,CAAC,sCAAsC,CAAC,2BAA2B,CAAC,wCAAwC,CAAC,oDAAoD,CAAC,2DAA2D,CAAC,6BAA6B,CAAC,6BAA6B,CAAC,uCAAuC,CAAC,0BAA0B,oBAAoB,CAAC,oBAAoB,CAAC,8BAA8B,CAAC,0BAA0B,CAAC,4CAA4C,CAAC,mDAAmD,CAAC,wCAAwC,CAAC,2BAA2B,CAAC,0CAA0C,CAAC,qDAAqD,CAAC,2DAA2D,CAAC,6BAA6B,CAAC,6BAA6B,CAAC,uCAAuC,CAAC,yBAAyB,oBAAoB,CAAC,oBAAoB,CAAC,8BAA8B,CAAC,0BAA0B,CAAC,wCAAwC,CAAC,kDAAkD,CAAC,qCAAqC,CAAC,2BAA2B,CAAC,yCAAyC,CAAC,mDAAmD,CAAC,2DAA2D,CAAC,6BAA6B,CAAC,6BAA6B,CAAC,uCAAuC,CAAC,oCAAoC,uBAAuB,CAAC,8BAA8B,CAAC,0BAA0B,CAAC,0BAA0B,CAAC,oCAAoC,CAAC,uCAAuC,CAAC,2BAA2B,CAAC,2BAA2B,CAAC,qCAAqC,CAAC,2DAA2D,CAAC,gCAAgC,CAAC,iCAAiC,CAAC,uCAAuC,CAAC,mBAAmB,CAAC,sCAAsC,uBAAuB,CAAC,8BAA8B,CAAC,0BAA0B,CAAC,0BAA0B,CAAC,oCAAoC,CAAC,wCAAwC,CAAC,2BAA2B,CAAC,2BAA2B,CAAC,qCAAqC,CAAC,2DAA2D,CAAC,gCAAgC,CAAC,iCAAiC,CAAC,uCAAuC,CAAC,mBAAmB,CAAC,oCAAoC,uBAAuB,CAAC,8BAA8B,CAAC,0BAA0B,CAAC,0BAA0B,CAAC,oCAAoC,CAAC,sCAAsC,CAAC,2BAA2B,CAAC,2BAA2B,CAAC,qCAAqC,CAAC,2DAA2D,CAAC,gCAAgC,CAAC,iCAAiC,CAAC,uCAAuC,CAAC,mBAAmB,CAAC,iCAAiC,uBAAuB,CAAC,8BAA8B,CAAC,0BAA0B,CAAC,0BAA0B,CAAC,oCAAoC,CAAC,uCAAuC,CAAC,2BAA2B,CAAC,2BAA2B,CAAC,qCAAqC,CAAC,2DAA2D,CAAC,gCAAgC,CAAC,iCAAiC,CAAC,uCAAuC,CAAC,mBAAmB,CAAC,oCAAoC,uBAAuB,CAAC,8BAA8B,CAAC,0BAA0B,CAAC,0BAA0B,CAAC,oCAAoC,CAAC,sCAAsC,CAAC,2BAA2B,CAAC,2BAA2B,CAAC,qCAAqC,CAAC,2DAA2D,CAAC,gCAAgC,CAAC,iCAAiC,CAAC,uCAAuC,CAAC,mBAAmB,CAAC,mCAAmC,uBAAuB,CAAC,8BAA8B,CAAC,0BAA0B,CAAC,0BAA0B,CAAC,oCAAoC,CAAC,sCAAsC,CAAC,2BAA2B,CAAC,2BAA2B,CAAC,qCAAqC,CAAC,2DAA2D,CAAC,gCAAgC,CAAC,iCAAiC,CAAC,uCAAuC,CAAC,mBAAmB,CAAC,kCAAkC,uBAAuB,CAAC,8BAA8B,CAAC,0BAA0B,CAAC,0BAA0B,CAAC,oCAAoC,CAAC,wCAAwC,CAAC,2BAA2B,CAAC,2BAA2B,CAAC,qCAAqC,CAAC,2DAA2D,CAAC,gCAAgC,CAAC,iCAAiC,CAAC,uCAAuC,CAAC,mBAAmB,CAAC,iCAAiC,uBAAuB,CAAC,8BAA8B,CAAC,0BAA0B,CAAC,0BAA0B,CAAC,oCAAoC,CAAC,qCAAqC,CAAC,2BAA2B,CAAC,2BAA2B,CAAC,qCAAqC,CAAC,2DAA2D,CAAC,gCAAgC,CAAC,iCAAiC,CAAC,uCAAuC,CAAC,mBAAmB,CAAC,yBAAyB,yBAAyB,CAAC,oCAAoC,CAAC,wBAAwB,CAAC,kCAAkC,CAAC,gDAAgD,CAAC,wCAAwC,CAAC,iDAAiD,CAAC,yCAAyC,CAAC,gCAAgC,CAAC,2CAA2C,CAAC,+BAA+B,CAAC,uCAAuC,CAAC,yBAAyB,CAAC,uCAAuC,yBAAyB,CAAC,+BAA+B,+BAA+B,CAAC,yDAAyD,yBAAyB,CAAC,wBAAwB,CAAC,2BAA2B,CAAC,kDAAkD,CAAC,yDAAyD,0BAA0B,CAAC,yBAAyB,CAAC,2BAA2B,CAAC,kDAAkD,CAAC,qBAAqB,8BAA8B,CAAC,wCAAwC,qBAAqB,eAAe,CAAC,CAAC,gCAAgC,SAAS,CAAC,oCAAoC,YAAY,CAAC,2BAA2B,QAAQ,CAAC,eAAe,CAAC,2BAA2B,CAAC,wCAAwC,2BAA2B,eAAe,CAAC,CAAC,+CAA+C,OAAO,CAAC,WAAW,CAAC,0BAA0B,CAAC,wCAAwC,+CAA+C,eAAe,CAAC,CAAC,gKAAgK,iBAAiB,CAAC,gCAAgC,kBAAkB,CAAC,sCAAsC,oBAAoB,CAAC,kBAAkB,CAAC,qBAAqB,CAAC,UAAU,CAAC,qBAAqB,CAAC,mCAAmC,CAAC,eAAe,CAAC,kCAAkC,CAAC,4CAA4C,aAAa,CAAC,8BAA8B,0BAA0B,CAAC,8BAA8B,CAAC,0BAA0B,CAAC,8BAA8B,CAAC,6BAA6B,CAAC,6BAA6B,CAAC,yCAAyC,CAAC,mCAAmC,CAAC,8DAA8D,CAAC,oDAAoD,CAAC,kDAAkD,CAAC,yFAAyF,CAAC,4DAA4D,CAAC,qCAAqC,CAAC,8CAA8C,CAAC,8CAA8C,CAAC,oDAAoD,CAAC,kDAAkD,CAAC,qCAAqC,CAAC,qCAAqC,CAAC,2DAA2D,CAAC,kCAAkC,CAAC,oCAAoC,CAAC,mCAAmC,CAAC,oCAAoC,CAAC,qCAAqC,CAAC,iBAAiB,CAAC,iCAAiC,CAAC,YAAY,CAAC,sCAAsC,CAAC,iEAAiE,CAAC,QAAQ,CAAC,sCAAsC,CAAC,8BAA8B,CAAC,eAAe,CAAC,eAAe,CAAC,sCAAsC,CAAC,2BAA2B,CAAC,4EAA4E,CAAC,8CAA8C,CAAC,8CAA8C,QAAQ,CAAC,MAAM,CAAC,oCAAoC,CAAC,oCAAoC,oBAAoB,CAAC,oDAAoD,UAAU,CAAC,MAAM,CAAC,kCAAkC,kBAAkB,CAAC,kDAAkD,OAAO,CAAC,SAAS,CAAC,0BAA0B,uCAAuC,oBAAoB,CAAC,uDAAuD,UAAU,CAAC,MAAM,CAAC,qCAAqC,kBAAkB,CAAC,qDAAqD,OAAO,CAAC,SAAS,CAAC,CAAC,0BAA0B,uCAAuC,oBAAoB,CAAC,uDAAuD,UAAU,CAAC,MAAM,CAAC,qCAAqC,kBAAkB,CAAC,qDAAqD,OAAO,CAAC,SAAS,CAAC,CAAC,0BAA0B,uCAAuC,oBAAoB,CAAC,uDAAuD,UAAU,CAAC,MAAM,CAAC,qCAAqC,kBAAkB,CAAC,qDAAqD,OAAO,CAAC,SAAS,CAAC,CAAC,2BAA2B,uCAAuC,oBAAoB,CAAC,uDAAuD,UAAU,CAAC,MAAM,CAAC,qCAAqC,kBAAkB,CAAC,qDAAqD,OAAO,CAAC,SAAS,CAAC,CAAC,2BAA2B,wCAAwC,oBAAoB,CAAC,wDAAwD,UAAU,CAAC,MAAM,CAAC,sCAAsC,kBAAkB,CAAC,sDAAsD,OAAO,CAAC,SAAS,CAAC,CAAC,sDAAsD,QAAQ,CAAC,WAAW,CAAC,YAAY,CAAC,uCAAuC,CAAC,8CAA8C,oBAAoB,CAAC,kBAAkB,CAAC,qBAAqB,CAAC,UAAU,CAAC,YAAY,CAAC,mCAAmC,CAAC,wBAAwB,CAAC,kCAAkC,CAAC,oDAAoD,aAAa,CAAC,uDAAuD,KAAK,CAAC,UAAU,CAAC,SAAS,CAAC,YAAY,CAAC,qCAAqC,CAAC,+CAA+C,oBAAoB,CAAC,kBAAkB,CAAC,qBAAqB,CAAC,UAAU,CAAC,iCAAiC,CAAC,cAAc,CAAC,oCAAoC,CAAC,sBAAsB,CAAC,qDAAqD,aAAa,CAAC,+CAA+C,gBAAgB,CAAC,yDAAyD,KAAK,CAAC,UAAU,CAAC,SAAS,CAAC,YAAY,CAAC,sCAAsC,CAAC,iDAAiD,oBAAoB,CAAC,kBAAkB,CAAC,qBAAqB,CAAC,UAAU,CAAC,iDAAiD,YAAY,CAAC,kDAAkD,oBAAoB,CAAC,mBAAmB,CAAC,qBAAqB,CAAC,UAAU,CAAC,iCAAiC,CAAC,uBAAuB,CAAC,oCAAoC,CAAC,uDAAuD,aAAa,CAAC,kDAAkD,gBAAgB,CAAC,iCAAiC,QAAQ,CAAC,4CAA4C,CAAC,eAAe,CAAC,kDAAkD,CAAC,SAAS,CAAC,8BAA8B,aAAa,CAAC,UAAU,CAAC,2EAA2E,CAAC,UAAU,CAAC,eAAe,CAAC,mCAAmC,CAAC,kBAAkB,CAAC,oBAAoB,CAAC,kBAAkB,CAAC,4BAA4B,CAAC,QAAQ,CAAC,sDAAsD,CAAC,wEAAwE,yCAAyC,CAAC,iDAAiD,CAAC,0EAA0E,0CAA0C,CAAC,oBAAoB,CAAC,kDAAkD,CAAC,8EAA8E,4CAA4C,CAAC,mBAAmB,CAAC,4BAA4B,CAAC,mCAAmC,aAAa,CAAC,gCAAgC,aAAa,CAAC,+EAA+E,CAAC,eAAe,CAAC,iBAAiB,CAAC,qCAAqC,CAAC,kBAAkB,CAAC,mCAAmC,aAAa,CAAC,2EAA2E,CAAC,mCAAmC,CAAC,mCAAmC,4BAA4B,CAAC,yBAAyB,CAAC,8DAA8D,CAAC,0BAA0B,CAAC,iCAAiC,CAAC,oCAAoC,CAAC,4DAA4D,CAAC,qDAAqD,CAAC,qCAAqC,CAAC,qCAAqC,CAAC,0CAA0C,CAAC,mCAAmC,CAAC,6DAA6D,iBAAiB,CAAC,mBAAmB,CAAC,qBAAqB,CAAC,uEAAuE,iBAAiB,CAAC,aAAa,CAAC,siBAAsiB,SAAS,CAAC,4BAA4B,YAAY,CAAC,cAAc,CAAC,0BAA0B,CAAC,yCAAyC,UAAU,CAAC,0BAA0B,qCAAqC,CAAC,mHAAmH,6CAA6C,CAAC,kMAAkM,yBAAyB,CAAC,4BAA4B,CAAC,0JAA0J,wBAAwB,CAAC,2BAA2B,CAAC,sCAAsC,sBAAsB,CAAC,qBAAqB,CAAC,qJAAqJ,aAAa,CAAC,wDAAwD,cAAc,CAAC,uGAAuG,qBAAqB,CAAC,oBAAoB,CAAC,uGAAuG,oBAAoB,CAAC,mBAAmB,CAAC,mCAAmC,qBAAqB,CAAC,sBAAsB,CAAC,sBAAsB,CAAC,sFAAsF,UAAU,CAAC,0HAA0H,4CAA4C,CAAC,mJAAmJ,4BAA4B,CAAC,2BAA2B,CAAC,qLAAqL,wBAAwB,CAAC,yBAAyB,CAAC,oBAAoB,6BAA6B,CAAC,8BAA8B,CAAC,2BAA2B,CAAC,yCAAyC,CAAC,qDAAqD,CAAC,uDAAuD,CAAC,YAAY,CAAC,cAAc,CAAC,cAAc,CAAC,eAAe,CAAC,eAAe,CAAC,yBAAyB,aAAa,CAAC,iEAAiE,CAAC,sCAAsC,CAAC,0CAA0C,CAAC,8BAA8B,CAAC,oBAAoB,CAAC,eAAe,CAAC,QAAQ,CAAC,iGAAiG,CAAC,wCAAwC,yBAAyB,eAAe,CAAC,CAAC,8DAA8D,oCAAoC,CAAC,uCAAuC,SAAS,CAAC,iCAAiC,CAAC,oEAAoE,uCAAuC,CAAC,mBAAmB,CAAC,cAAc,CAAC,yBAAyB,kDAAkD,CAAC,kDAAkD,CAAC,oDAAoD,CAAC,2GAA2G,CAAC,yDAAyD,CAAC,+CAA+C,CAAC,uGAAuG,CAAC,mFAAmF,CAAC,mCAAmC,wDAAwD,CAAC,wDAAwD,CAAC,uDAAuD,CAAC,wDAAwD,CAAC,kFAAkF,iBAAiB,CAAC,uDAAuD,CAAC,4FAA4F,0CAA0C,CAAC,kDAAkD,CAAC,wDAAwD,CAAC,wCAAwC,qDAAqD,CAAC,wBAAwB,CAAC,yBAAyB,CAAC,0BAA0B,qDAAqD,CAAC,sCAAsC,CAAC,sCAAsC,CAAC,oCAAoC,+CAA+C,CAAC,qFAAqF,2CAA2C,CAAC,mDAAmD,CAAC,8BAA8B,4BAA4B,CAAC,wCAAwC,CAAC,8DAA8D,CAAC,+BAA+B,CAAC,wCAAwC,eAAe,CAAC,cAAc,CAAC,oEAAoE,CAAC,4FAA4F,gCAAgC,CAAC,6FAA6F,eAAe,CAAC,+CAA+C,CAAC,gCAAgC,CAAC,sEAAsE,aAAa,CAAC,iBAAiB,CAAC,gFAAgF,WAAW,CAAC,YAAY,CAAC,iBAAiB,CAAC,+FAA+F,UAAU,CAAC,sCAAsC,YAAY,CAAC,oCAAoC,aAAa,CAAC,uBAAuB,wBAAwB,CAAC,4BAA4B,CAAC,0DAA0D,CAAC,+DAA+D,CAAC,kEAAkE,CAAC,+DAA+D,CAAC,qCAAqC,CAAC,kCAAkC,CAAC,oCAAoC,CAAC,8DAA8D,CAAC,oEAAoE,CAAC,qCAAqC,CAAC,qCAAqC,CAAC,qCAAqC,CAAC,sCAAsC,CAAC,qEAA2Q,CAAC,yEAAyE,CAAC,0DAA0D,CAAC,uCAAuC,CAAC,2DAA2D,CAAC,iBAAiB,CAAC,YAAY,CAAC,cAAc,CAAC,kBAAkB,CAAC,6BAA6B,CAAC,6DAA6D,CAAC,oQAAoQ,YAAY,CAAC,iBAAiB,CAAC,kBAAkB,CAAC,6BAA6B,CAAC,6BAA6B,4CAA4C,CAAC,+CAA+C,CAAC,8CAA8C,CAAC,0CAA0C,CAAC,kCAAkC,CAAC,oBAAoB,CAAC,kBAAkB,CAAC,sEAAsE,wCAAwC,CAAC,2BAA2B,0BAA0B,CAAC,8BAA8B,CAAC,2BAA2B,CAAC,2CAA2C,CAAC,uDAAuD,CAAC,6DAA6D,CAAC,YAAY,CAAC,qBAAqB,CAAC,cAAc,CAAC,eAAe,CAAC,eAAe,CAAC,sFAAsF,mCAAmC,CAAC,0CAA0C,eAAe,CAAC,4BAA4B,iBAAiB,CAAC,oBAAoB,CAAC,4BAA4B,CAAC,sGAAsG,mCAAmC,CAAC,gCAAgC,WAAW,CAAC,eAAe,CAAC,kBAAkB,CAAC,+BAA+B,6EAA6E,CAAC,4CAA4C,CAAC,aAAa,CAAC,4BAA4B,CAAC,4BAA4B,CAAC,yEAAyE,CAAC,oDAAoD,CAAC,8CAA8C,CAAC,wCAAwC,+BAA+B,eAAe,CAAC,CAAC,qCAAqC,oBAAoB,CAAC,qCAAqC,oBAAoB,CAAC,SAAS,CAAC,qDAAqD,CAAC,oCAAoC,oBAAoB,CAAC,WAAW,CAAC,YAAY,CAAC,qBAAqB,CAAC,iDAAiD,CAAC,2BAA2B,CAAC,0BAA0B,CAAC,oBAAoB,CAAC,kCAAkC,wCAAwC,CAAC,eAAe,CAAC,0BAA0B,iCAAiC,gBAAgB,CAAC,0BAA0B,CAAC,6CAA6C,kBAAkB,CAAC,4DAA4D,iBAAiB,CAAC,uDAAuD,iDAAiD,CAAC,gDAAgD,CAAC,oDAAoD,gBAAgB,CAAC,kDAAkD,sBAAsB,CAAC,eAAe,CAAC,iDAAiD,YAAY,CAAC,4CAA4C,eAAe,CAAC,YAAY,CAAC,WAAW,CAAC,oBAAoB,CAAC,qBAAqB,CAAC,4BAA4B,CAAC,sCAAsC,CAAC,kBAAkB,CAAC,wBAAwB,CAAC,eAAe,CAAC,8DAA8D,YAAY,CAAC,4DAA4D,YAAY,CAAC,WAAW,CAAC,SAAS,CAAC,kBAAkB,CAAC,CAAC,0BAA0B,iCAAiC,gBAAgB,CAAC,0BAA0B,CAAC,6CAA6C,kBAAkB,CAAC,4DAA4D,iBAAiB,CAAC,uDAAuD,iDAAiD,CAAC,gDAAgD,CAAC,oDAAoD,gBAAgB,CAAC,kDAAkD,sBAAsB,CAAC,eAAe,CAAC,iDAAiD,YAAY,CAAC,4CAA4C,eAAe,CAAC,YAAY,CAAC,WAAW,CAAC,oBAAoB,CAAC,qBAAqB,CAAC,4BAA4B,CAAC,sCAAsC,CAAC,kBAAkB,CAAC,wBAAwB,CAAC,eAAe,CAAC,8DAA8D,YAAY,CAAC,4DAA4D,YAAY,CAAC,WAAW,CAAC,SAAS,CAAC,kBAAkB,CAAC,CAAC,0BAA0B,iCAAiC,gBAAgB,CAAC,0BAA0B,CAAC,6CAA6C,kBAAkB,CAAC,4DAA4D,iBAAiB,CAAC,uDAAuD,iDAAiD,CAAC,gDAAgD,CAAC,oDAAoD,gBAAgB,CAAC,kDAAkD,sBAAsB,CAAC,eAAe,CAAC,iDAAiD,YAAY,CAAC,4CAA4C,eAAe,CAAC,YAAY,CAAC,WAAW,CAAC,oBAAoB,CAAC,qBAAqB,CAAC,4BAA4B,CAAC,sCAAsC,CAAC,kBAAkB,CAAC,wBAAwB,CAAC,eAAe,CAAC,8DAA8D,YAAY,CAAC,4DAA4D,YAAY,CAAC,WAAW,CAAC,SAAS,CAAC,kBAAkB,CAAC,CAAC,2BAA2B,iCAAiC,gBAAgB,CAAC,0BAA0B,CAAC,6CAA6C,kBAAkB,CAAC,4DAA4D,iBAAiB,CAAC,uDAAuD,iDAAiD,CAAC,gDAAgD,CAAC,oDAAoD,gBAAgB,CAAC,kDAAkD,sBAAsB,CAAC,eAAe,CAAC,iDAAiD,YAAY,CAAC,4CAA4C,eAAe,CAAC,YAAY,CAAC,WAAW,CAAC,oBAAoB,CAAC,qBAAqB,CAAC,4BAA4B,CAAC,sCAAsC,CAAC,kBAAkB,CAAC,wBAAwB,CAAC,eAAe,CAAC,8DAA8D,YAAY,CAAC,4DAA4D,YAAY,CAAC,WAAW,CAAC,SAAS,CAAC,kBAAkB,CAAC,CAAC,2BAA2B,kCAAkC,gBAAgB,CAAC,0BAA0B,CAAC,8CAA8C,kBAAkB,CAAC,6DAA6D,iBAAiB,CAAC,wDAAwD,iDAAiD,CAAC,gDAAgD,CAAC,qDAAqD,gBAAgB,CAAC,mDAAmD,sBAAsB,CAAC,eAAe,CAAC,kDAAkD,YAAY,CAAC,6CAA6C,eAAe,CAAC,YAAY,CAAC,WAAW,CAAC,oBAAoB,CAAC,qBAAqB,CAAC,4BAA4B,CAAC,sCAAsC,CAAC,kBAAkB,CAAC,wBAAwB,CAAC,eAAe,CAAC,+DAA+D,YAAY,CAAC,6DAA6D,YAAY,CAAC,WAAW,CAAC,SAAS,CAAC,kBAAkB,CAAC,CAAC,8BAA8B,gBAAgB,CAAC,0BAA0B,CAAC,0CAA0C,kBAAkB,CAAC,yDAAyD,iBAAiB,CAAC,oDAAoD,iDAAiD,CAAC,gDAAgD,CAAC,iDAAiD,gBAAgB,CAAC,+CAA+C,sBAAsB,CAAC,eAAe,CAAC,8CAA8C,YAAY,CAAC,yCAAyC,eAAe,CAAC,YAAY,CAAC,WAAW,CAAC,oBAAoB,CAAC,qBAAqB,CAAC,4BAA4B,CAAC,sCAAsC,CAAC,kBAAkB,CAAC,wBAAwB,CAAC,eAAe,CAAC,2DAA2D,YAAY,CAAC,yDAAyD,YAAY,CAAC,WAAW,CAAC,SAAS,CAAC,kBAAkB,CAAC,uEAAuE,2CAA2C,CAAC,iDAAiD,CAAC,oDAAoD,CAAC,8BAA8B,CAAC,6BAA6B,CAAC,mCAAmC,CAAC,yDAAyD,CAAC,qEAA8Q,CAAC,yDAAyD,qEAA8Q,CAAC,qBAAqB,wBAAwB,CAAC,wBAAwB,CAAC,+BAA+B,CAAC,uBAAuB,CAAC,0BAA0B,CAAC,8CAA8C,CAAC,0DAA0D,CAAC,gDAAgD,CAAC,sBAAsB,CAAC,uFAAuF,CAAC,8BAA8B,CAAC,6BAA6B,CAAC,qDAAqD,CAAC,qBAAqB,CAAC,kBAAkB,CAAC,iBAAiB,CAAC,+BAA+B,CAAC,mCAAmC,CAAC,8BAA8B,CAAC,iBAAiB,CAAC,YAAY,CAAC,qBAAqB,CAAC,WAAW,CAAC,4BAA4B,CAAC,0BAA0B,CAAC,oBAAoB,CAAC,kCAAkC,CAAC,0BAA0B,CAAC,oEAAoE,CAAC,0CAA0C,CAAC,wBAAwB,cAAc,CAAC,aAAa,CAAC,iCAAiC,kBAAkB,CAAC,qBAAqB,CAAC,6CAA6C,kBAAkB,CAAC,yDAAyD,CAAC,0DAA0D,CAAC,4CAA4C,qBAAqB,CAAC,6DAA6D,CAAC,4DAA4D,CAAC,4FAA4F,YAAY,CAAC,0BAA0B,aAAa,CAAC,uDAAuD,CAAC,0BAA0B,CAAC,2BAA2B,2CAA2C,CAAC,gCAAgC,CAAC,8BAA8B,oDAAoD,CAAC,eAAe,CAAC,mCAAmC,CAAC,qCAAqC,eAAe,CAAC,qCAAqC,mCAAmC,CAAC,4BAA4B,iEAAiE,CAAC,eAAe,CAAC,8BAA8B,CAAC,sCAAsC,CAAC,2EAA2E,CAAC,wCAAwC,uFAAuF,CAAC,4BAA4B,iEAAiE,CAAC,8BAA8B,CAAC,sCAAsC,CAAC,wEAAwE,CAAC,uCAAuC,uFAAuF,CAAC,iCAAiC,qDAAqD,CAAC,qDAAqD,CAAC,oDAAoD,CAAC,eAAe,CAAC,kDAAkD,kCAAkC,CAAC,qCAAqC,CAAC,kCAAkC,qDAAqD,CAAC,oDAAoD,CAAC,iCAAiC,iBAAiB,CAAC,KAAK,CAAC,OAAO,CAAC,QAAQ,CAAC,MAAM,CAAC,0CAA0C,CAAC,gDAAgD,CAAC,sFAAsF,UAAU,CAAC,sDAAsD,yDAAyD,CAAC,0DAA0D,CAAC,yDAAyD,6DAA6D,CAAC,4DAA4D,CAAC,iCAAiC,yCAAyC,CAAC,0BAA0B,2BAA2B,YAAY,CAAC,kBAAkB,CAAC,iCAAiC,UAAU,CAAC,eAAe,CAAC,uCAAuC,aAAa,CAAC,aAAa,CAAC,kDAAkD,yBAAyB,CAAC,4BAA4B,CAAC,+HAA+H,yBAAyB,CAAC,kIAAkI,4BAA4B,CAAC,mDAAmD,wBAAwB,CAAC,2BAA2B,CAAC,iIAAiI,wBAAwB,CAAC,oIAAoI,2BAA2B,CAAC,CAAC,0BAA0B,0CAA0C,CAAC,oCAAoC,CAAC,yKAAyK,CAAC,mDAAmD,CAAC,mDAAmD,CAAC,qDAAqD,CAAC,4FAA4F,CAAC,qCAAqC,CAAC,kCAAkC,CAAC,8CAA8C,CAAC,6CAA6C,CAAC,iEAAuO,CAAC,sCAAsC,CAAC,kDAAkD,CAAC,6DAA6D,CAAC,wEAA4P,CAAC,yEAAyE,CAAC,sCAAsC,CAAC,mCAAmC,CAAC,4DAA4D,CAAC,qDAAqD,CAAC,iCAAiC,iBAAiB,CAAC,YAAY,CAAC,kBAAkB,CAAC,UAAU,CAAC,2EAA2E,CAAC,cAAc,CAAC,mCAAmC,CAAC,eAAe,CAAC,2CAA2C,CAAC,QAAQ,CAAC,eAAe,CAAC,oBAAoB,CAAC,yCAAyC,CAAC,wCAAwC,iCAAiC,eAAe,CAAC,CAAC,iDAAiD,sCAAsC,CAAC,8CAA8C,CAAC,iGAAiG,CAAC,uDAAuD,oDAAoD,CAAC,gDAAgD,CAAC,uCAAuC,aAAa,CAAC,wCAAwC,CAAC,yCAAyC,CAAC,gBAAgB,CAAC,UAAU,CAAC,6CAA6C,CAAC,2BAA2B,CAAC,kDAAkD,CAAC,kDAAkD,CAAC,wCAAwC,uCAAuC,eAAe,CAAC,CAAC,uCAAuC,SAAS,CAAC,uCAAuC,SAAS,CAAC,SAAS,CAAC,mDAAmD,CAAC,iCAAiC,eAAe,CAAC,+BAA+B,+BAA+B,CAAC,uCAAuC,CAAC,8EAA8E,CAAC,6CAA6C,wDAAwD,CAAC,yDAAyD,CAAC,iFAAiF,8DAA8D,CAAC,+DAA+D,CAAC,mDAAmD,YAAY,CAAC,4CAA4C,4DAA4D,CAAC,2DAA2D,CAAC,0FAA0F,kEAAkE,CAAC,iEAAiE,CAAC,gEAAgE,4DAA4D,CAAC,2DAA2D,CAAC,+BAA+B,6EAA6E,CAAC,gDAAgD,cAAc,CAAC,aAAa,CAAC,eAAe,CAAC,4DAA4D,YAAY,CAAC,2DAA2D,eAAe,CAAC,sPAAsP,eAAe,CAAC,4DAA4D,iEAAwT,CAAC,wEAA+T,CAAC,2BAA2B,iCAAiC,CAAC,kCAAkC,CAAC,+BAA+B,CAAC,2CAA2C,CAAC,qCAAqC,CAAC,oDAAoD,CAAC,oDAAoD,CAAC,sDAAsD,CAAC,uDAAuD,CAAC,+CAA+C,CAAC,0DAA0D,CAAC,uDAAuD,CAAC,gDAAgD,CAAC,sEAAsE,CAAC,kCAAkC,CAAC,kCAAkC,CAAC,4CAA4C,CAAC,yDAAyD,CAAC,mDAAmD,CAAC,6DAA6D,CAAC,YAAY,CAAC,cAAc,CAAC,eAAe,CAAC,0BAA0B,iBAAiB,CAAC,aAAa,CAAC,qEAAqE,CAAC,wCAAwC,CAAC,gCAAgC,CAAC,oBAAoB,CAAC,wCAAwC,CAAC,gFAAgF,CAAC,6HAA6H,CAAC,wCAAwC,0BAA0B,eAAe,CAAC,CAAC,gCAAgC,SAAS,CAAC,sCAAsC,CAAC,8CAA8C,CAAC,oDAAoD,CAAC,gCAAgC,SAAS,CAAC,sCAAsC,CAAC,8CAA8C,CAAC,SAAS,CAAC,gDAAgD,CAAC,mEAAmE,SAAS,CAAC,uCAAuC,CAAC,+CAA+C,CAAC,qDAAqD,CAAC,uEAAuE,yCAAyC,CAAC,mBAAmB,CAAC,iDAAiD,CAAC,uDAAuD,CAAC,uDAAuD,6CAA6C,CAAC,iDAAiD,yDAAyD,CAAC,4DAA4D,CAAC,gDAAgD,0DAA0D,CAAC,6DAA6D,CAAC,8BAA8B,iCAAiC,CAAC,iCAAiC,CAAC,kCAAkC,CAAC,yDAAyD,CAAC,8BAA8B,gCAAgC,CAAC,iCAAiC,CAAC,kCAAkC,CAAC,yDAAyD,CAAC,sBAAsB,2BAA2B,CAAC,2BAA2B,CAAC,2BAA2B,CAAC,2BAA2B,CAAC,sBAAsB,CAAC,iDAAiD,CAAC,oBAAoB,CAAC,2DAA2D,CAAC,mCAAmC,CAAC,uCAAuC,CAAC,aAAa,CAAC,2BAA2B,CAAC,iBAAiB,CAAC,kBAAkB,CAAC,uBAAuB,CAAC,2CAA2C,CAAC,4BAA4B,YAAY,CAAC,2BAA2B,iBAAiB,CAAC,QAAQ,CAAC,sBAAsB,0BAA0B,CAAC,0BAA0B,CAAC,0BAA0B,CAAC,8BAA8B,CAAC,yBAAyB,CAAC,oCAAoC,CAAC,4EAA4E,CAAC,iDAAiD,CAAC,8BAA8B,CAAC,iBAAiB,CAAC,2DAA2D,CAAC,2CAA2C,CAAC,2BAA2B,CAAC,mCAAmC,CAAC,6BAA6B,CAAC,2CAA2C,CAAC,8BAA8B,aAAa,CAAC,2BAA2B,eAAe,CAAC,gCAAgC,CAAC,kCAAkC,kBAAkB,CAAC,6CAA6C,iBAAiB,CAAC,KAAK,CAAC,OAAO,CAAC,SAAS,CAAC,oBAAoB,CAAC,8BAA8B,iDAAiD,CAAC,0CAA0C,CAAC,wDAAwD,CAAC,sDAAsD,CAAC,gCAAgC,mDAAmD,CAAC,4CAA4C,CAAC,0DAA0D,CAAC,wDAAwD,CAAC,8BAA8B,iDAAiD,CAAC,0CAA0C,CAAC,wDAAwD,CAAC,sDAAsD,CAAC,2BAA2B,8CAA8C,CAAC,uCAAuC,CAAC,qDAAqD,CAAC,mDAAmD,CAAC,8BAA8B,iDAAiD,CAAC,0CAA0C,CAAC,wDAAwD,CAAC,sDAAsD,CAAC,6BAA6B,gDAAgD,CAAC,yCAAyC,CAAC,uDAAuD,CAAC,qDAAqD,CAAC,4BAA4B,+CAA+C,CAAC,wCAAwC,CAAC,sDAAsD,CAAC,oDAAoD,CAAC,2BAA2B,8CAA8C,CAAC,uCAAuC,CAAC,qDAAqD,CAAC,mDAAmD,CAAC,gCAAgC,GAAG,+CAA+C,CAAC,CAAC,0DAA0D,0BAA0B,CAAC,+BAA+B,CAAC,wCAAwC,CAAC,oDAAoD,CAAC,oDAAoD,CAAC,6BAA6B,CAAC,6BAA6B,CAAC,4CAA4C,CAAC,YAAY,CAAC,gCAAgC,CAAC,eAAe,CAAC,sCAAsC,CAAC,sCAAsC,CAAC,8CAA8C,CAAC,6BAA6B,YAAY,CAAC,qBAAqB,CAAC,sBAAsB,CAAC,eAAe,CAAC,kCAAkC,CAAC,iBAAiB,CAAC,kBAAkB,CAAC,0CAA0C,CAAC,4CAA4C,CAAC,wCAAwC,6BAA6B,eAAe,CAAC,CAAC,qCAAqC,iLAAiL,CAAC,mEAAmE,CAAC,2CAA2C,gBAAgB,CAAC,yDAAyD,UAAU,CAAC,sCAAsC,iDAAiD,CAAC,wCAAwC,sCAAsC,cAAc,CAAC,CAAC,sBAAsB,uBAAuB,CAAC,uBAAuB,CAAC,wBAAwB,CAAC,wBAAwB,CAAC,sCAAsC,CAAC,gCAAgC,CAAC,2DAA2D,CAAC,+CAA+C,CAAC,oDAAoD,CAAC,8CAA8C,CAAC,2FAA2F,CAAC,iCAAiC,CAAC,iCAAiC,CAAC,oCAAoC,CAAC,sDAAsD,CAAC,sDAAsD,CAAC,iCAAiC,CAAC,4BAA4B,CAAC,sBAAsB,CAAC,sDAAsD,CAAC,sDAAsD,CAAC,cAAc,CAAC,KAAK,CAAC,MAAM,CAAC,8BAA8B,CAAC,YAAY,CAAC,UAAU,CAAC,WAAW,CAAC,iBAAiB,CAAC,eAAe,CAAC,SAAS,CAAC,6BAA6B,iBAAiB,CAAC,UAAU,CAAC,6BAA6B,CAAC,mBAAmB,CAAC,yCAAyC,2BAA2B,CAAC,iCAAiC,CAAC,wCAAwC,yCAAyC,eAAe,CAAC,CAAC,yCAAyC,cAAc,CAAC,iDAAiD,qBAAqB,CAAC,wCAAwC,8CAA8C,CAAC,uDAAuD,eAAe,CAAC,eAAe,CAAC,oDAAoD,eAAe,CAAC,sCAAsC,YAAY,CAAC,kBAAkB,CAAC,kDAAkD,CAAC,8BAA8B,iBAAiB,CAAC,YAAY,CAAC,qBAAqB,CAAC,UAAU,CAAC,2BAA2B,CAAC,mBAAmB,CAAC,mCAAmC,CAAC,2BAA2B,CAAC,sEAAsE,CAAC,2CAA2C,CAAC,SAAS,CAAC,+BAA+B,0BAA0B,CAAC,sBAAsB,CAAC,yBAAyB,CAAC,cAAc,CAAC,KAAK,CAAC,MAAM,CAAC,iCAAiC,CAAC,WAAW,CAAC,YAAY,CAAC,sCAAsC,CAAC,oCAAoC,SAAS,CAAC,oCAAoC,kCAAkC,CAAC,6BAA6B,YAAY,CAAC,aAAa,CAAC,kBAAkB,CAAC,sCAAsC,CAAC,2FAA2F,CAAC,0DAA0D,CAAC,2DAA2D,CAAC,wCAAwC,+FAA+F,CAAC,uDAAuD,CAAC,yDAAyD,CAAC,0DAA0D,CAAC,gBAAgB,CAAC,4BAA4B,eAAe,CAAC,6CAA6C,CAAC,2BAA2B,iBAAiB,CAAC,aAAa,CAAC,+BAA+B,CAAC,6BAA6B,YAAY,CAAC,aAAa,CAAC,cAAc,CAAC,kBAAkB,CAAC,wBAAwB,CAAC,uEAAuE,CAAC,0CAA0C,CAAC,wFAAwF,CAAC,8DAA8D,CAAC,6DAA6D,CAAC,+BAA+B,4CAA4C,CAAC,0BAA0B,sBAAsB,0BAA0B,CAAC,2CAA2C,CAAC,6BAA6B,+BAA+B,CAAC,iBAAiB,CAAC,gBAAgB,CAAC,yBAAyB,uBAAuB,CAAC,CAAC,0BAA0B,kDAAkD,uBAAuB,CAAC,CAAC,2BAA2B,yBAAyB,wBAAwB,CAAC,CAAC,iCAAiC,WAAW,CAAC,cAAc,CAAC,WAAW,CAAC,QAAQ,CAAC,gDAAgD,WAAW,CAAC,QAAQ,CAAC,eAAe,CAAC,8FAA8F,eAAe,CAAC,6CAA6C,eAAe,CAAC,6BAA6B,yCAAyC,WAAW,CAAC,cAAc,CAAC,WAAW,CAAC,QAAQ,CAAC,wDAAwD,WAAW,CAAC,QAAQ,CAAC,eAAe,CAAC,8GAA8G,eAAe,CAAC,qDAAqD,eAAe,CAAC,CAAC,6BAA6B,yCAAyC,WAAW,CAAC,cAAc,CAAC,WAAW,CAAC,QAAQ,CAAC,wDAAwD,WAAW,CAAC,QAAQ,CAAC,eAAe,CAAC,8GAA8G,eAAe,CAAC,qDAAqD,eAAe,CAAC,CAAC,6BAA6B,yCAAyC,WAAW,CAAC,cAAc,CAAC,WAAW,CAAC,QAAQ,CAAC,wDAAwD,WAAW,CAAC,QAAQ,CAAC,eAAe,CAAC,8GAA8G,eAAe,CAAC,qDAAqD,eAAe,CAAC,CAAC,8BAA8B,yCAAyC,WAAW,CAAC,cAAc,CAAC,WAAW,CAAC,QAAQ,CAAC,wDAAwD,WAAW,CAAC,QAAQ,CAAC,eAAe,CAAC,8GAA8G,eAAe,CAAC,qDAAqD,eAAe,CAAC,CAAC,8BAA8B,0CAA0C,WAAW,CAAC,cAAc,CAAC,WAAW,CAAC,QAAQ,CAAC,yDAAyD,WAAW,CAAC,QAAQ,CAAC,eAAe,CAAC,gHAAgH,eAAe,CAAC,sDAAsD,eAAe,CAAC,CAAC,4DAA4D,oBAAoB,CAAC,aAAa,CAAC,6BAA6B,CAAC,+BAA+B,CAAC,+CAA+C,CAAC,iBAAiB,CAAC,4FAA4F,CAAC,0BAA0B,GAAG,wBAAwB,CAAC,CAAC,+BAA+B,wBAAwB,CAAC,yBAAyB,CAAC,oCAAoC,CAAC,gCAAgC,CAAC,kCAAkC,CAAC,2CAA2C,CAAC,wDAAwD,CAAC,8BAA8B,CAAC,kCAAkC,wBAAwB,CAAC,yBAAyB,CAAC,+BAA+B,CAAC,wBAAwB,GAAG,kBAAkB,CAAC,IAAI,SAAS,CAAC,cAAc,CAAC,CAAC,6BAA6B,wBAAwB,CAAC,yBAAyB,CAAC,oCAAoC,CAAC,kCAAkC,CAAC,yCAAyC,CAAC,6BAA6B,CAAC,SAAS,CAAC,gCAAgC,wBAAwB,CAAC,yBAAyB,CAAC,wCAAwC,4DAA4D,kCAAkC,CAAC,CAAC,8CAA8C,mDAAmD,CAAC,6BAA6B,CAAC,2DAA2D,CAAC,iEAAiE,CAAC,+BAA+B,cAAc,CAAC,KAAK,CAAC,MAAM,CAAC,UAAU,CAAC,WAAW,CAAC,eAAe,sCAAsC,CAAC,kCAAkC,CAAC,sCAAsC,CAAC,sCAAsC,CAAC,0BAA0B,CAAC,oCAAoC,CAAC,kCAAkC,CAAC,6BAA6B,CAAC,yCAAyC,CAAC,YAAY,CAAC,qBAAqB,CAAC,WAAW,CAAC,gBAAgB,aAAa,CAAC,UAAU,CAAC,UAAU,CAAC,iBAAiB,oBAAoB,CAAC,8EAA8E,CAAC,mBAAmB,oBAAoB,CAAC,gFAAgF,CAAC,iBAAiB,oBAAoB,CAAC,8EAA8E,CAAC,cAAc,oBAAoB,CAAC,2EAA2E,CAAC,iBAAiB,oBAAoB,CAAC,8EAA8E,CAAC,gBAAgB,oBAAoB,CAAC,6EAA6E,CAAC,eAAe,oBAAoB,CAAC,4EAA4E,CAAC,cAAc,oBAAoB,CAAC,2EAA2E,CAAC,cAAc,qEAAqE,CAAC,+FAA+F,CAAC,wCAAwC,yDAAyD,CAAC,mFAAmF,CAAC,gBAAgB,uEAAuE,CAAC,iGAAiG,CAAC,4CAA4C,yDAAyD,CAAC,mFAAmF,CAAC,cAAc,qEAAqE,CAAC,+FAA+F,CAAC,wCAAwC,yDAAyD,CAAC,mFAAmF,CAAC,WAAW,kEAAkE,CAAC,4FAA4F,CAAC,kCAAkC,0DAA0D,CAAC,oFAAoF,CAAC,cAAc,qEAAqE,CAAC,+FAA+F,CAAC,wCAAwC,0DAA0D,CAAC,oFAAoF,CAAC,aAAa,oEAAoE,CAAC,8FAA8F,CAAC,sCAAsC,yDAAyD,CAAC,mFAAmF,CAAC,YAAY,mEAAmE,CAAC,6FAA6F,CAAC,oCAAoC,2DAA2D,CAAC,qFAAqF,CAAC,WAAW,kEAAkE,CAAC,4FAA4F,CAAC,kCAAkC,wDAAwD,CAAC,kFAAkF,CAAC,oBAAoB,4EAA4E,CAAC,sGAAsG,CAAC,oDAAoD,8EAA8E,CAAC,wGAAwG,CAAC,kBAAkB,SAAS,CAAC,iJAAiJ,CAAC,WAAW,mBAAmB,CAAC,WAAW,CAAC,kBAAkB,CAAC,+EAA+E,CAAC,2BAA2B,CAAC,0BAA0B,CAAC,eAAe,aAAa,CAAC,SAAS,CAAC,UAAU,CAAC,iBAAiB,CAAC,oCAAoC,CAAC,wCAAwC,eAAe,eAAe,CAAC,CAAC,8DAA8D,iEAAiE,CAAC,OAAO,iBAAiB,CAAC,UAAU,CAAC,cAAc,aAAa,CAAC,kCAAkC,CAAC,UAAU,CAAC,SAAS,iBAAiB,CAAC,KAAK,CAAC,MAAM,CAAC,UAAU,CAAC,WAAW,CAAC,WAAW,uBAAuB,CAAC,WAAW,sBAAsB,CAAC,YAAY,yBAAyB,CAAC,YAAY,iCAAiC,CAAC,WAAW,cAAc,CAAC,KAAK,CAAC,OAAO,CAAC,MAAM,CAAC,YAAY,CAAC,cAAc,cAAc,CAAC,OAAO,CAAC,QAAQ,CAAC,MAAM,CAAC,YAAY,CAAC,YAAY,eAAe,CAAC,KAAK,CAAC,YAAY,CAAC,eAAe,eAAe,CAAC,QAAQ,CAAC,YAAY,CAAC,0BAA0B,eAAe,eAAe,CAAC,KAAK,CAAC,YAAY,CAAC,kBAAkB,eAAe,CAAC,QAAQ,CAAC,YAAY,CAAC,CAAC,0BAA0B,eAAe,eAAe,CAAC,KAAK,CAAC,YAAY,CAAC,kBAAkB,eAAe,CAAC,QAAQ,CAAC,YAAY,CAAC,CAAC,0BAA0B,eAAe,eAAe,CAAC,KAAK,CAAC,YAAY,CAAC,kBAAkB,eAAe,CAAC,QAAQ,CAAC,YAAY,CAAC,CAAC,2BAA2B,eAAe,eAAe,CAAC,KAAK,CAAC,YAAY,CAAC,kBAAkB,eAAe,CAAC,QAAQ,CAAC,YAAY,CAAC,CAAC,2BAA2B,gBAAgB,eAAe,CAAC,KAAK,CAAC,YAAY,CAAC,mBAAmB,eAAe,CAAC,QAAQ,CAAC,YAAY,CAAC,CAAC,QAAQ,YAAY,CAAC,kBAAkB,CAAC,kBAAkB,CAAC,kBAAkB,CAAC,QAAQ,YAAY,CAAC,aAAa,CAAC,qBAAqB,CAAC,kBAAkB,CAAC,2EAA2E,mBAAmB,CAAC,oBAAoB,CAAC,mBAAmB,CAAC,qBAAqB,CAAC,yBAAyB,CAAC,4BAA4B,CAAC,4BAA4B,CAAC,kBAAkB,CAAC,qGAAqG,2BAA2B,CAAC,+EAA+E,yBAAyB,CAAC,sBAAsB,iBAAiB,CAAC,KAAK,CAAC,OAAO,CAAC,QAAQ,CAAC,MAAM,CAAC,SAAS,CAAC,UAAU,CAAC,eAAe,eAAe,CAAC,sBAAsB,CAAC,kBAAkB,CAAC,IAAI,oBAAoB,CAAC,kBAAkB,CAAC,4BAA4B,CAAC,cAAc,CAAC,6BAA6B,CAAC,WAAW,CAAC,gBAAgB,iCAAiC,CAAC,WAAW,4BAA4B,CAAC,cAAc,+BAA+B,CAAC,cAAc,+BAA+B,CAAC,mBAAmB,oCAAoC,CAAC,gBAAgB,iCAAiC,CAAC,aAAa,oBAAoB,CAAC,WAAW,qBAAqB,CAAC,YAAY,oBAAoB,CAAC,oBAAoB,4BAA4B,CAAC,kBAAkB,0BAA0B,CAAC,iBAAiB,yBAAyB,CAAC,kBAAkB,+BAA+B,CAAC,iBAAiB,yBAAyB,CAAC,WAAW,mBAAmB,CAAC,YAAY,qBAAqB,CAAC,YAAY,oBAAoB,CAAC,YAAY,qBAAqB,CAAC,aAAa,mBAAmB,CAAC,eAAe,uBAAuB,CAAC,iBAAiB,yBAAyB,CAAC,kBAAkB,0BAA0B,CAAC,iBAAiB,yBAAyB,CAAC,iBAAiB,yBAAyB,CAAC,mBAAmB,2BAA2B,CAAC,oBAAoB,4BAA4B,CAAC,mBAAmB,2BAA2B,CAAC,iBAAiB,yBAAyB,CAAC,mBAAmB,2BAA2B,CAAC,oBAAoB,4BAA4B,CAAC,mBAAmB,2BAA2B,CAAC,UAAU,wBAAwB,CAAC,gBAAgB,8BAA8B,CAAC,SAAS,uBAAuB,CAAC,QAAQ,sBAAsB,CAAC,eAAe,6BAA6B,CAAC,SAAS,uBAAuB,CAAC,aAAa,2BAA2B,CAAC,cAAc,4BAA4B,CAAC,QAAQ,sBAAsB,CAAC,eAAe,6BAA6B,CAAC,QAAQ,sBAAsB,CAAC,QAAQ,yCAAyC,CAAC,WAAW,4CAA4C,CAAC,WAAW,4CAA4C,CAAC,aAAa,yBAAyB,CAAC,oBAAoB,gFAAgF,CAAC,sBAAsB,kFAAkF,CAAC,oBAAoB,gFAAgF,CAAC,iBAAiB,6EAA6E,CAAC,oBAAoB,gFAAgF,CAAC,mBAAmB,+EAA+E,CAAC,kBAAkB,8EAA8E,CAAC,iBAAiB,6EAA6E,CAAC,iBAAiB,yBAAyB,CAAC,mBAAmB,2BAA2B,CAAC,mBAAmB,2BAA2B,CAAC,gBAAgB,wBAAwB,CAAC,iBAAiB,yBAAyB,CAAC,OAAO,eAAe,CAAC,QAAQ,iBAAiB,CAAC,SAAS,kBAAkB,CAAC,UAAU,kBAAkB,CAAC,WAAW,oBAAoB,CAAC,YAAY,qBAAqB,CAAC,SAAS,gBAAgB,CAAC,UAAU,kBAAkB,CAAC,WAAW,mBAAmB,CAAC,OAAO,iBAAiB,CAAC,QAAQ,mBAAmB,CAAC,SAAS,oBAAoB,CAAC,kBAAkB,wCAAwC,CAAC,oBAAoB,mCAAmC,CAAC,oBAAoB,oCAAoC,CAAC,QAAQ,qFAAqF,CAAC,UAAU,kBAAkB,CAAC,YAAY,yFAAyF,CAAC,cAAc,sBAAsB,CAAC,YAAY,2FAA2F,CAAC,cAAc,wBAAwB,CAAC,eAAe,4FAA4F,CAAC,iBAAiB,yBAAyB,CAAC,cAAc,0FAA0F,CAAC,gBAAgB,uBAAuB,CAAC,gBAAgB,sBAAsB,CAAC,2EAA2E,CAAC,kBAAkB,sBAAsB,CAAC,6EAA6E,CAAC,gBAAgB,sBAAsB,CAAC,2EAA2E,CAAC,aAAa,sBAAsB,CAAC,wEAAwE,CAAC,gBAAgB,sBAAsB,CAAC,2EAA2E,CAAC,eAAe,sBAAsB,CAAC,0EAA0E,CAAC,cAAc,sBAAsB,CAAC,yEAAyE,CAAC,aAAa,sBAAsB,CAAC,wEAAwE,CAAC,cAAc,sBAAsB,CAAC,yEAAyE,CAAC,cAAc,sBAAsB,CAAC,yEAAyE,CAAC,uBAAuB,sDAAsD,CAAC,yBAAyB,wDAAwD,CAAC,uBAAuB,sDAAsD,CAAC,oBAAoB,mDAAmD,CAAC,uBAAuB,sDAAsD,CAAC,sBAAsB,qDAAqD,CAAC,qBAAqB,oDAAoD,CAAC,oBAAoB,mDAAmD,CAAC,UAAU,0BAA0B,CAAC,UAAU,0BAA0B,CAAC,UAAU,0BAA0B,CAAC,UAAU,0BAA0B,CAAC,UAAU,0BAA0B,CAAC,mBAAmB,uBAAuB,CAAC,mBAAmB,wBAAwB,CAAC,mBAAmB,uBAAuB,CAAC,mBAAmB,wBAAwB,CAAC,oBAAoB,sBAAsB,CAAC,MAAM,mBAAmB,CAAC,MAAM,mBAAmB,CAAC,MAAM,mBAAmB,CAAC,OAAO,oBAAoB,CAAC,QAAQ,oBAAoB,CAAC,QAAQ,wBAAwB,CAAC,QAAQ,qBAAqB,CAAC,YAAY,yBAAyB,CAAC,MAAM,oBAAoB,CAAC,MAAM,oBAAoB,CAAC,MAAM,oBAAoB,CAAC,OAAO,qBAAqB,CAAC,QAAQ,qBAAqB,CAAC,QAAQ,yBAAyB,CAAC,QAAQ,sBAAsB,CAAC,YAAY,0BAA0B,CAAC,WAAW,uBAAuB,CAAC,UAAU,4BAA4B,CAAC,aAAa,+BAA+B,CAAC,kBAAkB,oCAAoC,CAAC,qBAAqB,uCAAuC,CAAC,aAAa,qBAAqB,CAAC,aAAa,qBAAqB,CAAC,eAAe,uBAAuB,CAAC,eAAe,uBAAuB,CAAC,WAAW,wBAAwB,CAAC,aAAa,0BAA0B,CAAC,mBAAmB,gCAAgC,CAAC,uBAAuB,oCAAoC,CAAC,qBAAqB,kCAAkC,CAAC,wBAAwB,gCAAgC,CAAC,yBAAyB,uCAAuC,CAAC,wBAAwB,sCAAsC,CAAC,wBAAwB,sCAAsC,CAAC,mBAAmB,gCAAgC,CAAC,iBAAiB,8BAA8B,CAAC,oBAAoB,4BAA4B,CAAC,sBAAsB,8BAA8B,CAAC,qBAAqB,6BAA6B,CAAC,qBAAqB,kCAAkC,CAAC,mBAAmB,gCAAgC,CAAC,sBAAsB,8BAA8B,CAAC,uBAAuB,qCAAqC,CAAC,sBAAsB,oCAAoC,CAAC,uBAAuB,+BAA+B,CAAC,iBAAiB,yBAAyB,CAAC,kBAAkB,+BAA+B,CAAC,gBAAgB,6BAA6B,CAAC,mBAAmB,2BAA2B,CAAC,qBAAqB,6BAA6B,CAAC,oBAAoB,4BAA4B,CAAC,aAAa,kBAAkB,CAAC,SAAS,iBAAiB,CAAC,SAAS,iBAAiB,CAAC,SAAS,iBAAiB,CAAC,SAAS,iBAAiB,CAAC,SAAS,iBAAiB,CAAC,SAAS,iBAAiB,CAAC,YAAY,iBAAiB,CAAC,KAAK,kBAAkB,CAAC,KAAK,uBAAuB,CAAC,KAAK,sBAAsB,CAAC,KAAK,qBAAqB,CAAC,KAAK,uBAAuB,CAAC,KAAK,qBAAqB,CAAC,QAAQ,qBAAqB,CAAC,MAAM,wBAAwB,CAAC,uBAAuB,CAAC,MAAM,6BAA6B,CAAC,4BAA4B,CAAC,MAAM,4BAA4B,CAAC,2BAA2B,CAAC,MAAM,2BAA2B,CAAC,0BAA0B,CAAC,MAAM,6BAA6B,CAAC,4BAA4B,CAAC,MAAM,2BAA2B,CAAC,0BAA0B,CAAC,SAAS,2BAA2B,CAAC,0BAA0B,CAAC,MAAM,sBAAsB,CAAC,yBAAyB,CAAC,MAAM,2BAA2B,CAAC,8BAA8B,CAAC,MAAM,0BAA0B,CAAC,6BAA6B,CAAC,MAAM,yBAAyB,CAAC,4BAA4B,CAAC,MAAM,2BAA2B,CAAC,8BAA8B,CAAC,MAAM,yBAAyB,CAAC,4BAA4B,CAAC,SAAS,yBAAyB,CAAC,4BAA4B,CAAC,MAAM,sBAAsB,CAAC,MAAM,2BAA2B,CAAC,MAAM,0BAA0B,CAAC,MAAM,yBAAyB,CAAC,MAAM,2BAA2B,CAAC,MAAM,yBAAyB,CAAC,SAAS,yBAAyB,CAAC,MAAM,wBAAwB,CAAC,MAAM,6BAA6B,CAAC,MAAM,4BAA4B,CAAC,MAAM,2BAA2B,CAAC,MAAM,6BAA6B,CAAC,MAAM,2BAA2B,CAAC,SAAS,2BAA2B,CAAC,MAAM,yBAAyB,CAAC,MAAM,8BAA8B,CAAC,MAAM,6BAA6B,CAAC,MAAM,4BAA4B,CAAC,MAAM,8BAA8B,CAAC,MAAM,4BAA4B,CAAC,SAAS,4BAA4B,CAAC,MAAM,uBAAuB,CAAC,MAAM,4BAA4B,CAAC,MAAM,2BAA2B,CAAC,MAAM,0BAA0B,CAAC,MAAM,4BAA4B,CAAC,MAAM,0BAA0B,CAAC,SAAS,0BAA0B,CAAC,KAAK,mBAAmB,CAAC,KAAK,wBAAwB,CAAC,KAAK,uBAAuB,CAAC,KAAK,sBAAsB,CAAC,KAAK,wBAAwB,CAAC,KAAK,sBAAsB,CAAC,MAAM,yBAAyB,CAAC,wBAAwB,CAAC,MAAM,8BAA8B,CAAC,6BAA6B,CAAC,MAAM,6BAA6B,CAAC,4BAA4B,CAAC,MAAM,4BAA4B,CAAC,2BAA2B,CAAC,MAAM,8BAA8B,CAAC,6BAA6B,CAAC,MAAM,4BAA4B,CAAC,2BAA2B,CAAC,MAAM,uBAAuB,CAAC,0BAA0B,CAAC,MAAM,4BAA4B,CAAC,+BAA+B,CAAC,MAAM,2BAA2B,CAAC,8BAA8B,CAAC,MAAM,0BAA0B,CAAC,6BAA6B,CAAC,MAAM,4BAA4B,CAAC,+BAA+B,CAAC,MAAM,0BAA0B,CAAC,6BAA6B,CAAC,MAAM,uBAAuB,CAAC,MAAM,4BAA4B,CAAC,MAAM,2BAA2B,CAAC,MAAM,0BAA0B,CAAC,MAAM,4BAA4B,CAAC,MAAM,0BAA0B,CAAC,MAAM,yBAAyB,CAAC,MAAM,8BAA8B,CAAC,MAAM,6BAA6B,CAAC,MAAM,4BAA4B,CAAC,MAAM,8BAA8B,CAAC,MAAM,4BAA4B,CAAC,MAAM,0BAA0B,CAAC,MAAM,+BAA+B,CAAC,MAAM,8BAA8B,CAAC,MAAM,6BAA6B,CAAC,MAAM,+BAA+B,CAAC,MAAM,6BAA6B,CAAC,MAAM,wBAAwB,CAAC,MAAM,6BAA6B,CAAC,MAAM,4BAA4B,CAAC,MAAM,2BAA2B,CAAC,MAAM,6BAA6B,CAAC,MAAM,2BAA2B,CAAC,OAAO,eAAe,CAAC,OAAO,oBAAoB,CAAC,OAAO,mBAAmB,CAAC,OAAO,kBAAkB,CAAC,OAAO,oBAAoB,CAAC,OAAO,kBAAkB,CAAC,WAAW,mBAAmB,CAAC,WAAW,wBAAwB,CAAC,WAAW,uBAAuB,CAAC,WAAW,sBAAsB,CAAC,WAAW,wBAAwB,CAAC,WAAW,sBAAsB,CAAC,cAAc,sBAAsB,CAAC,cAAc,2BAA2B,CAAC,cAAc,0BAA0B,CAAC,cAAc,yBAAyB,CAAC,cAAc,2BAA2B,CAAC,cAAc,yBAAyB,CAAC,gBAAgB,8CAA8C,CAAC,MAAM,0CAA0C,CAAC,MAAM,yCAAyC,CAAC,MAAM,uCAAuC,CAAC,MAAM,yCAAyC,CAAC,MAAM,2BAA2B,CAAC,MAAM,wBAAwB,CAAC,YAAY,2BAA2B,CAAC,YAAY,2BAA2B,CAAC,YAAY,6BAA6B,CAAC,UAAU,yBAAyB,CAAC,WAAW,yBAAyB,CAAC,WAAW,yBAAyB,CAAC,aAAa,yBAAyB,CAAC,SAAS,yBAAyB,CAAC,WAAW,4BAA4B,CAAC,MAAM,uBAAuB,CAAC,OAAO,0BAA0B,CAAC,SAAS,yBAAyB,CAAC,OAAO,uBAAuB,CAAC,YAAY,yBAAyB,CAAC,UAAU,0BAA0B,CAAC,aAAa,2BAA2B,CAAC,sBAAsB,8BAA8B,CAAC,2BAA2B,mCAAmC,CAAC,8BAA8B,sCAAsC,CAAC,gBAAgB,kCAAkC,CAAC,gBAAgB,kCAAkC,CAAC,iBAAiB,mCAAmC,CAAC,WAAW,4BAA4B,CAAC,aAAa,4BAA4B,CAAC,YAAY,8BAA8B,CAAC,+BAA+B,CAAC,cAAc,oBAAoB,CAAC,kEAAkE,CAAC,gBAAgB,oBAAoB,CAAC,oEAAoE,CAAC,cAAc,oBAAoB,CAAC,kEAAkE,CAAC,WAAW,oBAAoB,CAAC,+DAA+D,CAAC,cAAc,oBAAoB,CAAC,kEAAkE,CAAC,aAAa,oBAAoB,CAAC,iEAAiE,CAAC,YAAY,oBAAoB,CAAC,gEAAgE,CAAC,WAAW,oBAAoB,CAAC,+DAA+D,CAAC,YAAY,oBAAoB,CAAC,gEAAgE,CAAC,YAAY,oBAAoB,CAAC,gEAAgE,CAAC,WAAW,oBAAoB,CAAC,qEAAqE,CAAC,YAAY,oBAAoB,CAAC,yCAAyC,CAAC,eAAe,oBAAoB,CAAC,yBAAyB,CAAC,eAAe,oBAAoB,CAAC,yBAAyB,CAAC,qBAAqB,oBAAoB,CAAC,yCAAyC,CAAC,oBAAoB,oBAAoB,CAAC,wCAAwC,CAAC,oBAAoB,oBAAoB,CAAC,wCAAwC,CAAC,YAAY,oBAAoB,CAAC,uBAAuB,CAAC,iBAAiB,sBAAsB,CAAC,iBAAiB,qBAAqB,CAAC,iBAAiB,sBAAsB,CAAC,kBAAkB,oBAAoB,CAAC,uBAAuB,+CAA+C,CAAC,yBAAyB,iDAAiD,CAAC,uBAAuB,+CAA+C,CAAC,oBAAoB,4CAA4C,CAAC,uBAAuB,+CAA+C,CAAC,sBAAsB,8CAA8C,CAAC,qBAAqB,6CAA6C,CAAC,oBAAoB,4CAA4C,CAAC,8CAA8C,qBAAqB,CAAC,8CAA8C,sBAAsB,CAAC,8CAA8C,qBAAqB,CAAC,8CAA8C,sBAAsB,CAAC,gDAAgD,oBAAoB,CAAC,0CAA0C,sCAAsC,CAAC,0CAA0C,qCAAqC,CAAC,0CAA0C,sCAAsC,CAAC,wBAAwB,8BAA8B,CAAC,4FAA4F,CAAC,0BAA0B,8BAA8B,CAAC,8FAA8F,CAAC,wBAAwB,8BAA8B,CAAC,4FAA4F,CAAC,qBAAqB,8BAA8B,CAAC,yFAAyF,CAAC,wBAAwB,8BAA8B,CAAC,4FAA4F,CAAC,uBAAuB,8BAA8B,CAAC,2FAA2F,CAAC,sBAAsB,8BAA8B,CAAC,0FAA0F,CAAC,qBAAqB,8BAA8B,CAAC,yFAAyF,CAAC,gBAAgB,8BAA8B,CAAC,kGAAkG,CAAC,gEAAgE,8BAA8B,CAAC,kEAAkE,+BAA+B,CAAC,kEAAkE,gCAAgC,CAAC,kEAAkE,+BAA+B,CAAC,kEAAkE,gCAAgC,CAAC,oEAAoE,8BAA8B,CAAC,YAAY,kBAAkB,CAAC,2EAA2E,CAAC,cAAc,kBAAkB,CAAC,6EAA6E,CAAC,YAAY,kBAAkB,CAAC,2EAA2E,CAAC,SAAS,kBAAkB,CAAC,wEAAwE,CAAC,YAAY,kBAAkB,CAAC,2EAA2E,CAAC,WAAW,kBAAkB,CAAC,0EAA0E,CAAC,UAAU,kBAAkB,CAAC,yEAAyE,CAAC,SAAS,kBAAkB,CAAC,wEAAwE,CAAC,UAAU,kBAAkB,CAAC,yEAAyE,CAAC,UAAU,kBAAkB,CAAC,yEAAyE,CAAC,SAAS,kBAAkB,CAAC,2EAA2E,CAAC,gBAAgB,kBAAkB,CAAC,sCAAsC,CAAC,mBAAmB,kBAAkB,CAAC,gFAAgF,CAAC,kBAAkB,kBAAkB,CAAC,+EAA+E,CAAC,eAAe,mBAAmB,CAAC,eAAe,oBAAoB,CAAC,eAAe,mBAAmB,CAAC,eAAe,oBAAoB,CAAC,gBAAgB,kBAAkB,CAAC,mBAAmB,sDAAsD,CAAC,qBAAqB,wDAAwD,CAAC,mBAAmB,sDAAsD,CAAC,gBAAgB,mDAAmD,CAAC,mBAAmB,sDAAsD,CAAC,kBAAkB,qDAAqD,CAAC,iBAAiB,oDAAoD,CAAC,gBAAgB,mDAAmD,CAAC,aAAa,6CAA6C,CAAC,iBAAiB,iCAAiC,CAAC,yBAAyB,CAAC,kBAAkB,kCAAkC,CAAC,0BAA0B,CAAC,kBAAkB,kCAAkC,CAAC,0BAA0B,CAAC,SAAS,6BAA6B,CAAC,SAAS,6BAA6B,CAAC,SAAS,+CAA+C,CAAC,WAAW,yBAAyB,CAAC,WAAW,kDAAkD,CAAC,WAAW,+CAA+C,CAAC,WAAW,kDAAkD,CAAC,WAAW,kDAAkD,CAAC,WAAW,mDAAmD,CAAC,gBAAgB,2BAA2B,CAAC,cAAc,oDAAoD,CAAC,aAAa,wDAAwD,CAAC,yDAAyD,CAAC,eAAe,kCAAkC,CAAC,mCAAmC,CAAC,eAAe,2DAA2D,CAAC,4DAA4D,CAAC,eAAe,wDAAwD,CAAC,yDAAyD,CAAC,eAAe,2DAA2D,CAAC,4DAA4D,CAAC,eAAe,2DAA2D,CAAC,4DAA4D,CAAC,eAAe,4DAA4D,CAAC,6DAA6D,CAAC,oBAAoB,oCAAoC,CAAC,qCAAqC,CAAC,kBAAkB,6DAA6D,CAAC,8DAA8D,CAAC,aAAa,yDAAyD,CAAC,4DAA4D,CAAC,eAAe,mCAAmC,CAAC,sCAAsC,CAAC,eAAe,4DAA4D,CAAC,+DAA+D,CAAC,eAAe,yDAAyD,CAAC,4DAA4D,CAAC,eAAe,4DAA4D,CAAC,+DAA+D,CAAC,eAAe,4DAA4D,CAAC,+DAA+D,CAAC,eAAe,6DAA6D,CAAC,gEAAgE,CAAC,oBAAoB,qCAAqC,CAAC,wCAAwC,CAAC,kBAAkB,8DAA8D,CAAC,iEAAiE,CAAC,gBAAgB,4DAA4D,CAAC,2DAA2D,CAAC,kBAAkB,sCAAsC,CAAC,qCAAqC,CAAC,kBAAkB,+DAA+D,CAAC,8DAA8D,CAAC,kBAAkB,4DAA4D,CAAC,2DAA2D,CAAC,kBAAkB,+DAA+D,CAAC,8DAA8D,CAAC,kBAAkB,+DAA+D,CAAC,8DAA8D,CAAC,kBAAkB,gEAAgE,CAAC,+DAA+D,CAAC,uBAAuB,wCAAwC,CAAC,uCAAuC,CAAC,qBAAqB,iEAAiE,CAAC,gEAAgE,CAAC,eAAe,2DAA2D,CAAC,wDAAwD,CAAC,iBAAiB,qCAAqC,CAAC,kCAAkC,CAAC,iBAAiB,8DAA8D,CAAC,2DAA2D,CAAC,iBAAiB,2DAA2D,CAAC,wDAAwD,CAAC,iBAAiB,8DAA8D,CAAC,2DAA2D,CAAC,iBAAiB,8DAA8D,CAAC,2DAA2D,CAAC,iBAAiB,+DAA+D,CAAC,4DAA4D,CAAC,sBAAsB,uCAAuC,CAAC,oCAAoC,CAAC,oBAAoB,gEAAgE,CAAC,6DAA6D,CAAC,SAAS,4BAA4B,CAAC,WAAW,2BAA2B,CAAC,MAAM,oBAAoB,CAAC,KAAK,mBAAmB,CAAC,KAAK,mBAAmB,CAAC,KAAK,mBAAmB,CAAC,KAAK,mBAAmB,CAAC,0BAA0B,gBAAgB,oBAAoB,CAAC,cAAc,qBAAqB,CAAC,eAAe,oBAAoB,CAAC,uBAAuB,4BAA4B,CAAC,qBAAqB,0BAA0B,CAAC,oBAAoB,yBAAyB,CAAC,qBAAqB,+BAA+B,CAAC,oBAAoB,yBAAyB,CAAC,aAAa,wBAAwB,CAAC,mBAAmB,8BAA8B,CAAC,YAAY,uBAAuB,CAAC,WAAW,sBAAsB,CAAC,kBAAkB,6BAA6B,CAAC,YAAY,uBAAuB,CAAC,gBAAgB,2BAA2B,CAAC,iBAAiB,4BAA4B,CAAC,WAAW,sBAAsB,CAAC,kBAAkB,6BAA6B,CAAC,WAAW,sBAAsB,CAAC,cAAc,uBAAuB,CAAC,aAAa,4BAA4B,CAAC,gBAAgB,+BAA+B,CAAC,qBAAqB,oCAAoC,CAAC,wBAAwB,uCAAuC,CAAC,gBAAgB,qBAAqB,CAAC,gBAAgB,qBAAqB,CAAC,kBAAkB,uBAAuB,CAAC,kBAAkB,uBAAuB,CAAC,cAAc,wBAAwB,CAAC,gBAAgB,0BAA0B,CAAC,sBAAsB,gCAAgC,CAAC,0BAA0B,oCAAoC,CAAC,wBAAwB,kCAAkC,CAAC,2BAA2B,gCAAgC,CAAC,4BAA4B,uCAAuC,CAAC,2BAA2B,sCAAsC,CAAC,2BAA2B,sCAAsC,CAAC,sBAAsB,gCAAgC,CAAC,oBAAoB,8BAA8B,CAAC,uBAAuB,4BAA4B,CAAC,yBAAyB,8BAA8B,CAAC,wBAAwB,6BAA6B,CAAC,wBAAwB,kCAAkC,CAAC,sBAAsB,gCAAgC,CAAC,yBAAyB,8BAA8B,CAAC,0BAA0B,qCAAqC,CAAC,yBAAyB,oCAAoC,CAAC,0BAA0B,+BAA+B,CAAC,oBAAoB,yBAAyB,CAAC,qBAAqB,+BAA+B,CAAC,mBAAmB,6BAA6B,CAAC,sBAAsB,2BAA2B,CAAC,wBAAwB,6BAA6B,CAAC,uBAAuB,4BAA4B,CAAC,gBAAgB,kBAAkB,CAAC,YAAY,iBAAiB,CAAC,YAAY,iBAAiB,CAAC,YAAY,iBAAiB,CAAC,YAAY,iBAAiB,CAAC,YAAY,iBAAiB,CAAC,YAAY,iBAAiB,CAAC,eAAe,iBAAiB,CAAC,QAAQ,kBAAkB,CAAC,QAAQ,uBAAuB,CAAC,QAAQ,sBAAsB,CAAC,QAAQ,qBAAqB,CAAC,QAAQ,uBAAuB,CAAC,QAAQ,qBAAqB,CAAC,WAAW,qBAAqB,CAAC,SAAS,wBAAwB,CAAC,uBAAuB,CAAC,SAAS,6BAA6B,CAAC,4BAA4B,CAAC,SAAS,4BAA4B,CAAC,2BAA2B,CAAC,SAAS,2BAA2B,CAAC,0BAA0B,CAAC,SAAS,6BAA6B,CAAC,4BAA4B,CAAC,SAAS,2BAA2B,CAAC,0BAA0B,CAAC,YAAY,2BAA2B,CAAC,0BAA0B,CAAC,SAAS,sBAAsB,CAAC,yBAAyB,CAAC,SAAS,2BAA2B,CAAC,8BAA8B,CAAC,SAAS,0BAA0B,CAAC,6BAA6B,CAAC,SAAS,yBAAyB,CAAC,4BAA4B,CAAC,SAAS,2BAA2B,CAAC,8BAA8B,CAAC,SAAS,yBAAyB,CAAC,4BAA4B,CAAC,YAAY,yBAAyB,CAAC,4BAA4B,CAAC,SAAS,sBAAsB,CAAC,SAAS,2BAA2B,CAAC,SAAS,0BAA0B,CAAC,SAAS,yBAAyB,CAAC,SAAS,2BAA2B,CAAC,SAAS,yBAAyB,CAAC,YAAY,yBAAyB,CAAC,SAAS,wBAAwB,CAAC,SAAS,6BAA6B,CAAC,SAAS,4BAA4B,CAAC,SAAS,2BAA2B,CAAC,SAAS,6BAA6B,CAAC,SAAS,2BAA2B,CAAC,YAAY,2BAA2B,CAAC,SAAS,yBAAyB,CAAC,SAAS,8BAA8B,CAAC,SAAS,6BAA6B,CAAC,SAAS,4BAA4B,CAAC,SAAS,8BAA8B,CAAC,SAAS,4BAA4B,CAAC,YAAY,4BAA4B,CAAC,SAAS,uBAAuB,CAAC,SAAS,4BAA4B,CAAC,SAAS,2BAA2B,CAAC,SAAS,0BAA0B,CAAC,SAAS,4BAA4B,CAAC,SAAS,0BAA0B,CAAC,YAAY,0BAA0B,CAAC,QAAQ,mBAAmB,CAAC,QAAQ,wBAAwB,CAAC,QAAQ,uBAAuB,CAAC,QAAQ,sBAAsB,CAAC,QAAQ,wBAAwB,CAAC,QAAQ,sBAAsB,CAAC,SAAS,yBAAyB,CAAC,wBAAwB,CAAC,SAAS,8BAA8B,CAAC,6BAA6B,CAAC,SAAS,6BAA6B,CAAC,4BAA4B,CAAC,SAAS,4BAA4B,CAAC,2BAA2B,CAAC,SAAS,8BAA8B,CAAC,6BAA6B,CAAC,SAAS,4BAA4B,CAAC,2BAA2B,CAAC,SAAS,uBAAuB,CAAC,0BAA0B,CAAC,SAAS,4BAA4B,CAAC,+BAA+B,CAAC,SAAS,2BAA2B,CAAC,8BAA8B,CAAC,SAAS,0BAA0B,CAAC,6BAA6B,CAAC,SAAS,4BAA4B,CAAC,+BAA+B,CAAC,SAAS,0BAA0B,CAAC,6BAA6B,CAAC,SAAS,uBAAuB,CAAC,SAAS,4BAA4B,CAAC,SAAS,2BAA2B,CAAC,SAAS,0BAA0B,CAAC,SAAS,4BAA4B,CAAC,SAAS,0BAA0B,CAAC,SAAS,yBAAyB,CAAC,SAAS,8BAA8B,CAAC,SAAS,6BAA6B,CAAC,SAAS,4BAA4B,CAAC,SAAS,8BAA8B,CAAC,SAAS,4BAA4B,CAAC,SAAS,0BAA0B,CAAC,SAAS,+BAA+B,CAAC,SAAS,8BAA8B,CAAC,SAAS,6BAA6B,CAAC,SAAS,+BAA+B,CAAC,SAAS,6BAA6B,CAAC,SAAS,wBAAwB,CAAC,SAAS,6BAA6B,CAAC,SAAS,4BAA4B,CAAC,SAAS,2BAA2B,CAAC,SAAS,6BAA6B,CAAC,SAAS,2BAA2B,CAAC,UAAU,eAAe,CAAC,UAAU,oBAAoB,CAAC,UAAU,mBAAmB,CAAC,UAAU,kBAAkB,CAAC,UAAU,oBAAoB,CAAC,UAAU,kBAAkB,CAAC,cAAc,mBAAmB,CAAC,cAAc,wBAAwB,CAAC,cAAc,uBAAuB,CAAC,cAAc,sBAAsB,CAAC,cAAc,wBAAwB,CAAC,cAAc,sBAAsB,CAAC,iBAAiB,sBAAsB,CAAC,iBAAiB,2BAA2B,CAAC,iBAAiB,0BAA0B,CAAC,iBAAiB,yBAAyB,CAAC,iBAAiB,2BAA2B,CAAC,iBAAiB,yBAAyB,CAAC,eAAe,yBAAyB,CAAC,aAAa,0BAA0B,CAAC,gBAAgB,2BAA2B,CAAC,CAAC,0BAA0B,gBAAgB,oBAAoB,CAAC,cAAc,qBAAqB,CAAC,eAAe,oBAAoB,CAAC,uBAAuB,4BAA4B,CAAC,qBAAqB,0BAA0B,CAAC,oBAAoB,yBAAyB,CAAC,qBAAqB,+BAA+B,CAAC,oBAAoB,yBAAyB,CAAC,aAAa,wBAAwB,CAAC,mBAAmB,8BAA8B,CAAC,YAAY,uBAAuB,CAAC,WAAW,sBAAsB,CAAC,kBAAkB,6BAA6B,CAAC,YAAY,uBAAuB,CAAC,gBAAgB,2BAA2B,CAAC,iBAAiB,4BAA4B,CAAC,WAAW,sBAAsB,CAAC,kBAAkB,6BAA6B,CAAC,WAAW,sBAAsB,CAAC,cAAc,uBAAuB,CAAC,aAAa,4BAA4B,CAAC,gBAAgB,+BAA+B,CAAC,qBAAqB,oCAAoC,CAAC,wBAAwB,uCAAuC,CAAC,gBAAgB,qBAAqB,CAAC,gBAAgB,qBAAqB,CAAC,kBAAkB,uBAAuB,CAAC,kBAAkB,uBAAuB,CAAC,cAAc,wBAAwB,CAAC,gBAAgB,0BAA0B,CAAC,sBAAsB,gCAAgC,CAAC,0BAA0B,oCAAoC,CAAC,wBAAwB,kCAAkC,CAAC,2BAA2B,gCAAgC,CAAC,4BAA4B,uCAAuC,CAAC,2BAA2B,sCAAsC,CAAC,2BAA2B,sCAAsC,CAAC,sBAAsB,gCAAgC,CAAC,oBAAoB,8BAA8B,CAAC,uBAAuB,4BAA4B,CAAC,yBAAyB,8BAA8B,CAAC,wBAAwB,6BAA6B,CAAC,wBAAwB,kCAAkC,CAAC,sBAAsB,gCAAgC,CAAC,yBAAyB,8BAA8B,CAAC,0BAA0B,qCAAqC,CAAC,yBAAyB,oCAAoC,CAAC,0BAA0B,+BAA+B,CAAC,oBAAoB,yBAAyB,CAAC,qBAAqB,+BAA+B,CAAC,mBAAmB,6BAA6B,CAAC,sBAAsB,2BAA2B,CAAC,wBAAwB,6BAA6B,CAAC,uBAAuB,4BAA4B,CAAC,gBAAgB,kBAAkB,CAAC,YAAY,iBAAiB,CAAC,YAAY,iBAAiB,CAAC,YAAY,iBAAiB,CAAC,YAAY,iBAAiB,CAAC,YAAY,iBAAiB,CAAC,YAAY,iBAAiB,CAAC,eAAe,iBAAiB,CAAC,QAAQ,kBAAkB,CAAC,QAAQ,uBAAuB,CAAC,QAAQ,sBAAsB,CAAC,QAAQ,qBAAqB,CAAC,QAAQ,uBAAuB,CAAC,QAAQ,qBAAqB,CAAC,WAAW,qBAAqB,CAAC,SAAS,wBAAwB,CAAC,uBAAuB,CAAC,SAAS,6BAA6B,CAAC,4BAA4B,CAAC,SAAS,4BAA4B,CAAC,2BAA2B,CAAC,SAAS,2BAA2B,CAAC,0BAA0B,CAAC,SAAS,6BAA6B,CAAC,4BAA4B,CAAC,SAAS,2BAA2B,CAAC,0BAA0B,CAAC,YAAY,2BAA2B,CAAC,0BAA0B,CAAC,SAAS,sBAAsB,CAAC,yBAAyB,CAAC,SAAS,2BAA2B,CAAC,8BAA8B,CAAC,SAAS,0BAA0B,CAAC,6BAA6B,CAAC,SAAS,yBAAyB,CAAC,4BAA4B,CAAC,SAAS,2BAA2B,CAAC,8BAA8B,CAAC,SAAS,yBAAyB,CAAC,4BAA4B,CAAC,YAAY,yBAAyB,CAAC,4BAA4B,CAAC,SAAS,sBAAsB,CAAC,SAAS,2BAA2B,CAAC,SAAS,0BAA0B,CAAC,SAAS,yBAAyB,CAAC,SAAS,2BAA2B,CAAC,SAAS,yBAAyB,CAAC,YAAY,yBAAyB,CAAC,SAAS,wBAAwB,CAAC,SAAS,6BAA6B,CAAC,SAAS,4BAA4B,CAAC,SAAS,2BAA2B,CAAC,SAAS,6BAA6B,CAAC,SAAS,2BAA2B,CAAC,YAAY,2BAA2B,CAAC,SAAS,yBAAyB,CAAC,SAAS,8BAA8B,CAAC,SAAS,6BAA6B,CAAC,SAAS,4BAA4B,CAAC,SAAS,8BAA8B,CAAC,SAAS,4BAA4B,CAAC,YAAY,4BAA4B,CAAC,SAAS,uBAAuB,CAAC,SAAS,4BAA4B,CAAC,SAAS,2BAA2B,CAAC,SAAS,0BAA0B,CAAC,SAAS,4BAA4B,CAAC,SAAS,0BAA0B,CAAC,YAAY,0BAA0B,CAAC,QAAQ,mBAAmB,CAAC,QAAQ,wBAAwB,CAAC,QAAQ,uBAAuB,CAAC,QAAQ,sBAAsB,CAAC,QAAQ,wBAAwB,CAAC,QAAQ,sBAAsB,CAAC,SAAS,yBAAyB,CAAC,wBAAwB,CAAC,SAAS,8BAA8B,CAAC,6BAA6B,CAAC,SAAS,6BAA6B,CAAC,4BAA4B,CAAC,SAAS,4BAA4B,CAAC,2BAA2B,CAAC,SAAS,8BAA8B,CAAC,6BAA6B,CAAC,SAAS,4BAA4B,CAAC,2BAA2B,CAAC,SAAS,uBAAuB,CAAC,0BAA0B,CAAC,SAAS,4BAA4B,CAAC,+BAA+B,CAAC,SAAS,2BAA2B,CAAC,8BAA8B,CAAC,SAAS,0BAA0B,CAAC,6BAA6B,CAAC,SAAS,4BAA4B,CAAC,+BAA+B,CAAC,SAAS,0BAA0B,CAAC,6BAA6B,CAAC,SAAS,uBAAuB,CAAC,SAAS,4BAA4B,CAAC,SAAS,2BAA2B,CAAC,SAAS,0BAA0B,CAAC,SAAS,4BAA4B,CAAC,SAAS,0BAA0B,CAAC,SAAS,yBAAyB,CAAC,SAAS,8BAA8B,CAAC,SAAS,6BAA6B,CAAC,SAAS,4BAA4B,CAAC,SAAS,8BAA8B,CAAC,SAAS,4BAA4B,CAAC,SAAS,0BAA0B,CAAC,SAAS,+BAA+B,CAAC,SAAS,8BAA8B,CAAC,SAAS,6BAA6B,CAAC,SAAS,+BAA+B,CAAC,SAAS,6BAA6B,CAAC,SAAS,wBAAwB,CAAC,SAAS,6BAA6B,CAAC,SAAS,4BAA4B,CAAC,SAAS,2BAA2B,CAAC,SAAS,6BAA6B,CAAC,SAAS,2BAA2B,CAAC,UAAU,eAAe,CAAC,UAAU,oBAAoB,CAAC,UAAU,mBAAmB,CAAC,UAAU,kBAAkB,CAAC,UAAU,oBAAoB,CAAC,UAAU,kBAAkB,CAAC,cAAc,mBAAmB,CAAC,cAAc,wBAAwB,CAAC,cAAc,uBAAuB,CAAC,cAAc,sBAAsB,CAAC,cAAc,wBAAwB,CAAC,cAAc,sBAAsB,CAAC,iBAAiB,sBAAsB,CAAC,iBAAiB,2BAA2B,CAAC,iBAAiB,0BAA0B,CAAC,iBAAiB,yBAAyB,CAAC,iBAAiB,2BAA2B,CAAC,iBAAiB,yBAAyB,CAAC,eAAe,yBAAyB,CAAC,aAAa,0BAA0B,CAAC,gBAAgB,2BAA2B,CAAC,CAAC,0BAA0B,gBAAgB,oBAAoB,CAAC,cAAc,qBAAqB,CAAC,eAAe,oBAAoB,CAAC,uBAAuB,4BAA4B,CAAC,qBAAqB,0BAA0B,CAAC,oBAAoB,yBAAyB,CAAC,qBAAqB,+BAA+B,CAAC,oBAAoB,yBAAyB,CAAC,aAAa,wBAAwB,CAAC,mBAAmB,8BAA8B,CAAC,YAAY,uBAAuB,CAAC,WAAW,sBAAsB,CAAC,kBAAkB,6BAA6B,CAAC,YAAY,uBAAuB,CAAC,gBAAgB,2BAA2B,CAAC,iBAAiB,4BAA4B,CAAC,WAAW,sBAAsB,CAAC,kBAAkB,6BAA6B,CAAC,WAAW,sBAAsB,CAAC,cAAc,uBAAuB,CAAC,aAAa,4BAA4B,CAAC,gBAAgB,+BAA+B,CAAC,qBAAqB,oCAAoC,CAAC,wBAAwB,uCAAuC,CAAC,gBAAgB,qBAAqB,CAAC,gBAAgB,qBAAqB,CAAC,kBAAkB,uBAAuB,CAAC,kBAAkB,uBAAuB,CAAC,cAAc,wBAAwB,CAAC,gBAAgB,0BAA0B,CAAC,sBAAsB,gCAAgC,CAAC,0BAA0B,oCAAoC,CAAC,wBAAwB,kCAAkC,CAAC,2BAA2B,gCAAgC,CAAC,4BAA4B,uCAAuC,CAAC,2BAA2B,sCAAsC,CAAC,2BAA2B,sCAAsC,CAAC,sBAAsB,gCAAgC,CAAC,oBAAoB,8BAA8B,CAAC,uBAAuB,4BAA4B,CAAC,yBAAyB,8BAA8B,CAAC,wBAAwB,6BAA6B,CAAC,wBAAwB,kCAAkC,CAAC,sBAAsB,gCAAgC,CAAC,yBAAyB,8BAA8B,CAAC,0BAA0B,qCAAqC,CAAC,yBAAyB,oCAAoC,CAAC,0BAA0B,+BAA+B,CAAC,oBAAoB,yBAAyB,CAAC,qBAAqB,+BAA+B,CAAC,mBAAmB,6BAA6B,CAAC,sBAAsB,2BAA2B,CAAC,wBAAwB,6BAA6B,CAAC,uBAAuB,4BAA4B,CAAC,gBAAgB,kBAAkB,CAAC,YAAY,iBAAiB,CAAC,YAAY,iBAAiB,CAAC,YAAY,iBAAiB,CAAC,YAAY,iBAAiB,CAAC,YAAY,iBAAiB,CAAC,YAAY,iBAAiB,CAAC,eAAe,iBAAiB,CAAC,QAAQ,kBAAkB,CAAC,QAAQ,uBAAuB,CAAC,QAAQ,sBAAsB,CAAC,QAAQ,qBAAqB,CAAC,QAAQ,uBAAuB,CAAC,QAAQ,qBAAqB,CAAC,WAAW,qBAAqB,CAAC,SAAS,wBAAwB,CAAC,uBAAuB,CAAC,SAAS,6BAA6B,CAAC,4BAA4B,CAAC,SAAS,4BAA4B,CAAC,2BAA2B,CAAC,SAAS,2BAA2B,CAAC,0BAA0B,CAAC,SAAS,6BAA6B,CAAC,4BAA4B,CAAC,SAAS,2BAA2B,CAAC,0BAA0B,CAAC,YAAY,2BAA2B,CAAC,0BAA0B,CAAC,SAAS,sBAAsB,CAAC,yBAAyB,CAAC,SAAS,2BAA2B,CAAC,8BAA8B,CAAC,SAAS,0BAA0B,CAAC,6BAA6B,CAAC,SAAS,yBAAyB,CAAC,4BAA4B,CAAC,SAAS,2BAA2B,CAAC,8BAA8B,CAAC,SAAS,yBAAyB,CAAC,4BAA4B,CAAC,YAAY,yBAAyB,CAAC,4BAA4B,CAAC,SAAS,sBAAsB,CAAC,SAAS,2BAA2B,CAAC,SAAS,0BAA0B,CAAC,SAAS,yBAAyB,CAAC,SAAS,2BAA2B,CAAC,SAAS,yBAAyB,CAAC,YAAY,yBAAyB,CAAC,SAAS,wBAAwB,CAAC,SAAS,6BAA6B,CAAC,SAAS,4BAA4B,CAAC,SAAS,2BAA2B,CAAC,SAAS,6BAA6B,CAAC,SAAS,2BAA2B,CAAC,YAAY,2BAA2B,CAAC,SAAS,yBAAyB,CAAC,SAAS,8BAA8B,CAAC,SAAS,6BAA6B,CAAC,SAAS,4BAA4B,CAAC,SAAS,8BAA8B,CAAC,SAAS,4BAA4B,CAAC,YAAY,4BAA4B,CAAC,SAAS,uBAAuB,CAAC,SAAS,4BAA4B,CAAC,SAAS,2BAA2B,CAAC,SAAS,0BAA0B,CAAC,SAAS,4BAA4B,CAAC,SAAS,0BAA0B,CAAC,YAAY,0BAA0B,CAAC,QAAQ,mBAAmB,CAAC,QAAQ,wBAAwB,CAAC,QAAQ,uBAAuB,CAAC,QAAQ,sBAAsB,CAAC,QAAQ,wBAAwB,CAAC,QAAQ,sBAAsB,CAAC,SAAS,yBAAyB,CAAC,wBAAwB,CAAC,SAAS,8BAA8B,CAAC,6BAA6B,CAAC,SAAS,6BAA6B,CAAC,4BAA4B,CAAC,SAAS,4BAA4B,CAAC,2BAA2B,CAAC,SAAS,8BAA8B,CAAC,6BAA6B,CAAC,SAAS,4BAA4B,CAAC,2BAA2B,CAAC,SAAS,uBAAuB,CAAC,0BAA0B,CAAC,SAAS,4BAA4B,CAAC,+BAA+B,CAAC,SAAS,2BAA2B,CAAC,8BAA8B,CAAC,SAAS,0BAA0B,CAAC,6BAA6B,CAAC,SAAS,4BAA4B,CAAC,+BAA+B,CAAC,SAAS,0BAA0B,CAAC,6BAA6B,CAAC,SAAS,uBAAuB,CAAC,SAAS,4BAA4B,CAAC,SAAS,2BAA2B,CAAC,SAAS,0BAA0B,CAAC,SAAS,4BAA4B,CAAC,SAAS,0BAA0B,CAAC,SAAS,yBAAyB,CAAC,SAAS,8BAA8B,CAAC,SAAS,6BAA6B,CAAC,SAAS,4BAA4B,CAAC,SAAS,8BAA8B,CAAC,SAAS,4BAA4B,CAAC,SAAS,0BAA0B,CAAC,SAAS,+BAA+B,CAAC,SAAS,8BAA8B,CAAC,SAAS,6BAA6B,CAAC,SAAS,+BAA+B,CAAC,SAAS,6BAA6B,CAAC,SAAS,wBAAwB,CAAC,SAAS,6BAA6B,CAAC,SAAS,4BAA4B,CAAC,SAAS,2BAA2B,CAAC,SAAS,6BAA6B,CAAC,SAAS,2BAA2B,CAAC,UAAU,eAAe,CAAC,UAAU,oBAAoB,CAAC,UAAU,mBAAmB,CAAC,UAAU,kBAAkB,CAAC,UAAU,oBAAoB,CAAC,UAAU,kBAAkB,CAAC,cAAc,mBAAmB,CAAC,cAAc,wBAAwB,CAAC,cAAc,uBAAuB,CAAC,cAAc,sBAAsB,CAAC,cAAc,wBAAwB,CAAC,cAAc,sBAAsB,CAAC,iBAAiB,sBAAsB,CAAC,iBAAiB,2BAA2B,CAAC,iBAAiB,0BAA0B,CAAC,iBAAiB,yBAAyB,CAAC,iBAAiB,2BAA2B,CAAC,iBAAiB,yBAAyB,CAAC,eAAe,yBAAyB,CAAC,aAAa,0BAA0B,CAAC,gBAAgB,2BAA2B,CAAC,CAAC,2BAA2B,gBAAgB,oBAAoB,CAAC,cAAc,qBAAqB,CAAC,eAAe,oBAAoB,CAAC,uBAAuB,4BAA4B,CAAC,qBAAqB,0BAA0B,CAAC,oBAAoB,yBAAyB,CAAC,qBAAqB,+BAA+B,CAAC,oBAAoB,yBAAyB,CAAC,aAAa,wBAAwB,CAAC,mBAAmB,8BAA8B,CAAC,YAAY,uBAAuB,CAAC,WAAW,sBAAsB,CAAC,kBAAkB,6BAA6B,CAAC,YAAY,uBAAuB,CAAC,gBAAgB,2BAA2B,CAAC,iBAAiB,4BAA4B,CAAC,WAAW,sBAAsB,CAAC,kBAAkB,6BAA6B,CAAC,WAAW,sBAAsB,CAAC,cAAc,uBAAuB,CAAC,aAAa,4BAA4B,CAAC,gBAAgB,+BAA+B,CAAC,qBAAqB,oCAAoC,CAAC,wBAAwB,uCAAuC,CAAC,gBAAgB,qBAAqB,CAAC,gBAAgB,qBAAqB,CAAC,kBAAkB,uBAAuB,CAAC,kBAAkB,uBAAuB,CAAC,cAAc,wBAAwB,CAAC,gBAAgB,0BAA0B,CAAC,sBAAsB,gCAAgC,CAAC,0BAA0B,oCAAoC,CAAC,wBAAwB,kCAAkC,CAAC,2BAA2B,gCAAgC,CAAC,4BAA4B,uCAAuC,CAAC,2BAA2B,sCAAsC,CAAC,2BAA2B,sCAAsC,CAAC,sBAAsB,gCAAgC,CAAC,oBAAoB,8BAA8B,CAAC,uBAAuB,4BAA4B,CAAC,yBAAyB,8BAA8B,CAAC,wBAAwB,6BAA6B,CAAC,wBAAwB,kCAAkC,CAAC,sBAAsB,gCAAgC,CAAC,yBAAyB,8BAA8B,CAAC,0BAA0B,qCAAqC,CAAC,yBAAyB,oCAAoC,CAAC,0BAA0B,+BAA+B,CAAC,oBAAoB,yBAAyB,CAAC,qBAAqB,+BAA+B,CAAC,mBAAmB,6BAA6B,CAAC,sBAAsB,2BAA2B,CAAC,wBAAwB,6BAA6B,CAAC,uBAAuB,4BAA4B,CAAC,gBAAgB,kBAAkB,CAAC,YAAY,iBAAiB,CAAC,YAAY,iBAAiB,CAAC,YAAY,iBAAiB,CAAC,YAAY,iBAAiB,CAAC,YAAY,iBAAiB,CAAC,YAAY,iBAAiB,CAAC,eAAe,iBAAiB,CAAC,QAAQ,kBAAkB,CAAC,QAAQ,uBAAuB,CAAC,QAAQ,sBAAsB,CAAC,QAAQ,qBAAqB,CAAC,QAAQ,uBAAuB,CAAC,QAAQ,qBAAqB,CAAC,WAAW,qBAAqB,CAAC,SAAS,wBAAwB,CAAC,uBAAuB,CAAC,SAAS,6BAA6B,CAAC,4BAA4B,CAAC,SAAS,4BAA4B,CAAC,2BAA2B,CAAC,SAAS,2BAA2B,CAAC,0BAA0B,CAAC,SAAS,6BAA6B,CAAC,4BAA4B,CAAC,SAAS,2BAA2B,CAAC,0BAA0B,CAAC,YAAY,2BAA2B,CAAC,0BAA0B,CAAC,SAAS,sBAAsB,CAAC,yBAAyB,CAAC,SAAS,2BAA2B,CAAC,8BAA8B,CAAC,SAAS,0BAA0B,CAAC,6BAA6B,CAAC,SAAS,yBAAyB,CAAC,4BAA4B,CAAC,SAAS,2BAA2B,CAAC,8BAA8B,CAAC,SAAS,yBAAyB,CAAC,4BAA4B,CAAC,YAAY,yBAAyB,CAAC,4BAA4B,CAAC,SAAS,sBAAsB,CAAC,SAAS,2BAA2B,CAAC,SAAS,0BAA0B,CAAC,SAAS,yBAAyB,CAAC,SAAS,2BAA2B,CAAC,SAAS,yBAAyB,CAAC,YAAY,yBAAyB,CAAC,SAAS,wBAAwB,CAAC,SAAS,6BAA6B,CAAC,SAAS,4BAA4B,CAAC,SAAS,2BAA2B,CAAC,SAAS,6BAA6B,CAAC,SAAS,2BAA2B,CAAC,YAAY,2BAA2B,CAAC,SAAS,yBAAyB,CAAC,SAAS,8BAA8B,CAAC,SAAS,6BAA6B,CAAC,SAAS,4BAA4B,CAAC,SAAS,8BAA8B,CAAC,SAAS,4BAA4B,CAAC,YAAY,4BAA4B,CAAC,SAAS,uBAAuB,CAAC,SAAS,4BAA4B,CAAC,SAAS,2BAA2B,CAAC,SAAS,0BAA0B,CAAC,SAAS,4BAA4B,CAAC,SAAS,0BAA0B,CAAC,YAAY,0BAA0B,CAAC,QAAQ,mBAAmB,CAAC,QAAQ,wBAAwB,CAAC,QAAQ,uBAAuB,CAAC,QAAQ,sBAAsB,CAAC,QAAQ,wBAAwB,CAAC,QAAQ,sBAAsB,CAAC,SAAS,yBAAyB,CAAC,wBAAwB,CAAC,SAAS,8BAA8B,CAAC,6BAA6B,CAAC,SAAS,6BAA6B,CAAC,4BAA4B,CAAC,SAAS,4BAA4B,CAAC,2BAA2B,CAAC,SAAS,8BAA8B,CAAC,6BAA6B,CAAC,SAAS,4BAA4B,CAAC,2BAA2B,CAAC,SAAS,uBAAuB,CAAC,0BAA0B,CAAC,SAAS,4BAA4B,CAAC,+BAA+B,CAAC,SAAS,2BAA2B,CAAC,8BAA8B,CAAC,SAAS,0BAA0B,CAAC,6BAA6B,CAAC,SAAS,4BAA4B,CAAC,+BAA+B,CAAC,SAAS,0BAA0B,CAAC,6BAA6B,CAAC,SAAS,uBAAuB,CAAC,SAAS,4BAA4B,CAAC,SAAS,2BAA2B,CAAC,SAAS,0BAA0B,CAAC,SAAS,4BAA4B,CAAC,SAAS,0BAA0B,CAAC,SAAS,yBAAyB,CAAC,SAAS,8BAA8B,CAAC,SAAS,6BAA6B,CAAC,SAAS,4BAA4B,CAAC,SAAS,8BAA8B,CAAC,SAAS,4BAA4B,CAAC,SAAS,0BAA0B,CAAC,SAAS,+BAA+B,CAAC,SAAS,8BAA8B,CAAC,SAAS,6BAA6B,CAAC,SAAS,+BAA+B,CAAC,SAAS,6BAA6B,CAAC,SAAS,wBAAwB,CAAC,SAAS,6BAA6B,CAAC,SAAS,4BAA4B,CAAC,SAAS,2BAA2B,CAAC,SAAS,6BAA6B,CAAC,SAAS,2BAA2B,CAAC,UAAU,eAAe,CAAC,UAAU,oBAAoB,CAAC,UAAU,mBAAmB,CAAC,UAAU,kBAAkB,CAAC,UAAU,oBAAoB,CAAC,UAAU,kBAAkB,CAAC,cAAc,mBAAmB,CAAC,cAAc,wBAAwB,CAAC,cAAc,uBAAuB,CAAC,cAAc,sBAAsB,CAAC,cAAc,wBAAwB,CAAC,cAAc,sBAAsB,CAAC,iBAAiB,sBAAsB,CAAC,iBAAiB,2BAA2B,CAAC,iBAAiB,0BAA0B,CAAC,iBAAiB,yBAAyB,CAAC,iBAAiB,2BAA2B,CAAC,iBAAiB,yBAAyB,CAAC,eAAe,yBAAyB,CAAC,aAAa,0BAA0B,CAAC,gBAAgB,2BAA2B,CAAC,CAAC,2BAA2B,iBAAiB,oBAAoB,CAAC,eAAe,qBAAqB,CAAC,gBAAgB,oBAAoB,CAAC,wBAAwB,4BAA4B,CAAC,sBAAsB,0BAA0B,CAAC,qBAAqB,yBAAyB,CAAC,sBAAsB,+BAA+B,CAAC,qBAAqB,yBAAyB,CAAC,cAAc,wBAAwB,CAAC,oBAAoB,8BAA8B,CAAC,aAAa,uBAAuB,CAAC,YAAY,sBAAsB,CAAC,mBAAmB,6BAA6B,CAAC,aAAa,uBAAuB,CAAC,iBAAiB,2BAA2B,CAAC,kBAAkB,4BAA4B,CAAC,YAAY,sBAAsB,CAAC,mBAAmB,6BAA6B,CAAC,YAAY,sBAAsB,CAAC,eAAe,uBAAuB,CAAC,cAAc,4BAA4B,CAAC,iBAAiB,+BAA+B,CAAC,sBAAsB,oCAAoC,CAAC,yBAAyB,uCAAuC,CAAC,iBAAiB,qBAAqB,CAAC,iBAAiB,qBAAqB,CAAC,mBAAmB,uBAAuB,CAAC,mBAAmB,uBAAuB,CAAC,eAAe,wBAAwB,CAAC,iBAAiB,0BAA0B,CAAC,uBAAuB,gCAAgC,CAAC,2BAA2B,oCAAoC,CAAC,yBAAyB,kCAAkC,CAAC,4BAA4B,gCAAgC,CAAC,6BAA6B,uCAAuC,CAAC,4BAA4B,sCAAsC,CAAC,4BAA4B,sCAAsC,CAAC,uBAAuB,gCAAgC,CAAC,qBAAqB,8BAA8B,CAAC,wBAAwB,4BAA4B,CAAC,0BAA0B,8BAA8B,CAAC,yBAAyB,6BAA6B,CAAC,yBAAyB,kCAAkC,CAAC,uBAAuB,gCAAgC,CAAC,0BAA0B,8BAA8B,CAAC,2BAA2B,qCAAqC,CAAC,0BAA0B,oCAAoC,CAAC,2BAA2B,+BAA+B,CAAC,qBAAqB,yBAAyB,CAAC,sBAAsB,+BAA+B,CAAC,oBAAoB,6BAA6B,CAAC,uBAAuB,2BAA2B,CAAC,yBAAyB,6BAA6B,CAAC,wBAAwB,4BAA4B,CAAC,iBAAiB,kBAAkB,CAAC,aAAa,iBAAiB,CAAC,aAAa,iBAAiB,CAAC,aAAa,iBAAiB,CAAC,aAAa,iBAAiB,CAAC,aAAa,iBAAiB,CAAC,aAAa,iBAAiB,CAAC,gBAAgB,iBAAiB,CAAC,SAAS,kBAAkB,CAAC,SAAS,uBAAuB,CAAC,SAAS,sBAAsB,CAAC,SAAS,qBAAqB,CAAC,SAAS,uBAAuB,CAAC,SAAS,qBAAqB,CAAC,YAAY,qBAAqB,CAAC,UAAU,wBAAwB,CAAC,uBAAuB,CAAC,UAAU,6BAA6B,CAAC,4BAA4B,CAAC,UAAU,4BAA4B,CAAC,2BAA2B,CAAC,UAAU,2BAA2B,CAAC,0BAA0B,CAAC,UAAU,6BAA6B,CAAC,4BAA4B,CAAC,UAAU,2BAA2B,CAAC,0BAA0B,CAAC,aAAa,2BAA2B,CAAC,0BAA0B,CAAC,UAAU,sBAAsB,CAAC,yBAAyB,CAAC,UAAU,2BAA2B,CAAC,8BAA8B,CAAC,UAAU,0BAA0B,CAAC,6BAA6B,CAAC,UAAU,yBAAyB,CAAC,4BAA4B,CAAC,UAAU,2BAA2B,CAAC,8BAA8B,CAAC,UAAU,yBAAyB,CAAC,4BAA4B,CAAC,aAAa,yBAAyB,CAAC,4BAA4B,CAAC,UAAU,sBAAsB,CAAC,UAAU,2BAA2B,CAAC,UAAU,0BAA0B,CAAC,UAAU,yBAAyB,CAAC,UAAU,2BAA2B,CAAC,UAAU,yBAAyB,CAAC,aAAa,yBAAyB,CAAC,UAAU,wBAAwB,CAAC,UAAU,6BAA6B,CAAC,UAAU,4BAA4B,CAAC,UAAU,2BAA2B,CAAC,UAAU,6BAA6B,CAAC,UAAU,2BAA2B,CAAC,aAAa,2BAA2B,CAAC,UAAU,yBAAyB,CAAC,UAAU,8BAA8B,CAAC,UAAU,6BAA6B,CAAC,UAAU,4BAA4B,CAAC,UAAU,8BAA8B,CAAC,UAAU,4BAA4B,CAAC,aAAa,4BAA4B,CAAC,UAAU,uBAAuB,CAAC,UAAU,4BAA4B,CAAC,UAAU,2BAA2B,CAAC,UAAU,0BAA0B,CAAC,UAAU,4BAA4B,CAAC,UAAU,0BAA0B,CAAC,aAAa,0BAA0B,CAAC,SAAS,mBAAmB,CAAC,SAAS,wBAAwB,CAAC,SAAS,uBAAuB,CAAC,SAAS,sBAAsB,CAAC,SAAS,wBAAwB,CAAC,SAAS,sBAAsB,CAAC,UAAU,yBAAyB,CAAC,wBAAwB,CAAC,UAAU,8BAA8B,CAAC,6BAA6B,CAAC,UAAU,6BAA6B,CAAC,4BAA4B,CAAC,UAAU,4BAA4B,CAAC,2BAA2B,CAAC,UAAU,8BAA8B,CAAC,6BAA6B,CAAC,UAAU,4BAA4B,CAAC,2BAA2B,CAAC,UAAU,uBAAuB,CAAC,0BAA0B,CAAC,UAAU,4BAA4B,CAAC,+BAA+B,CAAC,UAAU,2BAA2B,CAAC,8BAA8B,CAAC,UAAU,0BAA0B,CAAC,6BAA6B,CAAC,UAAU,4BAA4B,CAAC,+BAA+B,CAAC,UAAU,0BAA0B,CAAC,6BAA6B,CAAC,UAAU,uBAAuB,CAAC,UAAU,4BAA4B,CAAC,UAAU,2BAA2B,CAAC,UAAU,0BAA0B,CAAC,UAAU,4BAA4B,CAAC,UAAU,0BAA0B,CAAC,UAAU,yBAAyB,CAAC,UAAU,8BAA8B,CAAC,UAAU,6BAA6B,CAAC,UAAU,4BAA4B,CAAC,UAAU,8BAA8B,CAAC,UAAU,4BAA4B,CAAC,UAAU,0BAA0B,CAAC,UAAU,+BAA+B,CAAC,UAAU,8BAA8B,CAAC,UAAU,6BAA6B,CAAC,UAAU,+BAA+B,CAAC,UAAU,6BAA6B,CAAC,UAAU,wBAAwB,CAAC,UAAU,6BAA6B,CAAC,UAAU,4BAA4B,CAAC,UAAU,2BAA2B,CAAC,UAAU,6BAA6B,CAAC,UAAU,2BAA2B,CAAC,WAAW,eAAe,CAAC,WAAW,oBAAoB,CAAC,WAAW,mBAAmB,CAAC,WAAW,kBAAkB,CAAC,WAAW,oBAAoB,CAAC,WAAW,kBAAkB,CAAC,eAAe,mBAAmB,CAAC,eAAe,wBAAwB,CAAC,eAAe,uBAAuB,CAAC,eAAe,sBAAsB,CAAC,eAAe,wBAAwB,CAAC,eAAe,sBAAsB,CAAC,kBAAkB,sBAAsB,CAAC,kBAAkB,2BAA2B,CAAC,kBAAkB,0BAA0B,CAAC,kBAAkB,yBAAyB,CAAC,kBAAkB,2BAA2B,CAAC,kBAAkB,yBAAyB,CAAC,gBAAgB,yBAAyB,CAAC,cAAc,0BAA0B,CAAC,iBAAiB,2BAA2B,CAAC,CAAC,2BAA2B,MAAM,0BAA0B,CAAC,MAAM,wBAAwB,CAAC,MAAM,2BAA2B,CAAC,MAAM,0BAA0B,CAAC,CAAC,aAAa,gBAAgB,wBAAwB,CAAC,sBAAsB,8BAA8B,CAAC,eAAe,uBAAuB,CAAC,cAAc,sBAAsB,CAAC,qBAAqB,6BAA6B,CAAC,eAAe,uBAAuB,CAAC,mBAAmB,2BAA2B,CAAC,oBAAoB,4BAA4B,CAAC,cAAc,sBAAsB,CAAC,qBAAqB,6BAA6B,CAAC,cAAc,sBAAsB,CAAC","sourcesContent":["@charset \"UTF-8\";/*!\n * Bootstrap  v5.3.8 (https://getbootstrap.com/)\n * Copyright 2011-2025 The Bootstrap Authors\n * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)\n */:root,[data-bs-theme=light]{--bs-blue: #0d6efd;--bs-indigo: #6610f2;--bs-purple: #6f42c1;--bs-pink: #d63384;--bs-red: #dc3545;--bs-orange: #fd7e14;--bs-yellow: #ffc107;--bs-green: #198754;--bs-teal: #20c997;--bs-cyan: #0dcaf0;--bs-black: #000;--bs-white: #fff;--bs-gray: #6c757d;--bs-gray-dark: #343a40;--bs-gray-100: #f8f9fa;--bs-gray-200: #e9ecef;--bs-gray-300: #dee2e6;--bs-gray-400: #ced4da;--bs-gray-500: #adb5bd;--bs-gray-600: #6c757d;--bs-gray-700: #495057;--bs-gray-800: #343a40;--bs-gray-900: #212529;--bs-primary: #0d6efd;--bs-secondary: #6c757d;--bs-success: #198754;--bs-info: #0dcaf0;--bs-warning: #ffc107;--bs-danger: #dc3545;--bs-light: #f8f9fa;--bs-dark: #212529;--bs-primary-rgb: 13, 110, 253;--bs-secondary-rgb: 108, 117, 125;--bs-success-rgb: 25, 135, 84;--bs-info-rgb: 13, 202, 240;--bs-warning-rgb: 255, 193, 7;--bs-danger-rgb: 220, 53, 69;--bs-light-rgb: 248, 249, 250;--bs-dark-rgb: 33, 37, 41;--bs-primary-text-emphasis: rgb(5.2, 44, 101.2);--bs-secondary-text-emphasis: rgb(43.2, 46.8, 50);--bs-success-text-emphasis: rgb(10, 54, 33.6);--bs-info-text-emphasis: rgb(5.2, 80.8, 96);--bs-warning-text-emphasis: rgb(102, 77.2, 2.8);--bs-danger-text-emphasis: rgb(88, 21.2, 27.6);--bs-light-text-emphasis: #495057;--bs-dark-text-emphasis: #495057;--bs-primary-bg-subtle: rgb(206.6, 226, 254.6);--bs-secondary-bg-subtle: rgb(225.6, 227.4, 229);--bs-success-bg-subtle: rgb(209, 231, 220.8);--bs-info-bg-subtle: rgb(206.6, 244.4, 252);--bs-warning-bg-subtle: rgb(255, 242.6, 205.4);--bs-danger-bg-subtle: rgb(248, 214.6, 217.8);--bs-light-bg-subtle: rgb(251.5, 252, 252.5);--bs-dark-bg-subtle: #ced4da;--bs-primary-border-subtle: rgb(158.2, 197, 254.2);--bs-secondary-border-subtle: rgb(196.2, 199.8, 203);--bs-success-border-subtle: rgb(163, 207, 186.6);--bs-info-border-subtle: rgb(158.2, 233.8, 249);--bs-warning-border-subtle: rgb(255, 230.2, 155.8);--bs-danger-border-subtle: rgb(241, 174.2, 180.6);--bs-light-border-subtle: #e9ecef;--bs-dark-border-subtle: #adb5bd;--bs-white-rgb: 255, 255, 255;--bs-black-rgb: 0, 0, 0;--bs-font-sans-serif: system-ui, -apple-system, \"Segoe UI\", Roboto, \"Helvetica Neue\", \"Noto Sans\", \"Liberation Sans\", Arial, sans-serif, \"Apple Color Emoji\", \"Segoe UI Emoji\", \"Segoe UI Symbol\", \"Noto Color Emoji\";--bs-font-monospace: SFMono-Regular, Menlo, Monaco, Consolas, \"Liberation Mono\", \"Courier New\", monospace;--bs-gradient: linear-gradient(180deg, rgba(255, 255, 255, .15), rgba(255, 255, 255, 0));--bs-body-font-family: var(--bs-font-sans-serif);--bs-body-font-size: 1rem;--bs-body-font-weight: 400;--bs-body-line-height: 1.5;--bs-body-color: #212529;--bs-body-color-rgb: 33, 37, 41;--bs-body-bg: #fff;--bs-body-bg-rgb: 255, 255, 255;--bs-emphasis-color: #000;--bs-emphasis-color-rgb: 0, 0, 0;--bs-secondary-color: rgba(33, 37, 41, .75);--bs-secondary-color-rgb: 33, 37, 41;--bs-secondary-bg: #e9ecef;--bs-secondary-bg-rgb: 233, 236, 239;--bs-tertiary-color: rgba(33, 37, 41, .5);--bs-tertiary-color-rgb: 33, 37, 41;--bs-tertiary-bg: #f8f9fa;--bs-tertiary-bg-rgb: 248, 249, 250;--bs-heading-color: inherit;--bs-link-color: #0d6efd;--bs-link-color-rgb: 13, 110, 253;--bs-link-decoration: underline;--bs-link-hover-color: rgb(10.4, 88, 202.4);--bs-link-hover-color-rgb: 10, 88, 202;--bs-code-color: #d63384;--bs-highlight-color: #212529;--bs-highlight-bg: rgb(255, 242.6, 205.4);--bs-border-width: 1px;--bs-border-style: solid;--bs-border-color: #dee2e6;--bs-border-color-translucent: rgba(0, 0, 0, .175);--bs-border-radius: .375rem;--bs-border-radius-sm: .25rem;--bs-border-radius-lg: .5rem;--bs-border-radius-xl: 1rem;--bs-border-radius-xxl: 2rem;--bs-border-radius-2xl: var(--bs-border-radius-xxl);--bs-border-radius-pill: 50rem;--bs-box-shadow: 0 .5rem 1rem rgba(0, 0, 0, .15);--bs-box-shadow-sm: 0 .125rem .25rem rgba(0, 0, 0, .075);--bs-box-shadow-lg: 0 1rem 3rem rgba(0, 0, 0, .175);--bs-box-shadow-inset: inset 0 1px 2px rgba(0, 0, 0, .075);--bs-focus-ring-width: .25rem;--bs-focus-ring-opacity: .25;--bs-focus-ring-color: rgba(13, 110, 253, .25);--bs-form-valid-color: #198754;--bs-form-valid-border-color: #198754;--bs-form-invalid-color: #dc3545;--bs-form-invalid-border-color: #dc3545}[data-bs-theme=dark]{color-scheme:dark;--bs-body-color: #dee2e6;--bs-body-color-rgb: 222, 226, 230;--bs-body-bg: #212529;--bs-body-bg-rgb: 33, 37, 41;--bs-emphasis-color: #fff;--bs-emphasis-color-rgb: 255, 255, 255;--bs-secondary-color: rgba(222, 226, 230, .75);--bs-secondary-color-rgb: 222, 226, 230;--bs-secondary-bg: #343a40;--bs-secondary-bg-rgb: 52, 58, 64;--bs-tertiary-color: rgba(222, 226, 230, .5);--bs-tertiary-color-rgb: 222, 226, 230;--bs-tertiary-bg: rgb(42.5, 47.5, 52.5);--bs-tertiary-bg-rgb: 43, 48, 53;--bs-primary-text-emphasis: rgb(109.8, 168, 253.8);--bs-secondary-text-emphasis: rgb(166.8, 172.2, 177);--bs-success-text-emphasis: rgb(117, 183, 152.4);--bs-info-text-emphasis: rgb(109.8, 223.2, 246);--bs-warning-text-emphasis: rgb(255, 217.8, 106.2);--bs-danger-text-emphasis: rgb(234, 133.8, 143.4);--bs-light-text-emphasis: #f8f9fa;--bs-dark-text-emphasis: #dee2e6;--bs-primary-bg-subtle: rgb(2.6, 22, 50.6);--bs-secondary-bg-subtle: rgb(21.6, 23.4, 25);--bs-success-bg-subtle: rgb(5, 27, 16.8);--bs-info-bg-subtle: rgb(2.6, 40.4, 48);--bs-warning-bg-subtle: rgb(51, 38.6, 1.4);--bs-danger-bg-subtle: rgb(44, 10.6, 13.8);--bs-light-bg-subtle: #343a40;--bs-dark-bg-subtle: #1a1d20;--bs-primary-border-subtle: rgb(7.8, 66, 151.8);--bs-secondary-border-subtle: rgb(64.8, 70.2, 75);--bs-success-border-subtle: rgb(15, 81, 50.4);--bs-info-border-subtle: rgb(7.8, 121.2, 144);--bs-warning-border-subtle: rgb(153, 115.8, 4.2);--bs-danger-border-subtle: rgb(132, 31.8, 41.4);--bs-light-border-subtle: #495057;--bs-dark-border-subtle: #343a40;--bs-heading-color: inherit;--bs-link-color: rgb(109.8, 168, 253.8);--bs-link-hover-color: rgb(138.84, 185.4, 254.04);--bs-link-color-rgb: 110, 168, 254;--bs-link-hover-color-rgb: 139, 185, 254;--bs-code-color: rgb(230.4, 132.6, 181.2);--bs-highlight-color: #dee2e6;--bs-highlight-bg: rgb(102, 77.2, 2.8);--bs-border-color: #495057;--bs-border-color-translucent: rgba(255, 255, 255, .15);--bs-form-valid-color: rgb(117, 183, 152.4);--bs-form-valid-border-color: rgb(117, 183, 152.4);--bs-form-invalid-color: rgb(234, 133.8, 143.4);--bs-form-invalid-border-color: rgb(234, 133.8, 143.4)}.btn-close{--bs-btn-close-color: #000;--bs-btn-close-bg: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='%23000'%3e%3cpath d='M.293.293a1 1 0 0 1 1.414 0L8 6.586 14.293.293a1 1 0 1 1 1.414 1.414L9.414 8l6.293 6.293a1 1 0 0 1-1.414 1.414L8 9.414l-6.293 6.293a1 1 0 0 1-1.414-1.414L6.586 8 .293 1.707a1 1 0 0 1 0-1.414'/%3e%3c/svg%3e\");--bs-btn-close-opacity: .5;--bs-btn-close-hover-opacity: .75;--bs-btn-close-focus-shadow: 0 0 0 .25rem rgba(13, 110, 253, .25);--bs-btn-close-focus-opacity: 1;--bs-btn-close-disabled-opacity: .25;box-sizing:content-box;width:1em;height:1em;padding:.25em;color:var(--bs-btn-close-color);background:transparent var(--bs-btn-close-bg) center/1em auto no-repeat;filter:var(--bs-btn-close-filter);border:0;border-radius:.375rem;opacity:var(--bs-btn-close-opacity)}.btn-close:hover{color:var(--bs-btn-close-color);text-decoration:none;opacity:var(--bs-btn-close-hover-opacity)}.btn-close:focus{outline:0;box-shadow:var(--bs-btn-close-focus-shadow);opacity:var(--bs-btn-close-focus-opacity)}.btn-close:disabled,.btn-close.disabled{pointer-events:none;-webkit-user-select:none;user-select:none;opacity:var(--bs-btn-close-disabled-opacity)}.btn-close-white{--bs-btn-close-filter: invert(1) grayscale(100%) brightness(200%)}:root,[data-bs-theme=light]{--bs-btn-close-filter: }[data-bs-theme=dark]{--bs-btn-close-filter: invert(1) grayscale(100%) brightness(200%)}.climb-jupyter *,.climb-jupyter *:before,.climb-jupyter *:after{box-sizing:border-box}@media (prefers-reduced-motion: no-preference){.climb-jupyter :root{scroll-behavior:smooth}}.climb-jupyter body{margin:0;font-family:var(--bs-body-font-family);font-size:var(--bs-body-font-size);font-weight:var(--bs-body-font-weight);line-height:var(--bs-body-line-height);color:var(--bs-body-color);text-align:var(--bs-body-text-align);background-color:var(--bs-body-bg);-webkit-text-size-adjust:100%;-webkit-tap-highlight-color:rgba(0,0,0,0)}.climb-jupyter hr{margin:1rem 0;color:inherit;border:0;border-top:var(--bs-border-width) solid;opacity:.25}.climb-jupyter h6,.climb-jupyter .h6,.climb-jupyter h5,.climb-jupyter .h5,.climb-jupyter h4,.climb-jupyter .h4,.climb-jupyter h3,.climb-jupyter .h3,.climb-jupyter h2,.climb-jupyter .h2,.climb-jupyter h1,.climb-jupyter .h1{margin-top:0;margin-bottom:.5rem;font-weight:500;line-height:1.2;color:var(--bs-heading-color)}.climb-jupyter h1,.climb-jupyter .h1{font-size:calc(1.375rem + 1.5vw)}@media (min-width: 1200px){.climb-jupyter h1,.climb-jupyter .h1{font-size:2.5rem}}.climb-jupyter h2,.climb-jupyter .h2{font-size:calc(1.325rem + .9vw)}@media (min-width: 1200px){.climb-jupyter h2,.climb-jupyter .h2{font-size:2rem}}.climb-jupyter h3,.climb-jupyter .h3{font-size:calc(1.3rem + .6vw)}@media (min-width: 1200px){.climb-jupyter h3,.climb-jupyter .h3{font-size:1.75rem}}.climb-jupyter h4,.climb-jupyter .h4{font-size:calc(1.275rem + .3vw)}@media (min-width: 1200px){.climb-jupyter h4,.climb-jupyter .h4{font-size:1.5rem}}.climb-jupyter h5,.climb-jupyter .h5{font-size:1.25rem}.climb-jupyter h6,.climb-jupyter .h6{font-size:1rem}.climb-jupyter p{margin-top:0;margin-bottom:1rem}.climb-jupyter abbr[title]{text-decoration:underline dotted;cursor:help;text-decoration-skip-ink:none}.climb-jupyter address{margin-bottom:1rem;font-style:normal;line-height:inherit}.climb-jupyter ol,.climb-jupyter ul{padding-left:2rem}.climb-jupyter ol,.climb-jupyter ul,.climb-jupyter dl{margin-top:0;margin-bottom:1rem}.climb-jupyter ol ol,.climb-jupyter ul ul,.climb-jupyter ol ul,.climb-jupyter ul ol{margin-bottom:0}.climb-jupyter dt{font-weight:700}.climb-jupyter dd{margin-bottom:.5rem;margin-left:0}.climb-jupyter blockquote{margin:0 0 1rem}.climb-jupyter b,.climb-jupyter strong{font-weight:bolder}.climb-jupyter small,.climb-jupyter .small{font-size:.875em}.climb-jupyter mark,.climb-jupyter .mark{padding:.1875em;color:var(--bs-highlight-color);background-color:var(--bs-highlight-bg)}.climb-jupyter sub,.climb-jupyter sup{position:relative;font-size:.75em;line-height:0;vertical-align:baseline}.climb-jupyter sub{bottom:-.25em}.climb-jupyter sup{top:-.5em}.climb-jupyter a{color:rgba(var(--bs-link-color-rgb),var(--bs-link-opacity, 1));text-decoration:underline}.climb-jupyter a:hover{--bs-link-color-rgb: var(--bs-link-hover-color-rgb)}.climb-jupyter a:not([href]):not([class]),.climb-jupyter a:not([href]):not([class]):hover{color:inherit;text-decoration:none}.climb-jupyter pre,.climb-jupyter code,.climb-jupyter kbd,.climb-jupyter samp{font-family:var(--bs-font-monospace);font-size:1em}.climb-jupyter pre{display:block;margin-top:0;margin-bottom:1rem;overflow:auto;font-size:.875em}.climb-jupyter pre code{font-size:inherit;color:inherit;word-break:normal}.climb-jupyter code{font-size:.875em;color:var(--bs-code-color);word-wrap:break-word}a>.climb-jupyter code{color:inherit}.climb-jupyter kbd{padding:.1875rem .375rem;font-size:.875em;color:var(--bs-body-bg);background-color:var(--bs-body-color);border-radius:.25rem}.climb-jupyter kbd kbd{padding:0;font-size:1em}.climb-jupyter figure{margin:0 0 1rem}.climb-jupyter img,.climb-jupyter svg{vertical-align:middle}.climb-jupyter table{caption-side:bottom;border-collapse:collapse}.climb-jupyter caption{padding-top:.5rem;padding-bottom:.5rem;color:var(--bs-secondary-color);text-align:left}.climb-jupyter th{text-align:inherit;text-align:-webkit-match-parent}.climb-jupyter thead,.climb-jupyter tbody,.climb-jupyter tfoot,.climb-jupyter tr,.climb-jupyter td,.climb-jupyter th{border-color:inherit;border-style:solid;border-width:0}.climb-jupyter label{display:inline-block}.climb-jupyter button{border-radius:0}.climb-jupyter button:focus:not(:focus-visible){outline:0}.climb-jupyter input,.climb-jupyter button,.climb-jupyter select,.climb-jupyter optgroup,.climb-jupyter textarea{margin:0;font-family:inherit;font-size:inherit;line-height:inherit}.climb-jupyter button,.climb-jupyter select{text-transform:none}.climb-jupyter [role=button]{cursor:pointer}.climb-jupyter select{word-wrap:normal}.climb-jupyter select:disabled{opacity:1}.climb-jupyter [list]:not([type=date]):not([type=datetime-local]):not([type=month]):not([type=week]):not([type=time])::-webkit-calendar-picker-indicator{display:none!important}.climb-jupyter button,.climb-jupyter [type=button],.climb-jupyter [type=reset],.climb-jupyter [type=submit]{-webkit-appearance:button}.climb-jupyter button:not(:disabled),.climb-jupyter [type=button]:not(:disabled),.climb-jupyter [type=reset]:not(:disabled),.climb-jupyter [type=submit]:not(:disabled){cursor:pointer}.climb-jupyter ::-moz-focus-inner{padding:0;border-style:none}.climb-jupyter textarea{resize:vertical}.climb-jupyter fieldset{min-width:0;padding:0;margin:0;border:0}.climb-jupyter legend{float:left;width:100%;padding:0;margin-bottom:.5rem;line-height:inherit;font-size:calc(1.275rem + .3vw)}@media (min-width: 1200px){.climb-jupyter legend{font-size:1.5rem}}.climb-jupyter legend+*{clear:left}.climb-jupyter ::-webkit-datetime-edit-fields-wrapper,.climb-jupyter ::-webkit-datetime-edit-text,.climb-jupyter ::-webkit-datetime-edit-minute,.climb-jupyter ::-webkit-datetime-edit-hour-field,.climb-jupyter ::-webkit-datetime-edit-day-field,.climb-jupyter ::-webkit-datetime-edit-month-field,.climb-jupyter ::-webkit-datetime-edit-year-field{padding:0}.climb-jupyter ::-webkit-inner-spin-button{height:auto}.climb-jupyter [type=search]{-webkit-appearance:textfield;outline-offset:-2px}.climb-jupyter [type=search]::-webkit-search-cancel-button{cursor:pointer;filter:grayscale(1)}.climb-jupyter ::-webkit-search-decoration{-webkit-appearance:none}.climb-jupyter ::-webkit-color-swatch-wrapper{padding:0}.climb-jupyter ::file-selector-button{font:inherit;-webkit-appearance:button}.climb-jupyter output{display:inline-block}.climb-jupyter iframe{border:0}.climb-jupyter summary{display:list-item;cursor:pointer}.climb-jupyter progress{vertical-align:baseline}.climb-jupyter [hidden]{display:none!important}.climb-jupyter .lead{font-size:1.25rem;font-weight:300}.climb-jupyter .display-1{font-weight:300;line-height:1.2;font-size:calc(1.625rem + 4.5vw)}@media (min-width: 1200px){.climb-jupyter .display-1{font-size:5rem}}.climb-jupyter .display-2{font-weight:300;line-height:1.2;font-size:calc(1.575rem + 3.9vw)}@media (min-width: 1200px){.climb-jupyter .display-2{font-size:4.5rem}}.climb-jupyter .display-3{font-weight:300;line-height:1.2;font-size:calc(1.525rem + 3.3vw)}@media (min-width: 1200px){.climb-jupyter .display-3{font-size:4rem}}.climb-jupyter .display-4{font-weight:300;line-height:1.2;font-size:calc(1.475rem + 2.7vw)}@media (min-width: 1200px){.climb-jupyter .display-4{font-size:3.5rem}}.climb-jupyter .display-5{font-weight:300;line-height:1.2;font-size:calc(1.425rem + 2.1vw)}@media (min-width: 1200px){.climb-jupyter .display-5{font-size:3rem}}.climb-jupyter .display-6{font-weight:300;line-height:1.2;font-size:calc(1.375rem + 1.5vw)}@media (min-width: 1200px){.climb-jupyter .display-6{font-size:2.5rem}}.climb-jupyter .list-unstyled,.climb-jupyter .list-inline{padding-left:0;list-style:none}.climb-jupyter .list-inline-item{display:inline-block}.climb-jupyter .list-inline-item:not(:last-child){margin-right:.5rem}.climb-jupyter .initialism{font-size:.875em;text-transform:uppercase}.climb-jupyter .blockquote{margin-bottom:1rem;font-size:1.25rem}.climb-jupyter .blockquote>:last-child{margin-bottom:0}.climb-jupyter .blockquote-footer{margin-top:-1rem;margin-bottom:1rem;font-size:.875em;color:#6c757d}.climb-jupyter .blockquote-footer:before{content:\"— \"}.climb-jupyter .container,.climb-jupyter .container-fluid,.climb-jupyter .container-xxl,.climb-jupyter .container-xl,.climb-jupyter .container-lg,.climb-jupyter .container-md,.climb-jupyter .container-sm{--bs-gutter-x: 1.5rem;--bs-gutter-y: 0;width:100%;padding-right:calc(var(--bs-gutter-x) * .5);padding-left:calc(var(--bs-gutter-x) * .5);margin-right:auto;margin-left:auto}@media (min-width: 576px){.climb-jupyter .container-sm,.climb-jupyter .container{max-width:540px}}@media (min-width: 768px){.climb-jupyter .container-md,.climb-jupyter .container-sm,.climb-jupyter .container{max-width:720px}}@media (min-width: 992px){.climb-jupyter .container-lg,.climb-jupyter .container-md,.climb-jupyter .container-sm,.climb-jupyter .container{max-width:960px}}@media (min-width: 1200px){.climb-jupyter .container-xl,.climb-jupyter .container-lg,.climb-jupyter .container-md,.climb-jupyter .container-sm,.climb-jupyter .container{max-width:1140px}}@media (min-width: 1400px){.climb-jupyter .container-xxl,.climb-jupyter .container-xl,.climb-jupyter .container-lg,.climb-jupyter .container-md,.climb-jupyter .container-sm,.climb-jupyter .container{max-width:1320px}}.climb-jupyter :root{--bs-breakpoint-xs: 0;--bs-breakpoint-sm: 576px;--bs-breakpoint-md: 768px;--bs-breakpoint-lg: 992px;--bs-breakpoint-xl: 1200px;--bs-breakpoint-xxl: 1400px}.climb-jupyter .row{--bs-gutter-x: 1.5rem;--bs-gutter-y: 0;display:flex;flex-wrap:wrap;margin-top:calc(-1 * var(--bs-gutter-y));margin-right:calc(-.5 * var(--bs-gutter-x));margin-left:calc(-.5 * var(--bs-gutter-x))}.climb-jupyter .row>*{flex-shrink:0;width:100%;max-width:100%;padding-right:calc(var(--bs-gutter-x) * .5);padding-left:calc(var(--bs-gutter-x) * .5);margin-top:var(--bs-gutter-y)}.climb-jupyter .col{flex:1 0 0}.climb-jupyter .row-cols-auto>*{flex:0 0 auto;width:auto}.climb-jupyter .row-cols-1>*{flex:0 0 auto;width:100%}.climb-jupyter .row-cols-2>*{flex:0 0 auto;width:50%}.climb-jupyter .row-cols-3>*{flex:0 0 auto;width:33.33333333%}.climb-jupyter .row-cols-4>*{flex:0 0 auto;width:25%}.climb-jupyter .row-cols-5>*{flex:0 0 auto;width:20%}.climb-jupyter .row-cols-6>*{flex:0 0 auto;width:16.66666667%}.climb-jupyter .col-auto{flex:0 0 auto;width:auto}.climb-jupyter .col-1{flex:0 0 auto;width:8.33333333%}.climb-jupyter .col-2{flex:0 0 auto;width:16.66666667%}.climb-jupyter .col-3{flex:0 0 auto;width:25%}.climb-jupyter .col-4{flex:0 0 auto;width:33.33333333%}.climb-jupyter .col-5{flex:0 0 auto;width:41.66666667%}.climb-jupyter .col-6{flex:0 0 auto;width:50%}.climb-jupyter .col-7{flex:0 0 auto;width:58.33333333%}.climb-jupyter .col-8{flex:0 0 auto;width:66.66666667%}.climb-jupyter .col-9{flex:0 0 auto;width:75%}.climb-jupyter .col-10{flex:0 0 auto;width:83.33333333%}.climb-jupyter .col-11{flex:0 0 auto;width:91.66666667%}.climb-jupyter .col-12{flex:0 0 auto;width:100%}.climb-jupyter .offset-1{margin-left:8.33333333%}.climb-jupyter .offset-2{margin-left:16.66666667%}.climb-jupyter .offset-3{margin-left:25%}.climb-jupyter .offset-4{margin-left:33.33333333%}.climb-jupyter .offset-5{margin-left:41.66666667%}.climb-jupyter .offset-6{margin-left:50%}.climb-jupyter .offset-7{margin-left:58.33333333%}.climb-jupyter .offset-8{margin-left:66.66666667%}.climb-jupyter .offset-9{margin-left:75%}.climb-jupyter .offset-10{margin-left:83.33333333%}.climb-jupyter .offset-11{margin-left:91.66666667%}.climb-jupyter .g-0,.climb-jupyter .gx-0{--bs-gutter-x: 0}.climb-jupyter .g-0,.climb-jupyter .gy-0{--bs-gutter-y: 0}.climb-jupyter .g-1,.climb-jupyter .gx-1{--bs-gutter-x: .25rem}.climb-jupyter .g-1,.climb-jupyter .gy-1{--bs-gutter-y: .25rem}.climb-jupyter .g-2,.climb-jupyter .gx-2{--bs-gutter-x: .5rem}.climb-jupyter .g-2,.climb-jupyter .gy-2{--bs-gutter-y: .5rem}.climb-jupyter .g-3,.climb-jupyter .gx-3{--bs-gutter-x: 1rem}.climb-jupyter .g-3,.climb-jupyter .gy-3{--bs-gutter-y: 1rem}.climb-jupyter .g-4,.climb-jupyter .gx-4{--bs-gutter-x: 1.5rem}.climb-jupyter .g-4,.climb-jupyter .gy-4{--bs-gutter-y: 1.5rem}.climb-jupyter .g-5,.climb-jupyter .gx-5{--bs-gutter-x: 3rem}.climb-jupyter .g-5,.climb-jupyter .gy-5{--bs-gutter-y: 3rem}@media (min-width: 576px){.climb-jupyter .col-sm{flex:1 0 0}.climb-jupyter .row-cols-sm-auto>*{flex:0 0 auto;width:auto}.climb-jupyter .row-cols-sm-1>*{flex:0 0 auto;width:100%}.climb-jupyter .row-cols-sm-2>*{flex:0 0 auto;width:50%}.climb-jupyter .row-cols-sm-3>*{flex:0 0 auto;width:33.33333333%}.climb-jupyter .row-cols-sm-4>*{flex:0 0 auto;width:25%}.climb-jupyter .row-cols-sm-5>*{flex:0 0 auto;width:20%}.climb-jupyter .row-cols-sm-6>*{flex:0 0 auto;width:16.66666667%}.climb-jupyter .col-sm-auto{flex:0 0 auto;width:auto}.climb-jupyter .col-sm-1{flex:0 0 auto;width:8.33333333%}.climb-jupyter .col-sm-2{flex:0 0 auto;width:16.66666667%}.climb-jupyter .col-sm-3{flex:0 0 auto;width:25%}.climb-jupyter .col-sm-4{flex:0 0 auto;width:33.33333333%}.climb-jupyter .col-sm-5{flex:0 0 auto;width:41.66666667%}.climb-jupyter .col-sm-6{flex:0 0 auto;width:50%}.climb-jupyter .col-sm-7{flex:0 0 auto;width:58.33333333%}.climb-jupyter .col-sm-8{flex:0 0 auto;width:66.66666667%}.climb-jupyter .col-sm-9{flex:0 0 auto;width:75%}.climb-jupyter .col-sm-10{flex:0 0 auto;width:83.33333333%}.climb-jupyter .col-sm-11{flex:0 0 auto;width:91.66666667%}.climb-jupyter .col-sm-12{flex:0 0 auto;width:100%}.climb-jupyter .offset-sm-0{margin-left:0}.climb-jupyter .offset-sm-1{margin-left:8.33333333%}.climb-jupyter .offset-sm-2{margin-left:16.66666667%}.climb-jupyter .offset-sm-3{margin-left:25%}.climb-jupyter .offset-sm-4{margin-left:33.33333333%}.climb-jupyter .offset-sm-5{margin-left:41.66666667%}.climb-jupyter .offset-sm-6{margin-left:50%}.climb-jupyter .offset-sm-7{margin-left:58.33333333%}.climb-jupyter .offset-sm-8{margin-left:66.66666667%}.climb-jupyter .offset-sm-9{margin-left:75%}.climb-jupyter .offset-sm-10{margin-left:83.33333333%}.climb-jupyter .offset-sm-11{margin-left:91.66666667%}.climb-jupyter .g-sm-0,.climb-jupyter .gx-sm-0{--bs-gutter-x: 0}.climb-jupyter .g-sm-0,.climb-jupyter .gy-sm-0{--bs-gutter-y: 0}.climb-jupyter .g-sm-1,.climb-jupyter .gx-sm-1{--bs-gutter-x: .25rem}.climb-jupyter .g-sm-1,.climb-jupyter .gy-sm-1{--bs-gutter-y: .25rem}.climb-jupyter .g-sm-2,.climb-jupyter .gx-sm-2{--bs-gutter-x: .5rem}.climb-jupyter .g-sm-2,.climb-jupyter .gy-sm-2{--bs-gutter-y: .5rem}.climb-jupyter .g-sm-3,.climb-jupyter .gx-sm-3{--bs-gutter-x: 1rem}.climb-jupyter .g-sm-3,.climb-jupyter .gy-sm-3{--bs-gutter-y: 1rem}.climb-jupyter .g-sm-4,.climb-jupyter .gx-sm-4{--bs-gutter-x: 1.5rem}.climb-jupyter .g-sm-4,.climb-jupyter .gy-sm-4{--bs-gutter-y: 1.5rem}.climb-jupyter .g-sm-5,.climb-jupyter .gx-sm-5{--bs-gutter-x: 3rem}.climb-jupyter .g-sm-5,.climb-jupyter .gy-sm-5{--bs-gutter-y: 3rem}}@media (min-width: 768px){.climb-jupyter .col-md{flex:1 0 0}.climb-jupyter .row-cols-md-auto>*{flex:0 0 auto;width:auto}.climb-jupyter .row-cols-md-1>*{flex:0 0 auto;width:100%}.climb-jupyter .row-cols-md-2>*{flex:0 0 auto;width:50%}.climb-jupyter .row-cols-md-3>*{flex:0 0 auto;width:33.33333333%}.climb-jupyter .row-cols-md-4>*{flex:0 0 auto;width:25%}.climb-jupyter .row-cols-md-5>*{flex:0 0 auto;width:20%}.climb-jupyter .row-cols-md-6>*{flex:0 0 auto;width:16.66666667%}.climb-jupyter .col-md-auto{flex:0 0 auto;width:auto}.climb-jupyter .col-md-1{flex:0 0 auto;width:8.33333333%}.climb-jupyter .col-md-2{flex:0 0 auto;width:16.66666667%}.climb-jupyter .col-md-3{flex:0 0 auto;width:25%}.climb-jupyter .col-md-4{flex:0 0 auto;width:33.33333333%}.climb-jupyter .col-md-5{flex:0 0 auto;width:41.66666667%}.climb-jupyter .col-md-6{flex:0 0 auto;width:50%}.climb-jupyter .col-md-7{flex:0 0 auto;width:58.33333333%}.climb-jupyter .col-md-8{flex:0 0 auto;width:66.66666667%}.climb-jupyter .col-md-9{flex:0 0 auto;width:75%}.climb-jupyter .col-md-10{flex:0 0 auto;width:83.33333333%}.climb-jupyter .col-md-11{flex:0 0 auto;width:91.66666667%}.climb-jupyter .col-md-12{flex:0 0 auto;width:100%}.climb-jupyter .offset-md-0{margin-left:0}.climb-jupyter .offset-md-1{margin-left:8.33333333%}.climb-jupyter .offset-md-2{margin-left:16.66666667%}.climb-jupyter .offset-md-3{margin-left:25%}.climb-jupyter .offset-md-4{margin-left:33.33333333%}.climb-jupyter .offset-md-5{margin-left:41.66666667%}.climb-jupyter .offset-md-6{margin-left:50%}.climb-jupyter .offset-md-7{margin-left:58.33333333%}.climb-jupyter .offset-md-8{margin-left:66.66666667%}.climb-jupyter .offset-md-9{margin-left:75%}.climb-jupyter .offset-md-10{margin-left:83.33333333%}.climb-jupyter .offset-md-11{margin-left:91.66666667%}.climb-jupyter .g-md-0,.climb-jupyter .gx-md-0{--bs-gutter-x: 0}.climb-jupyter .g-md-0,.climb-jupyter .gy-md-0{--bs-gutter-y: 0}.climb-jupyter .g-md-1,.climb-jupyter .gx-md-1{--bs-gutter-x: .25rem}.climb-jupyter .g-md-1,.climb-jupyter .gy-md-1{--bs-gutter-y: .25rem}.climb-jupyter .g-md-2,.climb-jupyter .gx-md-2{--bs-gutter-x: .5rem}.climb-jupyter .g-md-2,.climb-jupyter .gy-md-2{--bs-gutter-y: .5rem}.climb-jupyter .g-md-3,.climb-jupyter .gx-md-3{--bs-gutter-x: 1rem}.climb-jupyter .g-md-3,.climb-jupyter .gy-md-3{--bs-gutter-y: 1rem}.climb-jupyter .g-md-4,.climb-jupyter .gx-md-4{--bs-gutter-x: 1.5rem}.climb-jupyter .g-md-4,.climb-jupyter .gy-md-4{--bs-gutter-y: 1.5rem}.climb-jupyter .g-md-5,.climb-jupyter .gx-md-5{--bs-gutter-x: 3rem}.climb-jupyter .g-md-5,.climb-jupyter .gy-md-5{--bs-gutter-y: 3rem}}@media (min-width: 992px){.climb-jupyter .col-lg{flex:1 0 0}.climb-jupyter .row-cols-lg-auto>*{flex:0 0 auto;width:auto}.climb-jupyter .row-cols-lg-1>*{flex:0 0 auto;width:100%}.climb-jupyter .row-cols-lg-2>*{flex:0 0 auto;width:50%}.climb-jupyter .row-cols-lg-3>*{flex:0 0 auto;width:33.33333333%}.climb-jupyter .row-cols-lg-4>*{flex:0 0 auto;width:25%}.climb-jupyter .row-cols-lg-5>*{flex:0 0 auto;width:20%}.climb-jupyter .row-cols-lg-6>*{flex:0 0 auto;width:16.66666667%}.climb-jupyter .col-lg-auto{flex:0 0 auto;width:auto}.climb-jupyter .col-lg-1{flex:0 0 auto;width:8.33333333%}.climb-jupyter .col-lg-2{flex:0 0 auto;width:16.66666667%}.climb-jupyter .col-lg-3{flex:0 0 auto;width:25%}.climb-jupyter .col-lg-4{flex:0 0 auto;width:33.33333333%}.climb-jupyter .col-lg-5{flex:0 0 auto;width:41.66666667%}.climb-jupyter .col-lg-6{flex:0 0 auto;width:50%}.climb-jupyter .col-lg-7{flex:0 0 auto;width:58.33333333%}.climb-jupyter .col-lg-8{flex:0 0 auto;width:66.66666667%}.climb-jupyter .col-lg-9{flex:0 0 auto;width:75%}.climb-jupyter .col-lg-10{flex:0 0 auto;width:83.33333333%}.climb-jupyter .col-lg-11{flex:0 0 auto;width:91.66666667%}.climb-jupyter .col-lg-12{flex:0 0 auto;width:100%}.climb-jupyter .offset-lg-0{margin-left:0}.climb-jupyter .offset-lg-1{margin-left:8.33333333%}.climb-jupyter .offset-lg-2{margin-left:16.66666667%}.climb-jupyter .offset-lg-3{margin-left:25%}.climb-jupyter .offset-lg-4{margin-left:33.33333333%}.climb-jupyter .offset-lg-5{margin-left:41.66666667%}.climb-jupyter .offset-lg-6{margin-left:50%}.climb-jupyter .offset-lg-7{margin-left:58.33333333%}.climb-jupyter .offset-lg-8{margin-left:66.66666667%}.climb-jupyter .offset-lg-9{margin-left:75%}.climb-jupyter .offset-lg-10{margin-left:83.33333333%}.climb-jupyter .offset-lg-11{margin-left:91.66666667%}.climb-jupyter .g-lg-0,.climb-jupyter .gx-lg-0{--bs-gutter-x: 0}.climb-jupyter .g-lg-0,.climb-jupyter .gy-lg-0{--bs-gutter-y: 0}.climb-jupyter .g-lg-1,.climb-jupyter .gx-lg-1{--bs-gutter-x: .25rem}.climb-jupyter .g-lg-1,.climb-jupyter .gy-lg-1{--bs-gutter-y: .25rem}.climb-jupyter .g-lg-2,.climb-jupyter .gx-lg-2{--bs-gutter-x: .5rem}.climb-jupyter .g-lg-2,.climb-jupyter .gy-lg-2{--bs-gutter-y: .5rem}.climb-jupyter .g-lg-3,.climb-jupyter .gx-lg-3{--bs-gutter-x: 1rem}.climb-jupyter .g-lg-3,.climb-jupyter .gy-lg-3{--bs-gutter-y: 1rem}.climb-jupyter .g-lg-4,.climb-jupyter .gx-lg-4{--bs-gutter-x: 1.5rem}.climb-jupyter .g-lg-4,.climb-jupyter .gy-lg-4{--bs-gutter-y: 1.5rem}.climb-jupyter .g-lg-5,.climb-jupyter .gx-lg-5{--bs-gutter-x: 3rem}.climb-jupyter .g-lg-5,.climb-jupyter .gy-lg-5{--bs-gutter-y: 3rem}}@media (min-width: 1200px){.climb-jupyter .col-xl{flex:1 0 0}.climb-jupyter .row-cols-xl-auto>*{flex:0 0 auto;width:auto}.climb-jupyter .row-cols-xl-1>*{flex:0 0 auto;width:100%}.climb-jupyter .row-cols-xl-2>*{flex:0 0 auto;width:50%}.climb-jupyter .row-cols-xl-3>*{flex:0 0 auto;width:33.33333333%}.climb-jupyter .row-cols-xl-4>*{flex:0 0 auto;width:25%}.climb-jupyter .row-cols-xl-5>*{flex:0 0 auto;width:20%}.climb-jupyter .row-cols-xl-6>*{flex:0 0 auto;width:16.66666667%}.climb-jupyter .col-xl-auto{flex:0 0 auto;width:auto}.climb-jupyter .col-xl-1{flex:0 0 auto;width:8.33333333%}.climb-jupyter .col-xl-2{flex:0 0 auto;width:16.66666667%}.climb-jupyter .col-xl-3{flex:0 0 auto;width:25%}.climb-jupyter .col-xl-4{flex:0 0 auto;width:33.33333333%}.climb-jupyter .col-xl-5{flex:0 0 auto;width:41.66666667%}.climb-jupyter .col-xl-6{flex:0 0 auto;width:50%}.climb-jupyter .col-xl-7{flex:0 0 auto;width:58.33333333%}.climb-jupyter .col-xl-8{flex:0 0 auto;width:66.66666667%}.climb-jupyter .col-xl-9{flex:0 0 auto;width:75%}.climb-jupyter .col-xl-10{flex:0 0 auto;width:83.33333333%}.climb-jupyter .col-xl-11{flex:0 0 auto;width:91.66666667%}.climb-jupyter .col-xl-12{flex:0 0 auto;width:100%}.climb-jupyter .offset-xl-0{margin-left:0}.climb-jupyter .offset-xl-1{margin-left:8.33333333%}.climb-jupyter .offset-xl-2{margin-left:16.66666667%}.climb-jupyter .offset-xl-3{margin-left:25%}.climb-jupyter .offset-xl-4{margin-left:33.33333333%}.climb-jupyter .offset-xl-5{margin-left:41.66666667%}.climb-jupyter .offset-xl-6{margin-left:50%}.climb-jupyter .offset-xl-7{margin-left:58.33333333%}.climb-jupyter .offset-xl-8{margin-left:66.66666667%}.climb-jupyter .offset-xl-9{margin-left:75%}.climb-jupyter .offset-xl-10{margin-left:83.33333333%}.climb-jupyter .offset-xl-11{margin-left:91.66666667%}.climb-jupyter .g-xl-0,.climb-jupyter .gx-xl-0{--bs-gutter-x: 0}.climb-jupyter .g-xl-0,.climb-jupyter .gy-xl-0{--bs-gutter-y: 0}.climb-jupyter .g-xl-1,.climb-jupyter .gx-xl-1{--bs-gutter-x: .25rem}.climb-jupyter .g-xl-1,.climb-jupyter .gy-xl-1{--bs-gutter-y: .25rem}.climb-jupyter .g-xl-2,.climb-jupyter .gx-xl-2{--bs-gutter-x: .5rem}.climb-jupyter .g-xl-2,.climb-jupyter .gy-xl-2{--bs-gutter-y: .5rem}.climb-jupyter .g-xl-3,.climb-jupyter .gx-xl-3{--bs-gutter-x: 1rem}.climb-jupyter .g-xl-3,.climb-jupyter .gy-xl-3{--bs-gutter-y: 1rem}.climb-jupyter .g-xl-4,.climb-jupyter .gx-xl-4{--bs-gutter-x: 1.5rem}.climb-jupyter .g-xl-4,.climb-jupyter .gy-xl-4{--bs-gutter-y: 1.5rem}.climb-jupyter .g-xl-5,.climb-jupyter .gx-xl-5{--bs-gutter-x: 3rem}.climb-jupyter .g-xl-5,.climb-jupyter .gy-xl-5{--bs-gutter-y: 3rem}}@media (min-width: 1400px){.climb-jupyter .col-xxl{flex:1 0 0}.climb-jupyter .row-cols-xxl-auto>*{flex:0 0 auto;width:auto}.climb-jupyter .row-cols-xxl-1>*{flex:0 0 auto;width:100%}.climb-jupyter .row-cols-xxl-2>*{flex:0 0 auto;width:50%}.climb-jupyter .row-cols-xxl-3>*{flex:0 0 auto;width:33.33333333%}.climb-jupyter .row-cols-xxl-4>*{flex:0 0 auto;width:25%}.climb-jupyter .row-cols-xxl-5>*{flex:0 0 auto;width:20%}.climb-jupyter .row-cols-xxl-6>*{flex:0 0 auto;width:16.66666667%}.climb-jupyter .col-xxl-auto{flex:0 0 auto;width:auto}.climb-jupyter .col-xxl-1{flex:0 0 auto;width:8.33333333%}.climb-jupyter .col-xxl-2{flex:0 0 auto;width:16.66666667%}.climb-jupyter .col-xxl-3{flex:0 0 auto;width:25%}.climb-jupyter .col-xxl-4{flex:0 0 auto;width:33.33333333%}.climb-jupyter .col-xxl-5{flex:0 0 auto;width:41.66666667%}.climb-jupyter .col-xxl-6{flex:0 0 auto;width:50%}.climb-jupyter .col-xxl-7{flex:0 0 auto;width:58.33333333%}.climb-jupyter .col-xxl-8{flex:0 0 auto;width:66.66666667%}.climb-jupyter .col-xxl-9{flex:0 0 auto;width:75%}.climb-jupyter .col-xxl-10{flex:0 0 auto;width:83.33333333%}.climb-jupyter .col-xxl-11{flex:0 0 auto;width:91.66666667%}.climb-jupyter .col-xxl-12{flex:0 0 auto;width:100%}.climb-jupyter .offset-xxl-0{margin-left:0}.climb-jupyter .offset-xxl-1{margin-left:8.33333333%}.climb-jupyter .offset-xxl-2{margin-left:16.66666667%}.climb-jupyter .offset-xxl-3{margin-left:25%}.climb-jupyter .offset-xxl-4{margin-left:33.33333333%}.climb-jupyter .offset-xxl-5{margin-left:41.66666667%}.climb-jupyter .offset-xxl-6{margin-left:50%}.climb-jupyter .offset-xxl-7{margin-left:58.33333333%}.climb-jupyter .offset-xxl-8{margin-left:66.66666667%}.climb-jupyter .offset-xxl-9{margin-left:75%}.climb-jupyter .offset-xxl-10{margin-left:83.33333333%}.climb-jupyter .offset-xxl-11{margin-left:91.66666667%}.climb-jupyter .g-xxl-0,.climb-jupyter .gx-xxl-0{--bs-gutter-x: 0}.climb-jupyter .g-xxl-0,.climb-jupyter .gy-xxl-0{--bs-gutter-y: 0}.climb-jupyter .g-xxl-1,.climb-jupyter .gx-xxl-1{--bs-gutter-x: .25rem}.climb-jupyter .g-xxl-1,.climb-jupyter .gy-xxl-1{--bs-gutter-y: .25rem}.climb-jupyter .g-xxl-2,.climb-jupyter .gx-xxl-2{--bs-gutter-x: .5rem}.climb-jupyter .g-xxl-2,.climb-jupyter .gy-xxl-2{--bs-gutter-y: .5rem}.climb-jupyter .g-xxl-3,.climb-jupyter .gx-xxl-3{--bs-gutter-x: 1rem}.climb-jupyter .g-xxl-3,.climb-jupyter .gy-xxl-3{--bs-gutter-y: 1rem}.climb-jupyter .g-xxl-4,.climb-jupyter .gx-xxl-4{--bs-gutter-x: 1.5rem}.climb-jupyter .g-xxl-4,.climb-jupyter .gy-xxl-4{--bs-gutter-y: 1.5rem}.climb-jupyter .g-xxl-5,.climb-jupyter .gx-xxl-5{--bs-gutter-x: 3rem}.climb-jupyter .g-xxl-5,.climb-jupyter .gy-xxl-5{--bs-gutter-y: 3rem}}.climb-jupyter .form-label{margin-bottom:.5rem}.climb-jupyter .col-form-label{padding-top:calc(.375rem + var(--bs-border-width));padding-bottom:calc(.375rem + var(--bs-border-width));margin-bottom:0;font-size:inherit;line-height:1.5}.climb-jupyter .col-form-label-lg{padding-top:calc(.5rem + var(--bs-border-width));padding-bottom:calc(.5rem + var(--bs-border-width));font-size:1.25rem}.climb-jupyter .col-form-label-sm{padding-top:calc(.25rem + var(--bs-border-width));padding-bottom:calc(.25rem + var(--bs-border-width));font-size:.875rem}.climb-jupyter .form-text{margin-top:.25rem;font-size:.875em;color:var(--bs-secondary-color)}.climb-jupyter .form-control{display:block;width:100%;padding:.375rem .75rem;font-size:1rem;font-weight:400;line-height:1.5;color:var(--bs-body-color);-webkit-appearance:none;-moz-appearance:none;appearance:none;background-color:var(--bs-body-bg);background-clip:padding-box;border:var(--bs-border-width) solid var(--bs-border-color);border-radius:var(--bs-border-radius);transition:border-color .15s ease-in-out,box-shadow .15s ease-in-out}@media (prefers-reduced-motion: reduce){.climb-jupyter .form-control{transition:none}}.climb-jupyter .form-control[type=file]{overflow:hidden}.climb-jupyter .form-control[type=file]:not(:disabled):not([readonly]){cursor:pointer}.climb-jupyter .form-control:focus{color:var(--bs-body-color);background-color:var(--bs-body-bg);border-color:#86b7fe;outline:0;box-shadow:0 0 0 .25rem #0d6efd40}.climb-jupyter .form-control::-webkit-date-and-time-value{min-width:85px;height:1.5em;margin:0}.climb-jupyter .form-control::-webkit-datetime-edit{display:block;padding:0}.climb-jupyter .form-control::placeholder{color:var(--bs-secondary-color);opacity:1}.climb-jupyter .form-control:disabled{background-color:var(--bs-secondary-bg);opacity:1}.climb-jupyter .form-control::file-selector-button{padding:.375rem .75rem;margin:-.375rem -.75rem;margin-inline-end:.75rem;color:var(--bs-body-color);background-color:var(--bs-tertiary-bg);pointer-events:none;border-color:inherit;border-style:solid;border-width:0;border-inline-end-width:var(--bs-border-width);border-radius:0;transition:color .15s ease-in-out,background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out}@media (prefers-reduced-motion: reduce){.climb-jupyter .form-control::file-selector-button{transition:none}}.climb-jupyter .form-control:hover:not(:disabled):not([readonly])::file-selector-button{background-color:var(--bs-secondary-bg)}.climb-jupyter .form-control-plaintext{display:block;width:100%;padding:.375rem 0;margin-bottom:0;line-height:1.5;color:var(--bs-body-color);background-color:transparent;border:solid transparent;border-width:var(--bs-border-width) 0}.climb-jupyter .form-control-plaintext:focus{outline:0}.climb-jupyter .form-control-plaintext.form-control-sm,.climb-jupyter .form-control-plaintext.form-control-lg{padding-right:0;padding-left:0}.climb-jupyter .form-control-sm{min-height:calc(1.5em + .5rem + calc(var(--bs-border-width) * 2));padding:.25rem .5rem;font-size:.875rem;border-radius:var(--bs-border-radius-sm)}.climb-jupyter .form-control-sm::file-selector-button{padding:.25rem .5rem;margin:-.25rem -.5rem;margin-inline-end:.5rem}.climb-jupyter .form-control-lg{min-height:calc(1.5em + 1rem + calc(var(--bs-border-width) * 2));padding:.5rem 1rem;font-size:1.25rem;border-radius:var(--bs-border-radius-lg)}.climb-jupyter .form-control-lg::file-selector-button{padding:.5rem 1rem;margin:-.5rem -1rem;margin-inline-end:1rem}.climb-jupyter textarea.form-control{min-height:calc(1.5em + .75rem + calc(var(--bs-border-width) * 2))}.climb-jupyter textarea.form-control-sm{min-height:calc(1.5em + .5rem + calc(var(--bs-border-width) * 2))}.climb-jupyter textarea.form-control-lg{min-height:calc(1.5em + 1rem + calc(var(--bs-border-width) * 2))}.climb-jupyter .form-control-color{width:3rem;height:calc(1.5em + .75rem + calc(var(--bs-border-width) * 2));padding:.375rem}.climb-jupyter .form-control-color:not(:disabled):not([readonly]){cursor:pointer}.climb-jupyter .form-control-color::-moz-color-swatch{border:0!important;border-radius:var(--bs-border-radius)}.climb-jupyter .form-control-color::-webkit-color-swatch{border:0!important;border-radius:var(--bs-border-radius)}.climb-jupyter .form-control-color.form-control-sm{height:calc(1.5em + .5rem + calc(var(--bs-border-width) * 2))}.climb-jupyter .form-control-color.form-control-lg{height:calc(1.5em + 1rem + calc(var(--bs-border-width) * 2))}.climb-jupyter .form-select{--bs-form-select-bg-img: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16'%3e%3cpath fill='none' stroke='%23343a40' stroke-linecap='round' stroke-linejoin='round' stroke-width='2' d='m2 5 6 6 6-6'/%3e%3c/svg%3e\");display:block;width:100%;padding:.375rem 2.25rem .375rem .75rem;font-size:1rem;font-weight:400;line-height:1.5;color:var(--bs-body-color);-webkit-appearance:none;-moz-appearance:none;appearance:none;background-color:var(--bs-body-bg);background-image:var(--bs-form-select-bg-img),var(--bs-form-select-bg-icon, none);background-repeat:no-repeat;background-position:right .75rem center;background-size:16px 12px;border:var(--bs-border-width) solid var(--bs-border-color);border-radius:var(--bs-border-radius);transition:border-color .15s ease-in-out,box-shadow .15s ease-in-out}@media (prefers-reduced-motion: reduce){.climb-jupyter .form-select{transition:none}}.climb-jupyter .form-select:focus{border-color:#86b7fe;outline:0;box-shadow:0 0 0 .25rem #0d6efd40}.climb-jupyter .form-select[multiple],.climb-jupyter .form-select[size]:not([size=\"1\"]){padding-right:.75rem;background-image:none}.climb-jupyter .form-select:disabled{background-color:var(--bs-secondary-bg)}.climb-jupyter .form-select:-moz-focusring{color:transparent;text-shadow:0 0 0 var(--bs-body-color)}.climb-jupyter .form-select-sm{padding-top:.25rem;padding-bottom:.25rem;padding-left:.5rem;font-size:.875rem;border-radius:var(--bs-border-radius-sm)}.climb-jupyter .form-select-lg{padding-top:.5rem;padding-bottom:.5rem;padding-left:1rem;font-size:1.25rem;border-radius:var(--bs-border-radius-lg)}.climb-jupyter [data-bs-theme=dark] .form-select{--bs-form-select-bg-img: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16'%3e%3cpath fill='none' stroke='%23dee2e6' stroke-linecap='round' stroke-linejoin='round' stroke-width='2' d='m2 5 6 6 6-6'/%3e%3c/svg%3e\")}.climb-jupyter .form-check{display:block;min-height:1.5rem;padding-left:1.5em;margin-bottom:.125rem}.climb-jupyter .form-check .form-check-input{float:left;margin-left:-1.5em}.climb-jupyter .form-check-reverse{padding-right:1.5em;padding-left:0;text-align:right}.climb-jupyter .form-check-reverse .form-check-input{float:right;margin-right:-1.5em;margin-left:0}.climb-jupyter .form-check-input{--bs-form-check-bg: var(--bs-body-bg);flex-shrink:0;width:1em;height:1em;margin-top:.25em;vertical-align:top;-webkit-appearance:none;-moz-appearance:none;appearance:none;background-color:var(--bs-form-check-bg);background-image:var(--bs-form-check-bg-image);background-repeat:no-repeat;background-position:center;background-size:contain;border:var(--bs-border-width) solid var(--bs-border-color);-webkit-print-color-adjust:exact;print-color-adjust:exact}.climb-jupyter .form-check-input[type=checkbox]{border-radius:.25em}.climb-jupyter .form-check-input[type=radio]{border-radius:50%}.climb-jupyter .form-check-input:active{filter:brightness(90%)}.climb-jupyter .form-check-input:focus{border-color:#86b7fe;outline:0;box-shadow:0 0 0 .25rem #0d6efd40}.climb-jupyter .form-check-input:checked{background-color:#0d6efd;border-color:#0d6efd}.climb-jupyter .form-check-input:checked[type=checkbox]{--bs-form-check-bg-image: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 20 20'%3e%3cpath fill='none' stroke='%23fff' stroke-linecap='round' stroke-linejoin='round' stroke-width='3' d='m6 10 3 3 6-6'/%3e%3c/svg%3e\")}.climb-jupyter .form-check-input:checked[type=radio]{--bs-form-check-bg-image: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='-4 -4 8 8'%3e%3ccircle r='2' fill='%23fff'/%3e%3c/svg%3e\")}.climb-jupyter .form-check-input[type=checkbox]:indeterminate{background-color:#0d6efd;border-color:#0d6efd;--bs-form-check-bg-image: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 20 20'%3e%3cpath fill='none' stroke='%23fff' stroke-linecap='round' stroke-linejoin='round' stroke-width='3' d='M6 10h8'/%3e%3c/svg%3e\")}.climb-jupyter .form-check-input:disabled{pointer-events:none;filter:none;opacity:.5}.climb-jupyter .form-check-input[disabled]~.form-check-label,.climb-jupyter .form-check-input:disabled~.form-check-label{cursor:default;opacity:.5}.climb-jupyter .form-switch{padding-left:2.5em}.climb-jupyter .form-switch .form-check-input{--bs-form-switch-bg: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='-4 -4 8 8'%3e%3ccircle r='3' fill='rgba%280, 0, 0, 0.25%29'/%3e%3c/svg%3e\");width:2em;margin-left:-2.5em;background-image:var(--bs-form-switch-bg);background-position:left center;border-radius:2em;transition:background-position .15s ease-in-out}@media (prefers-reduced-motion: reduce){.climb-jupyter .form-switch .form-check-input{transition:none}}.climb-jupyter .form-switch .form-check-input:focus{--bs-form-switch-bg: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='-4 -4 8 8'%3e%3ccircle r='3' fill='rgb%28134, 182.5, 254%29'/%3e%3c/svg%3e\")}.climb-jupyter .form-switch .form-check-input:checked{background-position:right center;--bs-form-switch-bg: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='-4 -4 8 8'%3e%3ccircle r='3' fill='%23fff'/%3e%3c/svg%3e\")}.climb-jupyter .form-switch.form-check-reverse{padding-right:2.5em;padding-left:0}.climb-jupyter .form-switch.form-check-reverse .form-check-input{margin-right:-2.5em;margin-left:0}.climb-jupyter .form-check-inline{display:inline-block;margin-right:1rem}.climb-jupyter .btn-check{position:absolute;clip:rect(0,0,0,0);pointer-events:none}.climb-jupyter .btn-check[disabled]+.btn,.climb-jupyter .btn-check:disabled+.btn{pointer-events:none;filter:none;opacity:.65}.climb-jupyter [data-bs-theme=dark] .form-switch .form-check-input:not(:checked):not(:focus){--bs-form-switch-bg: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='-4 -4 8 8'%3e%3ccircle r='3' fill='rgba%28255, 255, 255, 0.25%29'/%3e%3c/svg%3e\")}.climb-jupyter .form-range{width:100%;height:1.5rem;padding:0;-webkit-appearance:none;-moz-appearance:none;appearance:none;background-color:transparent}.climb-jupyter .form-range:focus{outline:0}.climb-jupyter .form-range:focus::-webkit-slider-thumb{box-shadow:0 0 0 1px #fff,0 0 0 .25rem #0d6efd40}.climb-jupyter .form-range:focus::-moz-range-thumb{box-shadow:0 0 0 1px #fff,0 0 0 .25rem #0d6efd40}.climb-jupyter .form-range::-moz-focus-outer{border:0}.climb-jupyter .form-range::-webkit-slider-thumb{width:1rem;height:1rem;margin-top:-.25rem;-webkit-appearance:none;-moz-appearance:none;appearance:none;background-color:#0d6efd;border:0;border-radius:1rem;transition:background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out}@media (prefers-reduced-motion: reduce){.climb-jupyter .form-range::-webkit-slider-thumb{transition:none}}.climb-jupyter .form-range::-webkit-slider-thumb:active{background-color:#b6d4fe}.climb-jupyter .form-range::-webkit-slider-runnable-track{width:100%;height:.5rem;color:transparent;cursor:pointer;background-color:var(--bs-secondary-bg);border-color:transparent;border-radius:1rem}.climb-jupyter .form-range::-moz-range-thumb{width:1rem;height:1rem;-webkit-appearance:none;-moz-appearance:none;appearance:none;background-color:#0d6efd;border:0;border-radius:1rem;transition:background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out}@media (prefers-reduced-motion: reduce){.climb-jupyter .form-range::-moz-range-thumb{transition:none}}.climb-jupyter .form-range::-moz-range-thumb:active{background-color:#b6d4fe}.climb-jupyter .form-range::-moz-range-track{width:100%;height:.5rem;color:transparent;cursor:pointer;background-color:var(--bs-secondary-bg);border-color:transparent;border-radius:1rem}.climb-jupyter .form-range:disabled{pointer-events:none}.climb-jupyter .form-range:disabled::-webkit-slider-thumb{background-color:var(--bs-secondary-color)}.climb-jupyter .form-range:disabled::-moz-range-thumb{background-color:var(--bs-secondary-color)}.climb-jupyter .form-floating{position:relative}.climb-jupyter .form-floating>.form-control,.climb-jupyter .form-floating>.form-control-plaintext,.climb-jupyter .form-floating>.form-select{height:calc(3.5rem + calc(var(--bs-border-width) * 2));min-height:calc(3.5rem + calc(var(--bs-border-width) * 2));line-height:1.25}.climb-jupyter .form-floating>label{position:absolute;top:0;left:0;z-index:2;max-width:100%;height:100%;padding:1rem .75rem;overflow:hidden;color:rgba(var(--bs-body-color-rgb),.65);text-align:start;text-overflow:ellipsis;white-space:nowrap;pointer-events:none;border:var(--bs-border-width) solid transparent;transform-origin:0 0;transition:opacity .1s ease-in-out,transform .1s ease-in-out}@media (prefers-reduced-motion: reduce){.climb-jupyter .form-floating>label{transition:none}}.climb-jupyter .form-floating>.form-control,.climb-jupyter .form-floating>.form-control-plaintext{padding:1rem .75rem}.climb-jupyter .form-floating>.form-control::placeholder,.climb-jupyter .form-floating>.form-control-plaintext::placeholder{color:transparent}.climb-jupyter .form-floating>.form-control:focus,.climb-jupyter .form-floating>.form-control:not(:placeholder-shown),.climb-jupyter .form-floating>.form-control-plaintext:focus,.climb-jupyter .form-floating>.form-control-plaintext:not(:placeholder-shown){padding-top:1.625rem;padding-bottom:.625rem}.climb-jupyter .form-floating>.form-control:-webkit-autofill,.climb-jupyter .form-floating>.form-control-plaintext:-webkit-autofill{padding-top:1.625rem;padding-bottom:.625rem}.climb-jupyter .form-floating>.form-select{padding-top:1.625rem;padding-bottom:.625rem;padding-left:.75rem}.climb-jupyter .form-floating>.form-control:focus~label,.climb-jupyter .form-floating>.form-control:not(:placeholder-shown)~label,.climb-jupyter .form-floating>.form-control-plaintext~label,.climb-jupyter .form-floating>.form-select~label{transform:scale(.85) translateY(-.5rem) translate(.15rem)}.climb-jupyter .form-floating>.form-control:-webkit-autofill~label{transform:scale(.85) translateY(-.5rem) translate(.15rem)}.climb-jupyter .form-floating>textarea:focus~label:after,.climb-jupyter .form-floating>textarea:not(:placeholder-shown)~label:after{position:absolute;top:1rem;right:.375rem;bottom:1rem;left:.375rem;z-index:-1;height:1.5em;content:\"\";background-color:var(--bs-body-bg);border-radius:var(--bs-border-radius)}.climb-jupyter .form-floating>textarea:disabled~label:after{background-color:var(--bs-secondary-bg)}.climb-jupyter .form-floating>.form-control-plaintext~label{border-width:var(--bs-border-width) 0}.climb-jupyter .form-floating>:disabled~label,.climb-jupyter .form-floating>.form-control:disabled~label{color:#6c757d}.climb-jupyter .input-group{position:relative;display:flex;flex-wrap:wrap;align-items:stretch;width:100%}.climb-jupyter .input-group>.form-control,.climb-jupyter .input-group>.form-select,.climb-jupyter .input-group>.form-floating{position:relative;flex:1 1 auto;width:1%;min-width:0}.climb-jupyter .input-group>.form-control:focus,.climb-jupyter .input-group>.form-select:focus,.climb-jupyter .input-group>.form-floating:focus-within{z-index:5}.climb-jupyter .input-group .btn{position:relative;z-index:2}.climb-jupyter .input-group .btn:focus{z-index:5}.climb-jupyter .input-group-text{display:flex;align-items:center;padding:.375rem .75rem;font-size:1rem;font-weight:400;line-height:1.5;color:var(--bs-body-color);text-align:center;white-space:nowrap;background-color:var(--bs-tertiary-bg);border:var(--bs-border-width) solid var(--bs-border-color);border-radius:var(--bs-border-radius)}.climb-jupyter .input-group-lg>.form-control,.climb-jupyter .input-group-lg>.form-select,.climb-jupyter .input-group-lg>.input-group-text,.climb-jupyter .input-group-lg>.btn{padding:.5rem 1rem;font-size:1.25rem;border-radius:var(--bs-border-radius-lg)}.climb-jupyter .input-group-sm>.form-control,.climb-jupyter .input-group-sm>.form-select,.climb-jupyter .input-group-sm>.input-group-text,.climb-jupyter .input-group-sm>.btn{padding:.25rem .5rem;font-size:.875rem;border-radius:var(--bs-border-radius-sm)}.climb-jupyter .input-group-lg>.form-select,.climb-jupyter .input-group-sm>.form-select{padding-right:3rem}.climb-jupyter .input-group:not(.has-validation)>:not(:last-child):not(.dropdown-toggle):not(.dropdown-menu):not(.form-floating),.climb-jupyter .input-group:not(.has-validation)>.dropdown-toggle:nth-last-child(n+3),.climb-jupyter .input-group:not(.has-validation)>.form-floating:not(:last-child)>.form-control,.climb-jupyter .input-group:not(.has-validation)>.form-floating:not(:last-child)>.form-select{border-top-right-radius:0;border-bottom-right-radius:0}.climb-jupyter .input-group.has-validation>:nth-last-child(n+3):not(.dropdown-toggle):not(.dropdown-menu):not(.form-floating),.climb-jupyter .input-group.has-validation>.dropdown-toggle:nth-last-child(n+4),.climb-jupyter .input-group.has-validation>.form-floating:nth-last-child(n+3)>.form-control,.climb-jupyter .input-group.has-validation>.form-floating:nth-last-child(n+3)>.form-select{border-top-right-radius:0;border-bottom-right-radius:0}.climb-jupyter .input-group>:not(:first-child):not(.dropdown-menu):not(.valid-tooltip):not(.valid-feedback):not(.invalid-tooltip):not(.invalid-feedback){margin-left:calc(-1 * var(--bs-border-width));border-top-left-radius:0;border-bottom-left-radius:0}.climb-jupyter .input-group>.form-floating:not(:first-child)>.form-control,.climb-jupyter .input-group>.form-floating:not(:first-child)>.form-select{border-top-left-radius:0;border-bottom-left-radius:0}.climb-jupyter .valid-feedback{display:none;width:100%;margin-top:.25rem;font-size:.875em;color:var(--bs-form-valid-color)}.climb-jupyter .valid-tooltip{position:absolute;top:100%;z-index:5;display:none;max-width:100%;padding:.25rem .5rem;margin-top:.1rem;font-size:.875rem;color:#fff;background-color:var(--bs-success);border-radius:var(--bs-border-radius)}.was-validated .climb-jupyter:valid~.valid-feedback,.was-validated .climb-jupyter:valid~.valid-tooltip,.climb-jupyter.is-valid~.valid-feedback,.climb-jupyter.is-valid~.valid-tooltip{display:block}.was-validated .climb-jupyter .form-control:valid,.climb-jupyter .form-control.is-valid{border-color:var(--bs-form-valid-border-color);padding-right:calc(1.5em + .75rem);background-image:url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 8 8'%3e%3cpath fill='%23198754' d='M2.3 6.73.6 4.53c-.4-1.04.46-1.4 1.1-.8l1.1 1.4 3.4-3.8c.6-.63 1.6-.27 1.2.7l-4 4.6c-.43.5-.8.4-1.1.1'/%3e%3c/svg%3e\");background-repeat:no-repeat;background-position:right calc(.375em + .1875rem) center;background-size:calc(.75em + .375rem) calc(.75em + .375rem)}.was-validated .climb-jupyter .form-control:valid:focus,.climb-jupyter .form-control.is-valid:focus{border-color:var(--bs-form-valid-border-color);box-shadow:0 0 0 .25rem rgba(var(--bs-success-rgb),.25)}.was-validated .climb-jupyter textarea.form-control:valid,.climb-jupyter textarea.form-control.is-valid{padding-right:calc(1.5em + .75rem);background-position:top calc(.375em + .1875rem) right calc(.375em + .1875rem)}.was-validated .climb-jupyter .form-select:valid,.climb-jupyter .form-select.is-valid{border-color:var(--bs-form-valid-border-color)}.was-validated .climb-jupyter .form-select:valid:not([multiple]):not([size]),.was-validated .climb-jupyter .form-select:valid:not([multiple])[size=\"1\"],.climb-jupyter .form-select.is-valid:not([multiple]):not([size]),.climb-jupyter .form-select.is-valid:not([multiple])[size=\"1\"]{--bs-form-select-bg-icon: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 8 8'%3e%3cpath fill='%23198754' d='M2.3 6.73.6 4.53c-.4-1.04.46-1.4 1.1-.8l1.1 1.4 3.4-3.8c.6-.63 1.6-.27 1.2.7l-4 4.6c-.43.5-.8.4-1.1.1'/%3e%3c/svg%3e\");padding-right:4.125rem;background-position:right .75rem center,center right 2.25rem;background-size:16px 12px,calc(.75em + .375rem) calc(.75em + .375rem)}.was-validated .climb-jupyter .form-select:valid:focus,.climb-jupyter .form-select.is-valid:focus{border-color:var(--bs-form-valid-border-color);box-shadow:0 0 0 .25rem rgba(var(--bs-success-rgb),.25)}.was-validated .climb-jupyter .form-control-color:valid,.climb-jupyter .form-control-color.is-valid{width:calc(3.75rem + 1.5em)}.was-validated .climb-jupyter .form-check-input:valid,.climb-jupyter .form-check-input.is-valid{border-color:var(--bs-form-valid-border-color)}.was-validated .climb-jupyter .form-check-input:valid:checked,.climb-jupyter .form-check-input.is-valid:checked{background-color:var(--bs-form-valid-color)}.was-validated .climb-jupyter .form-check-input:valid:focus,.climb-jupyter .form-check-input.is-valid:focus{box-shadow:0 0 0 .25rem rgba(var(--bs-success-rgb),.25)}.was-validated .climb-jupyter .form-check-input:valid~.form-check-label,.climb-jupyter .form-check-input.is-valid~.form-check-label{color:var(--bs-form-valid-color)}.climb-jupyter .form-check-inline .form-check-input~.valid-feedback{margin-left:.5em}.was-validated .climb-jupyter .input-group>.form-control:not(:focus):valid,.climb-jupyter .input-group>.form-control:not(:focus).is-valid,.was-validated .climb-jupyter .input-group>.form-select:not(:focus):valid,.climb-jupyter .input-group>.form-select:not(:focus).is-valid,.was-validated .climb-jupyter .input-group>.form-floating:not(:focus-within):valid,.climb-jupyter .input-group>.form-floating:not(:focus-within).is-valid{z-index:3}.climb-jupyter .invalid-feedback{display:none;width:100%;margin-top:.25rem;font-size:.875em;color:var(--bs-form-invalid-color)}.climb-jupyter .invalid-tooltip{position:absolute;top:100%;z-index:5;display:none;max-width:100%;padding:.25rem .5rem;margin-top:.1rem;font-size:.875rem;color:#fff;background-color:var(--bs-danger);border-radius:var(--bs-border-radius)}.was-validated .climb-jupyter:invalid~.invalid-feedback,.was-validated .climb-jupyter:invalid~.invalid-tooltip,.climb-jupyter.is-invalid~.invalid-feedback,.climb-jupyter.is-invalid~.invalid-tooltip{display:block}.was-validated .climb-jupyter .form-control:invalid,.climb-jupyter .form-control.is-invalid{border-color:var(--bs-form-invalid-border-color);padding-right:calc(1.5em + .75rem);background-image:url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 12 12' width='12' height='12' fill='none' stroke='%23dc3545'%3e%3ccircle cx='6' cy='6' r='4.5'/%3e%3cpath stroke-linejoin='round' d='M5.8 3.6h.4L6 6.5z'/%3e%3ccircle cx='6' cy='8.2' r='.6' fill='%23dc3545' stroke='none'/%3e%3c/svg%3e\");background-repeat:no-repeat;background-position:right calc(.375em + .1875rem) center;background-size:calc(.75em + .375rem) calc(.75em + .375rem)}.was-validated .climb-jupyter .form-control:invalid:focus,.climb-jupyter .form-control.is-invalid:focus{border-color:var(--bs-form-invalid-border-color);box-shadow:0 0 0 .25rem rgba(var(--bs-danger-rgb),.25)}.was-validated .climb-jupyter textarea.form-control:invalid,.climb-jupyter textarea.form-control.is-invalid{padding-right:calc(1.5em + .75rem);background-position:top calc(.375em + .1875rem) right calc(.375em + .1875rem)}.was-validated .climb-jupyter .form-select:invalid,.climb-jupyter .form-select.is-invalid{border-color:var(--bs-form-invalid-border-color)}.was-validated .climb-jupyter .form-select:invalid:not([multiple]):not([size]),.was-validated .climb-jupyter .form-select:invalid:not([multiple])[size=\"1\"],.climb-jupyter .form-select.is-invalid:not([multiple]):not([size]),.climb-jupyter .form-select.is-invalid:not([multiple])[size=\"1\"]{--bs-form-select-bg-icon: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 12 12' width='12' height='12' fill='none' stroke='%23dc3545'%3e%3ccircle cx='6' cy='6' r='4.5'/%3e%3cpath stroke-linejoin='round' d='M5.8 3.6h.4L6 6.5z'/%3e%3ccircle cx='6' cy='8.2' r='.6' fill='%23dc3545' stroke='none'/%3e%3c/svg%3e\");padding-right:4.125rem;background-position:right .75rem center,center right 2.25rem;background-size:16px 12px,calc(.75em + .375rem) calc(.75em + .375rem)}.was-validated .climb-jupyter .form-select:invalid:focus,.climb-jupyter .form-select.is-invalid:focus{border-color:var(--bs-form-invalid-border-color);box-shadow:0 0 0 .25rem rgba(var(--bs-danger-rgb),.25)}.was-validated .climb-jupyter .form-control-color:invalid,.climb-jupyter .form-control-color.is-invalid{width:calc(3.75rem + 1.5em)}.was-validated .climb-jupyter .form-check-input:invalid,.climb-jupyter .form-check-input.is-invalid{border-color:var(--bs-form-invalid-border-color)}.was-validated .climb-jupyter .form-check-input:invalid:checked,.climb-jupyter .form-check-input.is-invalid:checked{background-color:var(--bs-form-invalid-color)}.was-validated .climb-jupyter .form-check-input:invalid:focus,.climb-jupyter .form-check-input.is-invalid:focus{box-shadow:0 0 0 .25rem rgba(var(--bs-danger-rgb),.25)}.was-validated .climb-jupyter .form-check-input:invalid~.form-check-label,.climb-jupyter .form-check-input.is-invalid~.form-check-label{color:var(--bs-form-invalid-color)}.climb-jupyter .form-check-inline .form-check-input~.invalid-feedback{margin-left:.5em}.was-validated .climb-jupyter .input-group>.form-control:not(:focus):invalid,.climb-jupyter .input-group>.form-control:not(:focus).is-invalid,.was-validated .climb-jupyter .input-group>.form-select:not(:focus):invalid,.climb-jupyter .input-group>.form-select:not(:focus).is-invalid,.was-validated .climb-jupyter .input-group>.form-floating:not(:focus-within):invalid,.climb-jupyter .input-group>.form-floating:not(:focus-within).is-invalid{z-index:4}.climb-jupyter .btn{--bs-btn-padding-x: .75rem;--bs-btn-padding-y: .375rem;--bs-btn-font-family: ;--bs-btn-font-size: 1rem;--bs-btn-font-weight: 400;--bs-btn-line-height: 1.5;--bs-btn-color: var(--bs-body-color);--bs-btn-bg: transparent;--bs-btn-border-width: var(--bs-border-width);--bs-btn-border-color: transparent;--bs-btn-border-radius: var(--bs-border-radius);--bs-btn-hover-border-color: transparent;--bs-btn-box-shadow: inset 0 1px 0 rgba(255, 255, 255, .15), 0 1px 1px rgba(0, 0, 0, .075);--bs-btn-disabled-opacity: .65;--bs-btn-focus-box-shadow: 0 0 0 .25rem rgba(var(--bs-btn-focus-shadow-rgb), .5);display:inline-block;padding:var(--bs-btn-padding-y) var(--bs-btn-padding-x);font-family:var(--bs-btn-font-family);font-size:var(--bs-btn-font-size);font-weight:var(--bs-btn-font-weight);line-height:var(--bs-btn-line-height);color:var(--bs-btn-color);text-align:center;text-decoration:none;vertical-align:middle;cursor:pointer;-webkit-user-select:none;user-select:none;border:var(--bs-btn-border-width) solid var(--bs-btn-border-color);border-radius:var(--bs-btn-border-radius);background-color:var(--bs-btn-bg);transition:color .15s ease-in-out,background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out}@media (prefers-reduced-motion: reduce){.climb-jupyter .btn{transition:none}}.climb-jupyter .btn:hover{color:var(--bs-btn-hover-color);background-color:var(--bs-btn-hover-bg);border-color:var(--bs-btn-hover-border-color)}.btn-check+.climb-jupyter .btn:hover{color:var(--bs-btn-color);background-color:var(--bs-btn-bg);border-color:var(--bs-btn-border-color)}.climb-jupyter .btn:focus-visible{color:var(--bs-btn-hover-color);background-color:var(--bs-btn-hover-bg);border-color:var(--bs-btn-hover-border-color);outline:0;box-shadow:var(--bs-btn-focus-box-shadow)}.btn-check:focus-visible+.climb-jupyter .btn{border-color:var(--bs-btn-hover-border-color);outline:0;box-shadow:var(--bs-btn-focus-box-shadow)}.btn-check:checked+.climb-jupyter .btn,:not(.btn-check)+.climb-jupyter .btn:active,.climb-jupyter .btn:first-child:active,.climb-jupyter .btn.active,.climb-jupyter .btn.show{color:var(--bs-btn-active-color);background-color:var(--bs-btn-active-bg);border-color:var(--bs-btn-active-border-color)}.btn-check:checked+.climb-jupyter .btn:focus-visible,:not(.btn-check)+.climb-jupyter .btn:active:focus-visible,.climb-jupyter .btn:first-child:active:focus-visible,.climb-jupyter .btn.active:focus-visible,.climb-jupyter .btn.show:focus-visible{box-shadow:var(--bs-btn-focus-box-shadow)}.btn-check:checked:focus-visible+.climb-jupyter .btn{box-shadow:var(--bs-btn-focus-box-shadow)}.climb-jupyter .btn:disabled,.climb-jupyter .btn.disabled,fieldset:disabled .climb-jupyter .btn{color:var(--bs-btn-disabled-color);pointer-events:none;background-color:var(--bs-btn-disabled-bg);border-color:var(--bs-btn-disabled-border-color);opacity:var(--bs-btn-disabled-opacity)}.climb-jupyter .btn-primary{--bs-btn-color: #fff;--bs-btn-bg: #0d6efd;--bs-btn-border-color: #0d6efd;--bs-btn-hover-color: #fff;--bs-btn-hover-bg: rgb(11.05, 93.5, 215.05);--bs-btn-hover-border-color: rgb(10.4, 88, 202.4);--bs-btn-focus-shadow-rgb: 49, 132, 253;--bs-btn-active-color: #fff;--bs-btn-active-bg: rgb(10.4, 88, 202.4);--bs-btn-active-border-color: rgb(9.75, 82.5, 189.75);--bs-btn-active-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);--bs-btn-disabled-color: #fff;--bs-btn-disabled-bg: #0d6efd;--bs-btn-disabled-border-color: #0d6efd}.climb-jupyter .btn-secondary{--bs-btn-color: #fff;--bs-btn-bg: #6c757d;--bs-btn-border-color: #6c757d;--bs-btn-hover-color: #fff;--bs-btn-hover-bg: rgb(91.8, 99.45, 106.25);--bs-btn-hover-border-color: rgb(86.4, 93.6, 100);--bs-btn-focus-shadow-rgb: 130, 138, 145;--bs-btn-active-color: #fff;--bs-btn-active-bg: rgb(86.4, 93.6, 100);--bs-btn-active-border-color: rgb(81, 87.75, 93.75);--bs-btn-active-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);--bs-btn-disabled-color: #fff;--bs-btn-disabled-bg: #6c757d;--bs-btn-disabled-border-color: #6c757d}.climb-jupyter .btn-success{--bs-btn-color: #fff;--bs-btn-bg: #198754;--bs-btn-border-color: #198754;--bs-btn-hover-color: #fff;--bs-btn-hover-bg: rgb(21.25, 114.75, 71.4);--bs-btn-hover-border-color: rgb(20, 108, 67.2);--bs-btn-focus-shadow-rgb: 60, 153, 110;--bs-btn-active-color: #fff;--bs-btn-active-bg: rgb(20, 108, 67.2);--bs-btn-active-border-color: rgb(18.75, 101.25, 63);--bs-btn-active-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);--bs-btn-disabled-color: #fff;--bs-btn-disabled-bg: #198754;--bs-btn-disabled-border-color: #198754}.climb-jupyter .btn-info{--bs-btn-color: #000;--bs-btn-bg: #0dcaf0;--bs-btn-border-color: #0dcaf0;--bs-btn-hover-color: #000;--bs-btn-hover-bg: rgb(49.3, 209.95, 242.25);--bs-btn-hover-border-color: rgb(37.2, 207.3, 241.5);--bs-btn-focus-shadow-rgb: 11, 172, 204;--bs-btn-active-color: #000;--bs-btn-active-bg: rgb(61.4, 212.6, 243);--bs-btn-active-border-color: rgb(37.2, 207.3, 241.5);--bs-btn-active-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);--bs-btn-disabled-color: #000;--bs-btn-disabled-bg: #0dcaf0;--bs-btn-disabled-border-color: #0dcaf0}.climb-jupyter .btn-warning{--bs-btn-color: #000;--bs-btn-bg: #ffc107;--bs-btn-border-color: #ffc107;--bs-btn-hover-color: #000;--bs-btn-hover-bg: rgb(255, 202.3, 44.2);--bs-btn-hover-border-color: rgb(255, 199.2, 31.8);--bs-btn-focus-shadow-rgb: 217, 164, 6;--bs-btn-active-color: #000;--bs-btn-active-bg: rgb(255, 205.4, 56.6);--bs-btn-active-border-color: rgb(255, 199.2, 31.8);--bs-btn-active-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);--bs-btn-disabled-color: #000;--bs-btn-disabled-bg: #ffc107;--bs-btn-disabled-border-color: #ffc107}.climb-jupyter .btn-danger{--bs-btn-color: #fff;--bs-btn-bg: #dc3545;--bs-btn-border-color: #dc3545;--bs-btn-hover-color: #fff;--bs-btn-hover-bg: rgb(187, 45.05, 58.65);--bs-btn-hover-border-color: rgb(176, 42.4, 55.2);--bs-btn-focus-shadow-rgb: 225, 83, 97;--bs-btn-active-color: #fff;--bs-btn-active-bg: rgb(176, 42.4, 55.2);--bs-btn-active-border-color: rgb(165, 39.75, 51.75);--bs-btn-active-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);--bs-btn-disabled-color: #fff;--bs-btn-disabled-bg: #dc3545;--bs-btn-disabled-border-color: #dc3545}.climb-jupyter .btn-light{--bs-btn-color: #000;--bs-btn-bg: #f8f9fa;--bs-btn-border-color: #f8f9fa;--bs-btn-hover-color: #000;--bs-btn-hover-bg: rgb(210.8, 211.65, 212.5);--bs-btn-hover-border-color: rgb(198.4, 199.2, 200);--bs-btn-focus-shadow-rgb: 211, 212, 213;--bs-btn-active-color: #000;--bs-btn-active-bg: rgb(198.4, 199.2, 200);--bs-btn-active-border-color: rgb(186, 186.75, 187.5);--bs-btn-active-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);--bs-btn-disabled-color: #000;--bs-btn-disabled-bg: #f8f9fa;--bs-btn-disabled-border-color: #f8f9fa}.climb-jupyter .btn-dark{--bs-btn-color: #fff;--bs-btn-bg: #212529;--bs-btn-border-color: #212529;--bs-btn-hover-color: #fff;--bs-btn-hover-bg: rgb(66.3, 69.7, 73.1);--bs-btn-hover-border-color: rgb(55.2, 58.8, 62.4);--bs-btn-focus-shadow-rgb: 66, 70, 73;--bs-btn-active-color: #fff;--bs-btn-active-bg: rgb(77.4, 80.6, 83.8);--bs-btn-active-border-color: rgb(55.2, 58.8, 62.4);--bs-btn-active-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);--bs-btn-disabled-color: #fff;--bs-btn-disabled-bg: #212529;--bs-btn-disabled-border-color: #212529}.climb-jupyter .btn-outline-primary{--bs-btn-color: #0d6efd;--bs-btn-border-color: #0d6efd;--bs-btn-hover-color: #fff;--bs-btn-hover-bg: #0d6efd;--bs-btn-hover-border-color: #0d6efd;--bs-btn-focus-shadow-rgb: 13, 110, 253;--bs-btn-active-color: #fff;--bs-btn-active-bg: #0d6efd;--bs-btn-active-border-color: #0d6efd;--bs-btn-active-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);--bs-btn-disabled-color: #0d6efd;--bs-btn-disabled-bg: transparent;--bs-btn-disabled-border-color: #0d6efd;--bs-gradient: none}.climb-jupyter .btn-outline-secondary{--bs-btn-color: #6c757d;--bs-btn-border-color: #6c757d;--bs-btn-hover-color: #fff;--bs-btn-hover-bg: #6c757d;--bs-btn-hover-border-color: #6c757d;--bs-btn-focus-shadow-rgb: 108, 117, 125;--bs-btn-active-color: #fff;--bs-btn-active-bg: #6c757d;--bs-btn-active-border-color: #6c757d;--bs-btn-active-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);--bs-btn-disabled-color: #6c757d;--bs-btn-disabled-bg: transparent;--bs-btn-disabled-border-color: #6c757d;--bs-gradient: none}.climb-jupyter .btn-outline-success{--bs-btn-color: #198754;--bs-btn-border-color: #198754;--bs-btn-hover-color: #fff;--bs-btn-hover-bg: #198754;--bs-btn-hover-border-color: #198754;--bs-btn-focus-shadow-rgb: 25, 135, 84;--bs-btn-active-color: #fff;--bs-btn-active-bg: #198754;--bs-btn-active-border-color: #198754;--bs-btn-active-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);--bs-btn-disabled-color: #198754;--bs-btn-disabled-bg: transparent;--bs-btn-disabled-border-color: #198754;--bs-gradient: none}.climb-jupyter .btn-outline-info{--bs-btn-color: #0dcaf0;--bs-btn-border-color: #0dcaf0;--bs-btn-hover-color: #000;--bs-btn-hover-bg: #0dcaf0;--bs-btn-hover-border-color: #0dcaf0;--bs-btn-focus-shadow-rgb: 13, 202, 240;--bs-btn-active-color: #000;--bs-btn-active-bg: #0dcaf0;--bs-btn-active-border-color: #0dcaf0;--bs-btn-active-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);--bs-btn-disabled-color: #0dcaf0;--bs-btn-disabled-bg: transparent;--bs-btn-disabled-border-color: #0dcaf0;--bs-gradient: none}.climb-jupyter .btn-outline-warning{--bs-btn-color: #ffc107;--bs-btn-border-color: #ffc107;--bs-btn-hover-color: #000;--bs-btn-hover-bg: #ffc107;--bs-btn-hover-border-color: #ffc107;--bs-btn-focus-shadow-rgb: 255, 193, 7;--bs-btn-active-color: #000;--bs-btn-active-bg: #ffc107;--bs-btn-active-border-color: #ffc107;--bs-btn-active-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);--bs-btn-disabled-color: #ffc107;--bs-btn-disabled-bg: transparent;--bs-btn-disabled-border-color: #ffc107;--bs-gradient: none}.climb-jupyter .btn-outline-danger{--bs-btn-color: #dc3545;--bs-btn-border-color: #dc3545;--bs-btn-hover-color: #fff;--bs-btn-hover-bg: #dc3545;--bs-btn-hover-border-color: #dc3545;--bs-btn-focus-shadow-rgb: 220, 53, 69;--bs-btn-active-color: #fff;--bs-btn-active-bg: #dc3545;--bs-btn-active-border-color: #dc3545;--bs-btn-active-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);--bs-btn-disabled-color: #dc3545;--bs-btn-disabled-bg: transparent;--bs-btn-disabled-border-color: #dc3545;--bs-gradient: none}.climb-jupyter .btn-outline-light{--bs-btn-color: #f8f9fa;--bs-btn-border-color: #f8f9fa;--bs-btn-hover-color: #000;--bs-btn-hover-bg: #f8f9fa;--bs-btn-hover-border-color: #f8f9fa;--bs-btn-focus-shadow-rgb: 248, 249, 250;--bs-btn-active-color: #000;--bs-btn-active-bg: #f8f9fa;--bs-btn-active-border-color: #f8f9fa;--bs-btn-active-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);--bs-btn-disabled-color: #f8f9fa;--bs-btn-disabled-bg: transparent;--bs-btn-disabled-border-color: #f8f9fa;--bs-gradient: none}.climb-jupyter .btn-outline-dark{--bs-btn-color: #212529;--bs-btn-border-color: #212529;--bs-btn-hover-color: #fff;--bs-btn-hover-bg: #212529;--bs-btn-hover-border-color: #212529;--bs-btn-focus-shadow-rgb: 33, 37, 41;--bs-btn-active-color: #fff;--bs-btn-active-bg: #212529;--bs-btn-active-border-color: #212529;--bs-btn-active-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);--bs-btn-disabled-color: #212529;--bs-btn-disabled-bg: transparent;--bs-btn-disabled-border-color: #212529;--bs-gradient: none}.climb-jupyter .btn-link{--bs-btn-font-weight: 400;--bs-btn-color: var(--bs-link-color);--bs-btn-bg: transparent;--bs-btn-border-color: transparent;--bs-btn-hover-color: var(--bs-link-hover-color);--bs-btn-hover-border-color: transparent;--bs-btn-active-color: var(--bs-link-hover-color);--bs-btn-active-border-color: transparent;--bs-btn-disabled-color: #6c757d;--bs-btn-disabled-border-color: transparent;--bs-btn-box-shadow: 0 0 0 #000;--bs-btn-focus-shadow-rgb: 49, 132, 253;text-decoration:underline}.climb-jupyter .btn-link:focus-visible{color:var(--bs-btn-color)}.climb-jupyter .btn-link:hover{color:var(--bs-btn-hover-color)}.climb-jupyter .btn-lg,.climb-jupyter .btn-group-lg>.btn{--bs-btn-padding-y: .5rem;--bs-btn-padding-x: 1rem;--bs-btn-font-size: 1.25rem;--bs-btn-border-radius: var(--bs-border-radius-lg)}.climb-jupyter .btn-sm,.climb-jupyter .btn-group-sm>.btn{--bs-btn-padding-y: .25rem;--bs-btn-padding-x: .5rem;--bs-btn-font-size: .875rem;--bs-btn-border-radius: var(--bs-border-radius-sm)}.climb-jupyter .fade{transition:opacity .15s linear}@media (prefers-reduced-motion: reduce){.climb-jupyter .fade{transition:none}}.climb-jupyter .fade:not(.show){opacity:0}.climb-jupyter .collapse:not(.show){display:none}.climb-jupyter .collapsing{height:0;overflow:hidden;transition:height .35s ease}@media (prefers-reduced-motion: reduce){.climb-jupyter .collapsing{transition:none}}.climb-jupyter .collapsing.collapse-horizontal{width:0;height:auto;transition:width .35s ease}@media (prefers-reduced-motion: reduce){.climb-jupyter .collapsing.collapse-horizontal{transition:none}}.climb-jupyter .dropup,.climb-jupyter .dropend,.climb-jupyter .dropdown,.climb-jupyter .dropstart,.climb-jupyter .dropup-center,.climb-jupyter .dropdown-center{position:relative}.climb-jupyter .dropdown-toggle{white-space:nowrap}.climb-jupyter .dropdown-toggle:after{display:inline-block;margin-left:.255em;vertical-align:.255em;content:\"\";border-top:.3em solid;border-right:.3em solid transparent;border-bottom:0;border-left:.3em solid transparent}.climb-jupyter .dropdown-toggle:empty:after{margin-left:0}.climb-jupyter .dropdown-menu{--bs-dropdown-zindex: 1000;--bs-dropdown-min-width: 10rem;--bs-dropdown-padding-x: 0;--bs-dropdown-padding-y: .5rem;--bs-dropdown-spacer: .125rem;--bs-dropdown-font-size: 1rem;--bs-dropdown-color: var(--bs-body-color);--bs-dropdown-bg: var(--bs-body-bg);--bs-dropdown-border-color: var(--bs-border-color-translucent);--bs-dropdown-border-radius: var(--bs-border-radius);--bs-dropdown-border-width: var(--bs-border-width);--bs-dropdown-inner-border-radius: calc(var(--bs-border-radius) - var(--bs-border-width));--bs-dropdown-divider-bg: var(--bs-border-color-translucent);--bs-dropdown-divider-margin-y: .5rem;--bs-dropdown-box-shadow: var(--bs-box-shadow);--bs-dropdown-link-color: var(--bs-body-color);--bs-dropdown-link-hover-color: var(--bs-body-color);--bs-dropdown-link-hover-bg: var(--bs-tertiary-bg);--bs-dropdown-link-active-color: #fff;--bs-dropdown-link-active-bg: #0d6efd;--bs-dropdown-link-disabled-color: var(--bs-tertiary-color);--bs-dropdown-item-padding-x: 1rem;--bs-dropdown-item-padding-y: .25rem;--bs-dropdown-header-color: #6c757d;--bs-dropdown-header-padding-x: 1rem;--bs-dropdown-header-padding-y: .5rem;position:absolute;z-index:var(--bs-dropdown-zindex);display:none;min-width:var(--bs-dropdown-min-width);padding:var(--bs-dropdown-padding-y) var(--bs-dropdown-padding-x);margin:0;font-size:var(--bs-dropdown-font-size);color:var(--bs-dropdown-color);text-align:left;list-style:none;background-color:var(--bs-dropdown-bg);background-clip:padding-box;border:var(--bs-dropdown-border-width) solid var(--bs-dropdown-border-color);border-radius:var(--bs-dropdown-border-radius)}.climb-jupyter .dropdown-menu[data-bs-popper]{top:100%;left:0;margin-top:var(--bs-dropdown-spacer)}.climb-jupyter .dropdown-menu-start{--bs-position: start}.climb-jupyter .dropdown-menu-start[data-bs-popper]{right:auto;left:0}.climb-jupyter .dropdown-menu-end{--bs-position: end}.climb-jupyter .dropdown-menu-end[data-bs-popper]{right:0;left:auto}@media (min-width: 576px){.climb-jupyter .dropdown-menu-sm-start{--bs-position: start}.climb-jupyter .dropdown-menu-sm-start[data-bs-popper]{right:auto;left:0}.climb-jupyter .dropdown-menu-sm-end{--bs-position: end}.climb-jupyter .dropdown-menu-sm-end[data-bs-popper]{right:0;left:auto}}@media (min-width: 768px){.climb-jupyter .dropdown-menu-md-start{--bs-position: start}.climb-jupyter .dropdown-menu-md-start[data-bs-popper]{right:auto;left:0}.climb-jupyter .dropdown-menu-md-end{--bs-position: end}.climb-jupyter .dropdown-menu-md-end[data-bs-popper]{right:0;left:auto}}@media (min-width: 992px){.climb-jupyter .dropdown-menu-lg-start{--bs-position: start}.climb-jupyter .dropdown-menu-lg-start[data-bs-popper]{right:auto;left:0}.climb-jupyter .dropdown-menu-lg-end{--bs-position: end}.climb-jupyter .dropdown-menu-lg-end[data-bs-popper]{right:0;left:auto}}@media (min-width: 1200px){.climb-jupyter .dropdown-menu-xl-start{--bs-position: start}.climb-jupyter .dropdown-menu-xl-start[data-bs-popper]{right:auto;left:0}.climb-jupyter .dropdown-menu-xl-end{--bs-position: end}.climb-jupyter .dropdown-menu-xl-end[data-bs-popper]{right:0;left:auto}}@media (min-width: 1400px){.climb-jupyter .dropdown-menu-xxl-start{--bs-position: start}.climb-jupyter .dropdown-menu-xxl-start[data-bs-popper]{right:auto;left:0}.climb-jupyter .dropdown-menu-xxl-end{--bs-position: end}.climb-jupyter .dropdown-menu-xxl-end[data-bs-popper]{right:0;left:auto}}.climb-jupyter .dropup .dropdown-menu[data-bs-popper]{top:auto;bottom:100%;margin-top:0;margin-bottom:var(--bs-dropdown-spacer)}.climb-jupyter .dropup .dropdown-toggle:after{display:inline-block;margin-left:.255em;vertical-align:.255em;content:\"\";border-top:0;border-right:.3em solid transparent;border-bottom:.3em solid;border-left:.3em solid transparent}.climb-jupyter .dropup .dropdown-toggle:empty:after{margin-left:0}.climb-jupyter .dropend .dropdown-menu[data-bs-popper]{top:0;right:auto;left:100%;margin-top:0;margin-left:var(--bs-dropdown-spacer)}.climb-jupyter .dropend .dropdown-toggle:after{display:inline-block;margin-left:.255em;vertical-align:.255em;content:\"\";border-top:.3em solid transparent;border-right:0;border-bottom:.3em solid transparent;border-left:.3em solid}.climb-jupyter .dropend .dropdown-toggle:empty:after{margin-left:0}.climb-jupyter .dropend .dropdown-toggle:after{vertical-align:0}.climb-jupyter .dropstart .dropdown-menu[data-bs-popper]{top:0;right:100%;left:auto;margin-top:0;margin-right:var(--bs-dropdown-spacer)}.climb-jupyter .dropstart .dropdown-toggle:after{display:inline-block;margin-left:.255em;vertical-align:.255em;content:\"\"}.climb-jupyter .dropstart .dropdown-toggle:after{display:none}.climb-jupyter .dropstart .dropdown-toggle:before{display:inline-block;margin-right:.255em;vertical-align:.255em;content:\"\";border-top:.3em solid transparent;border-right:.3em solid;border-bottom:.3em solid transparent}.climb-jupyter .dropstart .dropdown-toggle:empty:after{margin-left:0}.climb-jupyter .dropstart .dropdown-toggle:before{vertical-align:0}.climb-jupyter .dropdown-divider{height:0;margin:var(--bs-dropdown-divider-margin-y) 0;overflow:hidden;border-top:1px solid var(--bs-dropdown-divider-bg);opacity:1}.climb-jupyter .dropdown-item{display:block;width:100%;padding:var(--bs-dropdown-item-padding-y) var(--bs-dropdown-item-padding-x);clear:both;font-weight:400;color:var(--bs-dropdown-link-color);text-align:inherit;text-decoration:none;white-space:nowrap;background-color:transparent;border:0;border-radius:var(--bs-dropdown-item-border-radius, 0)}.climb-jupyter .dropdown-item:hover,.climb-jupyter .dropdown-item:focus{color:var(--bs-dropdown-link-hover-color);background-color:var(--bs-dropdown-link-hover-bg)}.climb-jupyter .dropdown-item.active,.climb-jupyter .dropdown-item:active{color:var(--bs-dropdown-link-active-color);text-decoration:none;background-color:var(--bs-dropdown-link-active-bg)}.climb-jupyter .dropdown-item.disabled,.climb-jupyter .dropdown-item:disabled{color:var(--bs-dropdown-link-disabled-color);pointer-events:none;background-color:transparent}.climb-jupyter .dropdown-menu.show{display:block}.climb-jupyter .dropdown-header{display:block;padding:var(--bs-dropdown-header-padding-y) var(--bs-dropdown-header-padding-x);margin-bottom:0;font-size:.875rem;color:var(--bs-dropdown-header-color);white-space:nowrap}.climb-jupyter .dropdown-item-text{display:block;padding:var(--bs-dropdown-item-padding-y) var(--bs-dropdown-item-padding-x);color:var(--bs-dropdown-link-color)}.climb-jupyter .dropdown-menu-dark{--bs-dropdown-color: #dee2e6;--bs-dropdown-bg: #343a40;--bs-dropdown-border-color: var(--bs-border-color-translucent);--bs-dropdown-box-shadow: ;--bs-dropdown-link-color: #dee2e6;--bs-dropdown-link-hover-color: #fff;--bs-dropdown-divider-bg: var(--bs-border-color-translucent);--bs-dropdown-link-hover-bg: rgba(255, 255, 255, .15);--bs-dropdown-link-active-color: #fff;--bs-dropdown-link-active-bg: #0d6efd;--bs-dropdown-link-disabled-color: #adb5bd;--bs-dropdown-header-color: #adb5bd}.climb-jupyter .btn-group,.climb-jupyter .btn-group-vertical{position:relative;display:inline-flex;vertical-align:middle}.climb-jupyter .btn-group>.btn,.climb-jupyter .btn-group-vertical>.btn{position:relative;flex:1 1 auto}.climb-jupyter .btn-group>.btn-check:checked+.btn,.climb-jupyter .btn-group>.btn-check:focus+.btn,.climb-jupyter .btn-group>.btn:hover,.climb-jupyter .btn-group>.btn:focus,.climb-jupyter .btn-group>.btn:active,.climb-jupyter .btn-group>.btn.active,.climb-jupyter .btn-group-vertical>.btn-check:checked+.btn,.climb-jupyter .btn-group-vertical>.btn-check:focus+.btn,.climb-jupyter .btn-group-vertical>.btn:hover,.climb-jupyter .btn-group-vertical>.btn:focus,.climb-jupyter .btn-group-vertical>.btn:active,.climb-jupyter .btn-group-vertical>.btn.active{z-index:1}.climb-jupyter .btn-toolbar{display:flex;flex-wrap:wrap;justify-content:flex-start}.climb-jupyter .btn-toolbar .input-group{width:auto}.climb-jupyter .btn-group{border-radius:var(--bs-border-radius)}.climb-jupyter .btn-group>:not(.btn-check:first-child)+.btn,.climb-jupyter .btn-group>.btn-group:not(:first-child){margin-left:calc(-1 * var(--bs-border-width))}.climb-jupyter .btn-group>.btn:not(:last-child):not(.dropdown-toggle),.climb-jupyter .btn-group>.btn.dropdown-toggle-split:first-child,.climb-jupyter .btn-group>.btn-group:not(:last-child)>.btn{border-top-right-radius:0;border-bottom-right-radius:0}.climb-jupyter .btn-group>.btn:nth-child(n+3),.climb-jupyter .btn-group>:not(.btn-check)+.btn,.climb-jupyter .btn-group>.btn-group:not(:first-child)>.btn{border-top-left-radius:0;border-bottom-left-radius:0}.climb-jupyter .dropdown-toggle-split{padding-right:.5625rem;padding-left:.5625rem}.climb-jupyter .dropdown-toggle-split:after,.dropup .climb-jupyter .dropdown-toggle-split:after,.dropend .climb-jupyter .dropdown-toggle-split:after{margin-left:0}.dropstart .climb-jupyter .dropdown-toggle-split:before{margin-right:0}.climb-jupyter .btn-sm+.dropdown-toggle-split,.climb-jupyter .btn-group-sm>.btn+.dropdown-toggle-split{padding-right:.375rem;padding-left:.375rem}.climb-jupyter .btn-lg+.dropdown-toggle-split,.climb-jupyter .btn-group-lg>.btn+.dropdown-toggle-split{padding-right:.75rem;padding-left:.75rem}.climb-jupyter .btn-group-vertical{flex-direction:column;align-items:flex-start;justify-content:center}.climb-jupyter .btn-group-vertical>.btn,.climb-jupyter .btn-group-vertical>.btn-group{width:100%}.climb-jupyter .btn-group-vertical>.btn:not(:first-child),.climb-jupyter .btn-group-vertical>.btn-group:not(:first-child){margin-top:calc(-1 * var(--bs-border-width))}.climb-jupyter .btn-group-vertical>.btn:not(:last-child):not(.dropdown-toggle),.climb-jupyter .btn-group-vertical>.btn-group:not(:last-child)>.btn{border-bottom-right-radius:0;border-bottom-left-radius:0}.climb-jupyter .btn-group-vertical>.btn:nth-child(n+3),.climb-jupyter .btn-group-vertical>:not(.btn-check)+.btn,.climb-jupyter .btn-group-vertical>.btn-group:not(:first-child)>.btn{border-top-left-radius:0;border-top-right-radius:0}.climb-jupyter .nav{--bs-nav-link-padding-x: 1rem;--bs-nav-link-padding-y: .5rem;--bs-nav-link-font-weight: ;--bs-nav-link-color: var(--bs-link-color);--bs-nav-link-hover-color: var(--bs-link-hover-color);--bs-nav-link-disabled-color: var(--bs-secondary-color);display:flex;flex-wrap:wrap;padding-left:0;margin-bottom:0;list-style:none}.climb-jupyter .nav-link{display:block;padding:var(--bs-nav-link-padding-y) var(--bs-nav-link-padding-x);font-size:var(--bs-nav-link-font-size);font-weight:var(--bs-nav-link-font-weight);color:var(--bs-nav-link-color);text-decoration:none;background:none;border:0;transition:color .15s ease-in-out,background-color .15s ease-in-out,border-color .15s ease-in-out}@media (prefers-reduced-motion: reduce){.climb-jupyter .nav-link{transition:none}}.climb-jupyter .nav-link:hover,.climb-jupyter .nav-link:focus{color:var(--bs-nav-link-hover-color)}.climb-jupyter .nav-link:focus-visible{outline:0;box-shadow:0 0 0 .25rem #0d6efd40}.climb-jupyter .nav-link.disabled,.climb-jupyter .nav-link:disabled{color:var(--bs-nav-link-disabled-color);pointer-events:none;cursor:default}.climb-jupyter .nav-tabs{--bs-nav-tabs-border-width: var(--bs-border-width);--bs-nav-tabs-border-color: var(--bs-border-color);--bs-nav-tabs-border-radius: var(--bs-border-radius);--bs-nav-tabs-link-hover-border-color: var(--bs-secondary-bg) var(--bs-secondary-bg) var(--bs-border-color);--bs-nav-tabs-link-active-color: var(--bs-emphasis-color);--bs-nav-tabs-link-active-bg: var(--bs-body-bg);--bs-nav-tabs-link-active-border-color: var(--bs-border-color) var(--bs-border-color) var(--bs-body-bg);border-bottom:var(--bs-nav-tabs-border-width) solid var(--bs-nav-tabs-border-color)}.climb-jupyter .nav-tabs .nav-link{margin-bottom:calc(-1 * var(--bs-nav-tabs-border-width));border:var(--bs-nav-tabs-border-width) solid transparent;border-top-left-radius:var(--bs-nav-tabs-border-radius);border-top-right-radius:var(--bs-nav-tabs-border-radius)}.climb-jupyter .nav-tabs .nav-link:hover,.climb-jupyter .nav-tabs .nav-link:focus{isolation:isolate;border-color:var(--bs-nav-tabs-link-hover-border-color)}.climb-jupyter .nav-tabs .nav-link.active,.climb-jupyter .nav-tabs .nav-item.show .nav-link{color:var(--bs-nav-tabs-link-active-color);background-color:var(--bs-nav-tabs-link-active-bg);border-color:var(--bs-nav-tabs-link-active-border-color)}.climb-jupyter .nav-tabs .dropdown-menu{margin-top:calc(-1 * var(--bs-nav-tabs-border-width));border-top-left-radius:0;border-top-right-radius:0}.climb-jupyter .nav-pills{--bs-nav-pills-border-radius: var(--bs-border-radius);--bs-nav-pills-link-active-color: #fff;--bs-nav-pills-link-active-bg: #0d6efd}.climb-jupyter .nav-pills .nav-link{border-radius:var(--bs-nav-pills-border-radius)}.climb-jupyter .nav-pills .nav-link.active,.climb-jupyter .nav-pills .show>.nav-link{color:var(--bs-nav-pills-link-active-color);background-color:var(--bs-nav-pills-link-active-bg)}.climb-jupyter .nav-underline{--bs-nav-underline-gap: 1rem;--bs-nav-underline-border-width: .125rem;--bs-nav-underline-link-active-color: var(--bs-emphasis-color);gap:var(--bs-nav-underline-gap)}.climb-jupyter .nav-underline .nav-link{padding-right:0;padding-left:0;border-bottom:var(--bs-nav-underline-border-width) solid transparent}.climb-jupyter .nav-underline .nav-link:hover,.climb-jupyter .nav-underline .nav-link:focus{border-bottom-color:currentcolor}.climb-jupyter .nav-underline .nav-link.active,.climb-jupyter .nav-underline .show>.nav-link{font-weight:700;color:var(--bs-nav-underline-link-active-color);border-bottom-color:currentcolor}.climb-jupyter .nav-fill>.nav-link,.climb-jupyter .nav-fill .nav-item{flex:1 1 auto;text-align:center}.climb-jupyter .nav-justified>.nav-link,.climb-jupyter .nav-justified .nav-item{flex-grow:1;flex-basis:0;text-align:center}.climb-jupyter .nav-fill .nav-item .nav-link,.climb-jupyter .nav-justified .nav-item .nav-link{width:100%}.climb-jupyter .tab-content>.tab-pane{display:none}.climb-jupyter .tab-content>.active{display:block}.climb-jupyter .navbar{--bs-navbar-padding-x: 0;--bs-navbar-padding-y: .5rem;--bs-navbar-color: rgba(var(--bs-emphasis-color-rgb), .65);--bs-navbar-hover-color: rgba(var(--bs-emphasis-color-rgb), .8);--bs-navbar-disabled-color: rgba(var(--bs-emphasis-color-rgb), .3);--bs-navbar-active-color: rgba(var(--bs-emphasis-color-rgb), 1);--bs-navbar-brand-padding-y: .3125rem;--bs-navbar-brand-margin-end: 1rem;--bs-navbar-brand-font-size: 1.25rem;--bs-navbar-brand-color: rgba(var(--bs-emphasis-color-rgb), 1);--bs-navbar-brand-hover-color: rgba(var(--bs-emphasis-color-rgb), 1);--bs-navbar-nav-link-padding-x: .5rem;--bs-navbar-toggler-padding-y: .25rem;--bs-navbar-toggler-padding-x: .75rem;--bs-navbar-toggler-font-size: 1.25rem;--bs-navbar-toggler-icon-bg: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 30 30'%3e%3cpath stroke='rgba%2833, 37, 41, 0.75%29' stroke-linecap='round' stroke-miterlimit='10' stroke-width='2' d='M4 7h22M4 15h22M4 23h22'/%3e%3c/svg%3e\");--bs-navbar-toggler-border-color: rgba(var(--bs-emphasis-color-rgb), .15);--bs-navbar-toggler-border-radius: var(--bs-border-radius);--bs-navbar-toggler-focus-width: .25rem;--bs-navbar-toggler-transition: box-shadow .15s ease-in-out;position:relative;display:flex;flex-wrap:wrap;align-items:center;justify-content:space-between;padding:var(--bs-navbar-padding-y) var(--bs-navbar-padding-x)}.climb-jupyter .navbar>.container,.climb-jupyter .navbar>.container-fluid,.climb-jupyter .navbar>.container-sm,.climb-jupyter .navbar>.container-md,.climb-jupyter .navbar>.container-lg,.climb-jupyter .navbar>.container-xl,.climb-jupyter .navbar>.container-xxl{display:flex;flex-wrap:inherit;align-items:center;justify-content:space-between}.climb-jupyter .navbar-brand{padding-top:var(--bs-navbar-brand-padding-y);padding-bottom:var(--bs-navbar-brand-padding-y);margin-right:var(--bs-navbar-brand-margin-end);font-size:var(--bs-navbar-brand-font-size);color:var(--bs-navbar-brand-color);text-decoration:none;white-space:nowrap}.climb-jupyter .navbar-brand:hover,.climb-jupyter .navbar-brand:focus{color:var(--bs-navbar-brand-hover-color)}.climb-jupyter .navbar-nav{--bs-nav-link-padding-x: 0;--bs-nav-link-padding-y: .5rem;--bs-nav-link-font-weight: ;--bs-nav-link-color: var(--bs-navbar-color);--bs-nav-link-hover-color: var(--bs-navbar-hover-color);--bs-nav-link-disabled-color: var(--bs-navbar-disabled-color);display:flex;flex-direction:column;padding-left:0;margin-bottom:0;list-style:none}.climb-jupyter .navbar-nav .nav-link.active,.climb-jupyter .navbar-nav .nav-link.show{color:var(--bs-navbar-active-color)}.climb-jupyter .navbar-nav .dropdown-menu{position:static}.climb-jupyter .navbar-text{padding-top:.5rem;padding-bottom:.5rem;color:var(--bs-navbar-color)}.climb-jupyter .navbar-text a,.climb-jupyter .navbar-text a:hover,.climb-jupyter .navbar-text a:focus{color:var(--bs-navbar-active-color)}.climb-jupyter .navbar-collapse{flex-grow:1;flex-basis:100%;align-items:center}.climb-jupyter .navbar-toggler{padding:var(--bs-navbar-toggler-padding-y) var(--bs-navbar-toggler-padding-x);font-size:var(--bs-navbar-toggler-font-size);line-height:1;color:var(--bs-navbar-color);background-color:transparent;border:var(--bs-border-width) solid var(--bs-navbar-toggler-border-color);border-radius:var(--bs-navbar-toggler-border-radius);transition:var(--bs-navbar-toggler-transition)}@media (prefers-reduced-motion: reduce){.climb-jupyter .navbar-toggler{transition:none}}.climb-jupyter .navbar-toggler:hover{text-decoration:none}.climb-jupyter .navbar-toggler:focus{text-decoration:none;outline:0;box-shadow:0 0 0 var(--bs-navbar-toggler-focus-width)}.climb-jupyter .navbar-toggler-icon{display:inline-block;width:1.5em;height:1.5em;vertical-align:middle;background-image:var(--bs-navbar-toggler-icon-bg);background-repeat:no-repeat;background-position:center;background-size:100%}.climb-jupyter .navbar-nav-scroll{max-height:var(--bs-scroll-height, 75vh);overflow-y:auto}@media (min-width: 576px){.climb-jupyter .navbar-expand-sm{flex-wrap:nowrap;justify-content:flex-start}.climb-jupyter .navbar-expand-sm .navbar-nav{flex-direction:row}.climb-jupyter .navbar-expand-sm .navbar-nav .dropdown-menu{position:absolute}.climb-jupyter .navbar-expand-sm .navbar-nav .nav-link{padding-right:var(--bs-navbar-nav-link-padding-x);padding-left:var(--bs-navbar-nav-link-padding-x)}.climb-jupyter .navbar-expand-sm .navbar-nav-scroll{overflow:visible}.climb-jupyter .navbar-expand-sm .navbar-collapse{display:flex!important;flex-basis:auto}.climb-jupyter .navbar-expand-sm .navbar-toggler{display:none}.climb-jupyter .navbar-expand-sm .offcanvas{position:static;z-index:auto;flex-grow:1;width:auto!important;height:auto!important;visibility:visible!important;background-color:transparent!important;border:0!important;transform:none!important;transition:none}.climb-jupyter .navbar-expand-sm .offcanvas .offcanvas-header{display:none}.climb-jupyter .navbar-expand-sm .offcanvas .offcanvas-body{display:flex;flex-grow:0;padding:0;overflow-y:visible}}@media (min-width: 768px){.climb-jupyter .navbar-expand-md{flex-wrap:nowrap;justify-content:flex-start}.climb-jupyter .navbar-expand-md .navbar-nav{flex-direction:row}.climb-jupyter .navbar-expand-md .navbar-nav .dropdown-menu{position:absolute}.climb-jupyter .navbar-expand-md .navbar-nav .nav-link{padding-right:var(--bs-navbar-nav-link-padding-x);padding-left:var(--bs-navbar-nav-link-padding-x)}.climb-jupyter .navbar-expand-md .navbar-nav-scroll{overflow:visible}.climb-jupyter .navbar-expand-md .navbar-collapse{display:flex!important;flex-basis:auto}.climb-jupyter .navbar-expand-md .navbar-toggler{display:none}.climb-jupyter .navbar-expand-md .offcanvas{position:static;z-index:auto;flex-grow:1;width:auto!important;height:auto!important;visibility:visible!important;background-color:transparent!important;border:0!important;transform:none!important;transition:none}.climb-jupyter .navbar-expand-md .offcanvas .offcanvas-header{display:none}.climb-jupyter .navbar-expand-md .offcanvas .offcanvas-body{display:flex;flex-grow:0;padding:0;overflow-y:visible}}@media (min-width: 992px){.climb-jupyter .navbar-expand-lg{flex-wrap:nowrap;justify-content:flex-start}.climb-jupyter .navbar-expand-lg .navbar-nav{flex-direction:row}.climb-jupyter .navbar-expand-lg .navbar-nav .dropdown-menu{position:absolute}.climb-jupyter .navbar-expand-lg .navbar-nav .nav-link{padding-right:var(--bs-navbar-nav-link-padding-x);padding-left:var(--bs-navbar-nav-link-padding-x)}.climb-jupyter .navbar-expand-lg .navbar-nav-scroll{overflow:visible}.climb-jupyter .navbar-expand-lg .navbar-collapse{display:flex!important;flex-basis:auto}.climb-jupyter .navbar-expand-lg .navbar-toggler{display:none}.climb-jupyter .navbar-expand-lg .offcanvas{position:static;z-index:auto;flex-grow:1;width:auto!important;height:auto!important;visibility:visible!important;background-color:transparent!important;border:0!important;transform:none!important;transition:none}.climb-jupyter .navbar-expand-lg .offcanvas .offcanvas-header{display:none}.climb-jupyter .navbar-expand-lg .offcanvas .offcanvas-body{display:flex;flex-grow:0;padding:0;overflow-y:visible}}@media (min-width: 1200px){.climb-jupyter .navbar-expand-xl{flex-wrap:nowrap;justify-content:flex-start}.climb-jupyter .navbar-expand-xl .navbar-nav{flex-direction:row}.climb-jupyter .navbar-expand-xl .navbar-nav .dropdown-menu{position:absolute}.climb-jupyter .navbar-expand-xl .navbar-nav .nav-link{padding-right:var(--bs-navbar-nav-link-padding-x);padding-left:var(--bs-navbar-nav-link-padding-x)}.climb-jupyter .navbar-expand-xl .navbar-nav-scroll{overflow:visible}.climb-jupyter .navbar-expand-xl .navbar-collapse{display:flex!important;flex-basis:auto}.climb-jupyter .navbar-expand-xl .navbar-toggler{display:none}.climb-jupyter .navbar-expand-xl .offcanvas{position:static;z-index:auto;flex-grow:1;width:auto!important;height:auto!important;visibility:visible!important;background-color:transparent!important;border:0!important;transform:none!important;transition:none}.climb-jupyter .navbar-expand-xl .offcanvas .offcanvas-header{display:none}.climb-jupyter .navbar-expand-xl .offcanvas .offcanvas-body{display:flex;flex-grow:0;padding:0;overflow-y:visible}}@media (min-width: 1400px){.climb-jupyter .navbar-expand-xxl{flex-wrap:nowrap;justify-content:flex-start}.climb-jupyter .navbar-expand-xxl .navbar-nav{flex-direction:row}.climb-jupyter .navbar-expand-xxl .navbar-nav .dropdown-menu{position:absolute}.climb-jupyter .navbar-expand-xxl .navbar-nav .nav-link{padding-right:var(--bs-navbar-nav-link-padding-x);padding-left:var(--bs-navbar-nav-link-padding-x)}.climb-jupyter .navbar-expand-xxl .navbar-nav-scroll{overflow:visible}.climb-jupyter .navbar-expand-xxl .navbar-collapse{display:flex!important;flex-basis:auto}.climb-jupyter .navbar-expand-xxl .navbar-toggler{display:none}.climb-jupyter .navbar-expand-xxl .offcanvas{position:static;z-index:auto;flex-grow:1;width:auto!important;height:auto!important;visibility:visible!important;background-color:transparent!important;border:0!important;transform:none!important;transition:none}.climb-jupyter .navbar-expand-xxl .offcanvas .offcanvas-header{display:none}.climb-jupyter .navbar-expand-xxl .offcanvas .offcanvas-body{display:flex;flex-grow:0;padding:0;overflow-y:visible}}.climb-jupyter .navbar-expand{flex-wrap:nowrap;justify-content:flex-start}.climb-jupyter .navbar-expand .navbar-nav{flex-direction:row}.climb-jupyter .navbar-expand .navbar-nav .dropdown-menu{position:absolute}.climb-jupyter .navbar-expand .navbar-nav .nav-link{padding-right:var(--bs-navbar-nav-link-padding-x);padding-left:var(--bs-navbar-nav-link-padding-x)}.climb-jupyter .navbar-expand .navbar-nav-scroll{overflow:visible}.climb-jupyter .navbar-expand .navbar-collapse{display:flex!important;flex-basis:auto}.climb-jupyter .navbar-expand .navbar-toggler{display:none}.climb-jupyter .navbar-expand .offcanvas{position:static;z-index:auto;flex-grow:1;width:auto!important;height:auto!important;visibility:visible!important;background-color:transparent!important;border:0!important;transform:none!important;transition:none}.climb-jupyter .navbar-expand .offcanvas .offcanvas-header{display:none}.climb-jupyter .navbar-expand .offcanvas .offcanvas-body{display:flex;flex-grow:0;padding:0;overflow-y:visible}.climb-jupyter .navbar-dark,.climb-jupyter .navbar[data-bs-theme=dark]{--bs-navbar-color: rgba(255, 255, 255, .55);--bs-navbar-hover-color: rgba(255, 255, 255, .75);--bs-navbar-disabled-color: rgba(255, 255, 255, .25);--bs-navbar-active-color: #fff;--bs-navbar-brand-color: #fff;--bs-navbar-brand-hover-color: #fff;--bs-navbar-toggler-border-color: rgba(255, 255, 255, .1);--bs-navbar-toggler-icon-bg: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 30 30'%3e%3cpath stroke='rgba%28255, 255, 255, 0.55%29' stroke-linecap='round' stroke-miterlimit='10' stroke-width='2' d='M4 7h22M4 15h22M4 23h22'/%3e%3c/svg%3e\")}.climb-jupyter [data-bs-theme=dark] .navbar-toggler-icon{--bs-navbar-toggler-icon-bg: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 30 30'%3e%3cpath stroke='rgba%28255, 255, 255, 0.55%29' stroke-linecap='round' stroke-miterlimit='10' stroke-width='2' d='M4 7h22M4 15h22M4 23h22'/%3e%3c/svg%3e\")}.climb-jupyter .card{--bs-card-spacer-y: 1rem;--bs-card-spacer-x: 1rem;--bs-card-title-spacer-y: .5rem;--bs-card-title-color: ;--bs-card-subtitle-color: ;--bs-card-border-width: var(--bs-border-width);--bs-card-border-color: var(--bs-border-color-translucent);--bs-card-border-radius: var(--bs-border-radius);--bs-card-box-shadow: ;--bs-card-inner-border-radius: calc(var(--bs-border-radius) - (var(--bs-border-width)));--bs-card-cap-padding-y: .5rem;--bs-card-cap-padding-x: 1rem;--bs-card-cap-bg: rgba(var(--bs-body-color-rgb), .03);--bs-card-cap-color: ;--bs-card-height: ;--bs-card-color: ;--bs-card-bg: var(--bs-body-bg);--bs-card-img-overlay-padding: 1rem;--bs-card-group-margin: .75rem;position:relative;display:flex;flex-direction:column;min-width:0;height:var(--bs-card-height);color:var(--bs-body-color);word-wrap:break-word;background-color:var(--bs-card-bg);background-clip:border-box;border:var(--bs-card-border-width) solid var(--bs-card-border-color);border-radius:var(--bs-card-border-radius)}.climb-jupyter .card>hr{margin-right:0;margin-left:0}.climb-jupyter .card>.list-group{border-top:inherit;border-bottom:inherit}.climb-jupyter .card>.list-group:first-child{border-top-width:0;border-top-left-radius:var(--bs-card-inner-border-radius);border-top-right-radius:var(--bs-card-inner-border-radius)}.climb-jupyter .card>.list-group:last-child{border-bottom-width:0;border-bottom-right-radius:var(--bs-card-inner-border-radius);border-bottom-left-radius:var(--bs-card-inner-border-radius)}.climb-jupyter .card>.card-header+.list-group,.climb-jupyter .card>.list-group+.card-footer{border-top:0}.climb-jupyter .card-body{flex:1 1 auto;padding:var(--bs-card-spacer-y) var(--bs-card-spacer-x);color:var(--bs-card-color)}.climb-jupyter .card-title{margin-bottom:var(--bs-card-title-spacer-y);color:var(--bs-card-title-color)}.climb-jupyter .card-subtitle{margin-top:calc(-.5 * var(--bs-card-title-spacer-y));margin-bottom:0;color:var(--bs-card-subtitle-color)}.climb-jupyter .card-text:last-child{margin-bottom:0}.climb-jupyter .card-link+.card-link{margin-left:var(--bs-card-spacer-x)}.climb-jupyter .card-header{padding:var(--bs-card-cap-padding-y) var(--bs-card-cap-padding-x);margin-bottom:0;color:var(--bs-card-cap-color);background-color:var(--bs-card-cap-bg);border-bottom:var(--bs-card-border-width) solid var(--bs-card-border-color)}.climb-jupyter .card-header:first-child{border-radius:var(--bs-card-inner-border-radius) var(--bs-card-inner-border-radius) 0 0}.climb-jupyter .card-footer{padding:var(--bs-card-cap-padding-y) var(--bs-card-cap-padding-x);color:var(--bs-card-cap-color);background-color:var(--bs-card-cap-bg);border-top:var(--bs-card-border-width) solid var(--bs-card-border-color)}.climb-jupyter .card-footer:last-child{border-radius:0 0 var(--bs-card-inner-border-radius) var(--bs-card-inner-border-radius)}.climb-jupyter .card-header-tabs{margin-right:calc(-.5 * var(--bs-card-cap-padding-x));margin-bottom:calc(-1 * var(--bs-card-cap-padding-y));margin-left:calc(-.5 * var(--bs-card-cap-padding-x));border-bottom:0}.climb-jupyter .card-header-tabs .nav-link.active{background-color:var(--bs-card-bg);border-bottom-color:var(--bs-card-bg)}.climb-jupyter .card-header-pills{margin-right:calc(-.5 * var(--bs-card-cap-padding-x));margin-left:calc(-.5 * var(--bs-card-cap-padding-x))}.climb-jupyter .card-img-overlay{position:absolute;top:0;right:0;bottom:0;left:0;padding:var(--bs-card-img-overlay-padding);border-radius:var(--bs-card-inner-border-radius)}.climb-jupyter .card-img,.climb-jupyter .card-img-top,.climb-jupyter .card-img-bottom{width:100%}.climb-jupyter .card-img,.climb-jupyter .card-img-top{border-top-left-radius:var(--bs-card-inner-border-radius);border-top-right-radius:var(--bs-card-inner-border-radius)}.climb-jupyter .card-img,.climb-jupyter .card-img-bottom{border-bottom-right-radius:var(--bs-card-inner-border-radius);border-bottom-left-radius:var(--bs-card-inner-border-radius)}.climb-jupyter .card-group>.card{margin-bottom:var(--bs-card-group-margin)}@media (min-width: 576px){.climb-jupyter .card-group{display:flex;flex-flow:row wrap}.climb-jupyter .card-group>.card{flex:1 0 0;margin-bottom:0}.climb-jupyter .card-group>.card+.card{margin-left:0;border-left:0}.climb-jupyter .card-group>.card:not(:last-child){border-top-right-radius:0;border-bottom-right-radius:0}.climb-jupyter .card-group>.card:not(:last-child)>.card-img-top,.climb-jupyter .card-group>.card:not(:last-child)>.card-header{border-top-right-radius:0}.climb-jupyter .card-group>.card:not(:last-child)>.card-img-bottom,.climb-jupyter .card-group>.card:not(:last-child)>.card-footer{border-bottom-right-radius:0}.climb-jupyter .card-group>.card:not(:first-child){border-top-left-radius:0;border-bottom-left-radius:0}.climb-jupyter .card-group>.card:not(:first-child)>.card-img-top,.climb-jupyter .card-group>.card:not(:first-child)>.card-header{border-top-left-radius:0}.climb-jupyter .card-group>.card:not(:first-child)>.card-img-bottom,.climb-jupyter .card-group>.card:not(:first-child)>.card-footer{border-bottom-left-radius:0}}.climb-jupyter .accordion{--bs-accordion-color: var(--bs-body-color);--bs-accordion-bg: var(--bs-body-bg);--bs-accordion-transition: color .15s ease-in-out, background-color .15s ease-in-out, border-color .15s ease-in-out, box-shadow .15s ease-in-out, border-radius .15s ease;--bs-accordion-border-color: var(--bs-border-color);--bs-accordion-border-width: var(--bs-border-width);--bs-accordion-border-radius: var(--bs-border-radius);--bs-accordion-inner-border-radius: calc(var(--bs-border-radius) - (var(--bs-border-width)));--bs-accordion-btn-padding-x: 1.25rem;--bs-accordion-btn-padding-y: 1rem;--bs-accordion-btn-color: var(--bs-body-color);--bs-accordion-btn-bg: var(--bs-accordion-bg);--bs-accordion-btn-icon: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='none' stroke='%23212529' stroke-linecap='round' stroke-linejoin='round'%3e%3cpath d='m2 5 6 6 6-6'/%3e%3c/svg%3e\");--bs-accordion-btn-icon-width: 1.25rem;--bs-accordion-btn-icon-transform: rotate(-180deg);--bs-accordion-btn-icon-transition: transform .2s ease-in-out;--bs-accordion-btn-active-icon: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='none' stroke='rgb%285.2, 44, 101.2%29' stroke-linecap='round' stroke-linejoin='round'%3e%3cpath d='m2 5 6 6 6-6'/%3e%3c/svg%3e\");--bs-accordion-btn-focus-box-shadow: 0 0 0 .25rem rgba(13, 110, 253, .25);--bs-accordion-body-padding-x: 1.25rem;--bs-accordion-body-padding-y: 1rem;--bs-accordion-active-color: var(--bs-primary-text-emphasis);--bs-accordion-active-bg: var(--bs-primary-bg-subtle)}.climb-jupyter .accordion-button{position:relative;display:flex;align-items:center;width:100%;padding:var(--bs-accordion-btn-padding-y) var(--bs-accordion-btn-padding-x);font-size:1rem;color:var(--bs-accordion-btn-color);text-align:left;background-color:var(--bs-accordion-btn-bg);border:0;border-radius:0;overflow-anchor:none;transition:var(--bs-accordion-transition)}@media (prefers-reduced-motion: reduce){.climb-jupyter .accordion-button{transition:none}}.climb-jupyter .accordion-button:not(.collapsed){color:var(--bs-accordion-active-color);background-color:var(--bs-accordion-active-bg);box-shadow:inset 0 calc(-1 * var(--bs-accordion-border-width)) 0 var(--bs-accordion-border-color)}.climb-jupyter .accordion-button:not(.collapsed):after{background-image:var(--bs-accordion-btn-active-icon);transform:var(--bs-accordion-btn-icon-transform)}.climb-jupyter .accordion-button:after{flex-shrink:0;width:var(--bs-accordion-btn-icon-width);height:var(--bs-accordion-btn-icon-width);margin-left:auto;content:\"\";background-image:var(--bs-accordion-btn-icon);background-repeat:no-repeat;background-size:var(--bs-accordion-btn-icon-width);transition:var(--bs-accordion-btn-icon-transition)}@media (prefers-reduced-motion: reduce){.climb-jupyter .accordion-button:after{transition:none}}.climb-jupyter .accordion-button:hover{z-index:2}.climb-jupyter .accordion-button:focus{z-index:3;outline:0;box-shadow:var(--bs-accordion-btn-focus-box-shadow)}.climb-jupyter .accordion-header{margin-bottom:0}.climb-jupyter .accordion-item{color:var(--bs-accordion-color);background-color:var(--bs-accordion-bg);border:var(--bs-accordion-border-width) solid var(--bs-accordion-border-color)}.climb-jupyter .accordion-item:first-of-type{border-top-left-radius:var(--bs-accordion-border-radius);border-top-right-radius:var(--bs-accordion-border-radius)}.climb-jupyter .accordion-item:first-of-type>.accordion-header .accordion-button{border-top-left-radius:var(--bs-accordion-inner-border-radius);border-top-right-radius:var(--bs-accordion-inner-border-radius)}.climb-jupyter .accordion-item:not(:first-of-type){border-top:0}.climb-jupyter .accordion-item:last-of-type{border-bottom-right-radius:var(--bs-accordion-border-radius);border-bottom-left-radius:var(--bs-accordion-border-radius)}.climb-jupyter .accordion-item:last-of-type>.accordion-header .accordion-button.collapsed{border-bottom-right-radius:var(--bs-accordion-inner-border-radius);border-bottom-left-radius:var(--bs-accordion-inner-border-radius)}.climb-jupyter .accordion-item:last-of-type>.accordion-collapse{border-bottom-right-radius:var(--bs-accordion-border-radius);border-bottom-left-radius:var(--bs-accordion-border-radius)}.climb-jupyter .accordion-body{padding:var(--bs-accordion-body-padding-y) var(--bs-accordion-body-padding-x)}.climb-jupyter .accordion-flush>.accordion-item{border-right:0;border-left:0;border-radius:0}.climb-jupyter .accordion-flush>.accordion-item:first-child{border-top:0}.climb-jupyter .accordion-flush>.accordion-item:last-child{border-bottom:0}.climb-jupyter .accordion-flush>.accordion-item>.accordion-collapse,.climb-jupyter .accordion-flush>.accordion-item>.accordion-header .accordion-button,.climb-jupyter .accordion-flush>.accordion-item>.accordion-header .accordion-button.collapsed{border-radius:0}.climb-jupyter [data-bs-theme=dark] .accordion-button:after{--bs-accordion-btn-icon: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='rgb%28109.8, 168, 253.8%29'%3e%3cpath fill-rule='evenodd' d='M1.646 4.646a.5.5 0 0 1 .708 0L8 10.293l5.646-5.647a.5.5 0 0 1 .708.708l-6 6a.5.5 0 0 1-.708 0l-6-6a.5.5 0 0 1 0-.708'/%3e%3c/svg%3e\");--bs-accordion-btn-active-icon: url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='rgb%28109.8, 168, 253.8%29'%3e%3cpath fill-rule='evenodd' d='M1.646 4.646a.5.5 0 0 1 .708 0L8 10.293l5.646-5.647a.5.5 0 0 1 .708.708l-6 6a.5.5 0 0 1-.708 0l-6-6a.5.5 0 0 1 0-.708'/%3e%3c/svg%3e\")}.climb-jupyter .pagination{--bs-pagination-padding-x: .75rem;--bs-pagination-padding-y: .375rem;--bs-pagination-font-size: 1rem;--bs-pagination-color: var(--bs-link-color);--bs-pagination-bg: var(--bs-body-bg);--bs-pagination-border-width: var(--bs-border-width);--bs-pagination-border-color: var(--bs-border-color);--bs-pagination-border-radius: var(--bs-border-radius);--bs-pagination-hover-color: var(--bs-link-hover-color);--bs-pagination-hover-bg: var(--bs-tertiary-bg);--bs-pagination-hover-border-color: var(--bs-border-color);--bs-pagination-focus-color: var(--bs-link-hover-color);--bs-pagination-focus-bg: var(--bs-secondary-bg);--bs-pagination-focus-box-shadow: 0 0 0 .25rem rgba(13, 110, 253, .25);--bs-pagination-active-color: #fff;--bs-pagination-active-bg: #0d6efd;--bs-pagination-active-border-color: #0d6efd;--bs-pagination-disabled-color: var(--bs-secondary-color);--bs-pagination-disabled-bg: var(--bs-secondary-bg);--bs-pagination-disabled-border-color: var(--bs-border-color);display:flex;padding-left:0;list-style:none}.climb-jupyter .page-link{position:relative;display:block;padding:var(--bs-pagination-padding-y) var(--bs-pagination-padding-x);font-size:var(--bs-pagination-font-size);color:var(--bs-pagination-color);text-decoration:none;background-color:var(--bs-pagination-bg);border:var(--bs-pagination-border-width) solid var(--bs-pagination-border-color);transition:color .15s ease-in-out,background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out}@media (prefers-reduced-motion: reduce){.climb-jupyter .page-link{transition:none}}.climb-jupyter .page-link:hover{z-index:2;color:var(--bs-pagination-hover-color);background-color:var(--bs-pagination-hover-bg);border-color:var(--bs-pagination-hover-border-color)}.climb-jupyter .page-link:focus{z-index:3;color:var(--bs-pagination-focus-color);background-color:var(--bs-pagination-focus-bg);outline:0;box-shadow:var(--bs-pagination-focus-box-shadow)}.climb-jupyter .page-link.active,.active>.climb-jupyter .page-link{z-index:3;color:var(--bs-pagination-active-color);background-color:var(--bs-pagination-active-bg);border-color:var(--bs-pagination-active-border-color)}.climb-jupyter .page-link.disabled,.disabled>.climb-jupyter .page-link{color:var(--bs-pagination-disabled-color);pointer-events:none;background-color:var(--bs-pagination-disabled-bg);border-color:var(--bs-pagination-disabled-border-color)}.climb-jupyter .page-item:not(:first-child) .page-link{margin-left:calc(-1 * var(--bs-border-width))}.climb-jupyter .page-item:first-child .page-link{border-top-left-radius:var(--bs-pagination-border-radius);border-bottom-left-radius:var(--bs-pagination-border-radius)}.climb-jupyter .page-item:last-child .page-link{border-top-right-radius:var(--bs-pagination-border-radius);border-bottom-right-radius:var(--bs-pagination-border-radius)}.climb-jupyter .pagination-lg{--bs-pagination-padding-x: 1.5rem;--bs-pagination-padding-y: .75rem;--bs-pagination-font-size: 1.25rem;--bs-pagination-border-radius: var(--bs-border-radius-lg)}.climb-jupyter .pagination-sm{--bs-pagination-padding-x: .5rem;--bs-pagination-padding-y: .25rem;--bs-pagination-font-size: .875rem;--bs-pagination-border-radius: var(--bs-border-radius-sm)}.climb-jupyter .badge{--bs-badge-padding-x: .65em;--bs-badge-padding-y: .35em;--bs-badge-font-size: .75em;--bs-badge-font-weight: 700;--bs-badge-color: #fff;--bs-badge-border-radius: var(--bs-border-radius);display:inline-block;padding:var(--bs-badge-padding-y) var(--bs-badge-padding-x);font-size:var(--bs-badge-font-size);font-weight:var(--bs-badge-font-weight);line-height:1;color:var(--bs-badge-color);text-align:center;white-space:nowrap;vertical-align:baseline;border-radius:var(--bs-badge-border-radius)}.climb-jupyter .badge:empty{display:none}.climb-jupyter .btn .badge{position:relative;top:-1px}.climb-jupyter .alert{--bs-alert-bg: transparent;--bs-alert-padding-x: 1rem;--bs-alert-padding-y: 1rem;--bs-alert-margin-bottom: 1rem;--bs-alert-color: inherit;--bs-alert-border-color: transparent;--bs-alert-border: var(--bs-border-width) solid var(--bs-alert-border-color);--bs-alert-border-radius: var(--bs-border-radius);--bs-alert-link-color: inherit;position:relative;padding:var(--bs-alert-padding-y) var(--bs-alert-padding-x);margin-bottom:var(--bs-alert-margin-bottom);color:var(--bs-alert-color);background-color:var(--bs-alert-bg);border:var(--bs-alert-border);border-radius:var(--bs-alert-border-radius)}.climb-jupyter .alert-heading{color:inherit}.climb-jupyter .alert-link{font-weight:700;color:var(--bs-alert-link-color)}.climb-jupyter .alert-dismissible{padding-right:3rem}.climb-jupyter .alert-dismissible .btn-close{position:absolute;top:0;right:0;z-index:2;padding:1.25rem 1rem}.climb-jupyter .alert-primary{--bs-alert-color: var(--bs-primary-text-emphasis);--bs-alert-bg: var(--bs-primary-bg-subtle);--bs-alert-border-color: var(--bs-primary-border-subtle);--bs-alert-link-color: var(--bs-primary-text-emphasis)}.climb-jupyter .alert-secondary{--bs-alert-color: var(--bs-secondary-text-emphasis);--bs-alert-bg: var(--bs-secondary-bg-subtle);--bs-alert-border-color: var(--bs-secondary-border-subtle);--bs-alert-link-color: var(--bs-secondary-text-emphasis)}.climb-jupyter .alert-success{--bs-alert-color: var(--bs-success-text-emphasis);--bs-alert-bg: var(--bs-success-bg-subtle);--bs-alert-border-color: var(--bs-success-border-subtle);--bs-alert-link-color: var(--bs-success-text-emphasis)}.climb-jupyter .alert-info{--bs-alert-color: var(--bs-info-text-emphasis);--bs-alert-bg: var(--bs-info-bg-subtle);--bs-alert-border-color: var(--bs-info-border-subtle);--bs-alert-link-color: var(--bs-info-text-emphasis)}.climb-jupyter .alert-warning{--bs-alert-color: var(--bs-warning-text-emphasis);--bs-alert-bg: var(--bs-warning-bg-subtle);--bs-alert-border-color: var(--bs-warning-border-subtle);--bs-alert-link-color: var(--bs-warning-text-emphasis)}.climb-jupyter .alert-danger{--bs-alert-color: var(--bs-danger-text-emphasis);--bs-alert-bg: var(--bs-danger-bg-subtle);--bs-alert-border-color: var(--bs-danger-border-subtle);--bs-alert-link-color: var(--bs-danger-text-emphasis)}.climb-jupyter .alert-light{--bs-alert-color: var(--bs-light-text-emphasis);--bs-alert-bg: var(--bs-light-bg-subtle);--bs-alert-border-color: var(--bs-light-border-subtle);--bs-alert-link-color: var(--bs-light-text-emphasis)}.climb-jupyter .alert-dark{--bs-alert-color: var(--bs-dark-text-emphasis);--bs-alert-bg: var(--bs-dark-bg-subtle);--bs-alert-border-color: var(--bs-dark-border-subtle);--bs-alert-link-color: var(--bs-dark-text-emphasis)}@keyframes progress-bar-stripes{0%{background-position-x:var(--bs-progress-height)}}.climb-jupyter .progress,.climb-jupyter .progress-stacked{--bs-progress-height: 1rem;--bs-progress-font-size: .75rem;--bs-progress-bg: var(--bs-secondary-bg);--bs-progress-border-radius: var(--bs-border-radius);--bs-progress-box-shadow: var(--bs-box-shadow-inset);--bs-progress-bar-color: #fff;--bs-progress-bar-bg: #0d6efd;--bs-progress-bar-transition: width .6s ease;display:flex;height:var(--bs-progress-height);overflow:hidden;font-size:var(--bs-progress-font-size);background-color:var(--bs-progress-bg);border-radius:var(--bs-progress-border-radius)}.climb-jupyter .progress-bar{display:flex;flex-direction:column;justify-content:center;overflow:hidden;color:var(--bs-progress-bar-color);text-align:center;white-space:nowrap;background-color:var(--bs-progress-bar-bg);transition:var(--bs-progress-bar-transition)}@media (prefers-reduced-motion: reduce){.climb-jupyter .progress-bar{transition:none}}.climb-jupyter .progress-bar-striped{background-image:linear-gradient(45deg,rgba(255,255,255,.15) 25%,transparent 25%,transparent 50%,rgba(255,255,255,.15) 50%,rgba(255,255,255,.15) 75%,transparent 75%,transparent);background-size:var(--bs-progress-height) var(--bs-progress-height)}.climb-jupyter .progress-stacked>.progress{overflow:visible}.climb-jupyter .progress-stacked>.progress>.progress-bar{width:100%}.climb-jupyter .progress-bar-animated{animation:1s linear infinite progress-bar-stripes}@media (prefers-reduced-motion: reduce){.climb-jupyter .progress-bar-animated{animation:none}}.climb-jupyter .modal{--bs-modal-zindex: 1055;--bs-modal-width: 500px;--bs-modal-padding: 1rem;--bs-modal-margin: .5rem;--bs-modal-color: var(--bs-body-color);--bs-modal-bg: var(--bs-body-bg);--bs-modal-border-color: var(--bs-border-color-translucent);--bs-modal-border-width: var(--bs-border-width);--bs-modal-border-radius: var(--bs-border-radius-lg);--bs-modal-box-shadow: var(--bs-box-shadow-sm);--bs-modal-inner-border-radius: calc(var(--bs-border-radius-lg) - (var(--bs-border-width)));--bs-modal-header-padding-x: 1rem;--bs-modal-header-padding-y: 1rem;--bs-modal-header-padding: 1rem 1rem;--bs-modal-header-border-color: var(--bs-border-color);--bs-modal-header-border-width: var(--bs-border-width);--bs-modal-title-line-height: 1.5;--bs-modal-footer-gap: .5rem;--bs-modal-footer-bg: ;--bs-modal-footer-border-color: var(--bs-border-color);--bs-modal-footer-border-width: var(--bs-border-width);position:fixed;top:0;left:0;z-index:var(--bs-modal-zindex);display:none;width:100%;height:100%;overflow-x:hidden;overflow-y:auto;outline:0}.climb-jupyter .modal-dialog{position:relative;width:auto;margin:var(--bs-modal-margin);pointer-events:none}.modal.fade .climb-jupyter .modal-dialog{transform:translateY(-50px);transition:transform .3s ease-out}@media (prefers-reduced-motion: reduce){.modal.fade .climb-jupyter .modal-dialog{transition:none}}.modal.show .climb-jupyter .modal-dialog{transform:none}.modal.modal-static .climb-jupyter .modal-dialog{transform:scale(1.02)}.climb-jupyter .modal-dialog-scrollable{height:calc(100% - var(--bs-modal-margin) * 2)}.climb-jupyter .modal-dialog-scrollable .modal-content{max-height:100%;overflow:hidden}.climb-jupyter .modal-dialog-scrollable .modal-body{overflow-y:auto}.climb-jupyter .modal-dialog-centered{display:flex;align-items:center;min-height:calc(100% - var(--bs-modal-margin) * 2)}.climb-jupyter .modal-content{position:relative;display:flex;flex-direction:column;width:100%;color:var(--bs-modal-color);pointer-events:auto;background-color:var(--bs-modal-bg);background-clip:padding-box;border:var(--bs-modal-border-width) solid var(--bs-modal-border-color);border-radius:var(--bs-modal-border-radius);outline:0}.climb-jupyter .modal-backdrop{--bs-backdrop-zindex: 1050;--bs-backdrop-bg: #000;--bs-backdrop-opacity: .5;position:fixed;top:0;left:0;z-index:var(--bs-backdrop-zindex);width:100vw;height:100vh;background-color:var(--bs-backdrop-bg)}.climb-jupyter .modal-backdrop.fade{opacity:0}.climb-jupyter .modal-backdrop.show{opacity:var(--bs-backdrop-opacity)}.climb-jupyter .modal-header{display:flex;flex-shrink:0;align-items:center;padding:var(--bs-modal-header-padding);border-bottom:var(--bs-modal-header-border-width) solid var(--bs-modal-header-border-color);border-top-left-radius:var(--bs-modal-inner-border-radius);border-top-right-radius:var(--bs-modal-inner-border-radius)}.climb-jupyter .modal-header .btn-close{padding:calc(var(--bs-modal-header-padding-y) * .5) calc(var(--bs-modal-header-padding-x) * .5);margin-top:calc(-.5 * var(--bs-modal-header-padding-y));margin-right:calc(-.5 * var(--bs-modal-header-padding-x));margin-bottom:calc(-.5 * var(--bs-modal-header-padding-y));margin-left:auto}.climb-jupyter .modal-title{margin-bottom:0;line-height:var(--bs-modal-title-line-height)}.climb-jupyter .modal-body{position:relative;flex:1 1 auto;padding:var(--bs-modal-padding)}.climb-jupyter .modal-footer{display:flex;flex-shrink:0;flex-wrap:wrap;align-items:center;justify-content:flex-end;padding:calc(var(--bs-modal-padding) - var(--bs-modal-footer-gap) * .5);background-color:var(--bs-modal-footer-bg);border-top:var(--bs-modal-footer-border-width) solid var(--bs-modal-footer-border-color);border-bottom-right-radius:var(--bs-modal-inner-border-radius);border-bottom-left-radius:var(--bs-modal-inner-border-radius)}.climb-jupyter .modal-footer>*{margin:calc(var(--bs-modal-footer-gap) * .5)}@media (min-width: 576px){.climb-jupyter .modal{--bs-modal-margin: 1.75rem;--bs-modal-box-shadow: var(--bs-box-shadow)}.climb-jupyter .modal-dialog{max-width:var(--bs-modal-width);margin-right:auto;margin-left:auto}.climb-jupyter .modal-sm{--bs-modal-width: 300px}}@media (min-width: 992px){.climb-jupyter .modal-lg,.climb-jupyter .modal-xl{--bs-modal-width: 800px}}@media (min-width: 1200px){.climb-jupyter .modal-xl{--bs-modal-width: 1140px}}.climb-jupyter .modal-fullscreen{width:100vw;max-width:none;height:100%;margin:0}.climb-jupyter .modal-fullscreen .modal-content{height:100%;border:0;border-radius:0}.climb-jupyter .modal-fullscreen .modal-header,.climb-jupyter .modal-fullscreen .modal-footer{border-radius:0}.climb-jupyter .modal-fullscreen .modal-body{overflow-y:auto}@media (max-width: 575.98px){.climb-jupyter .modal-fullscreen-sm-down{width:100vw;max-width:none;height:100%;margin:0}.climb-jupyter .modal-fullscreen-sm-down .modal-content{height:100%;border:0;border-radius:0}.climb-jupyter .modal-fullscreen-sm-down .modal-header,.climb-jupyter .modal-fullscreen-sm-down .modal-footer{border-radius:0}.climb-jupyter .modal-fullscreen-sm-down .modal-body{overflow-y:auto}}@media (max-width: 767.98px){.climb-jupyter .modal-fullscreen-md-down{width:100vw;max-width:none;height:100%;margin:0}.climb-jupyter .modal-fullscreen-md-down .modal-content{height:100%;border:0;border-radius:0}.climb-jupyter .modal-fullscreen-md-down .modal-header,.climb-jupyter .modal-fullscreen-md-down .modal-footer{border-radius:0}.climb-jupyter .modal-fullscreen-md-down .modal-body{overflow-y:auto}}@media (max-width: 991.98px){.climb-jupyter .modal-fullscreen-lg-down{width:100vw;max-width:none;height:100%;margin:0}.climb-jupyter .modal-fullscreen-lg-down .modal-content{height:100%;border:0;border-radius:0}.climb-jupyter .modal-fullscreen-lg-down .modal-header,.climb-jupyter .modal-fullscreen-lg-down .modal-footer{border-radius:0}.climb-jupyter .modal-fullscreen-lg-down .modal-body{overflow-y:auto}}@media (max-width: 1199.98px){.climb-jupyter .modal-fullscreen-xl-down{width:100vw;max-width:none;height:100%;margin:0}.climb-jupyter .modal-fullscreen-xl-down .modal-content{height:100%;border:0;border-radius:0}.climb-jupyter .modal-fullscreen-xl-down .modal-header,.climb-jupyter .modal-fullscreen-xl-down .modal-footer{border-radius:0}.climb-jupyter .modal-fullscreen-xl-down .modal-body{overflow-y:auto}}@media (max-width: 1399.98px){.climb-jupyter .modal-fullscreen-xxl-down{width:100vw;max-width:none;height:100%;margin:0}.climb-jupyter .modal-fullscreen-xxl-down .modal-content{height:100%;border:0;border-radius:0}.climb-jupyter .modal-fullscreen-xxl-down .modal-header,.climb-jupyter .modal-fullscreen-xxl-down .modal-footer{border-radius:0}.climb-jupyter .modal-fullscreen-xxl-down .modal-body{overflow-y:auto}}.climb-jupyter .spinner-grow,.climb-jupyter .spinner-border{display:inline-block;flex-shrink:0;width:var(--bs-spinner-width);height:var(--bs-spinner-height);vertical-align:var(--bs-spinner-vertical-align);border-radius:50%;animation:var(--bs-spinner-animation-speed) linear infinite var(--bs-spinner-animation-name)}@keyframes spinner-border{to{transform:rotate(360deg)}}.climb-jupyter .spinner-border{--bs-spinner-width: 2rem;--bs-spinner-height: 2rem;--bs-spinner-vertical-align: -.125em;--bs-spinner-border-width: .25em;--bs-spinner-animation-speed: .75s;--bs-spinner-animation-name: spinner-border;border:var(--bs-spinner-border-width) solid currentcolor;border-right-color:transparent}.climb-jupyter .spinner-border-sm{--bs-spinner-width: 1rem;--bs-spinner-height: 1rem;--bs-spinner-border-width: .2em}@keyframes spinner-grow{0%{transform:scale(0)}50%{opacity:1;transform:none}}.climb-jupyter .spinner-grow{--bs-spinner-width: 2rem;--bs-spinner-height: 2rem;--bs-spinner-vertical-align: -.125em;--bs-spinner-animation-speed: .75s;--bs-spinner-animation-name: spinner-grow;background-color:currentcolor;opacity:0}.climb-jupyter .spinner-grow-sm{--bs-spinner-width: 1rem;--bs-spinner-height: 1rem}@media (prefers-reduced-motion: reduce){.climb-jupyter .spinner-border,.climb-jupyter .spinner-grow{--bs-spinner-animation-speed: 1.5s}}.climb-jupyter .page-item.disabled .page-link{color:var(--bs-pagination-disabled-color)!important;pointer-events:none!important;background-color:var(--bs-pagination-disabled-bg)!important;border-color:var(--bs-pagination-disabled-border-color)!important}.climb-jupyter .modal-backdrop{position:fixed;top:0;left:0;width:100%;height:100%}.climb-jupyter{font-family:var(--bs-body-font-family);font-size:var(--bs-body-font-size);font-weight:var(--bs-body-font-weight);line-height:var(--bs-body-line-height);color:var(--bs-body-color);text-align:var(--bs-body-text-align);background-color:var(--bs-body-bg);-webkit-text-size-adjust:100%;-webkit-tap-highlight-color:rgba(0,0,0,0);display:flex;flex-direction:column;height:100%}.clearfix:after{display:block;clear:both;content:\"\"}.text-bg-primary{color:#fff!important;background-color:RGBA(var(--bs-primary-rgb),var(--bs-bg-opacity, 1))!important}.text-bg-secondary{color:#fff!important;background-color:RGBA(var(--bs-secondary-rgb),var(--bs-bg-opacity, 1))!important}.text-bg-success{color:#fff!important;background-color:RGBA(var(--bs-success-rgb),var(--bs-bg-opacity, 1))!important}.text-bg-info{color:#000!important;background-color:RGBA(var(--bs-info-rgb),var(--bs-bg-opacity, 1))!important}.text-bg-warning{color:#000!important;background-color:RGBA(var(--bs-warning-rgb),var(--bs-bg-opacity, 1))!important}.text-bg-danger{color:#fff!important;background-color:RGBA(var(--bs-danger-rgb),var(--bs-bg-opacity, 1))!important}.text-bg-light{color:#000!important;background-color:RGBA(var(--bs-light-rgb),var(--bs-bg-opacity, 1))!important}.text-bg-dark{color:#fff!important;background-color:RGBA(var(--bs-dark-rgb),var(--bs-bg-opacity, 1))!important}.link-primary{color:RGBA(var(--bs-primary-rgb),var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(var(--bs-primary-rgb),var(--bs-link-underline-opacity, 1))!important}.link-primary:hover,.link-primary:focus{color:RGBA(10,88,202,var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(10,88,202,var(--bs-link-underline-opacity, 1))!important}.link-secondary{color:RGBA(var(--bs-secondary-rgb),var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(var(--bs-secondary-rgb),var(--bs-link-underline-opacity, 1))!important}.link-secondary:hover,.link-secondary:focus{color:RGBA(86,94,100,var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(86,94,100,var(--bs-link-underline-opacity, 1))!important}.link-success{color:RGBA(var(--bs-success-rgb),var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(var(--bs-success-rgb),var(--bs-link-underline-opacity, 1))!important}.link-success:hover,.link-success:focus{color:RGBA(20,108,67,var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(20,108,67,var(--bs-link-underline-opacity, 1))!important}.link-info{color:RGBA(var(--bs-info-rgb),var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(var(--bs-info-rgb),var(--bs-link-underline-opacity, 1))!important}.link-info:hover,.link-info:focus{color:RGBA(61,213,243,var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(61,213,243,var(--bs-link-underline-opacity, 1))!important}.link-warning{color:RGBA(var(--bs-warning-rgb),var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(var(--bs-warning-rgb),var(--bs-link-underline-opacity, 1))!important}.link-warning:hover,.link-warning:focus{color:RGBA(255,205,57,var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(255,205,57,var(--bs-link-underline-opacity, 1))!important}.link-danger{color:RGBA(var(--bs-danger-rgb),var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(var(--bs-danger-rgb),var(--bs-link-underline-opacity, 1))!important}.link-danger:hover,.link-danger:focus{color:RGBA(176,42,55,var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(176,42,55,var(--bs-link-underline-opacity, 1))!important}.link-light{color:RGBA(var(--bs-light-rgb),var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(var(--bs-light-rgb),var(--bs-link-underline-opacity, 1))!important}.link-light:hover,.link-light:focus{color:RGBA(249,250,251,var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(249,250,251,var(--bs-link-underline-opacity, 1))!important}.link-dark{color:RGBA(var(--bs-dark-rgb),var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(var(--bs-dark-rgb),var(--bs-link-underline-opacity, 1))!important}.link-dark:hover,.link-dark:focus{color:RGBA(26,30,33,var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(26,30,33,var(--bs-link-underline-opacity, 1))!important}.link-body-emphasis{color:RGBA(var(--bs-emphasis-color-rgb),var(--bs-link-opacity, 1))!important;text-decoration-color:RGBA(var(--bs-emphasis-color-rgb),var(--bs-link-underline-opacity, 1))!important}.link-body-emphasis:hover,.link-body-emphasis:focus{color:RGBA(var(--bs-emphasis-color-rgb),var(--bs-link-opacity, .75))!important;text-decoration-color:RGBA(var(--bs-emphasis-color-rgb),var(--bs-link-underline-opacity, .75))!important}.focus-ring:focus{outline:0;box-shadow:var(--bs-focus-ring-x, 0) var(--bs-focus-ring-y, 0) var(--bs-focus-ring-blur, 0) var(--bs-focus-ring-width) var(--bs-focus-ring-color)}.icon-link{display:inline-flex;gap:.375rem;align-items:center;text-decoration-color:rgba(var(--bs-link-color-rgb),var(--bs-link-opacity, .5));text-underline-offset:.25em;backface-visibility:hidden}.icon-link>.bi{flex-shrink:0;width:1em;height:1em;fill:currentcolor;transition:.2s ease-in-out transform}@media (prefers-reduced-motion: reduce){.icon-link>.bi{transition:none}}.icon-link-hover:hover>.bi,.icon-link-hover:focus-visible>.bi{transform:var(--bs-icon-link-transform, translate3d(.25em, 0, 0))}.ratio{position:relative;width:100%}.ratio:before{display:block;padding-top:var(--bs-aspect-ratio);content:\"\"}.ratio>*{position:absolute;top:0;left:0;width:100%;height:100%}.ratio-1x1{--bs-aspect-ratio: 100%}.ratio-4x3{--bs-aspect-ratio: 75%}.ratio-16x9{--bs-aspect-ratio: 56.25%}.ratio-21x9{--bs-aspect-ratio: 42.8571428571%}.fixed-top{position:fixed;top:0;right:0;left:0;z-index:1030}.fixed-bottom{position:fixed;right:0;bottom:0;left:0;z-index:1030}.sticky-top{position:sticky;top:0;z-index:1020}.sticky-bottom{position:sticky;bottom:0;z-index:1020}@media (min-width: 576px){.sticky-sm-top{position:sticky;top:0;z-index:1020}.sticky-sm-bottom{position:sticky;bottom:0;z-index:1020}}@media (min-width: 768px){.sticky-md-top{position:sticky;top:0;z-index:1020}.sticky-md-bottom{position:sticky;bottom:0;z-index:1020}}@media (min-width: 992px){.sticky-lg-top{position:sticky;top:0;z-index:1020}.sticky-lg-bottom{position:sticky;bottom:0;z-index:1020}}@media (min-width: 1200px){.sticky-xl-top{position:sticky;top:0;z-index:1020}.sticky-xl-bottom{position:sticky;bottom:0;z-index:1020}}@media (min-width: 1400px){.sticky-xxl-top{position:sticky;top:0;z-index:1020}.sticky-xxl-bottom{position:sticky;bottom:0;z-index:1020}}.hstack{display:flex;flex-direction:row;align-items:center;align-self:stretch}.vstack{display:flex;flex:1 1 auto;flex-direction:column;align-self:stretch}.visually-hidden,.visually-hidden-focusable:not(:focus):not(:focus-within){width:1px!important;height:1px!important;padding:0!important;margin:-1px!important;overflow:hidden!important;clip:rect(0,0,0,0)!important;white-space:nowrap!important;border:0!important}.visually-hidden:not(caption),.visually-hidden-focusable:not(:focus):not(:focus-within):not(caption){position:absolute!important}.visually-hidden *,.visually-hidden-focusable:not(:focus):not(:focus-within) *{overflow:hidden!important}.stretched-link:after{position:absolute;top:0;right:0;bottom:0;left:0;z-index:1;content:\"\"}.text-truncate{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.vr{display:inline-block;align-self:stretch;width:var(--bs-border-width);min-height:1em;background-color:currentcolor;opacity:.25}.align-baseline{vertical-align:baseline!important}.align-top{vertical-align:top!important}.align-middle{vertical-align:middle!important}.align-bottom{vertical-align:bottom!important}.align-text-bottom{vertical-align:text-bottom!important}.align-text-top{vertical-align:text-top!important}.float-start{float:left!important}.float-end{float:right!important}.float-none{float:none!important}.object-fit-contain{object-fit:contain!important}.object-fit-cover{object-fit:cover!important}.object-fit-fill{object-fit:fill!important}.object-fit-scale{object-fit:scale-down!important}.object-fit-none{object-fit:none!important}.opacity-0{opacity:0!important}.opacity-25{opacity:.25!important}.opacity-50{opacity:.5!important}.opacity-75{opacity:.75!important}.opacity-100{opacity:1!important}.overflow-auto{overflow:auto!important}.overflow-hidden{overflow:hidden!important}.overflow-visible{overflow:visible!important}.overflow-scroll{overflow:scroll!important}.overflow-x-auto{overflow-x:auto!important}.overflow-x-hidden{overflow-x:hidden!important}.overflow-x-visible{overflow-x:visible!important}.overflow-x-scroll{overflow-x:scroll!important}.overflow-y-auto{overflow-y:auto!important}.overflow-y-hidden{overflow-y:hidden!important}.overflow-y-visible{overflow-y:visible!important}.overflow-y-scroll{overflow-y:scroll!important}.d-inline{display:inline!important}.d-inline-block{display:inline-block!important}.d-block{display:block!important}.d-grid{display:grid!important}.d-inline-grid{display:inline-grid!important}.d-table{display:table!important}.d-table-row{display:table-row!important}.d-table-cell{display:table-cell!important}.d-flex{display:flex!important}.d-inline-flex{display:inline-flex!important}.d-none{display:none!important}.shadow{box-shadow:var(--bs-box-shadow)!important}.shadow-sm{box-shadow:var(--bs-box-shadow-sm)!important}.shadow-lg{box-shadow:var(--bs-box-shadow-lg)!important}.shadow-none{box-shadow:none!important}.focus-ring-primary{--bs-focus-ring-color: rgba(var(--bs-primary-rgb), var(--bs-focus-ring-opacity))}.focus-ring-secondary{--bs-focus-ring-color: rgba(var(--bs-secondary-rgb), var(--bs-focus-ring-opacity))}.focus-ring-success{--bs-focus-ring-color: rgba(var(--bs-success-rgb), var(--bs-focus-ring-opacity))}.focus-ring-info{--bs-focus-ring-color: rgba(var(--bs-info-rgb), var(--bs-focus-ring-opacity))}.focus-ring-warning{--bs-focus-ring-color: rgba(var(--bs-warning-rgb), var(--bs-focus-ring-opacity))}.focus-ring-danger{--bs-focus-ring-color: rgba(var(--bs-danger-rgb), var(--bs-focus-ring-opacity))}.focus-ring-light{--bs-focus-ring-color: rgba(var(--bs-light-rgb), var(--bs-focus-ring-opacity))}.focus-ring-dark{--bs-focus-ring-color: rgba(var(--bs-dark-rgb), var(--bs-focus-ring-opacity))}.position-static{position:static!important}.position-relative{position:relative!important}.position-absolute{position:absolute!important}.position-fixed{position:fixed!important}.position-sticky{position:sticky!important}.top-0{top:0!important}.top-50{top:50%!important}.top-100{top:100%!important}.bottom-0{bottom:0!important}.bottom-50{bottom:50%!important}.bottom-100{bottom:100%!important}.start-0{left:0!important}.start-50{left:50%!important}.start-100{left:100%!important}.end-0{right:0!important}.end-50{right:50%!important}.end-100{right:100%!important}.translate-middle{transform:translate(-50%,-50%)!important}.translate-middle-x{transform:translate(-50%)!important}.translate-middle-y{transform:translateY(-50%)!important}.border{border:var(--bs-border-width) var(--bs-border-style) var(--bs-border-color)!important}.border-0{border:0!important}.border-top{border-top:var(--bs-border-width) var(--bs-border-style) var(--bs-border-color)!important}.border-top-0{border-top:0!important}.border-end{border-right:var(--bs-border-width) var(--bs-border-style) var(--bs-border-color)!important}.border-end-0{border-right:0!important}.border-bottom{border-bottom:var(--bs-border-width) var(--bs-border-style) var(--bs-border-color)!important}.border-bottom-0{border-bottom:0!important}.border-start{border-left:var(--bs-border-width) var(--bs-border-style) var(--bs-border-color)!important}.border-start-0{border-left:0!important}.border-primary{--bs-border-opacity: 1;border-color:rgba(var(--bs-primary-rgb),var(--bs-border-opacity))!important}.border-secondary{--bs-border-opacity: 1;border-color:rgba(var(--bs-secondary-rgb),var(--bs-border-opacity))!important}.border-success{--bs-border-opacity: 1;border-color:rgba(var(--bs-success-rgb),var(--bs-border-opacity))!important}.border-info{--bs-border-opacity: 1;border-color:rgba(var(--bs-info-rgb),var(--bs-border-opacity))!important}.border-warning{--bs-border-opacity: 1;border-color:rgba(var(--bs-warning-rgb),var(--bs-border-opacity))!important}.border-danger{--bs-border-opacity: 1;border-color:rgba(var(--bs-danger-rgb),var(--bs-border-opacity))!important}.border-light{--bs-border-opacity: 1;border-color:rgba(var(--bs-light-rgb),var(--bs-border-opacity))!important}.border-dark{--bs-border-opacity: 1;border-color:rgba(var(--bs-dark-rgb),var(--bs-border-opacity))!important}.border-black{--bs-border-opacity: 1;border-color:rgba(var(--bs-black-rgb),var(--bs-border-opacity))!important}.border-white{--bs-border-opacity: 1;border-color:rgba(var(--bs-white-rgb),var(--bs-border-opacity))!important}.border-primary-subtle{border-color:var(--bs-primary-border-subtle)!important}.border-secondary-subtle{border-color:var(--bs-secondary-border-subtle)!important}.border-success-subtle{border-color:var(--bs-success-border-subtle)!important}.border-info-subtle{border-color:var(--bs-info-border-subtle)!important}.border-warning-subtle{border-color:var(--bs-warning-border-subtle)!important}.border-danger-subtle{border-color:var(--bs-danger-border-subtle)!important}.border-light-subtle{border-color:var(--bs-light-border-subtle)!important}.border-dark-subtle{border-color:var(--bs-dark-border-subtle)!important}.border-1{border-width:1px!important}.border-2{border-width:2px!important}.border-3{border-width:3px!important}.border-4{border-width:4px!important}.border-5{border-width:5px!important}.border-opacity-10{--bs-border-opacity: .1}.border-opacity-25{--bs-border-opacity: .25}.border-opacity-50{--bs-border-opacity: .5}.border-opacity-75{--bs-border-opacity: .75}.border-opacity-100{--bs-border-opacity: 1}.w-25{width:25%!important}.w-50{width:50%!important}.w-75{width:75%!important}.w-100{width:100%!important}.w-auto{width:auto!important}.mw-100{max-width:100%!important}.vw-100{width:100vw!important}.min-vw-100{min-width:100vw!important}.h-25{height:25%!important}.h-50{height:50%!important}.h-75{height:75%!important}.h-100{height:100%!important}.h-auto{height:auto!important}.mh-100{max-height:100%!important}.vh-100{height:100vh!important}.min-vh-100{min-height:100vh!important}.flex-fill{flex:1 1 auto!important}.flex-row{flex-direction:row!important}.flex-column{flex-direction:column!important}.flex-row-reverse{flex-direction:row-reverse!important}.flex-column-reverse{flex-direction:column-reverse!important}.flex-grow-0{flex-grow:0!important}.flex-grow-1{flex-grow:1!important}.flex-shrink-0{flex-shrink:0!important}.flex-shrink-1{flex-shrink:1!important}.flex-wrap{flex-wrap:wrap!important}.flex-nowrap{flex-wrap:nowrap!important}.flex-wrap-reverse{flex-wrap:wrap-reverse!important}.justify-content-start{justify-content:flex-start!important}.justify-content-end{justify-content:flex-end!important}.justify-content-center{justify-content:center!important}.justify-content-between{justify-content:space-between!important}.justify-content-around{justify-content:space-around!important}.justify-content-evenly{justify-content:space-evenly!important}.align-items-start{align-items:flex-start!important}.align-items-end{align-items:flex-end!important}.align-items-center{align-items:center!important}.align-items-baseline{align-items:baseline!important}.align-items-stretch{align-items:stretch!important}.align-content-start{align-content:flex-start!important}.align-content-end{align-content:flex-end!important}.align-content-center{align-content:center!important}.align-content-between{align-content:space-between!important}.align-content-around{align-content:space-around!important}.align-content-stretch{align-content:stretch!important}.align-self-auto{align-self:auto!important}.align-self-start{align-self:flex-start!important}.align-self-end{align-self:flex-end!important}.align-self-center{align-self:center!important}.align-self-baseline{align-self:baseline!important}.align-self-stretch{align-self:stretch!important}.order-first{order:-1!important}.order-0{order:0!important}.order-1{order:1!important}.order-2{order:2!important}.order-3{order:3!important}.order-4{order:4!important}.order-5{order:5!important}.order-last{order:6!important}.m-0{margin:0!important}.m-1{margin:.25rem!important}.m-2{margin:.5rem!important}.m-3{margin:1rem!important}.m-4{margin:1.5rem!important}.m-5{margin:3rem!important}.m-auto{margin:auto!important}.mx-0{margin-right:0!important;margin-left:0!important}.mx-1{margin-right:.25rem!important;margin-left:.25rem!important}.mx-2{margin-right:.5rem!important;margin-left:.5rem!important}.mx-3{margin-right:1rem!important;margin-left:1rem!important}.mx-4{margin-right:1.5rem!important;margin-left:1.5rem!important}.mx-5{margin-right:3rem!important;margin-left:3rem!important}.mx-auto{margin-right:auto!important;margin-left:auto!important}.my-0{margin-top:0!important;margin-bottom:0!important}.my-1{margin-top:.25rem!important;margin-bottom:.25rem!important}.my-2{margin-top:.5rem!important;margin-bottom:.5rem!important}.my-3{margin-top:1rem!important;margin-bottom:1rem!important}.my-4{margin-top:1.5rem!important;margin-bottom:1.5rem!important}.my-5{margin-top:3rem!important;margin-bottom:3rem!important}.my-auto{margin-top:auto!important;margin-bottom:auto!important}.mt-0{margin-top:0!important}.mt-1{margin-top:.25rem!important}.mt-2{margin-top:.5rem!important}.mt-3{margin-top:1rem!important}.mt-4{margin-top:1.5rem!important}.mt-5{margin-top:3rem!important}.mt-auto{margin-top:auto!important}.me-0{margin-right:0!important}.me-1{margin-right:.25rem!important}.me-2{margin-right:.5rem!important}.me-3{margin-right:1rem!important}.me-4{margin-right:1.5rem!important}.me-5{margin-right:3rem!important}.me-auto{margin-right:auto!important}.mb-0{margin-bottom:0!important}.mb-1{margin-bottom:.25rem!important}.mb-2{margin-bottom:.5rem!important}.mb-3{margin-bottom:1rem!important}.mb-4{margin-bottom:1.5rem!important}.mb-5{margin-bottom:3rem!important}.mb-auto{margin-bottom:auto!important}.ms-0{margin-left:0!important}.ms-1{margin-left:.25rem!important}.ms-2{margin-left:.5rem!important}.ms-3{margin-left:1rem!important}.ms-4{margin-left:1.5rem!important}.ms-5{margin-left:3rem!important}.ms-auto{margin-left:auto!important}.p-0{padding:0!important}.p-1{padding:.25rem!important}.p-2{padding:.5rem!important}.p-3{padding:1rem!important}.p-4{padding:1.5rem!important}.p-5{padding:3rem!important}.px-0{padding-right:0!important;padding-left:0!important}.px-1{padding-right:.25rem!important;padding-left:.25rem!important}.px-2{padding-right:.5rem!important;padding-left:.5rem!important}.px-3{padding-right:1rem!important;padding-left:1rem!important}.px-4{padding-right:1.5rem!important;padding-left:1.5rem!important}.px-5{padding-right:3rem!important;padding-left:3rem!important}.py-0{padding-top:0!important;padding-bottom:0!important}.py-1{padding-top:.25rem!important;padding-bottom:.25rem!important}.py-2{padding-top:.5rem!important;padding-bottom:.5rem!important}.py-3{padding-top:1rem!important;padding-bottom:1rem!important}.py-4{padding-top:1.5rem!important;padding-bottom:1.5rem!important}.py-5{padding-top:3rem!important;padding-bottom:3rem!important}.pt-0{padding-top:0!important}.pt-1{padding-top:.25rem!important}.pt-2{padding-top:.5rem!important}.pt-3{padding-top:1rem!important}.pt-4{padding-top:1.5rem!important}.pt-5{padding-top:3rem!important}.pe-0{padding-right:0!important}.pe-1{padding-right:.25rem!important}.pe-2{padding-right:.5rem!important}.pe-3{padding-right:1rem!important}.pe-4{padding-right:1.5rem!important}.pe-5{padding-right:3rem!important}.pb-0{padding-bottom:0!important}.pb-1{padding-bottom:.25rem!important}.pb-2{padding-bottom:.5rem!important}.pb-3{padding-bottom:1rem!important}.pb-4{padding-bottom:1.5rem!important}.pb-5{padding-bottom:3rem!important}.ps-0{padding-left:0!important}.ps-1{padding-left:.25rem!important}.ps-2{padding-left:.5rem!important}.ps-3{padding-left:1rem!important}.ps-4{padding-left:1.5rem!important}.ps-5{padding-left:3rem!important}.gap-0{gap:0!important}.gap-1{gap:.25rem!important}.gap-2{gap:.5rem!important}.gap-3{gap:1rem!important}.gap-4{gap:1.5rem!important}.gap-5{gap:3rem!important}.row-gap-0{row-gap:0!important}.row-gap-1{row-gap:.25rem!important}.row-gap-2{row-gap:.5rem!important}.row-gap-3{row-gap:1rem!important}.row-gap-4{row-gap:1.5rem!important}.row-gap-5{row-gap:3rem!important}.column-gap-0{column-gap:0!important}.column-gap-1{column-gap:.25rem!important}.column-gap-2{column-gap:.5rem!important}.column-gap-3{column-gap:1rem!important}.column-gap-4{column-gap:1.5rem!important}.column-gap-5{column-gap:3rem!important}.font-monospace{font-family:var(--bs-font-monospace)!important}.fs-1{font-size:calc(1.375rem + 1.5vw)!important}.fs-2{font-size:calc(1.325rem + .9vw)!important}.fs-3{font-size:calc(1.3rem + .6vw)!important}.fs-4{font-size:calc(1.275rem + .3vw)!important}.fs-5{font-size:1.25rem!important}.fs-6{font-size:1rem!important}.fst-italic{font-style:italic!important}.fst-normal{font-style:normal!important}.fw-lighter{font-weight:lighter!important}.fw-light{font-weight:300!important}.fw-normal{font-weight:400!important}.fw-medium{font-weight:500!important}.fw-semibold{font-weight:600!important}.fw-bold{font-weight:700!important}.fw-bolder{font-weight:bolder!important}.lh-1{line-height:1!important}.lh-sm{line-height:1.25!important}.lh-base{line-height:1.5!important}.lh-lg{line-height:2!important}.text-start{text-align:left!important}.text-end{text-align:right!important}.text-center{text-align:center!important}.text-decoration-none{text-decoration:none!important}.text-decoration-underline{text-decoration:underline!important}.text-decoration-line-through{text-decoration:line-through!important}.text-lowercase{text-transform:lowercase!important}.text-uppercase{text-transform:uppercase!important}.text-capitalize{text-transform:capitalize!important}.text-wrap{white-space:normal!important}.text-nowrap{white-space:nowrap!important}.text-break{word-wrap:break-word!important;word-break:break-word!important}.text-primary{--bs-text-opacity: 1;color:rgba(var(--bs-primary-rgb),var(--bs-text-opacity))!important}.text-secondary{--bs-text-opacity: 1;color:rgba(var(--bs-secondary-rgb),var(--bs-text-opacity))!important}.text-success{--bs-text-opacity: 1;color:rgba(var(--bs-success-rgb),var(--bs-text-opacity))!important}.text-info{--bs-text-opacity: 1;color:rgba(var(--bs-info-rgb),var(--bs-text-opacity))!important}.text-warning{--bs-text-opacity: 1;color:rgba(var(--bs-warning-rgb),var(--bs-text-opacity))!important}.text-danger{--bs-text-opacity: 1;color:rgba(var(--bs-danger-rgb),var(--bs-text-opacity))!important}.text-light{--bs-text-opacity: 1;color:rgba(var(--bs-light-rgb),var(--bs-text-opacity))!important}.text-dark{--bs-text-opacity: 1;color:rgba(var(--bs-dark-rgb),var(--bs-text-opacity))!important}.text-black{--bs-text-opacity: 1;color:rgba(var(--bs-black-rgb),var(--bs-text-opacity))!important}.text-white{--bs-text-opacity: 1;color:rgba(var(--bs-white-rgb),var(--bs-text-opacity))!important}.text-body{--bs-text-opacity: 1;color:rgba(var(--bs-body-color-rgb),var(--bs-text-opacity))!important}.text-muted{--bs-text-opacity: 1;color:var(--bs-secondary-color)!important}.text-black-50{--bs-text-opacity: 1;color:#00000080!important}.text-white-50{--bs-text-opacity: 1;color:#ffffff80!important}.text-body-secondary{--bs-text-opacity: 1;color:var(--bs-secondary-color)!important}.text-body-tertiary{--bs-text-opacity: 1;color:var(--bs-tertiary-color)!important}.text-body-emphasis{--bs-text-opacity: 1;color:var(--bs-emphasis-color)!important}.text-reset{--bs-text-opacity: 1;color:inherit!important}.text-opacity-25{--bs-text-opacity: .25}.text-opacity-50{--bs-text-opacity: .5}.text-opacity-75{--bs-text-opacity: .75}.text-opacity-100{--bs-text-opacity: 1}.text-primary-emphasis{color:var(--bs-primary-text-emphasis)!important}.text-secondary-emphasis{color:var(--bs-secondary-text-emphasis)!important}.text-success-emphasis{color:var(--bs-success-text-emphasis)!important}.text-info-emphasis{color:var(--bs-info-text-emphasis)!important}.text-warning-emphasis{color:var(--bs-warning-text-emphasis)!important}.text-danger-emphasis{color:var(--bs-danger-text-emphasis)!important}.text-light-emphasis{color:var(--bs-light-text-emphasis)!important}.text-dark-emphasis{color:var(--bs-dark-text-emphasis)!important}.link-opacity-10,.link-opacity-10-hover:hover{--bs-link-opacity: .1}.link-opacity-25,.link-opacity-25-hover:hover{--bs-link-opacity: .25}.link-opacity-50,.link-opacity-50-hover:hover{--bs-link-opacity: .5}.link-opacity-75,.link-opacity-75-hover:hover{--bs-link-opacity: .75}.link-opacity-100,.link-opacity-100-hover:hover{--bs-link-opacity: 1}.link-offset-1,.link-offset-1-hover:hover{text-underline-offset:.125em!important}.link-offset-2,.link-offset-2-hover:hover{text-underline-offset:.25em!important}.link-offset-3,.link-offset-3-hover:hover{text-underline-offset:.375em!important}.link-underline-primary{--bs-link-underline-opacity: 1;text-decoration-color:rgba(var(--bs-primary-rgb),var(--bs-link-underline-opacity))!important}.link-underline-secondary{--bs-link-underline-opacity: 1;text-decoration-color:rgba(var(--bs-secondary-rgb),var(--bs-link-underline-opacity))!important}.link-underline-success{--bs-link-underline-opacity: 1;text-decoration-color:rgba(var(--bs-success-rgb),var(--bs-link-underline-opacity))!important}.link-underline-info{--bs-link-underline-opacity: 1;text-decoration-color:rgba(var(--bs-info-rgb),var(--bs-link-underline-opacity))!important}.link-underline-warning{--bs-link-underline-opacity: 1;text-decoration-color:rgba(var(--bs-warning-rgb),var(--bs-link-underline-opacity))!important}.link-underline-danger{--bs-link-underline-opacity: 1;text-decoration-color:rgba(var(--bs-danger-rgb),var(--bs-link-underline-opacity))!important}.link-underline-light{--bs-link-underline-opacity: 1;text-decoration-color:rgba(var(--bs-light-rgb),var(--bs-link-underline-opacity))!important}.link-underline-dark{--bs-link-underline-opacity: 1;text-decoration-color:rgba(var(--bs-dark-rgb),var(--bs-link-underline-opacity))!important}.link-underline{--bs-link-underline-opacity: 1;text-decoration-color:rgba(var(--bs-link-color-rgb),var(--bs-link-underline-opacity, 1))!important}.link-underline-opacity-0,.link-underline-opacity-0-hover:hover{--bs-link-underline-opacity: 0}.link-underline-opacity-10,.link-underline-opacity-10-hover:hover{--bs-link-underline-opacity: .1}.link-underline-opacity-25,.link-underline-opacity-25-hover:hover{--bs-link-underline-opacity: .25}.link-underline-opacity-50,.link-underline-opacity-50-hover:hover{--bs-link-underline-opacity: .5}.link-underline-opacity-75,.link-underline-opacity-75-hover:hover{--bs-link-underline-opacity: .75}.link-underline-opacity-100,.link-underline-opacity-100-hover:hover{--bs-link-underline-opacity: 1}.bg-primary{--bs-bg-opacity: 1;background-color:rgba(var(--bs-primary-rgb),var(--bs-bg-opacity))!important}.bg-secondary{--bs-bg-opacity: 1;background-color:rgba(var(--bs-secondary-rgb),var(--bs-bg-opacity))!important}.bg-success{--bs-bg-opacity: 1;background-color:rgba(var(--bs-success-rgb),var(--bs-bg-opacity))!important}.bg-info{--bs-bg-opacity: 1;background-color:rgba(var(--bs-info-rgb),var(--bs-bg-opacity))!important}.bg-warning{--bs-bg-opacity: 1;background-color:rgba(var(--bs-warning-rgb),var(--bs-bg-opacity))!important}.bg-danger{--bs-bg-opacity: 1;background-color:rgba(var(--bs-danger-rgb),var(--bs-bg-opacity))!important}.bg-light{--bs-bg-opacity: 1;background-color:rgba(var(--bs-light-rgb),var(--bs-bg-opacity))!important}.bg-dark{--bs-bg-opacity: 1;background-color:rgba(var(--bs-dark-rgb),var(--bs-bg-opacity))!important}.bg-black{--bs-bg-opacity: 1;background-color:rgba(var(--bs-black-rgb),var(--bs-bg-opacity))!important}.bg-white{--bs-bg-opacity: 1;background-color:rgba(var(--bs-white-rgb),var(--bs-bg-opacity))!important}.bg-body{--bs-bg-opacity: 1;background-color:rgba(var(--bs-body-bg-rgb),var(--bs-bg-opacity))!important}.bg-transparent{--bs-bg-opacity: 1;background-color:transparent!important}.bg-body-secondary{--bs-bg-opacity: 1;background-color:rgba(var(--bs-secondary-bg-rgb),var(--bs-bg-opacity))!important}.bg-body-tertiary{--bs-bg-opacity: 1;background-color:rgba(var(--bs-tertiary-bg-rgb),var(--bs-bg-opacity))!important}.bg-opacity-10{--bs-bg-opacity: .1}.bg-opacity-25{--bs-bg-opacity: .25}.bg-opacity-50{--bs-bg-opacity: .5}.bg-opacity-75{--bs-bg-opacity: .75}.bg-opacity-100{--bs-bg-opacity: 1}.bg-primary-subtle{background-color:var(--bs-primary-bg-subtle)!important}.bg-secondary-subtle{background-color:var(--bs-secondary-bg-subtle)!important}.bg-success-subtle{background-color:var(--bs-success-bg-subtle)!important}.bg-info-subtle{background-color:var(--bs-info-bg-subtle)!important}.bg-warning-subtle{background-color:var(--bs-warning-bg-subtle)!important}.bg-danger-subtle{background-color:var(--bs-danger-bg-subtle)!important}.bg-light-subtle{background-color:var(--bs-light-bg-subtle)!important}.bg-dark-subtle{background-color:var(--bs-dark-bg-subtle)!important}.bg-gradient{background-image:var(--bs-gradient)!important}.user-select-all{-webkit-user-select:all!important;user-select:all!important}.user-select-auto{-webkit-user-select:auto!important;user-select:auto!important}.user-select-none{-webkit-user-select:none!important;user-select:none!important}.pe-none{pointer-events:none!important}.pe-auto{pointer-events:auto!important}.rounded{border-radius:var(--bs-border-radius)!important}.rounded-0{border-radius:0!important}.rounded-1{border-radius:var(--bs-border-radius-sm)!important}.rounded-2{border-radius:var(--bs-border-radius)!important}.rounded-3{border-radius:var(--bs-border-radius-lg)!important}.rounded-4{border-radius:var(--bs-border-radius-xl)!important}.rounded-5{border-radius:var(--bs-border-radius-xxl)!important}.rounded-circle{border-radius:50%!important}.rounded-pill{border-radius:var(--bs-border-radius-pill)!important}.rounded-top{border-top-left-radius:var(--bs-border-radius)!important;border-top-right-radius:var(--bs-border-radius)!important}.rounded-top-0{border-top-left-radius:0!important;border-top-right-radius:0!important}.rounded-top-1{border-top-left-radius:var(--bs-border-radius-sm)!important;border-top-right-radius:var(--bs-border-radius-sm)!important}.rounded-top-2{border-top-left-radius:var(--bs-border-radius)!important;border-top-right-radius:var(--bs-border-radius)!important}.rounded-top-3{border-top-left-radius:var(--bs-border-radius-lg)!important;border-top-right-radius:var(--bs-border-radius-lg)!important}.rounded-top-4{border-top-left-radius:var(--bs-border-radius-xl)!important;border-top-right-radius:var(--bs-border-radius-xl)!important}.rounded-top-5{border-top-left-radius:var(--bs-border-radius-xxl)!important;border-top-right-radius:var(--bs-border-radius-xxl)!important}.rounded-top-circle{border-top-left-radius:50%!important;border-top-right-radius:50%!important}.rounded-top-pill{border-top-left-radius:var(--bs-border-radius-pill)!important;border-top-right-radius:var(--bs-border-radius-pill)!important}.rounded-end{border-top-right-radius:var(--bs-border-radius)!important;border-bottom-right-radius:var(--bs-border-radius)!important}.rounded-end-0{border-top-right-radius:0!important;border-bottom-right-radius:0!important}.rounded-end-1{border-top-right-radius:var(--bs-border-radius-sm)!important;border-bottom-right-radius:var(--bs-border-radius-sm)!important}.rounded-end-2{border-top-right-radius:var(--bs-border-radius)!important;border-bottom-right-radius:var(--bs-border-radius)!important}.rounded-end-3{border-top-right-radius:var(--bs-border-radius-lg)!important;border-bottom-right-radius:var(--bs-border-radius-lg)!important}.rounded-end-4{border-top-right-radius:var(--bs-border-radius-xl)!important;border-bottom-right-radius:var(--bs-border-radius-xl)!important}.rounded-end-5{border-top-right-radius:var(--bs-border-radius-xxl)!important;border-bottom-right-radius:var(--bs-border-radius-xxl)!important}.rounded-end-circle{border-top-right-radius:50%!important;border-bottom-right-radius:50%!important}.rounded-end-pill{border-top-right-radius:var(--bs-border-radius-pill)!important;border-bottom-right-radius:var(--bs-border-radius-pill)!important}.rounded-bottom{border-bottom-right-radius:var(--bs-border-radius)!important;border-bottom-left-radius:var(--bs-border-radius)!important}.rounded-bottom-0{border-bottom-right-radius:0!important;border-bottom-left-radius:0!important}.rounded-bottom-1{border-bottom-right-radius:var(--bs-border-radius-sm)!important;border-bottom-left-radius:var(--bs-border-radius-sm)!important}.rounded-bottom-2{border-bottom-right-radius:var(--bs-border-radius)!important;border-bottom-left-radius:var(--bs-border-radius)!important}.rounded-bottom-3{border-bottom-right-radius:var(--bs-border-radius-lg)!important;border-bottom-left-radius:var(--bs-border-radius-lg)!important}.rounded-bottom-4{border-bottom-right-radius:var(--bs-border-radius-xl)!important;border-bottom-left-radius:var(--bs-border-radius-xl)!important}.rounded-bottom-5{border-bottom-right-radius:var(--bs-border-radius-xxl)!important;border-bottom-left-radius:var(--bs-border-radius-xxl)!important}.rounded-bottom-circle{border-bottom-right-radius:50%!important;border-bottom-left-radius:50%!important}.rounded-bottom-pill{border-bottom-right-radius:var(--bs-border-radius-pill)!important;border-bottom-left-radius:var(--bs-border-radius-pill)!important}.rounded-start{border-bottom-left-radius:var(--bs-border-radius)!important;border-top-left-radius:var(--bs-border-radius)!important}.rounded-start-0{border-bottom-left-radius:0!important;border-top-left-radius:0!important}.rounded-start-1{border-bottom-left-radius:var(--bs-border-radius-sm)!important;border-top-left-radius:var(--bs-border-radius-sm)!important}.rounded-start-2{border-bottom-left-radius:var(--bs-border-radius)!important;border-top-left-radius:var(--bs-border-radius)!important}.rounded-start-3{border-bottom-left-radius:var(--bs-border-radius-lg)!important;border-top-left-radius:var(--bs-border-radius-lg)!important}.rounded-start-4{border-bottom-left-radius:var(--bs-border-radius-xl)!important;border-top-left-radius:var(--bs-border-radius-xl)!important}.rounded-start-5{border-bottom-left-radius:var(--bs-border-radius-xxl)!important;border-top-left-radius:var(--bs-border-radius-xxl)!important}.rounded-start-circle{border-bottom-left-radius:50%!important;border-top-left-radius:50%!important}.rounded-start-pill{border-bottom-left-radius:var(--bs-border-radius-pill)!important;border-top-left-radius:var(--bs-border-radius-pill)!important}.visible{visibility:visible!important}.invisible{visibility:hidden!important}.z-n1{z-index:-1!important}.z-0{z-index:0!important}.z-1{z-index:1!important}.z-2{z-index:2!important}.z-3{z-index:3!important}@media (min-width: 576px){.float-sm-start{float:left!important}.float-sm-end{float:right!important}.float-sm-none{float:none!important}.object-fit-sm-contain{object-fit:contain!important}.object-fit-sm-cover{object-fit:cover!important}.object-fit-sm-fill{object-fit:fill!important}.object-fit-sm-scale{object-fit:scale-down!important}.object-fit-sm-none{object-fit:none!important}.d-sm-inline{display:inline!important}.d-sm-inline-block{display:inline-block!important}.d-sm-block{display:block!important}.d-sm-grid{display:grid!important}.d-sm-inline-grid{display:inline-grid!important}.d-sm-table{display:table!important}.d-sm-table-row{display:table-row!important}.d-sm-table-cell{display:table-cell!important}.d-sm-flex{display:flex!important}.d-sm-inline-flex{display:inline-flex!important}.d-sm-none{display:none!important}.flex-sm-fill{flex:1 1 auto!important}.flex-sm-row{flex-direction:row!important}.flex-sm-column{flex-direction:column!important}.flex-sm-row-reverse{flex-direction:row-reverse!important}.flex-sm-column-reverse{flex-direction:column-reverse!important}.flex-sm-grow-0{flex-grow:0!important}.flex-sm-grow-1{flex-grow:1!important}.flex-sm-shrink-0{flex-shrink:0!important}.flex-sm-shrink-1{flex-shrink:1!important}.flex-sm-wrap{flex-wrap:wrap!important}.flex-sm-nowrap{flex-wrap:nowrap!important}.flex-sm-wrap-reverse{flex-wrap:wrap-reverse!important}.justify-content-sm-start{justify-content:flex-start!important}.justify-content-sm-end{justify-content:flex-end!important}.justify-content-sm-center{justify-content:center!important}.justify-content-sm-between{justify-content:space-between!important}.justify-content-sm-around{justify-content:space-around!important}.justify-content-sm-evenly{justify-content:space-evenly!important}.align-items-sm-start{align-items:flex-start!important}.align-items-sm-end{align-items:flex-end!important}.align-items-sm-center{align-items:center!important}.align-items-sm-baseline{align-items:baseline!important}.align-items-sm-stretch{align-items:stretch!important}.align-content-sm-start{align-content:flex-start!important}.align-content-sm-end{align-content:flex-end!important}.align-content-sm-center{align-content:center!important}.align-content-sm-between{align-content:space-between!important}.align-content-sm-around{align-content:space-around!important}.align-content-sm-stretch{align-content:stretch!important}.align-self-sm-auto{align-self:auto!important}.align-self-sm-start{align-self:flex-start!important}.align-self-sm-end{align-self:flex-end!important}.align-self-sm-center{align-self:center!important}.align-self-sm-baseline{align-self:baseline!important}.align-self-sm-stretch{align-self:stretch!important}.order-sm-first{order:-1!important}.order-sm-0{order:0!important}.order-sm-1{order:1!important}.order-sm-2{order:2!important}.order-sm-3{order:3!important}.order-sm-4{order:4!important}.order-sm-5{order:5!important}.order-sm-last{order:6!important}.m-sm-0{margin:0!important}.m-sm-1{margin:.25rem!important}.m-sm-2{margin:.5rem!important}.m-sm-3{margin:1rem!important}.m-sm-4{margin:1.5rem!important}.m-sm-5{margin:3rem!important}.m-sm-auto{margin:auto!important}.mx-sm-0{margin-right:0!important;margin-left:0!important}.mx-sm-1{margin-right:.25rem!important;margin-left:.25rem!important}.mx-sm-2{margin-right:.5rem!important;margin-left:.5rem!important}.mx-sm-3{margin-right:1rem!important;margin-left:1rem!important}.mx-sm-4{margin-right:1.5rem!important;margin-left:1.5rem!important}.mx-sm-5{margin-right:3rem!important;margin-left:3rem!important}.mx-sm-auto{margin-right:auto!important;margin-left:auto!important}.my-sm-0{margin-top:0!important;margin-bottom:0!important}.my-sm-1{margin-top:.25rem!important;margin-bottom:.25rem!important}.my-sm-2{margin-top:.5rem!important;margin-bottom:.5rem!important}.my-sm-3{margin-top:1rem!important;margin-bottom:1rem!important}.my-sm-4{margin-top:1.5rem!important;margin-bottom:1.5rem!important}.my-sm-5{margin-top:3rem!important;margin-bottom:3rem!important}.my-sm-auto{margin-top:auto!important;margin-bottom:auto!important}.mt-sm-0{margin-top:0!important}.mt-sm-1{margin-top:.25rem!important}.mt-sm-2{margin-top:.5rem!important}.mt-sm-3{margin-top:1rem!important}.mt-sm-4{margin-top:1.5rem!important}.mt-sm-5{margin-top:3rem!important}.mt-sm-auto{margin-top:auto!important}.me-sm-0{margin-right:0!important}.me-sm-1{margin-right:.25rem!important}.me-sm-2{margin-right:.5rem!important}.me-sm-3{margin-right:1rem!important}.me-sm-4{margin-right:1.5rem!important}.me-sm-5{margin-right:3rem!important}.me-sm-auto{margin-right:auto!important}.mb-sm-0{margin-bottom:0!important}.mb-sm-1{margin-bottom:.25rem!important}.mb-sm-2{margin-bottom:.5rem!important}.mb-sm-3{margin-bottom:1rem!important}.mb-sm-4{margin-bottom:1.5rem!important}.mb-sm-5{margin-bottom:3rem!important}.mb-sm-auto{margin-bottom:auto!important}.ms-sm-0{margin-left:0!important}.ms-sm-1{margin-left:.25rem!important}.ms-sm-2{margin-left:.5rem!important}.ms-sm-3{margin-left:1rem!important}.ms-sm-4{margin-left:1.5rem!important}.ms-sm-5{margin-left:3rem!important}.ms-sm-auto{margin-left:auto!important}.p-sm-0{padding:0!important}.p-sm-1{padding:.25rem!important}.p-sm-2{padding:.5rem!important}.p-sm-3{padding:1rem!important}.p-sm-4{padding:1.5rem!important}.p-sm-5{padding:3rem!important}.px-sm-0{padding-right:0!important;padding-left:0!important}.px-sm-1{padding-right:.25rem!important;padding-left:.25rem!important}.px-sm-2{padding-right:.5rem!important;padding-left:.5rem!important}.px-sm-3{padding-right:1rem!important;padding-left:1rem!important}.px-sm-4{padding-right:1.5rem!important;padding-left:1.5rem!important}.px-sm-5{padding-right:3rem!important;padding-left:3rem!important}.py-sm-0{padding-top:0!important;padding-bottom:0!important}.py-sm-1{padding-top:.25rem!important;padding-bottom:.25rem!important}.py-sm-2{padding-top:.5rem!important;padding-bottom:.5rem!important}.py-sm-3{padding-top:1rem!important;padding-bottom:1rem!important}.py-sm-4{padding-top:1.5rem!important;padding-bottom:1.5rem!important}.py-sm-5{padding-top:3rem!important;padding-bottom:3rem!important}.pt-sm-0{padding-top:0!important}.pt-sm-1{padding-top:.25rem!important}.pt-sm-2{padding-top:.5rem!important}.pt-sm-3{padding-top:1rem!important}.pt-sm-4{padding-top:1.5rem!important}.pt-sm-5{padding-top:3rem!important}.pe-sm-0{padding-right:0!important}.pe-sm-1{padding-right:.25rem!important}.pe-sm-2{padding-right:.5rem!important}.pe-sm-3{padding-right:1rem!important}.pe-sm-4{padding-right:1.5rem!important}.pe-sm-5{padding-right:3rem!important}.pb-sm-0{padding-bottom:0!important}.pb-sm-1{padding-bottom:.25rem!important}.pb-sm-2{padding-bottom:.5rem!important}.pb-sm-3{padding-bottom:1rem!important}.pb-sm-4{padding-bottom:1.5rem!important}.pb-sm-5{padding-bottom:3rem!important}.ps-sm-0{padding-left:0!important}.ps-sm-1{padding-left:.25rem!important}.ps-sm-2{padding-left:.5rem!important}.ps-sm-3{padding-left:1rem!important}.ps-sm-4{padding-left:1.5rem!important}.ps-sm-5{padding-left:3rem!important}.gap-sm-0{gap:0!important}.gap-sm-1{gap:.25rem!important}.gap-sm-2{gap:.5rem!important}.gap-sm-3{gap:1rem!important}.gap-sm-4{gap:1.5rem!important}.gap-sm-5{gap:3rem!important}.row-gap-sm-0{row-gap:0!important}.row-gap-sm-1{row-gap:.25rem!important}.row-gap-sm-2{row-gap:.5rem!important}.row-gap-sm-3{row-gap:1rem!important}.row-gap-sm-4{row-gap:1.5rem!important}.row-gap-sm-5{row-gap:3rem!important}.column-gap-sm-0{column-gap:0!important}.column-gap-sm-1{column-gap:.25rem!important}.column-gap-sm-2{column-gap:.5rem!important}.column-gap-sm-3{column-gap:1rem!important}.column-gap-sm-4{column-gap:1.5rem!important}.column-gap-sm-5{column-gap:3rem!important}.text-sm-start{text-align:left!important}.text-sm-end{text-align:right!important}.text-sm-center{text-align:center!important}}@media (min-width: 768px){.float-md-start{float:left!important}.float-md-end{float:right!important}.float-md-none{float:none!important}.object-fit-md-contain{object-fit:contain!important}.object-fit-md-cover{object-fit:cover!important}.object-fit-md-fill{object-fit:fill!important}.object-fit-md-scale{object-fit:scale-down!important}.object-fit-md-none{object-fit:none!important}.d-md-inline{display:inline!important}.d-md-inline-block{display:inline-block!important}.d-md-block{display:block!important}.d-md-grid{display:grid!important}.d-md-inline-grid{display:inline-grid!important}.d-md-table{display:table!important}.d-md-table-row{display:table-row!important}.d-md-table-cell{display:table-cell!important}.d-md-flex{display:flex!important}.d-md-inline-flex{display:inline-flex!important}.d-md-none{display:none!important}.flex-md-fill{flex:1 1 auto!important}.flex-md-row{flex-direction:row!important}.flex-md-column{flex-direction:column!important}.flex-md-row-reverse{flex-direction:row-reverse!important}.flex-md-column-reverse{flex-direction:column-reverse!important}.flex-md-grow-0{flex-grow:0!important}.flex-md-grow-1{flex-grow:1!important}.flex-md-shrink-0{flex-shrink:0!important}.flex-md-shrink-1{flex-shrink:1!important}.flex-md-wrap{flex-wrap:wrap!important}.flex-md-nowrap{flex-wrap:nowrap!important}.flex-md-wrap-reverse{flex-wrap:wrap-reverse!important}.justify-content-md-start{justify-content:flex-start!important}.justify-content-md-end{justify-content:flex-end!important}.justify-content-md-center{justify-content:center!important}.justify-content-md-between{justify-content:space-between!important}.justify-content-md-around{justify-content:space-around!important}.justify-content-md-evenly{justify-content:space-evenly!important}.align-items-md-start{align-items:flex-start!important}.align-items-md-end{align-items:flex-end!important}.align-items-md-center{align-items:center!important}.align-items-md-baseline{align-items:baseline!important}.align-items-md-stretch{align-items:stretch!important}.align-content-md-start{align-content:flex-start!important}.align-content-md-end{align-content:flex-end!important}.align-content-md-center{align-content:center!important}.align-content-md-between{align-content:space-between!important}.align-content-md-around{align-content:space-around!important}.align-content-md-stretch{align-content:stretch!important}.align-self-md-auto{align-self:auto!important}.align-self-md-start{align-self:flex-start!important}.align-self-md-end{align-self:flex-end!important}.align-self-md-center{align-self:center!important}.align-self-md-baseline{align-self:baseline!important}.align-self-md-stretch{align-self:stretch!important}.order-md-first{order:-1!important}.order-md-0{order:0!important}.order-md-1{order:1!important}.order-md-2{order:2!important}.order-md-3{order:3!important}.order-md-4{order:4!important}.order-md-5{order:5!important}.order-md-last{order:6!important}.m-md-0{margin:0!important}.m-md-1{margin:.25rem!important}.m-md-2{margin:.5rem!important}.m-md-3{margin:1rem!important}.m-md-4{margin:1.5rem!important}.m-md-5{margin:3rem!important}.m-md-auto{margin:auto!important}.mx-md-0{margin-right:0!important;margin-left:0!important}.mx-md-1{margin-right:.25rem!important;margin-left:.25rem!important}.mx-md-2{margin-right:.5rem!important;margin-left:.5rem!important}.mx-md-3{margin-right:1rem!important;margin-left:1rem!important}.mx-md-4{margin-right:1.5rem!important;margin-left:1.5rem!important}.mx-md-5{margin-right:3rem!important;margin-left:3rem!important}.mx-md-auto{margin-right:auto!important;margin-left:auto!important}.my-md-0{margin-top:0!important;margin-bottom:0!important}.my-md-1{margin-top:.25rem!important;margin-bottom:.25rem!important}.my-md-2{margin-top:.5rem!important;margin-bottom:.5rem!important}.my-md-3{margin-top:1rem!important;margin-bottom:1rem!important}.my-md-4{margin-top:1.5rem!important;margin-bottom:1.5rem!important}.my-md-5{margin-top:3rem!important;margin-bottom:3rem!important}.my-md-auto{margin-top:auto!important;margin-bottom:auto!important}.mt-md-0{margin-top:0!important}.mt-md-1{margin-top:.25rem!important}.mt-md-2{margin-top:.5rem!important}.mt-md-3{margin-top:1rem!important}.mt-md-4{margin-top:1.5rem!important}.mt-md-5{margin-top:3rem!important}.mt-md-auto{margin-top:auto!important}.me-md-0{margin-right:0!important}.me-md-1{margin-right:.25rem!important}.me-md-2{margin-right:.5rem!important}.me-md-3{margin-right:1rem!important}.me-md-4{margin-right:1.5rem!important}.me-md-5{margin-right:3rem!important}.me-md-auto{margin-right:auto!important}.mb-md-0{margin-bottom:0!important}.mb-md-1{margin-bottom:.25rem!important}.mb-md-2{margin-bottom:.5rem!important}.mb-md-3{margin-bottom:1rem!important}.mb-md-4{margin-bottom:1.5rem!important}.mb-md-5{margin-bottom:3rem!important}.mb-md-auto{margin-bottom:auto!important}.ms-md-0{margin-left:0!important}.ms-md-1{margin-left:.25rem!important}.ms-md-2{margin-left:.5rem!important}.ms-md-3{margin-left:1rem!important}.ms-md-4{margin-left:1.5rem!important}.ms-md-5{margin-left:3rem!important}.ms-md-auto{margin-left:auto!important}.p-md-0{padding:0!important}.p-md-1{padding:.25rem!important}.p-md-2{padding:.5rem!important}.p-md-3{padding:1rem!important}.p-md-4{padding:1.5rem!important}.p-md-5{padding:3rem!important}.px-md-0{padding-right:0!important;padding-left:0!important}.px-md-1{padding-right:.25rem!important;padding-left:.25rem!important}.px-md-2{padding-right:.5rem!important;padding-left:.5rem!important}.px-md-3{padding-right:1rem!important;padding-left:1rem!important}.px-md-4{padding-right:1.5rem!important;padding-left:1.5rem!important}.px-md-5{padding-right:3rem!important;padding-left:3rem!important}.py-md-0{padding-top:0!important;padding-bottom:0!important}.py-md-1{padding-top:.25rem!important;padding-bottom:.25rem!important}.py-md-2{padding-top:.5rem!important;padding-bottom:.5rem!important}.py-md-3{padding-top:1rem!important;padding-bottom:1rem!important}.py-md-4{padding-top:1.5rem!important;padding-bottom:1.5rem!important}.py-md-5{padding-top:3rem!important;padding-bottom:3rem!important}.pt-md-0{padding-top:0!important}.pt-md-1{padding-top:.25rem!important}.pt-md-2{padding-top:.5rem!important}.pt-md-3{padding-top:1rem!important}.pt-md-4{padding-top:1.5rem!important}.pt-md-5{padding-top:3rem!important}.pe-md-0{padding-right:0!important}.pe-md-1{padding-right:.25rem!important}.pe-md-2{padding-right:.5rem!important}.pe-md-3{padding-right:1rem!important}.pe-md-4{padding-right:1.5rem!important}.pe-md-5{padding-right:3rem!important}.pb-md-0{padding-bottom:0!important}.pb-md-1{padding-bottom:.25rem!important}.pb-md-2{padding-bottom:.5rem!important}.pb-md-3{padding-bottom:1rem!important}.pb-md-4{padding-bottom:1.5rem!important}.pb-md-5{padding-bottom:3rem!important}.ps-md-0{padding-left:0!important}.ps-md-1{padding-left:.25rem!important}.ps-md-2{padding-left:.5rem!important}.ps-md-3{padding-left:1rem!important}.ps-md-4{padding-left:1.5rem!important}.ps-md-5{padding-left:3rem!important}.gap-md-0{gap:0!important}.gap-md-1{gap:.25rem!important}.gap-md-2{gap:.5rem!important}.gap-md-3{gap:1rem!important}.gap-md-4{gap:1.5rem!important}.gap-md-5{gap:3rem!important}.row-gap-md-0{row-gap:0!important}.row-gap-md-1{row-gap:.25rem!important}.row-gap-md-2{row-gap:.5rem!important}.row-gap-md-3{row-gap:1rem!important}.row-gap-md-4{row-gap:1.5rem!important}.row-gap-md-5{row-gap:3rem!important}.column-gap-md-0{column-gap:0!important}.column-gap-md-1{column-gap:.25rem!important}.column-gap-md-2{column-gap:.5rem!important}.column-gap-md-3{column-gap:1rem!important}.column-gap-md-4{column-gap:1.5rem!important}.column-gap-md-5{column-gap:3rem!important}.text-md-start{text-align:left!important}.text-md-end{text-align:right!important}.text-md-center{text-align:center!important}}@media (min-width: 992px){.float-lg-start{float:left!important}.float-lg-end{float:right!important}.float-lg-none{float:none!important}.object-fit-lg-contain{object-fit:contain!important}.object-fit-lg-cover{object-fit:cover!important}.object-fit-lg-fill{object-fit:fill!important}.object-fit-lg-scale{object-fit:scale-down!important}.object-fit-lg-none{object-fit:none!important}.d-lg-inline{display:inline!important}.d-lg-inline-block{display:inline-block!important}.d-lg-block{display:block!important}.d-lg-grid{display:grid!important}.d-lg-inline-grid{display:inline-grid!important}.d-lg-table{display:table!important}.d-lg-table-row{display:table-row!important}.d-lg-table-cell{display:table-cell!important}.d-lg-flex{display:flex!important}.d-lg-inline-flex{display:inline-flex!important}.d-lg-none{display:none!important}.flex-lg-fill{flex:1 1 auto!important}.flex-lg-row{flex-direction:row!important}.flex-lg-column{flex-direction:column!important}.flex-lg-row-reverse{flex-direction:row-reverse!important}.flex-lg-column-reverse{flex-direction:column-reverse!important}.flex-lg-grow-0{flex-grow:0!important}.flex-lg-grow-1{flex-grow:1!important}.flex-lg-shrink-0{flex-shrink:0!important}.flex-lg-shrink-1{flex-shrink:1!important}.flex-lg-wrap{flex-wrap:wrap!important}.flex-lg-nowrap{flex-wrap:nowrap!important}.flex-lg-wrap-reverse{flex-wrap:wrap-reverse!important}.justify-content-lg-start{justify-content:flex-start!important}.justify-content-lg-end{justify-content:flex-end!important}.justify-content-lg-center{justify-content:center!important}.justify-content-lg-between{justify-content:space-between!important}.justify-content-lg-around{justify-content:space-around!important}.justify-content-lg-evenly{justify-content:space-evenly!important}.align-items-lg-start{align-items:flex-start!important}.align-items-lg-end{align-items:flex-end!important}.align-items-lg-center{align-items:center!important}.align-items-lg-baseline{align-items:baseline!important}.align-items-lg-stretch{align-items:stretch!important}.align-content-lg-start{align-content:flex-start!important}.align-content-lg-end{align-content:flex-end!important}.align-content-lg-center{align-content:center!important}.align-content-lg-between{align-content:space-between!important}.align-content-lg-around{align-content:space-around!important}.align-content-lg-stretch{align-content:stretch!important}.align-self-lg-auto{align-self:auto!important}.align-self-lg-start{align-self:flex-start!important}.align-self-lg-end{align-self:flex-end!important}.align-self-lg-center{align-self:center!important}.align-self-lg-baseline{align-self:baseline!important}.align-self-lg-stretch{align-self:stretch!important}.order-lg-first{order:-1!important}.order-lg-0{order:0!important}.order-lg-1{order:1!important}.order-lg-2{order:2!important}.order-lg-3{order:3!important}.order-lg-4{order:4!important}.order-lg-5{order:5!important}.order-lg-last{order:6!important}.m-lg-0{margin:0!important}.m-lg-1{margin:.25rem!important}.m-lg-2{margin:.5rem!important}.m-lg-3{margin:1rem!important}.m-lg-4{margin:1.5rem!important}.m-lg-5{margin:3rem!important}.m-lg-auto{margin:auto!important}.mx-lg-0{margin-right:0!important;margin-left:0!important}.mx-lg-1{margin-right:.25rem!important;margin-left:.25rem!important}.mx-lg-2{margin-right:.5rem!important;margin-left:.5rem!important}.mx-lg-3{margin-right:1rem!important;margin-left:1rem!important}.mx-lg-4{margin-right:1.5rem!important;margin-left:1.5rem!important}.mx-lg-5{margin-right:3rem!important;margin-left:3rem!important}.mx-lg-auto{margin-right:auto!important;margin-left:auto!important}.my-lg-0{margin-top:0!important;margin-bottom:0!important}.my-lg-1{margin-top:.25rem!important;margin-bottom:.25rem!important}.my-lg-2{margin-top:.5rem!important;margin-bottom:.5rem!important}.my-lg-3{margin-top:1rem!important;margin-bottom:1rem!important}.my-lg-4{margin-top:1.5rem!important;margin-bottom:1.5rem!important}.my-lg-5{margin-top:3rem!important;margin-bottom:3rem!important}.my-lg-auto{margin-top:auto!important;margin-bottom:auto!important}.mt-lg-0{margin-top:0!important}.mt-lg-1{margin-top:.25rem!important}.mt-lg-2{margin-top:.5rem!important}.mt-lg-3{margin-top:1rem!important}.mt-lg-4{margin-top:1.5rem!important}.mt-lg-5{margin-top:3rem!important}.mt-lg-auto{margin-top:auto!important}.me-lg-0{margin-right:0!important}.me-lg-1{margin-right:.25rem!important}.me-lg-2{margin-right:.5rem!important}.me-lg-3{margin-right:1rem!important}.me-lg-4{margin-right:1.5rem!important}.me-lg-5{margin-right:3rem!important}.me-lg-auto{margin-right:auto!important}.mb-lg-0{margin-bottom:0!important}.mb-lg-1{margin-bottom:.25rem!important}.mb-lg-2{margin-bottom:.5rem!important}.mb-lg-3{margin-bottom:1rem!important}.mb-lg-4{margin-bottom:1.5rem!important}.mb-lg-5{margin-bottom:3rem!important}.mb-lg-auto{margin-bottom:auto!important}.ms-lg-0{margin-left:0!important}.ms-lg-1{margin-left:.25rem!important}.ms-lg-2{margin-left:.5rem!important}.ms-lg-3{margin-left:1rem!important}.ms-lg-4{margin-left:1.5rem!important}.ms-lg-5{margin-left:3rem!important}.ms-lg-auto{margin-left:auto!important}.p-lg-0{padding:0!important}.p-lg-1{padding:.25rem!important}.p-lg-2{padding:.5rem!important}.p-lg-3{padding:1rem!important}.p-lg-4{padding:1.5rem!important}.p-lg-5{padding:3rem!important}.px-lg-0{padding-right:0!important;padding-left:0!important}.px-lg-1{padding-right:.25rem!important;padding-left:.25rem!important}.px-lg-2{padding-right:.5rem!important;padding-left:.5rem!important}.px-lg-3{padding-right:1rem!important;padding-left:1rem!important}.px-lg-4{padding-right:1.5rem!important;padding-left:1.5rem!important}.px-lg-5{padding-right:3rem!important;padding-left:3rem!important}.py-lg-0{padding-top:0!important;padding-bottom:0!important}.py-lg-1{padding-top:.25rem!important;padding-bottom:.25rem!important}.py-lg-2{padding-top:.5rem!important;padding-bottom:.5rem!important}.py-lg-3{padding-top:1rem!important;padding-bottom:1rem!important}.py-lg-4{padding-top:1.5rem!important;padding-bottom:1.5rem!important}.py-lg-5{padding-top:3rem!important;padding-bottom:3rem!important}.pt-lg-0{padding-top:0!important}.pt-lg-1{padding-top:.25rem!important}.pt-lg-2{padding-top:.5rem!important}.pt-lg-3{padding-top:1rem!important}.pt-lg-4{padding-top:1.5rem!important}.pt-lg-5{padding-top:3rem!important}.pe-lg-0{padding-right:0!important}.pe-lg-1{padding-right:.25rem!important}.pe-lg-2{padding-right:.5rem!important}.pe-lg-3{padding-right:1rem!important}.pe-lg-4{padding-right:1.5rem!important}.pe-lg-5{padding-right:3rem!important}.pb-lg-0{padding-bottom:0!important}.pb-lg-1{padding-bottom:.25rem!important}.pb-lg-2{padding-bottom:.5rem!important}.pb-lg-3{padding-bottom:1rem!important}.pb-lg-4{padding-bottom:1.5rem!important}.pb-lg-5{padding-bottom:3rem!important}.ps-lg-0{padding-left:0!important}.ps-lg-1{padding-left:.25rem!important}.ps-lg-2{padding-left:.5rem!important}.ps-lg-3{padding-left:1rem!important}.ps-lg-4{padding-left:1.5rem!important}.ps-lg-5{padding-left:3rem!important}.gap-lg-0{gap:0!important}.gap-lg-1{gap:.25rem!important}.gap-lg-2{gap:.5rem!important}.gap-lg-3{gap:1rem!important}.gap-lg-4{gap:1.5rem!important}.gap-lg-5{gap:3rem!important}.row-gap-lg-0{row-gap:0!important}.row-gap-lg-1{row-gap:.25rem!important}.row-gap-lg-2{row-gap:.5rem!important}.row-gap-lg-3{row-gap:1rem!important}.row-gap-lg-4{row-gap:1.5rem!important}.row-gap-lg-5{row-gap:3rem!important}.column-gap-lg-0{column-gap:0!important}.column-gap-lg-1{column-gap:.25rem!important}.column-gap-lg-2{column-gap:.5rem!important}.column-gap-lg-3{column-gap:1rem!important}.column-gap-lg-4{column-gap:1.5rem!important}.column-gap-lg-5{column-gap:3rem!important}.text-lg-start{text-align:left!important}.text-lg-end{text-align:right!important}.text-lg-center{text-align:center!important}}@media (min-width: 1200px){.float-xl-start{float:left!important}.float-xl-end{float:right!important}.float-xl-none{float:none!important}.object-fit-xl-contain{object-fit:contain!important}.object-fit-xl-cover{object-fit:cover!important}.object-fit-xl-fill{object-fit:fill!important}.object-fit-xl-scale{object-fit:scale-down!important}.object-fit-xl-none{object-fit:none!important}.d-xl-inline{display:inline!important}.d-xl-inline-block{display:inline-block!important}.d-xl-block{display:block!important}.d-xl-grid{display:grid!important}.d-xl-inline-grid{display:inline-grid!important}.d-xl-table{display:table!important}.d-xl-table-row{display:table-row!important}.d-xl-table-cell{display:table-cell!important}.d-xl-flex{display:flex!important}.d-xl-inline-flex{display:inline-flex!important}.d-xl-none{display:none!important}.flex-xl-fill{flex:1 1 auto!important}.flex-xl-row{flex-direction:row!important}.flex-xl-column{flex-direction:column!important}.flex-xl-row-reverse{flex-direction:row-reverse!important}.flex-xl-column-reverse{flex-direction:column-reverse!important}.flex-xl-grow-0{flex-grow:0!important}.flex-xl-grow-1{flex-grow:1!important}.flex-xl-shrink-0{flex-shrink:0!important}.flex-xl-shrink-1{flex-shrink:1!important}.flex-xl-wrap{flex-wrap:wrap!important}.flex-xl-nowrap{flex-wrap:nowrap!important}.flex-xl-wrap-reverse{flex-wrap:wrap-reverse!important}.justify-content-xl-start{justify-content:flex-start!important}.justify-content-xl-end{justify-content:flex-end!important}.justify-content-xl-center{justify-content:center!important}.justify-content-xl-between{justify-content:space-between!important}.justify-content-xl-around{justify-content:space-around!important}.justify-content-xl-evenly{justify-content:space-evenly!important}.align-items-xl-start{align-items:flex-start!important}.align-items-xl-end{align-items:flex-end!important}.align-items-xl-center{align-items:center!important}.align-items-xl-baseline{align-items:baseline!important}.align-items-xl-stretch{align-items:stretch!important}.align-content-xl-start{align-content:flex-start!important}.align-content-xl-end{align-content:flex-end!important}.align-content-xl-center{align-content:center!important}.align-content-xl-between{align-content:space-between!important}.align-content-xl-around{align-content:space-around!important}.align-content-xl-stretch{align-content:stretch!important}.align-self-xl-auto{align-self:auto!important}.align-self-xl-start{align-self:flex-start!important}.align-self-xl-end{align-self:flex-end!important}.align-self-xl-center{align-self:center!important}.align-self-xl-baseline{align-self:baseline!important}.align-self-xl-stretch{align-self:stretch!important}.order-xl-first{order:-1!important}.order-xl-0{order:0!important}.order-xl-1{order:1!important}.order-xl-2{order:2!important}.order-xl-3{order:3!important}.order-xl-4{order:4!important}.order-xl-5{order:5!important}.order-xl-last{order:6!important}.m-xl-0{margin:0!important}.m-xl-1{margin:.25rem!important}.m-xl-2{margin:.5rem!important}.m-xl-3{margin:1rem!important}.m-xl-4{margin:1.5rem!important}.m-xl-5{margin:3rem!important}.m-xl-auto{margin:auto!important}.mx-xl-0{margin-right:0!important;margin-left:0!important}.mx-xl-1{margin-right:.25rem!important;margin-left:.25rem!important}.mx-xl-2{margin-right:.5rem!important;margin-left:.5rem!important}.mx-xl-3{margin-right:1rem!important;margin-left:1rem!important}.mx-xl-4{margin-right:1.5rem!important;margin-left:1.5rem!important}.mx-xl-5{margin-right:3rem!important;margin-left:3rem!important}.mx-xl-auto{margin-right:auto!important;margin-left:auto!important}.my-xl-0{margin-top:0!important;margin-bottom:0!important}.my-xl-1{margin-top:.25rem!important;margin-bottom:.25rem!important}.my-xl-2{margin-top:.5rem!important;margin-bottom:.5rem!important}.my-xl-3{margin-top:1rem!important;margin-bottom:1rem!important}.my-xl-4{margin-top:1.5rem!important;margin-bottom:1.5rem!important}.my-xl-5{margin-top:3rem!important;margin-bottom:3rem!important}.my-xl-auto{margin-top:auto!important;margin-bottom:auto!important}.mt-xl-0{margin-top:0!important}.mt-xl-1{margin-top:.25rem!important}.mt-xl-2{margin-top:.5rem!important}.mt-xl-3{margin-top:1rem!important}.mt-xl-4{margin-top:1.5rem!important}.mt-xl-5{margin-top:3rem!important}.mt-xl-auto{margin-top:auto!important}.me-xl-0{margin-right:0!important}.me-xl-1{margin-right:.25rem!important}.me-xl-2{margin-right:.5rem!important}.me-xl-3{margin-right:1rem!important}.me-xl-4{margin-right:1.5rem!important}.me-xl-5{margin-right:3rem!important}.me-xl-auto{margin-right:auto!important}.mb-xl-0{margin-bottom:0!important}.mb-xl-1{margin-bottom:.25rem!important}.mb-xl-2{margin-bottom:.5rem!important}.mb-xl-3{margin-bottom:1rem!important}.mb-xl-4{margin-bottom:1.5rem!important}.mb-xl-5{margin-bottom:3rem!important}.mb-xl-auto{margin-bottom:auto!important}.ms-xl-0{margin-left:0!important}.ms-xl-1{margin-left:.25rem!important}.ms-xl-2{margin-left:.5rem!important}.ms-xl-3{margin-left:1rem!important}.ms-xl-4{margin-left:1.5rem!important}.ms-xl-5{margin-left:3rem!important}.ms-xl-auto{margin-left:auto!important}.p-xl-0{padding:0!important}.p-xl-1{padding:.25rem!important}.p-xl-2{padding:.5rem!important}.p-xl-3{padding:1rem!important}.p-xl-4{padding:1.5rem!important}.p-xl-5{padding:3rem!important}.px-xl-0{padding-right:0!important;padding-left:0!important}.px-xl-1{padding-right:.25rem!important;padding-left:.25rem!important}.px-xl-2{padding-right:.5rem!important;padding-left:.5rem!important}.px-xl-3{padding-right:1rem!important;padding-left:1rem!important}.px-xl-4{padding-right:1.5rem!important;padding-left:1.5rem!important}.px-xl-5{padding-right:3rem!important;padding-left:3rem!important}.py-xl-0{padding-top:0!important;padding-bottom:0!important}.py-xl-1{padding-top:.25rem!important;padding-bottom:.25rem!important}.py-xl-2{padding-top:.5rem!important;padding-bottom:.5rem!important}.py-xl-3{padding-top:1rem!important;padding-bottom:1rem!important}.py-xl-4{padding-top:1.5rem!important;padding-bottom:1.5rem!important}.py-xl-5{padding-top:3rem!important;padding-bottom:3rem!important}.pt-xl-0{padding-top:0!important}.pt-xl-1{padding-top:.25rem!important}.pt-xl-2{padding-top:.5rem!important}.pt-xl-3{padding-top:1rem!important}.pt-xl-4{padding-top:1.5rem!important}.pt-xl-5{padding-top:3rem!important}.pe-xl-0{padding-right:0!important}.pe-xl-1{padding-right:.25rem!important}.pe-xl-2{padding-right:.5rem!important}.pe-xl-3{padding-right:1rem!important}.pe-xl-4{padding-right:1.5rem!important}.pe-xl-5{padding-right:3rem!important}.pb-xl-0{padding-bottom:0!important}.pb-xl-1{padding-bottom:.25rem!important}.pb-xl-2{padding-bottom:.5rem!important}.pb-xl-3{padding-bottom:1rem!important}.pb-xl-4{padding-bottom:1.5rem!important}.pb-xl-5{padding-bottom:3rem!important}.ps-xl-0{padding-left:0!important}.ps-xl-1{padding-left:.25rem!important}.ps-xl-2{padding-left:.5rem!important}.ps-xl-3{padding-left:1rem!important}.ps-xl-4{padding-left:1.5rem!important}.ps-xl-5{padding-left:3rem!important}.gap-xl-0{gap:0!important}.gap-xl-1{gap:.25rem!important}.gap-xl-2{gap:.5rem!important}.gap-xl-3{gap:1rem!important}.gap-xl-4{gap:1.5rem!important}.gap-xl-5{gap:3rem!important}.row-gap-xl-0{row-gap:0!important}.row-gap-xl-1{row-gap:.25rem!important}.row-gap-xl-2{row-gap:.5rem!important}.row-gap-xl-3{row-gap:1rem!important}.row-gap-xl-4{row-gap:1.5rem!important}.row-gap-xl-5{row-gap:3rem!important}.column-gap-xl-0{column-gap:0!important}.column-gap-xl-1{column-gap:.25rem!important}.column-gap-xl-2{column-gap:.5rem!important}.column-gap-xl-3{column-gap:1rem!important}.column-gap-xl-4{column-gap:1.5rem!important}.column-gap-xl-5{column-gap:3rem!important}.text-xl-start{text-align:left!important}.text-xl-end{text-align:right!important}.text-xl-center{text-align:center!important}}@media (min-width: 1400px){.float-xxl-start{float:left!important}.float-xxl-end{float:right!important}.float-xxl-none{float:none!important}.object-fit-xxl-contain{object-fit:contain!important}.object-fit-xxl-cover{object-fit:cover!important}.object-fit-xxl-fill{object-fit:fill!important}.object-fit-xxl-scale{object-fit:scale-down!important}.object-fit-xxl-none{object-fit:none!important}.d-xxl-inline{display:inline!important}.d-xxl-inline-block{display:inline-block!important}.d-xxl-block{display:block!important}.d-xxl-grid{display:grid!important}.d-xxl-inline-grid{display:inline-grid!important}.d-xxl-table{display:table!important}.d-xxl-table-row{display:table-row!important}.d-xxl-table-cell{display:table-cell!important}.d-xxl-flex{display:flex!important}.d-xxl-inline-flex{display:inline-flex!important}.d-xxl-none{display:none!important}.flex-xxl-fill{flex:1 1 auto!important}.flex-xxl-row{flex-direction:row!important}.flex-xxl-column{flex-direction:column!important}.flex-xxl-row-reverse{flex-direction:row-reverse!important}.flex-xxl-column-reverse{flex-direction:column-reverse!important}.flex-xxl-grow-0{flex-grow:0!important}.flex-xxl-grow-1{flex-grow:1!important}.flex-xxl-shrink-0{flex-shrink:0!important}.flex-xxl-shrink-1{flex-shrink:1!important}.flex-xxl-wrap{flex-wrap:wrap!important}.flex-xxl-nowrap{flex-wrap:nowrap!important}.flex-xxl-wrap-reverse{flex-wrap:wrap-reverse!important}.justify-content-xxl-start{justify-content:flex-start!important}.justify-content-xxl-end{justify-content:flex-end!important}.justify-content-xxl-center{justify-content:center!important}.justify-content-xxl-between{justify-content:space-between!important}.justify-content-xxl-around{justify-content:space-around!important}.justify-content-xxl-evenly{justify-content:space-evenly!important}.align-items-xxl-start{align-items:flex-start!important}.align-items-xxl-end{align-items:flex-end!important}.align-items-xxl-center{align-items:center!important}.align-items-xxl-baseline{align-items:baseline!important}.align-items-xxl-stretch{align-items:stretch!important}.align-content-xxl-start{align-content:flex-start!important}.align-content-xxl-end{align-content:flex-end!important}.align-content-xxl-center{align-content:center!important}.align-content-xxl-between{align-content:space-between!important}.align-content-xxl-around{align-content:space-around!important}.align-content-xxl-stretch{align-content:stretch!important}.align-self-xxl-auto{align-self:auto!important}.align-self-xxl-start{align-self:flex-start!important}.align-self-xxl-end{align-self:flex-end!important}.align-self-xxl-center{align-self:center!important}.align-self-xxl-baseline{align-self:baseline!important}.align-self-xxl-stretch{align-self:stretch!important}.order-xxl-first{order:-1!important}.order-xxl-0{order:0!important}.order-xxl-1{order:1!important}.order-xxl-2{order:2!important}.order-xxl-3{order:3!important}.order-xxl-4{order:4!important}.order-xxl-5{order:5!important}.order-xxl-last{order:6!important}.m-xxl-0{margin:0!important}.m-xxl-1{margin:.25rem!important}.m-xxl-2{margin:.5rem!important}.m-xxl-3{margin:1rem!important}.m-xxl-4{margin:1.5rem!important}.m-xxl-5{margin:3rem!important}.m-xxl-auto{margin:auto!important}.mx-xxl-0{margin-right:0!important;margin-left:0!important}.mx-xxl-1{margin-right:.25rem!important;margin-left:.25rem!important}.mx-xxl-2{margin-right:.5rem!important;margin-left:.5rem!important}.mx-xxl-3{margin-right:1rem!important;margin-left:1rem!important}.mx-xxl-4{margin-right:1.5rem!important;margin-left:1.5rem!important}.mx-xxl-5{margin-right:3rem!important;margin-left:3rem!important}.mx-xxl-auto{margin-right:auto!important;margin-left:auto!important}.my-xxl-0{margin-top:0!important;margin-bottom:0!important}.my-xxl-1{margin-top:.25rem!important;margin-bottom:.25rem!important}.my-xxl-2{margin-top:.5rem!important;margin-bottom:.5rem!important}.my-xxl-3{margin-top:1rem!important;margin-bottom:1rem!important}.my-xxl-4{margin-top:1.5rem!important;margin-bottom:1.5rem!important}.my-xxl-5{margin-top:3rem!important;margin-bottom:3rem!important}.my-xxl-auto{margin-top:auto!important;margin-bottom:auto!important}.mt-xxl-0{margin-top:0!important}.mt-xxl-1{margin-top:.25rem!important}.mt-xxl-2{margin-top:.5rem!important}.mt-xxl-3{margin-top:1rem!important}.mt-xxl-4{margin-top:1.5rem!important}.mt-xxl-5{margin-top:3rem!important}.mt-xxl-auto{margin-top:auto!important}.me-xxl-0{margin-right:0!important}.me-xxl-1{margin-right:.25rem!important}.me-xxl-2{margin-right:.5rem!important}.me-xxl-3{margin-right:1rem!important}.me-xxl-4{margin-right:1.5rem!important}.me-xxl-5{margin-right:3rem!important}.me-xxl-auto{margin-right:auto!important}.mb-xxl-0{margin-bottom:0!important}.mb-xxl-1{margin-bottom:.25rem!important}.mb-xxl-2{margin-bottom:.5rem!important}.mb-xxl-3{margin-bottom:1rem!important}.mb-xxl-4{margin-bottom:1.5rem!important}.mb-xxl-5{margin-bottom:3rem!important}.mb-xxl-auto{margin-bottom:auto!important}.ms-xxl-0{margin-left:0!important}.ms-xxl-1{margin-left:.25rem!important}.ms-xxl-2{margin-left:.5rem!important}.ms-xxl-3{margin-left:1rem!important}.ms-xxl-4{margin-left:1.5rem!important}.ms-xxl-5{margin-left:3rem!important}.ms-xxl-auto{margin-left:auto!important}.p-xxl-0{padding:0!important}.p-xxl-1{padding:.25rem!important}.p-xxl-2{padding:.5rem!important}.p-xxl-3{padding:1rem!important}.p-xxl-4{padding:1.5rem!important}.p-xxl-5{padding:3rem!important}.px-xxl-0{padding-right:0!important;padding-left:0!important}.px-xxl-1{padding-right:.25rem!important;padding-left:.25rem!important}.px-xxl-2{padding-right:.5rem!important;padding-left:.5rem!important}.px-xxl-3{padding-right:1rem!important;padding-left:1rem!important}.px-xxl-4{padding-right:1.5rem!important;padding-left:1.5rem!important}.px-xxl-5{padding-right:3rem!important;padding-left:3rem!important}.py-xxl-0{padding-top:0!important;padding-bottom:0!important}.py-xxl-1{padding-top:.25rem!important;padding-bottom:.25rem!important}.py-xxl-2{padding-top:.5rem!important;padding-bottom:.5rem!important}.py-xxl-3{padding-top:1rem!important;padding-bottom:1rem!important}.py-xxl-4{padding-top:1.5rem!important;padding-bottom:1.5rem!important}.py-xxl-5{padding-top:3rem!important;padding-bottom:3rem!important}.pt-xxl-0{padding-top:0!important}.pt-xxl-1{padding-top:.25rem!important}.pt-xxl-2{padding-top:.5rem!important}.pt-xxl-3{padding-top:1rem!important}.pt-xxl-4{padding-top:1.5rem!important}.pt-xxl-5{padding-top:3rem!important}.pe-xxl-0{padding-right:0!important}.pe-xxl-1{padding-right:.25rem!important}.pe-xxl-2{padding-right:.5rem!important}.pe-xxl-3{padding-right:1rem!important}.pe-xxl-4{padding-right:1.5rem!important}.pe-xxl-5{padding-right:3rem!important}.pb-xxl-0{padding-bottom:0!important}.pb-xxl-1{padding-bottom:.25rem!important}.pb-xxl-2{padding-bottom:.5rem!important}.pb-xxl-3{padding-bottom:1rem!important}.pb-xxl-4{padding-bottom:1.5rem!important}.pb-xxl-5{padding-bottom:3rem!important}.ps-xxl-0{padding-left:0!important}.ps-xxl-1{padding-left:.25rem!important}.ps-xxl-2{padding-left:.5rem!important}.ps-xxl-3{padding-left:1rem!important}.ps-xxl-4{padding-left:1.5rem!important}.ps-xxl-5{padding-left:3rem!important}.gap-xxl-0{gap:0!important}.gap-xxl-1{gap:.25rem!important}.gap-xxl-2{gap:.5rem!important}.gap-xxl-3{gap:1rem!important}.gap-xxl-4{gap:1.5rem!important}.gap-xxl-5{gap:3rem!important}.row-gap-xxl-0{row-gap:0!important}.row-gap-xxl-1{row-gap:.25rem!important}.row-gap-xxl-2{row-gap:.5rem!important}.row-gap-xxl-3{row-gap:1rem!important}.row-gap-xxl-4{row-gap:1.5rem!important}.row-gap-xxl-5{row-gap:3rem!important}.column-gap-xxl-0{column-gap:0!important}.column-gap-xxl-1{column-gap:.25rem!important}.column-gap-xxl-2{column-gap:.5rem!important}.column-gap-xxl-3{column-gap:1rem!important}.column-gap-xxl-4{column-gap:1.5rem!important}.column-gap-xxl-5{column-gap:3rem!important}.text-xxl-start{text-align:left!important}.text-xxl-end{text-align:right!important}.text-xxl-center{text-align:center!important}}@media (min-width: 1200px){.fs-1{font-size:2.5rem!important}.fs-2{font-size:2rem!important}.fs-3{font-size:1.75rem!important}.fs-4{font-size:1.5rem!important}}@media print{.d-print-inline{display:inline!important}.d-print-inline-block{display:inline-block!important}.d-print-block{display:block!important}.d-print-grid{display:grid!important}.d-print-inline-grid{display:inline-grid!important}.d-print-table{display:table!important}.d-print-table-row{display:table-row!important}.d-print-table-cell{display:table-cell!important}.d-print-flex{display:flex!important}.d-print-inline-flex{display:inline-flex!important}.d-print-none{display:none!important}}\n"],"sourceRoot":""}]);
// Exports
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (___CSS_LOADER_EXPORT___);


/***/ },

/***/ "./node_modules/css-loader/dist/runtime/api.js"
/*!*****************************************************!*\
  !*** ./node_modules/css-loader/dist/runtime/api.js ***!
  \*****************************************************/
(module) {



/*
  MIT License http://www.opensource.org/licenses/mit-license.php
  Author Tobias Koppers @sokra
*/
module.exports = function (cssWithMappingToString) {
  var list = [];

  // return the list of modules as css string
  list.toString = function toString() {
    return this.map(function (item) {
      var content = "";
      var needLayer = typeof item[5] !== "undefined";
      if (item[4]) {
        content += "@supports (".concat(item[4], ") {");
      }
      if (item[2]) {
        content += "@media ".concat(item[2], " {");
      }
      if (needLayer) {
        content += "@layer".concat(item[5].length > 0 ? " ".concat(item[5]) : "", " {");
      }
      content += cssWithMappingToString(item);
      if (needLayer) {
        content += "}";
      }
      if (item[2]) {
        content += "}";
      }
      if (item[4]) {
        content += "}";
      }
      return content;
    }).join("");
  };

  // import a list of modules into the list
  list.i = function i(modules, media, dedupe, supports, layer) {
    if (typeof modules === "string") {
      modules = [[null, modules, undefined]];
    }
    var alreadyImportedModules = {};
    if (dedupe) {
      for (var k = 0; k < this.length; k++) {
        var id = this[k][0];
        if (id != null) {
          alreadyImportedModules[id] = true;
        }
      }
    }
    for (var _k = 0; _k < modules.length; _k++) {
      var item = [].concat(modules[_k]);
      if (dedupe && alreadyImportedModules[item[0]]) {
        continue;
      }
      if (typeof layer !== "undefined") {
        if (typeof item[5] === "undefined") {
          item[5] = layer;
        } else {
          item[1] = "@layer".concat(item[5].length > 0 ? " ".concat(item[5]) : "", " {").concat(item[1], "}");
          item[5] = layer;
        }
      }
      if (media) {
        if (!item[2]) {
          item[2] = media;
        } else {
          item[1] = "@media ".concat(item[2], " {").concat(item[1], "}");
          item[2] = media;
        }
      }
      if (supports) {
        if (!item[4]) {
          item[4] = "".concat(supports);
        } else {
          item[1] = "@supports (".concat(item[4], ") {").concat(item[1], "}");
          item[4] = supports;
        }
      }
      list.push(item);
    }
  };
  return list;
};

/***/ },

/***/ "./node_modules/css-loader/dist/runtime/getUrl.js"
/*!********************************************************!*\
  !*** ./node_modules/css-loader/dist/runtime/getUrl.js ***!
  \********************************************************/
(module) {



module.exports = function (url, options) {
  if (!options) {
    options = {};
  }
  if (!url) {
    return url;
  }
  url = String(url.__esModule ? url.default : url);

  // If url is already wrapped in quotes, remove them
  if (/^['"].*['"]$/.test(url)) {
    url = url.slice(1, -1);
  }
  if (options.hash) {
    url += options.hash;
  }

  // Should url be wrapped?
  // See https://drafts.csswg.org/css-values-3/#urls
  if (/["'() \t\n]|(%20)/.test(url) || options.needQuotes) {
    return "\"".concat(url.replace(/"/g, '\\"').replace(/\n/g, "\\n"), "\"");
  }
  return url;
};

/***/ },

/***/ "./node_modules/css-loader/dist/runtime/sourceMaps.js"
/*!************************************************************!*\
  !*** ./node_modules/css-loader/dist/runtime/sourceMaps.js ***!
  \************************************************************/
(module) {



module.exports = function (item) {
  var content = item[1];
  var cssMapping = item[3];
  if (!cssMapping) {
    return content;
  }
  if (typeof btoa === "function") {
    var base64 = btoa(unescape(encodeURIComponent(JSON.stringify(cssMapping))));
    var data = "sourceMappingURL=data:application/json;charset=utf-8;base64,".concat(base64);
    var sourceMapping = "/*# ".concat(data, " */");
    return [content].concat([sourceMapping]).join("\n");
  }
  return [content].join("\n");
};

/***/ },

/***/ "./node_modules/style-loader/dist/runtime/injectStylesIntoStyleTag.js"
/*!****************************************************************************!*\
  !*** ./node_modules/style-loader/dist/runtime/injectStylesIntoStyleTag.js ***!
  \****************************************************************************/
(module) {



var stylesInDOM = [];
function getIndexByIdentifier(identifier) {
  var result = -1;
  for (var i = 0; i < stylesInDOM.length; i++) {
    if (stylesInDOM[i].identifier === identifier) {
      result = i;
      break;
    }
  }
  return result;
}
function modulesToDom(list, options) {
  var idCountMap = {};
  var identifiers = [];
  for (var i = 0; i < list.length; i++) {
    var item = list[i];
    var id = options.base ? item[0] + options.base : item[0];
    var count = idCountMap[id] || 0;
    var identifier = "".concat(id, " ").concat(count);
    idCountMap[id] = count + 1;
    var indexByIdentifier = getIndexByIdentifier(identifier);
    var obj = {
      css: item[1],
      media: item[2],
      sourceMap: item[3],
      supports: item[4],
      layer: item[5]
    };
    if (indexByIdentifier !== -1) {
      stylesInDOM[indexByIdentifier].references++;
      stylesInDOM[indexByIdentifier].updater(obj);
    } else {
      var updater = addElementStyle(obj, options);
      options.byIndex = i;
      stylesInDOM.splice(i, 0, {
        identifier: identifier,
        updater: updater,
        references: 1
      });
    }
    identifiers.push(identifier);
  }
  return identifiers;
}
function addElementStyle(obj, options) {
  var api = options.domAPI(options);
  api.update(obj);
  var updater = function updater(newObj) {
    if (newObj) {
      if (newObj.css === obj.css && newObj.media === obj.media && newObj.sourceMap === obj.sourceMap && newObj.supports === obj.supports && newObj.layer === obj.layer) {
        return;
      }
      api.update(obj = newObj);
    } else {
      api.remove();
    }
  };
  return updater;
}
module.exports = function (list, options) {
  options = options || {};
  list = list || [];
  var lastIdentifiers = modulesToDom(list, options);
  return function update(newList) {
    newList = newList || [];
    for (var i = 0; i < lastIdentifiers.length; i++) {
      var identifier = lastIdentifiers[i];
      var index = getIndexByIdentifier(identifier);
      stylesInDOM[index].references--;
    }
    var newLastIdentifiers = modulesToDom(newList, options);
    for (var _i = 0; _i < lastIdentifiers.length; _i++) {
      var _identifier = lastIdentifiers[_i];
      var _index = getIndexByIdentifier(_identifier);
      if (stylesInDOM[_index].references === 0) {
        stylesInDOM[_index].updater();
        stylesInDOM.splice(_index, 1);
      }
    }
    lastIdentifiers = newLastIdentifiers;
  };
};

/***/ },

/***/ "./node_modules/style-loader/dist/runtime/insertBySelector.js"
/*!********************************************************************!*\
  !*** ./node_modules/style-loader/dist/runtime/insertBySelector.js ***!
  \********************************************************************/
(module) {



var memo = {};

/* istanbul ignore next  */
function getTarget(target) {
  if (typeof memo[target] === "undefined") {
    var styleTarget = document.querySelector(target);

    // Special case to return head of iframe instead of iframe itself
    if (window.HTMLIFrameElement && styleTarget instanceof window.HTMLIFrameElement) {
      try {
        // This will throw an exception if access to iframe is blocked
        // due to cross-origin restrictions
        styleTarget = styleTarget.contentDocument.head;
      } catch (e) {
        // istanbul ignore next
        styleTarget = null;
      }
    }
    memo[target] = styleTarget;
  }
  return memo[target];
}

/* istanbul ignore next  */
function insertBySelector(insert, style) {
  var target = getTarget(insert);
  if (!target) {
    throw new Error("Couldn't find a style target. This probably means that the value for the 'insert' parameter is invalid.");
  }
  target.appendChild(style);
}
module.exports = insertBySelector;

/***/ },

/***/ "./node_modules/style-loader/dist/runtime/insertStyleElement.js"
/*!**********************************************************************!*\
  !*** ./node_modules/style-loader/dist/runtime/insertStyleElement.js ***!
  \**********************************************************************/
(module) {



/* istanbul ignore next  */
function insertStyleElement(options) {
  var element = document.createElement("style");
  options.setAttributes(element, options.attributes);
  options.insert(element, options.options);
  return element;
}
module.exports = insertStyleElement;

/***/ },

/***/ "./node_modules/style-loader/dist/runtime/setAttributesWithoutAttributes.js"
/*!**********************************************************************************!*\
  !*** ./node_modules/style-loader/dist/runtime/setAttributesWithoutAttributes.js ***!
  \**********************************************************************************/
(module, __unused_webpack_exports, __webpack_require__) {



/* istanbul ignore next  */
function setAttributesWithoutAttributes(styleElement) {
  var nonce =  true ? __webpack_require__.nc : 0;
  if (nonce) {
    styleElement.setAttribute("nonce", nonce);
  }
}
module.exports = setAttributesWithoutAttributes;

/***/ },

/***/ "./node_modules/style-loader/dist/runtime/styleDomAPI.js"
/*!***************************************************************!*\
  !*** ./node_modules/style-loader/dist/runtime/styleDomAPI.js ***!
  \***************************************************************/
(module) {



/* istanbul ignore next  */
function apply(styleElement, options, obj) {
  var css = "";
  if (obj.supports) {
    css += "@supports (".concat(obj.supports, ") {");
  }
  if (obj.media) {
    css += "@media ".concat(obj.media, " {");
  }
  var needLayer = typeof obj.layer !== "undefined";
  if (needLayer) {
    css += "@layer".concat(obj.layer.length > 0 ? " ".concat(obj.layer) : "", " {");
  }
  css += obj.css;
  if (needLayer) {
    css += "}";
  }
  if (obj.media) {
    css += "}";
  }
  if (obj.supports) {
    css += "}";
  }
  var sourceMap = obj.sourceMap;
  if (sourceMap && typeof btoa !== "undefined") {
    css += "\n/*# sourceMappingURL=data:application/json;base64,".concat(btoa(unescape(encodeURIComponent(JSON.stringify(sourceMap)))), " */");
  }

  // For old IE
  /* istanbul ignore if  */
  options.styleTagTransform(css, styleElement, options.options);
}
function removeStyleElement(styleElement) {
  // istanbul ignore if
  if (styleElement.parentNode === null) {
    return false;
  }
  styleElement.parentNode.removeChild(styleElement);
}

/* istanbul ignore next  */
function domAPI(options) {
  if (typeof document === "undefined") {
    return {
      update: function update() {},
      remove: function remove() {}
    };
  }
  var styleElement = options.insertStyleElement(options);
  return {
    update: function update(obj) {
      apply(styleElement, options, obj);
    },
    remove: function remove() {
      removeStyleElement(styleElement);
    }
  };
}
module.exports = domAPI;

/***/ },

/***/ "./node_modules/style-loader/dist/runtime/styleTagTransform.js"
/*!*********************************************************************!*\
  !*** ./node_modules/style-loader/dist/runtime/styleTagTransform.js ***!
  \*********************************************************************/
(module) {



/* istanbul ignore next  */
function styleTagTransform(css, styleElement) {
  if (styleElement.styleSheet) {
    styleElement.styleSheet.cssText = css;
  } else {
    while (styleElement.firstChild) {
      styleElement.removeChild(styleElement.firstChild);
    }
    styleElement.appendChild(document.createTextNode(css));
  }
}
module.exports = styleTagTransform;

/***/ }

}]);
//# sourceMappingURL=vendors-node_modules_style-loader_dist_runtime_injectStylesIntoStyleTag_js-node_modules_style-12ea8e.5b1d5b8c92aa504e9e99.js.map