"use strict";
(self["webpackChunkclimb_dashboard_gui_extension"] = self["webpackChunkclimb_dashboard_gui_extension"] || []).push([["vendors-node_modules_climb-dashboard-gui_dist_climb-dashboard-gui_js"],{

/***/ "./node_modules/climb-dashboard-gui/dist/climb-dashboard-gui.js"
/*!**********************************************************************!*\
  !*** ./node_modules/climb-dashboard-gui/dist/climb-dashboard-gui.js ***!
  \**********************************************************************/
(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ LD)
/* harmony export */ });
/* harmony import */ var react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react/jsx-runtime */ "./node_modules/react/jsx-runtime.js");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_1__);



function s0(c) {
  return c && c.__esModule && Object.prototype.hasOwnProperty.call(c, "default") ? c.default : c;
}
var Nb = { exports: {} };
/*!
	Copyright (c) 2018 Jed Watson.
	Licensed under the MIT License (MIT), see
	http://jedwatson.github.io/classnames
*/
(function(c) {
  (function() {
    var p = {}.hasOwnProperty;
    function g() {
      for (var C = "", y = 0; y < arguments.length; y++) {
        var D = arguments[y];
        D && (C = b(C, h(D)));
      }
      return C;
    }
    function h(C) {
      if (typeof C == "string" || typeof C == "number")
        return C;
      if (typeof C != "object")
        return "";
      if (Array.isArray(C))
        return g.apply(null, C);
      if (C.toString !== Object.prototype.toString && !C.toString.toString().includes("[native code]"))
        return C.toString();
      var y = "";
      for (var D in C)
        p.call(C, D) && C[D] && (y = b(y, D));
      return y;
    }
    function b(C, y) {
      return y ? C ? C + " " + y : C + y : C;
    }
    c.exports ? (g.default = g, c.exports = g) : window.classNames = g;
  })();
})(Nb);
var Rk = Nb.exports;
const yt = /* @__PURE__ */ s0(Rk), Mb = ["xxl", "xl", "lg", "md", "sm", "xs"], Lb = "xs", c0 = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.createContext({
  prefixes: {},
  breakpoints: Mb,
  minBreakpoint: Lb
});
function Lt(c, p) {
  const {
    prefixes: g
  } = (0,react__WEBPACK_IMPORTED_MODULE_1__.useContext)(c0);
  return c || g[p] || p;
}
function xk() {
  const {
    breakpoints: c
  } = (0,react__WEBPACK_IMPORTED_MODULE_1__.useContext)(c0);
  return c;
}
function wk() {
  const {
    minBreakpoint: c
  } = (0,react__WEBPACK_IMPORTED_MODULE_1__.useContext)(c0);
  return c;
}
var n0 = { exports: {} }, vh = { exports: {} }, Ct = {};
/** @license React v16.13.1
 * react-is.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
var ZC;
function kk() {
  if (ZC) return Ct;
  ZC = 1;
  var c = typeof Symbol == "function" && Symbol.for, p = c ? Symbol.for("react.element") : 60103, g = c ? Symbol.for("react.portal") : 60106, h = c ? Symbol.for("react.fragment") : 60107, b = c ? Symbol.for("react.strict_mode") : 60108, C = c ? Symbol.for("react.profiler") : 60114, y = c ? Symbol.for("react.provider") : 60109, D = c ? Symbol.for("react.context") : 60110, A = c ? Symbol.for("react.async_mode") : 60111, L = c ? Symbol.for("react.concurrent_mode") : 60111, I = c ? Symbol.for("react.forward_ref") : 60112, B = c ? Symbol.for("react.suspense") : 60113, Y = c ? Symbol.for("react.suspense_list") : 60120, re = c ? Symbol.for("react.memo") : 60115, ue = c ? Symbol.for("react.lazy") : 60116, Te = c ? Symbol.for("react.block") : 60121, ce = c ? Symbol.for("react.fundamental") : 60117, _e = c ? Symbol.for("react.responder") : 60118, we = c ? Symbol.for("react.scope") : 60119;
  function ee(z) {
    if (typeof z == "object" && z !== null) {
      var le = z.$$typeof;
      switch (le) {
        case p:
          switch (z = z.type, z) {
            case A:
            case L:
            case h:
            case C:
            case b:
            case B:
              return z;
            default:
              switch (z = z && z.$$typeof, z) {
                case D:
                case I:
                case ue:
                case re:
                case y:
                  return z;
                default:
                  return le;
              }
          }
        case g:
          return le;
      }
    }
  }
  function ie(z) {
    return ee(z) === L;
  }
  return Ct.AsyncMode = A, Ct.ConcurrentMode = L, Ct.ContextConsumer = D, Ct.ContextProvider = y, Ct.Element = p, Ct.ForwardRef = I, Ct.Fragment = h, Ct.Lazy = ue, Ct.Memo = re, Ct.Portal = g, Ct.Profiler = C, Ct.StrictMode = b, Ct.Suspense = B, Ct.isAsyncMode = function(z) {
    return ie(z) || ee(z) === A;
  }, Ct.isConcurrentMode = ie, Ct.isContextConsumer = function(z) {
    return ee(z) === D;
  }, Ct.isContextProvider = function(z) {
    return ee(z) === y;
  }, Ct.isElement = function(z) {
    return typeof z == "object" && z !== null && z.$$typeof === p;
  }, Ct.isForwardRef = function(z) {
    return ee(z) === I;
  }, Ct.isFragment = function(z) {
    return ee(z) === h;
  }, Ct.isLazy = function(z) {
    return ee(z) === ue;
  }, Ct.isMemo = function(z) {
    return ee(z) === re;
  }, Ct.isPortal = function(z) {
    return ee(z) === g;
  }, Ct.isProfiler = function(z) {
    return ee(z) === C;
  }, Ct.isStrictMode = function(z) {
    return ee(z) === b;
  }, Ct.isSuspense = function(z) {
    return ee(z) === B;
  }, Ct.isValidElementType = function(z) {
    return typeof z == "string" || typeof z == "function" || z === h || z === L || z === C || z === b || z === B || z === Y || typeof z == "object" && z !== null && (z.$$typeof === ue || z.$$typeof === re || z.$$typeof === y || z.$$typeof === D || z.$$typeof === I || z.$$typeof === ce || z.$$typeof === _e || z.$$typeof === we || z.$$typeof === Te);
  }, Ct.typeOf = ee, Ct;
}
var bt = {};
/** @license React v16.13.1
 * react-is.development.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
var JC;
function _k() {
  return JC || (JC = 1,  true && function() {
    var c = typeof Symbol == "function" && Symbol.for, p = c ? Symbol.for("react.element") : 60103, g = c ? Symbol.for("react.portal") : 60106, h = c ? Symbol.for("react.fragment") : 60107, b = c ? Symbol.for("react.strict_mode") : 60108, C = c ? Symbol.for("react.profiler") : 60114, y = c ? Symbol.for("react.provider") : 60109, D = c ? Symbol.for("react.context") : 60110, A = c ? Symbol.for("react.async_mode") : 60111, L = c ? Symbol.for("react.concurrent_mode") : 60111, I = c ? Symbol.for("react.forward_ref") : 60112, B = c ? Symbol.for("react.suspense") : 60113, Y = c ? Symbol.for("react.suspense_list") : 60120, re = c ? Symbol.for("react.memo") : 60115, ue = c ? Symbol.for("react.lazy") : 60116, Te = c ? Symbol.for("react.block") : 60121, ce = c ? Symbol.for("react.fundamental") : 60117, _e = c ? Symbol.for("react.responder") : 60118, we = c ? Symbol.for("react.scope") : 60119;
    function ee(ne) {
      return typeof ne == "string" || typeof ne == "function" || // Note: its typeof might be other than 'symbol' or 'number' if it's a polyfill.
      ne === h || ne === L || ne === C || ne === b || ne === B || ne === Y || typeof ne == "object" && ne !== null && (ne.$$typeof === ue || ne.$$typeof === re || ne.$$typeof === y || ne.$$typeof === D || ne.$$typeof === I || ne.$$typeof === ce || ne.$$typeof === _e || ne.$$typeof === we || ne.$$typeof === Te);
    }
    function ie(ne) {
      if (typeof ne == "object" && ne !== null) {
        var At = ne.$$typeof;
        switch (At) {
          case p:
            var Yt = ne.type;
            switch (Yt) {
              case A:
              case L:
              case h:
              case C:
              case b:
              case B:
                return Yt;
              default:
                var tt = Yt && Yt.$$typeof;
                switch (tt) {
                  case D:
                  case I:
                  case ue:
                  case re:
                  case y:
                    return tt;
                  default:
                    return At;
                }
            }
          case g:
            return At;
        }
      }
    }
    var z = A, le = L, Se = D, We = y, Ae = p, lt = I, it = h, ot = ue, rt = re, ut = g, st = C, Be = b, mt = B, Ke = !1;
    function Rt(ne) {
      return Ke || (Ke = !0, console.warn("The ReactIs.isAsyncMode() alias has been deprecated, and will be removed in React 17+. Update your code to use ReactIs.isConcurrentMode() instead. It has the exact same API.")), Z(ne) || ie(ne) === A;
    }
    function Z(ne) {
      return ie(ne) === L;
    }
    function F(ne) {
      return ie(ne) === D;
    }
    function te(ne) {
      return ie(ne) === y;
    }
    function G(ne) {
      return typeof ne == "object" && ne !== null && ne.$$typeof === p;
    }
    function oe(ne) {
      return ie(ne) === I;
    }
    function ve(ne) {
      return ie(ne) === h;
    }
    function Re(ne) {
      return ie(ne) === ue;
    }
    function Oe(ne) {
      return ie(ne) === re;
    }
    function xe(ne) {
      return ie(ne) === g;
    }
    function Ne(ne) {
      return ie(ne) === C;
    }
    function Fe(ne) {
      return ie(ne) === b;
    }
    function Ze(ne) {
      return ie(ne) === B;
    }
    bt.AsyncMode = z, bt.ConcurrentMode = le, bt.ContextConsumer = Se, bt.ContextProvider = We, bt.Element = Ae, bt.ForwardRef = lt, bt.Fragment = it, bt.Lazy = ot, bt.Memo = rt, bt.Portal = ut, bt.Profiler = st, bt.StrictMode = Be, bt.Suspense = mt, bt.isAsyncMode = Rt, bt.isConcurrentMode = Z, bt.isContextConsumer = F, bt.isContextProvider = te, bt.isElement = G, bt.isForwardRef = oe, bt.isFragment = ve, bt.isLazy = Re, bt.isMemo = Oe, bt.isPortal = xe, bt.isProfiler = Ne, bt.isStrictMode = Fe, bt.isSuspense = Ze, bt.isValidElementType = ee, bt.typeOf = ie;
  }()), bt;
}
var eb;
function Ab() {
  return eb || (eb = 1,  false ? 0 : vh.exports = _k()), vh.exports;
}
/*
object-assign
(c) Sindre Sorhus
@license MIT
*/
var Pg, tb;
function f0() {
  if (tb) return Pg;
  tb = 1;
  var c = Object.getOwnPropertySymbols, p = Object.prototype.hasOwnProperty, g = Object.prototype.propertyIsEnumerable;
  function h(C) {
    if (C == null)
      throw new TypeError("Object.assign cannot be called with null or undefined");
    return Object(C);
  }
  function b() {
    try {
      if (!Object.assign)
        return !1;
      var C = new String("abc");
      if (C[5] = "de", Object.getOwnPropertyNames(C)[0] === "5")
        return !1;
      for (var y = {}, D = 0; D < 10; D++)
        y["_" + String.fromCharCode(D)] = D;
      var A = Object.getOwnPropertyNames(y).map(function(I) {
        return y[I];
      });
      if (A.join("") !== "0123456789")
        return !1;
      var L = {};
      return "abcdefghijklmnopqrst".split("").forEach(function(I) {
        L[I] = I;
      }), Object.keys(Object.assign({}, L)).join("") === "abcdefghijklmnopqrst";
    } catch {
      return !1;
    }
  }
  return Pg = b() ? Object.assign : function(C, y) {
    for (var D, A = h(C), L, I = 1; I < arguments.length; I++) {
      D = Object(arguments[I]);
      for (var B in D)
        p.call(D, B) && (A[B] = D[B]);
      if (c) {
        L = c(D);
        for (var Y = 0; Y < L.length; Y++)
          g.call(D, L[Y]) && (A[L[Y]] = D[L[Y]]);
      }
    }
    return A;
  }, Pg;
}
var Bg, nb;
function d0() {
  if (nb) return Bg;
  nb = 1;
  var c = "SECRET_DO_NOT_PASS_THIS_OR_YOU_WILL_BE_FIRED";
  return Bg = c, Bg;
}
var Vg, rb;
function Ub() {
  return rb || (rb = 1, Vg = Function.call.bind(Object.prototype.hasOwnProperty)), Vg;
}
var Ig, ab;
function Dk() {
  if (ab) return Ig;
  ab = 1;
  var c = function() {
  };
  if (true) {
    var p = d0(), g = {}, h = Ub();
    c = function(C) {
      var y = "Warning: " + C;
      typeof console < "u" && console.error(y);
      try {
        throw new Error(y);
      } catch {
      }
    };
  }
  function b(C, y, D, A, L) {
    if (true) {
      for (var I in C)
        if (h(C, I)) {
          var B;
          try {
            if (typeof C[I] != "function") {
              var Y = Error(
                (A || "React class") + ": " + D + " type `" + I + "` is invalid; it must be a function, usually from the `prop-types` package, but received `" + typeof C[I] + "`.This often happens because of typos such as `PropTypes.function` instead of `PropTypes.func`."
              );
              throw Y.name = "Invariant Violation", Y;
            }
            B = C[I](y, I, A, D, null, p);
          } catch (ue) {
            B = ue;
          }
          if (B && !(B instanceof Error) && c(
            (A || "React class") + ": type specification of " + D + " `" + I + "` is invalid; the type checker function must return `null` or an `Error` but returned a " + typeof B + ". You may have forgotten to pass an argument to the type checker creator (arrayOf, instanceOf, objectOf, oneOf, oneOfType, and shape all require an argument)."
          ), B instanceof Error && !(B.message in g)) {
            g[B.message] = !0;
            var re = L ? L() : "";
            c(
              "Failed " + D + " type: " + B.message + (re ?? "")
            );
          }
        }
    }
  }
  return b.resetWarningCache = function() {
     true && (g = {});
  }, Ig = b, Ig;
}
var $g, ib;
function Ok() {
  if (ib) return $g;
  ib = 1;
  var c = Ab(), p = f0(), g = d0(), h = Ub(), b = Dk(), C = function() {
  };
   true && (C = function(D) {
    var A = "Warning: " + D;
    typeof console < "u" && console.error(A);
    try {
      throw new Error(A);
    } catch {
    }
  });
  function y() {
    return null;
  }
  return $g = function(D, A) {
    var L = typeof Symbol == "function" && Symbol.iterator, I = "@@iterator";
    function B(Z) {
      var F = Z && (L && Z[L] || Z[I]);
      if (typeof F == "function")
        return F;
    }
    var Y = "<<anonymous>>", re = {
      array: _e("array"),
      bigint: _e("bigint"),
      bool: _e("boolean"),
      func: _e("function"),
      number: _e("number"),
      object: _e("object"),
      string: _e("string"),
      symbol: _e("symbol"),
      any: we(),
      arrayOf: ee,
      element: ie(),
      elementType: z(),
      instanceOf: le,
      node: lt(),
      objectOf: We,
      oneOf: Se,
      oneOfType: Ae,
      shape: ot,
      exact: rt
    };
    function ue(Z, F) {
      return Z === F ? Z !== 0 || 1 / Z === 1 / F : Z !== Z && F !== F;
    }
    function Te(Z, F) {
      this.message = Z, this.data = F && typeof F == "object" ? F : {}, this.stack = "";
    }
    Te.prototype = Error.prototype;
    function ce(Z) {
      if (true)
        var F = {}, te = 0;
      function G(ve, Re, Oe, xe, Ne, Fe, Ze) {
        if (xe = xe || Y, Fe = Fe || Oe, Ze !== g) {
          if (A) {
            var ne = new Error(
              "Calling PropTypes validators directly is not supported by the `prop-types` package. Use `PropTypes.checkPropTypes()` to call them. Read more at http://fb.me/use-check-prop-types"
            );
            throw ne.name = "Invariant Violation", ne;
          } else if ( true && typeof console < "u") {
            var At = xe + ":" + Oe;
            !F[At] && // Avoid spamming the console because they are often not actionable except for lib authors
            te < 3 && (C(
              "You are manually calling a React.PropTypes validation function for the `" + Fe + "` prop on `" + xe + "`. This is deprecated and will throw in the standalone `prop-types` package. You may be seeing this warning due to a third-party PropTypes library. See https://fb.me/react-warning-dont-call-proptypes for details."
            ), F[At] = !0, te++);
          }
        }
        return Re[Oe] == null ? ve ? Re[Oe] === null ? new Te("The " + Ne + " `" + Fe + "` is marked as required " + ("in `" + xe + "`, but its value is `null`.")) : new Te("The " + Ne + " `" + Fe + "` is marked as required in " + ("`" + xe + "`, but its value is `undefined`.")) : null : Z(Re, Oe, xe, Ne, Fe);
      }
      var oe = G.bind(null, !1);
      return oe.isRequired = G.bind(null, !0), oe;
    }
    function _e(Z) {
      function F(te, G, oe, ve, Re, Oe) {
        var xe = te[G], Ne = Be(xe);
        if (Ne !== Z) {
          var Fe = mt(xe);
          return new Te(
            "Invalid " + ve + " `" + Re + "` of type " + ("`" + Fe + "` supplied to `" + oe + "`, expected ") + ("`" + Z + "`."),
            { expectedType: Z }
          );
        }
        return null;
      }
      return ce(F);
    }
    function we() {
      return ce(y);
    }
    function ee(Z) {
      function F(te, G, oe, ve, Re) {
        if (typeof Z != "function")
          return new Te("Property `" + Re + "` of component `" + oe + "` has invalid PropType notation inside arrayOf.");
        var Oe = te[G];
        if (!Array.isArray(Oe)) {
          var xe = Be(Oe);
          return new Te("Invalid " + ve + " `" + Re + "` of type " + ("`" + xe + "` supplied to `" + oe + "`, expected an array."));
        }
        for (var Ne = 0; Ne < Oe.length; Ne++) {
          var Fe = Z(Oe, Ne, oe, ve, Re + "[" + Ne + "]", g);
          if (Fe instanceof Error)
            return Fe;
        }
        return null;
      }
      return ce(F);
    }
    function ie() {
      function Z(F, te, G, oe, ve) {
        var Re = F[te];
        if (!D(Re)) {
          var Oe = Be(Re);
          return new Te("Invalid " + oe + " `" + ve + "` of type " + ("`" + Oe + "` supplied to `" + G + "`, expected a single ReactElement."));
        }
        return null;
      }
      return ce(Z);
    }
    function z() {
      function Z(F, te, G, oe, ve) {
        var Re = F[te];
        if (!c.isValidElementType(Re)) {
          var Oe = Be(Re);
          return new Te("Invalid " + oe + " `" + ve + "` of type " + ("`" + Oe + "` supplied to `" + G + "`, expected a single ReactElement type."));
        }
        return null;
      }
      return ce(Z);
    }
    function le(Z) {
      function F(te, G, oe, ve, Re) {
        if (!(te[G] instanceof Z)) {
          var Oe = Z.name || Y, xe = Rt(te[G]);
          return new Te("Invalid " + ve + " `" + Re + "` of type " + ("`" + xe + "` supplied to `" + oe + "`, expected ") + ("instance of `" + Oe + "`."));
        }
        return null;
      }
      return ce(F);
    }
    function Se(Z) {
      if (!Array.isArray(Z))
        return  true && (arguments.length > 1 ? C(
          "Invalid arguments supplied to oneOf, expected an array, got " + arguments.length + " arguments. A common mistake is to write oneOf(x, y, z) instead of oneOf([x, y, z])."
        ) : C("Invalid argument supplied to oneOf, expected an array.")), y;
      function F(te, G, oe, ve, Re) {
        for (var Oe = te[G], xe = 0; xe < Z.length; xe++)
          if (ue(Oe, Z[xe]))
            return null;
        var Ne = JSON.stringify(Z, function(Ze, ne) {
          var At = mt(ne);
          return At === "symbol" ? String(ne) : ne;
        });
        return new Te("Invalid " + ve + " `" + Re + "` of value `" + String(Oe) + "` " + ("supplied to `" + oe + "`, expected one of " + Ne + "."));
      }
      return ce(F);
    }
    function We(Z) {
      function F(te, G, oe, ve, Re) {
        if (typeof Z != "function")
          return new Te("Property `" + Re + "` of component `" + oe + "` has invalid PropType notation inside objectOf.");
        var Oe = te[G], xe = Be(Oe);
        if (xe !== "object")
          return new Te("Invalid " + ve + " `" + Re + "` of type " + ("`" + xe + "` supplied to `" + oe + "`, expected an object."));
        for (var Ne in Oe)
          if (h(Oe, Ne)) {
            var Fe = Z(Oe, Ne, oe, ve, Re + "." + Ne, g);
            if (Fe instanceof Error)
              return Fe;
          }
        return null;
      }
      return ce(F);
    }
    function Ae(Z) {
      if (!Array.isArray(Z))
        return  true && C("Invalid argument supplied to oneOfType, expected an instance of array."), y;
      for (var F = 0; F < Z.length; F++) {
        var te = Z[F];
        if (typeof te != "function")
          return C(
            "Invalid argument supplied to oneOfType. Expected an array of check functions, but received " + Ke(te) + " at index " + F + "."
          ), y;
      }
      function G(oe, ve, Re, Oe, xe) {
        for (var Ne = [], Fe = 0; Fe < Z.length; Fe++) {
          var Ze = Z[Fe], ne = Ze(oe, ve, Re, Oe, xe, g);
          if (ne == null)
            return null;
          ne.data && h(ne.data, "expectedType") && Ne.push(ne.data.expectedType);
        }
        var At = Ne.length > 0 ? ", expected one of type [" + Ne.join(", ") + "]" : "";
        return new Te("Invalid " + Oe + " `" + xe + "` supplied to " + ("`" + Re + "`" + At + "."));
      }
      return ce(G);
    }
    function lt() {
      function Z(F, te, G, oe, ve) {
        return ut(F[te]) ? null : new Te("Invalid " + oe + " `" + ve + "` supplied to " + ("`" + G + "`, expected a ReactNode."));
      }
      return ce(Z);
    }
    function it(Z, F, te, G, oe) {
      return new Te(
        (Z || "React class") + ": " + F + " type `" + te + "." + G + "` is invalid; it must be a function, usually from the `prop-types` package, but received `" + oe + "`."
      );
    }
    function ot(Z) {
      function F(te, G, oe, ve, Re) {
        var Oe = te[G], xe = Be(Oe);
        if (xe !== "object")
          return new Te("Invalid " + ve + " `" + Re + "` of type `" + xe + "` " + ("supplied to `" + oe + "`, expected `object`."));
        for (var Ne in Z) {
          var Fe = Z[Ne];
          if (typeof Fe != "function")
            return it(oe, ve, Re, Ne, mt(Fe));
          var Ze = Fe(Oe, Ne, oe, ve, Re + "." + Ne, g);
          if (Ze)
            return Ze;
        }
        return null;
      }
      return ce(F);
    }
    function rt(Z) {
      function F(te, G, oe, ve, Re) {
        var Oe = te[G], xe = Be(Oe);
        if (xe !== "object")
          return new Te("Invalid " + ve + " `" + Re + "` of type `" + xe + "` " + ("supplied to `" + oe + "`, expected `object`."));
        var Ne = p({}, te[G], Z);
        for (var Fe in Ne) {
          var Ze = Z[Fe];
          if (h(Z, Fe) && typeof Ze != "function")
            return it(oe, ve, Re, Fe, mt(Ze));
          if (!Ze)
            return new Te(
              "Invalid " + ve + " `" + Re + "` key `" + Fe + "` supplied to `" + oe + "`.\nBad object: " + JSON.stringify(te[G], null, "  ") + `
Valid keys: ` + JSON.stringify(Object.keys(Z), null, "  ")
            );
          var ne = Ze(Oe, Fe, oe, ve, Re + "." + Fe, g);
          if (ne)
            return ne;
        }
        return null;
      }
      return ce(F);
    }
    function ut(Z) {
      switch (typeof Z) {
        case "number":
        case "string":
        case "undefined":
          return !0;
        case "boolean":
          return !Z;
        case "object":
          if (Array.isArray(Z))
            return Z.every(ut);
          if (Z === null || D(Z))
            return !0;
          var F = B(Z);
          if (F) {
            var te = F.call(Z), G;
            if (F !== Z.entries) {
              for (; !(G = te.next()).done; )
                if (!ut(G.value))
                  return !1;
            } else
              for (; !(G = te.next()).done; ) {
                var oe = G.value;
                if (oe && !ut(oe[1]))
                  return !1;
              }
          } else
            return !1;
          return !0;
        default:
          return !1;
      }
    }
    function st(Z, F) {
      return Z === "symbol" ? !0 : F ? F["@@toStringTag"] === "Symbol" || typeof Symbol == "function" && F instanceof Symbol : !1;
    }
    function Be(Z) {
      var F = typeof Z;
      return Array.isArray(Z) ? "array" : Z instanceof RegExp ? "object" : st(F, Z) ? "symbol" : F;
    }
    function mt(Z) {
      if (typeof Z > "u" || Z === null)
        return "" + Z;
      var F = Be(Z);
      if (F === "object") {
        if (Z instanceof Date)
          return "date";
        if (Z instanceof RegExp)
          return "regexp";
      }
      return F;
    }
    function Ke(Z) {
      var F = mt(Z);
      switch (F) {
        case "array":
        case "object":
          return "an " + F;
        case "boolean":
        case "date":
        case "regexp":
          return "a " + F;
        default:
          return F;
      }
    }
    function Rt(Z) {
      return !Z.constructor || !Z.constructor.name ? Y : Z.constructor.name;
    }
    return re.checkPropTypes = b, re.resetWarningCache = b.resetWarningCache, re.PropTypes = re, re;
  }, $g;
}
var Wg, lb;
function Nk() {
  if (lb) return Wg;
  lb = 1;
  var c = d0();
  function p() {
  }
  function g() {
  }
  return g.resetWarningCache = p, Wg = function() {
    function h(y, D, A, L, I, B) {
      if (B !== c) {
        var Y = new Error(
          "Calling PropTypes validators directly is not supported by the `prop-types` package. Use PropTypes.checkPropTypes() to call them. Read more at http://fb.me/use-check-prop-types"
        );
        throw Y.name = "Invariant Violation", Y;
      }
    }
    h.isRequired = h;
    function b() {
      return h;
    }
    var C = {
      array: h,
      bigint: h,
      bool: h,
      func: h,
      number: h,
      object: h,
      string: h,
      symbol: h,
      any: h,
      arrayOf: b,
      element: h,
      elementType: h,
      instanceOf: b,
      node: h,
      objectOf: b,
      oneOf: b,
      oneOfType: b,
      shape: b,
      exact: b,
      checkPropTypes: g,
      resetWarningCache: p
    };
    return C.PropTypes = C, C;
  }, Wg;
}
if (true) {
  var Mk = Ab(), Lk = !0;
  n0.exports = Ok()(Mk.isElement, Lk);
} else
  // removed by dead control flow
{}
var Ak = n0.exports;
const nt = /* @__PURE__ */ s0(Ak);
function Uk(c, p = Mb, g = Lb) {
  const h = [];
  return Object.entries(c).forEach(([b, C]) => {
    C != null && (typeof C == "object" ? p.forEach((y) => {
      const D = C[y];
      if (D != null) {
        const A = y !== g ? `-${y}` : "";
        h.push(`${b}${A}-${D}`);
      }
    }) : h.push(`${b}-${C}`));
  }), h;
}
const zb = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef(({
  as: c = "div",
  bsPrefix: p,
  className: g,
  direction: h,
  gap: b,
  ...C
}, y) => {
  p = Lt(p, h === "horizontal" ? "hstack" : "vstack");
  const D = xk(), A = wk();
  return /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(c, {
    ...C,
    ref: y,
    className: yt(g, p, ...Uk({
      gap: b
    }, D, A))
  });
});
zb.displayName = "Stack";
const jb = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef(({
  bsPrefix: c,
  fluid: p = !1,
  // Need to define the default "as" during prop destructuring to be compatible with styled-components github.com/react-bootstrap/react-bootstrap/issues/3595
  as: g = "div",
  className: h,
  ...b
}, C) => {
  const y = Lt(c, "container"), D = typeof p == "string" ? `-${p}` : "-fluid";
  return /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(g, {
    ref: C,
    ...b,
    className: yt(h, p ? `${y}${D}` : y)
  });
});
jb.displayName = "Container";
function r0() {
  return r0 = Object.assign ? Object.assign.bind() : function(c) {
    for (var p = 1; p < arguments.length; p++) {
      var g = arguments[p];
      for (var h in g) ({}).hasOwnProperty.call(g, h) && (c[h] = g[h]);
    }
    return c;
  }, r0.apply(null, arguments);
}
function Fb(c, p) {
  if (c == null) return {};
  var g = {};
  for (var h in c) if ({}.hasOwnProperty.call(c, h)) {
    if (p.indexOf(h) !== -1) continue;
    g[h] = c[h];
  }
  return g;
}
function ob(c) {
  return "default" + c.charAt(0).toUpperCase() + c.substr(1);
}
function zk(c) {
  var p = jk(c, "string");
  return typeof p == "symbol" ? p : String(p);
}
function jk(c, p) {
  if (typeof c != "object" || c === null) return c;
  var g = c[Symbol.toPrimitive];
  if (g !== void 0) {
    var h = g.call(c, p);
    if (typeof h != "object") return h;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return String(c);
}
function Fk(c, p, g) {
  var h = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)(c !== void 0), b = (0,react__WEBPACK_IMPORTED_MODULE_1__.useState)(p), C = b[0], y = b[1], D = c !== void 0, A = h.current;
  return h.current = D, !D && A && C !== p && y(p), [D ? c : C, (0,react__WEBPACK_IMPORTED_MODULE_1__.useCallback)(function(L) {
    for (var I = arguments.length, B = new Array(I > 1 ? I - 1 : 0), Y = 1; Y < I; Y++)
      B[Y - 1] = arguments[Y];
    g && g.apply(void 0, [L].concat(B)), y(L);
  }, [g])];
}
function Hb(c, p) {
  return Object.keys(p).reduce(function(g, h) {
    var b, C = g, y = C[ob(h)], D = C[h], A = Fb(C, [ob(h), h].map(zk)), L = p[h], I = Fk(D, y, c[L]), B = I[0], Y = I[1];
    return r0({}, A, (b = {}, b[h] = B, b[L] = Y, b));
  }, c);
}
function a0(c, p) {
  return a0 = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function(g, h) {
    return g.__proto__ = h, g;
  }, a0(c, p);
}
function Hk(c, p) {
  c.prototype = Object.create(p.prototype), c.prototype.constructor = c, a0(c, p);
}
var Pk = Function.prototype.bind.call(Function.prototype.call, [].slice);
function Du(c, p) {
  return Pk(c.querySelectorAll(p));
}
function Bk() {
  const [, c] = (0,react__WEBPACK_IMPORTED_MODULE_1__.useReducer)((p) => p + 1, 0);
  return c;
}
const ub = (c) => !c || typeof c == "function" ? c : (p) => {
  c.current = p;
};
function Vk(c, p) {
  const g = ub(c), h = ub(p);
  return (b) => {
    g && g(b), h && h(b);
  };
}
function Rh(c, p) {
  return (0,react__WEBPACK_IMPORTED_MODULE_1__.useMemo)(() => Vk(c, p), [c, p]);
}
const p0 = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.createContext(null);
p0.displayName = "NavContext";
const Sh = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.createContext(null), v0 = (c, p = null) => c != null ? String(c) : p || null, Pb = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.createContext(null), Ik = "data-rr-ui-", $k = "rrUi";
function xh(c) {
  return `${Ik}${c}`;
}
function Wk(c) {
  return `${$k}${c}`;
}
function Yk(c) {
  const p = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)(c);
  return (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(() => {
    p.current = c;
  }, [c]), p;
}
function Ki(c) {
  const p = Yk(c);
  return (0,react__WEBPACK_IMPORTED_MODULE_1__.useCallback)(function(...g) {
    return p.current && p.current(...g);
  }, [p]);
}
const qk = ["as", "disabled"];
function Qk(c, p) {
  if (c == null) return {};
  var g = {};
  for (var h in c) if ({}.hasOwnProperty.call(c, h)) {
    if (p.indexOf(h) >= 0) continue;
    g[h] = c[h];
  }
  return g;
}
function Gk(c) {
  return !c || c.trim() === "#";
}
function Bb({
  tagName: c,
  disabled: p,
  href: g,
  target: h,
  rel: b,
  role: C,
  onClick: y,
  tabIndex: D = 0,
  type: A
}) {
  c || (g != null || h != null || b != null ? c = "a" : c = "button");
  const L = {
    tagName: c
  };
  if (c === "button")
    return [{
      type: A || "button",
      disabled: p
    }, L];
  const I = (Y) => {
    if ((p || c === "a" && Gk(g)) && Y.preventDefault(), p) {
      Y.stopPropagation();
      return;
    }
    y == null || y(Y);
  }, B = (Y) => {
    Y.key === " " && (Y.preventDefault(), I(Y));
  };
  return c === "a" && (g || (g = "#"), p && (g = void 0)), [{
    role: C ?? "button",
    // explicitly undefined so that it overrides the props disabled in a spread
    // e.g. <Tag {...props} {...hookProps} />
    disabled: void 0,
    tabIndex: p ? void 0 : D,
    href: g,
    target: c === "a" ? h : void 0,
    "aria-disabled": p || void 0,
    rel: c === "a" ? b : void 0,
    onClick: I,
    onKeyDown: B
  }, L];
}
const Vb = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef((c, p) => {
  let {
    as: g,
    disabled: h
  } = c, b = Qk(c, qk);
  const [C, {
    tagName: y
  }] = Bb(Object.assign({
    tagName: g,
    disabled: h
  }, b));
  return /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(y, Object.assign({}, b, C, {
    ref: p
  }));
});
Vb.displayName = "Button";
const Xk = ["as", "active", "eventKey"];
function Kk(c, p) {
  if (c == null) return {};
  var g = {};
  for (var h in c) if ({}.hasOwnProperty.call(c, h)) {
    if (p.indexOf(h) >= 0) continue;
    g[h] = c[h];
  }
  return g;
}
function Ib({
  key: c,
  onClick: p,
  active: g,
  id: h,
  role: b,
  disabled: C
}) {
  const y = (0,react__WEBPACK_IMPORTED_MODULE_1__.useContext)(Sh), D = (0,react__WEBPACK_IMPORTED_MODULE_1__.useContext)(p0), A = (0,react__WEBPACK_IMPORTED_MODULE_1__.useContext)(Pb);
  let L = g;
  const I = {
    role: b
  };
  if (D) {
    !b && D.role === "tablist" && (I.role = "tab");
    const B = D.getControllerId(c ?? null), Y = D.getControlledId(c ?? null);
    I[xh("event-key")] = c, I.id = B || h, L = g == null && c != null ? D.activeKey === c : g, (L || !(A != null && A.unmountOnExit) && !(A != null && A.mountOnEnter)) && (I["aria-controls"] = Y);
  }
  return I.role === "tab" && (I["aria-selected"] = L, L || (I.tabIndex = -1), C && (I.tabIndex = -1, I["aria-disabled"] = !0)), I.onClick = Ki((B) => {
    C || (p == null || p(B), c != null && y && !B.isPropagationStopped() && y(c, B));
  }), [I, {
    isActive: L
  }];
}
const $b = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef((c, p) => {
  let {
    as: g = Vb,
    active: h,
    eventKey: b
  } = c, C = Kk(c, Xk);
  const [y, D] = Ib(Object.assign({
    key: v0(b, C.href),
    active: h
  }, C));
  return y[xh("active")] = D.isActive, /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(g, Object.assign({}, C, y, {
    ref: p
  }));
});
$b.displayName = "NavItem";
const Zk = ["as", "onSelect", "activeKey", "role", "onKeyDown"];
function Jk(c, p) {
  if (c == null) return {};
  var g = {};
  for (var h in c) if ({}.hasOwnProperty.call(c, h)) {
    if (p.indexOf(h) >= 0) continue;
    g[h] = c[h];
  }
  return g;
}
const sb = () => {
}, cb = xh("event-key"), Wb = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef((c, p) => {
  let {
    // Need to define the default "as" during prop destructuring to be compatible with styled-components github.com/react-bootstrap/react-bootstrap/issues/3595
    as: g = "div",
    onSelect: h,
    activeKey: b,
    role: C,
    onKeyDown: y
  } = c, D = Jk(c, Zk);
  const A = Bk(), L = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)(!1), I = (0,react__WEBPACK_IMPORTED_MODULE_1__.useContext)(Sh), B = (0,react__WEBPACK_IMPORTED_MODULE_1__.useContext)(Pb);
  let Y, re;
  B && (C = C || "tablist", b = B.activeKey, Y = B.getControlledId, re = B.getControllerId);
  const ue = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)(null), Te = (ee) => {
    const ie = ue.current;
    if (!ie) return null;
    const z = Du(ie, `[${cb}]:not([aria-disabled=true])`), le = ie.querySelector("[aria-selected=true]");
    if (!le || le !== document.activeElement) return null;
    const Se = z.indexOf(le);
    if (Se === -1) return null;
    let We = Se + ee;
    return We >= z.length && (We = 0), We < 0 && (We = z.length - 1), z[We];
  }, ce = (ee, ie) => {
    ee != null && (h == null || h(ee, ie), I == null || I(ee, ie));
  }, _e = (ee) => {
    if (y == null || y(ee), !B)
      return;
    let ie;
    switch (ee.key) {
      case "ArrowLeft":
      case "ArrowUp":
        ie = Te(-1);
        break;
      case "ArrowRight":
      case "ArrowDown":
        ie = Te(1);
        break;
      default:
        return;
    }
    ie && (ee.preventDefault(), ce(ie.dataset[Wk("EventKey")] || null, ee), L.current = !0, A());
  };
  (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(() => {
    if (ue.current && L.current) {
      const ee = ue.current.querySelector(`[${cb}][aria-selected=true]`);
      ee == null || ee.focus();
    }
    L.current = !1;
  });
  const we = Rh(p, ue);
  return /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(Sh.Provider, {
    value: ce,
    children: /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(p0.Provider, {
      value: {
        role: C,
        // used by NavLink to determine it's role
        activeKey: v0(b),
        getControlledId: Y || sb,
        getControllerId: re || sb
      },
      children: /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(g, Object.assign({}, D, {
        onKeyDown: _e,
        ref: we,
        role: C
      }))
    })
  });
});
Wb.displayName = "Nav";
const e_ = Object.assign(Wb, {
  Item: $b
}), oc = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.createContext(null);
oc.displayName = "NavbarContext";
const h0 = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.createContext(null);
h0.displayName = "CardHeaderContext";
const Yb = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef(({
  className: c,
  bsPrefix: p,
  as: g = "div",
  ...h
}, b) => (p = Lt(p, "nav-item"), /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(g, {
  ref: b,
  className: yt(c, p),
  ...h
})));
Yb.displayName = "NavItem";
function t_() {
  const c = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)(!0), p = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)(() => c.current);
  return (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(() => (c.current = !0, () => {
    c.current = !1;
  }), []), p.current;
}
function n_(c) {
  const p = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)(null);
  return (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(() => {
    p.current = c;
  }), p.current;
}
const r_ = typeof __webpack_require__.g < "u" && // @ts-ignore
__webpack_require__.g.navigator && // @ts-ignore
__webpack_require__.g.navigator.product === "ReactNative", a_ = typeof document < "u", fb = a_ || r_ ? react__WEBPACK_IMPORTED_MODULE_1__.useLayoutEffect : react__WEBPACK_IMPORTED_MODULE_1__.useEffect, i_ = ["onKeyDown"];
function l_(c, p) {
  if (c == null) return {};
  var g = {};
  for (var h in c) if ({}.hasOwnProperty.call(c, h)) {
    if (p.indexOf(h) >= 0) continue;
    g[h] = c[h];
  }
  return g;
}
function o_(c) {
  return !c || c.trim() === "#";
}
const qb = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef((c, p) => {
  let {
    onKeyDown: g
  } = c, h = l_(c, i_);
  const [b] = Bb(Object.assign({
    tagName: "a"
  }, h)), C = Ki((y) => {
    b.onKeyDown(y), g == null || g(y);
  });
  return o_(h.href) || h.role === "button" ? /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("a", Object.assign({
    ref: p
  }, h, b, {
    onKeyDown: C
  })) : /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("a", Object.assign({
    ref: p
  }, h, {
    onKeyDown: g
  }));
});
qb.displayName = "Anchor";
const Qb = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef(({
  bsPrefix: c,
  className: p,
  as: g = qb,
  active: h,
  eventKey: b,
  disabled: C = !1,
  ...y
}, D) => {
  c = Lt(c, "nav-link");
  const [A, L] = Ib({
    key: v0(b, y.href),
    active: h,
    disabled: C,
    ...y
  });
  return /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(g, {
    ...y,
    ...A,
    ref: D,
    disabled: C,
    className: yt(p, c, C && "disabled", L.isActive && "active")
  });
});
Qb.displayName = "NavLink";
const Gb = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef((c, p) => {
  const {
    as: g = "div",
    bsPrefix: h,
    variant: b,
    fill: C = !1,
    justify: y = !1,
    navbar: D,
    navbarScroll: A,
    className: L,
    activeKey: I,
    ...B
  } = Hb(c, {
    activeKey: "onSelect"
  }), Y = Lt(h, "nav");
  let re, ue, Te = !1;
  const ce = (0,react__WEBPACK_IMPORTED_MODULE_1__.useContext)(oc), _e = (0,react__WEBPACK_IMPORTED_MODULE_1__.useContext)(h0);
  return ce ? (re = ce.bsPrefix, Te = D ?? !0) : _e && ({
    cardHeaderBsPrefix: ue
  } = _e), /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(e_, {
    as: g,
    ref: p,
    activeKey: I,
    className: yt(L, {
      [Y]: !Te,
      [`${re}-nav`]: Te,
      [`${re}-nav-scroll`]: Te && A,
      [`${ue}-${b}`]: !!ue,
      [`${Y}-${b}`]: !!b,
      [`${Y}-fill`]: C,
      [`${Y}-justified`]: y
    }),
    ...B
  });
});
Gb.displayName = "Nav";
const hh = Object.assign(Gb, {
  Item: Yb,
  Link: Qb
}), Xb = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef(({
  bsPrefix: c,
  className: p,
  as: g,
  ...h
}, b) => {
  c = Lt(c, "navbar-brand");
  const C = g || (h.href ? "a" : "span");
  return /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(C, {
    ...h,
    ref: b,
    className: yt(p, c)
  });
});
Xb.displayName = "NavbarBrand";
function m0(c) {
  return c && c.ownerDocument || document;
}
function u_(c) {
  var p = m0(c);
  return p && p.defaultView || window;
}
function s_(c, p) {
  return u_(c).getComputedStyle(c, p);
}
var c_ = /([A-Z])/g;
function f_(c) {
  return c.replace(c_, "-$1").toLowerCase();
}
var d_ = /^ms-/;
function mh(c) {
  return f_(c).replace(d_, "-ms-");
}
var p_ = /^((translate|rotate|scale)(X|Y|Z|3d)?|matrix(3d)?|perspective|skew(X|Y)?)$/i;
function v_(c) {
  return !!(c && p_.test(c));
}
function Ji(c, p) {
  var g = "", h = "";
  if (typeof p == "string")
    return c.style.getPropertyValue(mh(p)) || s_(c).getPropertyValue(mh(p));
  Object.keys(p).forEach(function(b) {
    var C = p[b];
    !C && C !== 0 ? c.style.removeProperty(mh(b)) : v_(b) ? h += b + "(" + C + ") " : g += mh(b) + ": " + C + ";";
  }), h && (g += "transform: " + h + ";"), c.style.cssText += ";" + g;
}
var i0 = { exports: {} }, Rr = {}, yh = { exports: {} }, Yg = {};
/** @license React v0.20.2
 * scheduler.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
var db;
function h_() {
  return db || (db = 1, function(c) {
    var p, g, h, b;
    if (typeof performance == "object" && typeof performance.now == "function") {
      var C = performance;
      c.unstable_now = function() {
        return C.now();
      };
    } else {
      var y = Date, D = y.now();
      c.unstable_now = function() {
        return y.now() - D;
      };
    }
    if (typeof window > "u" || typeof MessageChannel != "function") {
      var A = null, L = null, I = function() {
        if (A !== null) try {
          var F = c.unstable_now();
          A(!0, F), A = null;
        } catch (te) {
          throw setTimeout(I, 0), te;
        }
      };
      p = function(F) {
        A !== null ? setTimeout(p, 0, F) : (A = F, setTimeout(I, 0));
      }, g = function(F, te) {
        L = setTimeout(F, te);
      }, h = function() {
        clearTimeout(L);
      }, c.unstable_shouldYield = function() {
        return !1;
      }, b = c.unstable_forceFrameRate = function() {
      };
    } else {
      var B = window.setTimeout, Y = window.clearTimeout;
      if (typeof console < "u") {
        var re = window.cancelAnimationFrame;
        typeof window.requestAnimationFrame != "function" && console.error("This browser doesn't support requestAnimationFrame. Make sure that you load a polyfill in older browsers. https://reactjs.org/link/react-polyfills"), typeof re != "function" && console.error("This browser doesn't support cancelAnimationFrame. Make sure that you load a polyfill in older browsers. https://reactjs.org/link/react-polyfills");
      }
      var ue = !1, Te = null, ce = -1, _e = 5, we = 0;
      c.unstable_shouldYield = function() {
        return c.unstable_now() >= we;
      }, b = function() {
      }, c.unstable_forceFrameRate = function(F) {
        0 > F || 125 < F ? console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported") : _e = 0 < F ? Math.floor(1e3 / F) : 5;
      };
      var ee = new MessageChannel(), ie = ee.port2;
      ee.port1.onmessage = function() {
        if (Te !== null) {
          var F = c.unstable_now();
          we = F + _e;
          try {
            Te(!0, F) ? ie.postMessage(null) : (ue = !1, Te = null);
          } catch (te) {
            throw ie.postMessage(null), te;
          }
        } else ue = !1;
      }, p = function(F) {
        Te = F, ue || (ue = !0, ie.postMessage(null));
      }, g = function(F, te) {
        ce = B(function() {
          F(c.unstable_now());
        }, te);
      }, h = function() {
        Y(ce), ce = -1;
      };
    }
    function z(F, te) {
      var G = F.length;
      F.push(te);
      e: for (; ; ) {
        var oe = G - 1 >>> 1, ve = F[oe];
        if (ve !== void 0 && 0 < We(ve, te)) F[oe] = te, F[G] = ve, G = oe;
        else break e;
      }
    }
    function le(F) {
      return F = F[0], F === void 0 ? null : F;
    }
    function Se(F) {
      var te = F[0];
      if (te !== void 0) {
        var G = F.pop();
        if (G !== te) {
          F[0] = G;
          e: for (var oe = 0, ve = F.length; oe < ve; ) {
            var Re = 2 * (oe + 1) - 1, Oe = F[Re], xe = Re + 1, Ne = F[xe];
            if (Oe !== void 0 && 0 > We(Oe, G)) Ne !== void 0 && 0 > We(Ne, Oe) ? (F[oe] = Ne, F[xe] = G, oe = xe) : (F[oe] = Oe, F[Re] = G, oe = Re);
            else if (Ne !== void 0 && 0 > We(Ne, G)) F[oe] = Ne, F[xe] = G, oe = xe;
            else break e;
          }
        }
        return te;
      }
      return null;
    }
    function We(F, te) {
      var G = F.sortIndex - te.sortIndex;
      return G !== 0 ? G : F.id - te.id;
    }
    var Ae = [], lt = [], it = 1, ot = null, rt = 3, ut = !1, st = !1, Be = !1;
    function mt(F) {
      for (var te = le(lt); te !== null; ) {
        if (te.callback === null) Se(lt);
        else if (te.startTime <= F) Se(lt), te.sortIndex = te.expirationTime, z(Ae, te);
        else break;
        te = le(lt);
      }
    }
    function Ke(F) {
      if (Be = !1, mt(F), !st) if (le(Ae) !== null) st = !0, p(Rt);
      else {
        var te = le(lt);
        te !== null && g(Ke, te.startTime - F);
      }
    }
    function Rt(F, te) {
      st = !1, Be && (Be = !1, h()), ut = !0;
      var G = rt;
      try {
        for (mt(te), ot = le(Ae); ot !== null && (!(ot.expirationTime > te) || F && !c.unstable_shouldYield()); ) {
          var oe = ot.callback;
          if (typeof oe == "function") {
            ot.callback = null, rt = ot.priorityLevel;
            var ve = oe(ot.expirationTime <= te);
            te = c.unstable_now(), typeof ve == "function" ? ot.callback = ve : ot === le(Ae) && Se(Ae), mt(te);
          } else Se(Ae);
          ot = le(Ae);
        }
        if (ot !== null) var Re = !0;
        else {
          var Oe = le(lt);
          Oe !== null && g(Ke, Oe.startTime - te), Re = !1;
        }
        return Re;
      } finally {
        ot = null, rt = G, ut = !1;
      }
    }
    var Z = b;
    c.unstable_IdlePriority = 5, c.unstable_ImmediatePriority = 1, c.unstable_LowPriority = 4, c.unstable_NormalPriority = 3, c.unstable_Profiling = null, c.unstable_UserBlockingPriority = 2, c.unstable_cancelCallback = function(F) {
      F.callback = null;
    }, c.unstable_continueExecution = function() {
      st || ut || (st = !0, p(Rt));
    }, c.unstable_getCurrentPriorityLevel = function() {
      return rt;
    }, c.unstable_getFirstCallbackNode = function() {
      return le(Ae);
    }, c.unstable_next = function(F) {
      switch (rt) {
        case 1:
        case 2:
        case 3:
          var te = 3;
          break;
        default:
          te = rt;
      }
      var G = rt;
      rt = te;
      try {
        return F();
      } finally {
        rt = G;
      }
    }, c.unstable_pauseExecution = function() {
    }, c.unstable_requestPaint = Z, c.unstable_runWithPriority = function(F, te) {
      switch (F) {
        case 1:
        case 2:
        case 3:
        case 4:
        case 5:
          break;
        default:
          F = 3;
      }
      var G = rt;
      rt = F;
      try {
        return te();
      } finally {
        rt = G;
      }
    }, c.unstable_scheduleCallback = function(F, te, G) {
      var oe = c.unstable_now();
      switch (typeof G == "object" && G !== null ? (G = G.delay, G = typeof G == "number" && 0 < G ? oe + G : oe) : G = oe, F) {
        case 1:
          var ve = -1;
          break;
        case 2:
          ve = 250;
          break;
        case 5:
          ve = 1073741823;
          break;
        case 4:
          ve = 1e4;
          break;
        default:
          ve = 5e3;
      }
      return ve = G + ve, F = { id: it++, callback: te, priorityLevel: F, startTime: G, expirationTime: ve, sortIndex: -1 }, G > oe ? (F.sortIndex = G, z(lt, F), le(Ae) === null && F === le(lt) && (Be ? h() : Be = !0, g(Ke, G - oe))) : (F.sortIndex = ve, z(Ae, F), st || ut || (st = !0, p(Rt))), F;
    }, c.unstable_wrapCallback = function(F) {
      var te = rt;
      return function() {
        var G = rt;
        rt = te;
        try {
          return F.apply(this, arguments);
        } finally {
          rt = G;
        }
      };
    };
  }(Yg)), Yg;
}
var qg = {};
/** @license React v0.20.2
 * scheduler.development.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
var pb;
function m_() {
  return pb || (pb = 1, function(c) {
     true && function() {
      var p = !1, g = !1, h, b, C, y, D = typeof performance == "object" && typeof performance.now == "function";
      if (D) {
        var A = performance;
        c.unstable_now = function() {
          return A.now();
        };
      } else {
        var L = Date, I = L.now();
        c.unstable_now = function() {
          return L.now() - I;
        };
      }
      if (
        // If Scheduler runs in a non-DOM environment, it falls back to a naive
        // implementation using setTimeout.
        typeof window > "u" || // Check if MessageChannel is supported, too.
        typeof MessageChannel != "function"
      ) {
        var B = null, Y = null, re = function() {
          if (B !== null)
            try {
              var de = c.unstable_now(), De = !0;
              B(De, de), B = null;
            } catch (Je) {
              throw setTimeout(re, 0), Je;
            }
        };
        h = function(de) {
          B !== null ? setTimeout(h, 0, de) : (B = de, setTimeout(re, 0));
        }, b = function(de, De) {
          Y = setTimeout(de, De);
        }, C = function() {
          clearTimeout(Y);
        }, c.unstable_shouldYield = function() {
          return !1;
        }, y = c.unstable_forceFrameRate = function() {
        };
      } else {
        var ue = window.setTimeout, Te = window.clearTimeout;
        if (typeof console < "u") {
          var ce = window.requestAnimationFrame, _e = window.cancelAnimationFrame;
          typeof ce != "function" && console.error("This browser doesn't support requestAnimationFrame. Make sure that you load a polyfill in older browsers. https://reactjs.org/link/react-polyfills"), typeof _e != "function" && console.error("This browser doesn't support cancelAnimationFrame. Make sure that you load a polyfill in older browsers. https://reactjs.org/link/react-polyfills");
        }
        var we = !1, ee = null, ie = -1, z = 5, le = 0;
        c.unstable_shouldYield = function() {
          return c.unstable_now() >= le;
        }, y = function() {
        }, c.unstable_forceFrameRate = function(de) {
          if (de < 0 || de > 125) {
            console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported");
            return;
          }
          de > 0 ? z = Math.floor(1e3 / de) : z = 5;
        };
        var Se = function() {
          if (ee !== null) {
            var de = c.unstable_now();
            le = de + z;
            var De = !0;
            try {
              var Je = ee(De, de);
              Je ? Ae.postMessage(null) : (we = !1, ee = null);
            } catch (pt) {
              throw Ae.postMessage(null), pt;
            }
          } else
            we = !1;
        }, We = new MessageChannel(), Ae = We.port2;
        We.port1.onmessage = Se, h = function(de) {
          ee = de, we || (we = !0, Ae.postMessage(null));
        }, b = function(de, De) {
          ie = ue(function() {
            de(c.unstable_now());
          }, De);
        }, C = function() {
          Te(ie), ie = -1;
        };
      }
      function lt(de, De) {
        var Je = de.length;
        de.push(De), rt(de, De, Je);
      }
      function it(de) {
        var De = de[0];
        return De === void 0 ? null : De;
      }
      function ot(de) {
        var De = de[0];
        if (De !== void 0) {
          var Je = de.pop();
          return Je !== De && (de[0] = Je, ut(de, Je, 0)), De;
        } else
          return null;
      }
      function rt(de, De, Je) {
        for (var pt = Je; ; ) {
          var Jt = pt - 1 >>> 1, Ft = de[Jt];
          if (Ft !== void 0 && st(Ft, De) > 0)
            de[Jt] = De, de[pt] = Ft, pt = Jt;
          else
            return;
        }
      }
      function ut(de, De, Je) {
        for (var pt = Je, Jt = de.length; pt < Jt; ) {
          var Ft = (pt + 1) * 2 - 1, Ht = de[Ft], Rn = Ft + 1, Ut = de[Rn];
          if (Ht !== void 0 && st(Ht, De) < 0)
            Ut !== void 0 && st(Ut, Ht) < 0 ? (de[pt] = Ut, de[Rn] = De, pt = Rn) : (de[pt] = Ht, de[Ft] = De, pt = Ft);
          else if (Ut !== void 0 && st(Ut, De) < 0)
            de[pt] = Ut, de[Rn] = De, pt = Rn;
          else
            return;
        }
      }
      function st(de, De) {
        var Je = de.sortIndex - De.sortIndex;
        return Je !== 0 ? Je : de.id - De.id;
      }
      var Be = 1, mt = 2, Ke = 3, Rt = 4, Z = 5;
      function F(de, De) {
      }
      var te = 1073741823, G = -1, oe = 250, ve = 5e3, Re = 1e4, Oe = te, xe = [], Ne = [], Fe = 1, Ze = null, ne = Ke, At = !1, Yt = !1, tt = !1;
      function wr(de) {
        for (var De = it(Ne); De !== null; ) {
          if (De.callback === null)
            ot(Ne);
          else if (De.startTime <= de)
            ot(Ne), De.sortIndex = De.expirationTime, lt(xe, De);
          else
            return;
          De = it(Ne);
        }
      }
      function Xn(de) {
        if (tt = !1, wr(de), !Yt)
          if (it(xe) !== null)
            Yt = !0, h(Ca);
          else {
            var De = it(Ne);
            De !== null && b(Xn, De.startTime - de);
          }
      }
      function Ca(de, De) {
        Yt = !1, tt && (tt = !1, C()), At = !0;
        var Je = ne;
        try {
          var pt;
          if (!g) return io(de, De);
        } finally {
          Ze = null, ne = Je, At = !1;
        }
      }
      function io(de, De) {
        var Je = De;
        for (wr(Je), Ze = it(xe); Ze !== null && !p && !(Ze.expirationTime > Je && (!de || c.unstable_shouldYield())); ) {
          var pt = Ze.callback;
          if (typeof pt == "function") {
            Ze.callback = null, ne = Ze.priorityLevel;
            var Jt = Ze.expirationTime <= Je, Ft = pt(Jt);
            Je = c.unstable_now(), typeof Ft == "function" ? Ze.callback = Ft : Ze === it(xe) && ot(xe), wr(Je);
          } else
            ot(xe);
          Ze = it(xe);
        }
        if (Ze !== null)
          return !0;
        var Ht = it(Ne);
        return Ht !== null && b(Xn, Ht.startTime - Je), !1;
      }
      function lo(de, De) {
        switch (de) {
          case Be:
          case mt:
          case Ke:
          case Rt:
          case Z:
            break;
          default:
            de = Ke;
        }
        var Je = ne;
        ne = de;
        try {
          return De();
        } finally {
          ne = Je;
        }
      }
      function tl(de) {
        var De;
        switch (ne) {
          case Be:
          case mt:
          case Ke:
            De = Ke;
            break;
          default:
            De = ne;
            break;
        }
        var Je = ne;
        ne = De;
        try {
          return de();
        } finally {
          ne = Je;
        }
      }
      function oo(de) {
        var De = ne;
        return function() {
          var Je = ne;
          ne = De;
          try {
            return de.apply(this, arguments);
          } finally {
            ne = Je;
          }
        };
      }
      function ci(de, De, Je) {
        var pt = c.unstable_now(), Jt;
        if (typeof Je == "object" && Je !== null) {
          var Ft = Je.delay;
          typeof Ft == "number" && Ft > 0 ? Jt = pt + Ft : Jt = pt;
        } else
          Jt = pt;
        var Ht;
        switch (de) {
          case Be:
            Ht = G;
            break;
          case mt:
            Ht = oe;
            break;
          case Z:
            Ht = Oe;
            break;
          case Rt:
            Ht = Re;
            break;
          case Ke:
          default:
            Ht = ve;
            break;
        }
        var Rn = Jt + Ht, Ut = {
          id: Fe++,
          callback: De,
          priorityLevel: de,
          startTime: Jt,
          expirationTime: Rn,
          sortIndex: -1
        };
        return Jt > pt ? (Ut.sortIndex = Jt, lt(Ne, Ut), it(xe) === null && Ut === it(Ne) && (tt ? C() : tt = !0, b(Xn, Jt - pt))) : (Ut.sortIndex = Rn, lt(xe, Ut), !Yt && !At && (Yt = !0, h(Ca))), Ut;
      }
      function fi() {
      }
      function di() {
        !Yt && !At && (Yt = !0, h(Ca));
      }
      function jt() {
        return it(xe);
      }
      function Wt(de) {
        de.callback = null;
      }
      function Ou() {
        return ne;
      }
      var nl = y, rl = null;
      c.unstable_IdlePriority = Z, c.unstable_ImmediatePriority = Be, c.unstable_LowPriority = Rt, c.unstable_NormalPriority = Ke, c.unstable_Profiling = rl, c.unstable_UserBlockingPriority = mt, c.unstable_cancelCallback = Wt, c.unstable_continueExecution = di, c.unstable_getCurrentPriorityLevel = Ou, c.unstable_getFirstCallbackNode = jt, c.unstable_next = tl, c.unstable_pauseExecution = fi, c.unstable_requestPaint = nl, c.unstable_runWithPriority = lo, c.unstable_scheduleCallback = ci, c.unstable_wrapCallback = oo;
    }();
  }(qg)), qg;
}
var vb;
function Kb() {
  return vb || (vb = 1,  false ? 0 : yh.exports = m_()), yh.exports;
}
/** @license React v17.0.2
 * react-dom.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
var hb;
function y_() {
  if (hb) return Rr;
  hb = 1;
  var c = (react__WEBPACK_IMPORTED_MODULE_1___default()), p = f0(), g = Kb();
  function h(n) {
    for (var a = "https://reactjs.org/docs/error-decoder.html?invariant=" + n, l = 1; l < arguments.length; l++) a += "&args[]=" + encodeURIComponent(arguments[l]);
    return "Minified React error #" + n + "; visit " + a + " for the full message or use the non-minified dev environment for full errors and additional helpful warnings.";
  }
  if (!c) throw Error(h(227));
  var b = /* @__PURE__ */ new Set(), C = {};
  function y(n, a) {
    D(n, a), D(n + "Capture", a);
  }
  function D(n, a) {
    for (C[n] = a, n = 0; n < a.length; n++) b.add(a[n]);
  }
  var A = !(typeof window > "u" || typeof window.document > "u" || typeof window.document.createElement > "u"), L = /^[:A-Z_a-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD][:A-Z_a-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD\-.0-9\u00B7\u0300-\u036F\u203F-\u2040]*$/, I = Object.prototype.hasOwnProperty, B = {}, Y = {};
  function re(n) {
    return I.call(Y, n) ? !0 : I.call(B, n) ? !1 : L.test(n) ? Y[n] = !0 : (B[n] = !0, !1);
  }
  function ue(n, a, l, u) {
    if (l !== null && l.type === 0) return !1;
    switch (typeof a) {
      case "function":
      case "symbol":
        return !0;
      case "boolean":
        return u ? !1 : l !== null ? !l.acceptsBooleans : (n = n.toLowerCase().slice(0, 5), n !== "data-" && n !== "aria-");
      default:
        return !1;
    }
  }
  function Te(n, a, l, u) {
    if (a === null || typeof a > "u" || ue(n, a, l, u)) return !0;
    if (u) return !1;
    if (l !== null) switch (l.type) {
      case 3:
        return !a;
      case 4:
        return a === !1;
      case 5:
        return isNaN(a);
      case 6:
        return isNaN(a) || 1 > a;
    }
    return !1;
  }
  function ce(n, a, l, u, f, m, S) {
    this.acceptsBooleans = a === 2 || a === 3 || a === 4, this.attributeName = u, this.attributeNamespace = f, this.mustUseProperty = l, this.propertyName = n, this.type = a, this.sanitizeURL = m, this.removeEmptyString = S;
  }
  var _e = {};
  "children dangerouslySetInnerHTML defaultValue defaultChecked innerHTML suppressContentEditableWarning suppressHydrationWarning style".split(" ").forEach(function(n) {
    _e[n] = new ce(n, 0, !1, n, null, !1, !1);
  }), [["acceptCharset", "accept-charset"], ["className", "class"], ["htmlFor", "for"], ["httpEquiv", "http-equiv"]].forEach(function(n) {
    var a = n[0];
    _e[a] = new ce(a, 1, !1, n[1], null, !1, !1);
  }), ["contentEditable", "draggable", "spellCheck", "value"].forEach(function(n) {
    _e[n] = new ce(n, 2, !1, n.toLowerCase(), null, !1, !1);
  }), ["autoReverse", "externalResourcesRequired", "focusable", "preserveAlpha"].forEach(function(n) {
    _e[n] = new ce(n, 2, !1, n, null, !1, !1);
  }), "allowFullScreen async autoFocus autoPlay controls default defer disabled disablePictureInPicture disableRemotePlayback formNoValidate hidden loop noModule noValidate open playsInline readOnly required reversed scoped seamless itemScope".split(" ").forEach(function(n) {
    _e[n] = new ce(n, 3, !1, n.toLowerCase(), null, !1, !1);
  }), ["checked", "multiple", "muted", "selected"].forEach(function(n) {
    _e[n] = new ce(n, 3, !0, n, null, !1, !1);
  }), ["capture", "download"].forEach(function(n) {
    _e[n] = new ce(n, 4, !1, n, null, !1, !1);
  }), ["cols", "rows", "size", "span"].forEach(function(n) {
    _e[n] = new ce(n, 6, !1, n, null, !1, !1);
  }), ["rowSpan", "start"].forEach(function(n) {
    _e[n] = new ce(n, 5, !1, n.toLowerCase(), null, !1, !1);
  });
  var we = /[\-:]([a-z])/g;
  function ee(n) {
    return n[1].toUpperCase();
  }
  "accent-height alignment-baseline arabic-form baseline-shift cap-height clip-path clip-rule color-interpolation color-interpolation-filters color-profile color-rendering dominant-baseline enable-background fill-opacity fill-rule flood-color flood-opacity font-family font-size font-size-adjust font-stretch font-style font-variant font-weight glyph-name glyph-orientation-horizontal glyph-orientation-vertical horiz-adv-x horiz-origin-x image-rendering letter-spacing lighting-color marker-end marker-mid marker-start overline-position overline-thickness paint-order panose-1 pointer-events rendering-intent shape-rendering stop-color stop-opacity strikethrough-position strikethrough-thickness stroke-dasharray stroke-dashoffset stroke-linecap stroke-linejoin stroke-miterlimit stroke-opacity stroke-width text-anchor text-decoration text-rendering underline-position underline-thickness unicode-bidi unicode-range units-per-em v-alphabetic v-hanging v-ideographic v-mathematical vector-effect vert-adv-y vert-origin-x vert-origin-y word-spacing writing-mode xmlns:xlink x-height".split(" ").forEach(function(n) {
    var a = n.replace(
      we,
      ee
    );
    _e[a] = new ce(a, 1, !1, n, null, !1, !1);
  }), "xlink:actuate xlink:arcrole xlink:role xlink:show xlink:title xlink:type".split(" ").forEach(function(n) {
    var a = n.replace(we, ee);
    _e[a] = new ce(a, 1, !1, n, "http://www.w3.org/1999/xlink", !1, !1);
  }), ["xml:base", "xml:lang", "xml:space"].forEach(function(n) {
    var a = n.replace(we, ee);
    _e[a] = new ce(a, 1, !1, n, "http://www.w3.org/XML/1998/namespace", !1, !1);
  }), ["tabIndex", "crossOrigin"].forEach(function(n) {
    _e[n] = new ce(n, 1, !1, n.toLowerCase(), null, !1, !1);
  }), _e.xlinkHref = new ce("xlinkHref", 1, !1, "xlink:href", "http://www.w3.org/1999/xlink", !0, !1), ["src", "href", "action", "formAction"].forEach(function(n) {
    _e[n] = new ce(n, 1, !1, n.toLowerCase(), null, !0, !0);
  });
  function ie(n, a, l, u) {
    var f = _e.hasOwnProperty(a) ? _e[a] : null, m = f !== null ? f.type === 0 : u ? !1 : !(!(2 < a.length) || a[0] !== "o" && a[0] !== "O" || a[1] !== "n" && a[1] !== "N");
    m || (Te(a, l, f, u) && (l = null), u || f === null ? re(a) && (l === null ? n.removeAttribute(a) : n.setAttribute(a, "" + l)) : f.mustUseProperty ? n[f.propertyName] = l === null ? f.type === 3 ? !1 : "" : l : (a = f.attributeName, u = f.attributeNamespace, l === null ? n.removeAttribute(a) : (f = f.type, l = f === 3 || f === 4 && l === !0 ? "" : "" + l, u ? n.setAttributeNS(u, a, l) : n.setAttribute(a, l))));
  }
  var z = c.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED, le = 60103, Se = 60106, We = 60107, Ae = 60108, lt = 60114, it = 60109, ot = 60110, rt = 60112, ut = 60113, st = 60120, Be = 60115, mt = 60116, Ke = 60121, Rt = 60128, Z = 60129, F = 60130, te = 60131;
  if (typeof Symbol == "function" && Symbol.for) {
    var G = Symbol.for;
    le = G("react.element"), Se = G("react.portal"), We = G("react.fragment"), Ae = G("react.strict_mode"), lt = G("react.profiler"), it = G("react.provider"), ot = G("react.context"), rt = G("react.forward_ref"), ut = G("react.suspense"), st = G("react.suspense_list"), Be = G("react.memo"), mt = G("react.lazy"), Ke = G("react.block"), G("react.scope"), Rt = G("react.opaque.id"), Z = G("react.debug_trace_mode"), F = G("react.offscreen"), te = G("react.legacy_hidden");
  }
  var oe = typeof Symbol == "function" && Symbol.iterator;
  function ve(n) {
    return n === null || typeof n != "object" ? null : (n = oe && n[oe] || n["@@iterator"], typeof n == "function" ? n : null);
  }
  var Re;
  function Oe(n) {
    if (Re === void 0) try {
      throw Error();
    } catch (l) {
      var a = l.stack.trim().match(/\n( *(at )?)/);
      Re = a && a[1] || "";
    }
    return `
` + Re + n;
  }
  var xe = !1;
  function Ne(n, a) {
    if (!n || xe) return "";
    xe = !0;
    var l = Error.prepareStackTrace;
    Error.prepareStackTrace = void 0;
    try {
      if (a) if (a = function() {
        throw Error();
      }, Object.defineProperty(a.prototype, "props", { set: function() {
        throw Error();
      } }), typeof Reflect == "object" && Reflect.construct) {
        try {
          Reflect.construct(a, []);
        } catch (w) {
          var u = w;
        }
        Reflect.construct(n, [], a);
      } else {
        try {
          a.call();
        } catch (w) {
          u = w;
        }
        n.call(a.prototype);
      }
      else {
        try {
          throw Error();
        } catch (w) {
          u = w;
        }
        n();
      }
    } catch (w) {
      if (w && u && typeof w.stack == "string") {
        for (var f = w.stack.split(`
`), m = u.stack.split(`
`), S = f.length - 1, T = m.length - 1; 1 <= S && 0 <= T && f[S] !== m[T]; ) T--;
        for (; 1 <= S && 0 <= T; S--, T--) if (f[S] !== m[T]) {
          if (S !== 1 || T !== 1)
            do
              if (S--, T--, 0 > T || f[S] !== m[T]) return `
` + f[S].replace(" at new ", " at ");
            while (1 <= S && 0 <= T);
          break;
        }
      }
    } finally {
      xe = !1, Error.prepareStackTrace = l;
    }
    return (n = n ? n.displayName || n.name : "") ? Oe(n) : "";
  }
  function Fe(n) {
    switch (n.tag) {
      case 5:
        return Oe(n.type);
      case 16:
        return Oe("Lazy");
      case 13:
        return Oe("Suspense");
      case 19:
        return Oe("SuspenseList");
      case 0:
      case 2:
      case 15:
        return n = Ne(n.type, !1), n;
      case 11:
        return n = Ne(n.type.render, !1), n;
      case 22:
        return n = Ne(n.type._render, !1), n;
      case 1:
        return n = Ne(n.type, !0), n;
      default:
        return "";
    }
  }
  function Ze(n) {
    if (n == null) return null;
    if (typeof n == "function") return n.displayName || n.name || null;
    if (typeof n == "string") return n;
    switch (n) {
      case We:
        return "Fragment";
      case Se:
        return "Portal";
      case lt:
        return "Profiler";
      case Ae:
        return "StrictMode";
      case ut:
        return "Suspense";
      case st:
        return "SuspenseList";
    }
    if (typeof n == "object") switch (n.$$typeof) {
      case ot:
        return (n.displayName || "Context") + ".Consumer";
      case it:
        return (n._context.displayName || "Context") + ".Provider";
      case rt:
        var a = n.render;
        return a = a.displayName || a.name || "", n.displayName || (a !== "" ? "ForwardRef(" + a + ")" : "ForwardRef");
      case Be:
        return Ze(n.type);
      case Ke:
        return Ze(n._render);
      case mt:
        a = n._payload, n = n._init;
        try {
          return Ze(n(a));
        } catch {
        }
    }
    return null;
  }
  function ne(n) {
    switch (typeof n) {
      case "boolean":
      case "number":
      case "object":
      case "string":
      case "undefined":
        return n;
      default:
        return "";
    }
  }
  function At(n) {
    var a = n.type;
    return (n = n.nodeName) && n.toLowerCase() === "input" && (a === "checkbox" || a === "radio");
  }
  function Yt(n) {
    var a = At(n) ? "checked" : "value", l = Object.getOwnPropertyDescriptor(n.constructor.prototype, a), u = "" + n[a];
    if (!n.hasOwnProperty(a) && typeof l < "u" && typeof l.get == "function" && typeof l.set == "function") {
      var f = l.get, m = l.set;
      return Object.defineProperty(n, a, { configurable: !0, get: function() {
        return f.call(this);
      }, set: function(S) {
        u = "" + S, m.call(this, S);
      } }), Object.defineProperty(n, a, { enumerable: l.enumerable }), { getValue: function() {
        return u;
      }, setValue: function(S) {
        u = "" + S;
      }, stopTracking: function() {
        n._valueTracker = null, delete n[a];
      } };
    }
  }
  function tt(n) {
    n._valueTracker || (n._valueTracker = Yt(n));
  }
  function wr(n) {
    if (!n) return !1;
    var a = n._valueTracker;
    if (!a) return !0;
    var l = a.getValue(), u = "";
    return n && (u = At(n) ? n.checked ? "true" : "false" : n.value), n = u, n !== l ? (a.setValue(n), !0) : !1;
  }
  function Xn(n) {
    if (n = n || (typeof document < "u" ? document : void 0), typeof n > "u") return null;
    try {
      return n.activeElement || n.body;
    } catch {
      return n.body;
    }
  }
  function Ca(n, a) {
    var l = a.checked;
    return p({}, a, { defaultChecked: void 0, defaultValue: void 0, value: void 0, checked: l ?? n._wrapperState.initialChecked });
  }
  function io(n, a) {
    var l = a.defaultValue == null ? "" : a.defaultValue, u = a.checked != null ? a.checked : a.defaultChecked;
    l = ne(a.value != null ? a.value : l), n._wrapperState = { initialChecked: u, initialValue: l, controlled: a.type === "checkbox" || a.type === "radio" ? a.checked != null : a.value != null };
  }
  function lo(n, a) {
    a = a.checked, a != null && ie(n, "checked", a, !1);
  }
  function tl(n, a) {
    lo(n, a);
    var l = ne(a.value), u = a.type;
    if (l != null) u === "number" ? (l === 0 && n.value === "" || n.value != l) && (n.value = "" + l) : n.value !== "" + l && (n.value = "" + l);
    else if (u === "submit" || u === "reset") {
      n.removeAttribute("value");
      return;
    }
    a.hasOwnProperty("value") ? ci(n, a.type, l) : a.hasOwnProperty("defaultValue") && ci(n, a.type, ne(a.defaultValue)), a.checked == null && a.defaultChecked != null && (n.defaultChecked = !!a.defaultChecked);
  }
  function oo(n, a, l) {
    if (a.hasOwnProperty("value") || a.hasOwnProperty("defaultValue")) {
      var u = a.type;
      if (!(u !== "submit" && u !== "reset" || a.value !== void 0 && a.value !== null)) return;
      a = "" + n._wrapperState.initialValue, l || a === n.value || (n.value = a), n.defaultValue = a;
    }
    l = n.name, l !== "" && (n.name = ""), n.defaultChecked = !!n._wrapperState.initialChecked, l !== "" && (n.name = l);
  }
  function ci(n, a, l) {
    (a !== "number" || Xn(n.ownerDocument) !== n) && (l == null ? n.defaultValue = "" + n._wrapperState.initialValue : n.defaultValue !== "" + l && (n.defaultValue = "" + l));
  }
  function fi(n) {
    var a = "";
    return c.Children.forEach(n, function(l) {
      l != null && (a += l);
    }), a;
  }
  function di(n, a) {
    return n = p({ children: void 0 }, a), (a = fi(a.children)) && (n.children = a), n;
  }
  function jt(n, a, l, u) {
    if (n = n.options, a) {
      a = {};
      for (var f = 0; f < l.length; f++) a["$" + l[f]] = !0;
      for (l = 0; l < n.length; l++) f = a.hasOwnProperty("$" + n[l].value), n[l].selected !== f && (n[l].selected = f), f && u && (n[l].defaultSelected = !0);
    } else {
      for (l = "" + ne(l), a = null, f = 0; f < n.length; f++) {
        if (n[f].value === l) {
          n[f].selected = !0, u && (n[f].defaultSelected = !0);
          return;
        }
        a !== null || n[f].disabled || (a = n[f]);
      }
      a !== null && (a.selected = !0);
    }
  }
  function Wt(n, a) {
    if (a.dangerouslySetInnerHTML != null) throw Error(h(91));
    return p({}, a, { value: void 0, defaultValue: void 0, children: "" + n._wrapperState.initialValue });
  }
  function Ou(n, a) {
    var l = a.value;
    if (l == null) {
      if (l = a.children, a = a.defaultValue, l != null) {
        if (a != null) throw Error(h(92));
        if (Array.isArray(l)) {
          if (!(1 >= l.length)) throw Error(h(93));
          l = l[0];
        }
        a = l;
      }
      a == null && (a = ""), l = a;
    }
    n._wrapperState = { initialValue: ne(l) };
  }
  function nl(n, a) {
    var l = ne(a.value), u = ne(a.defaultValue);
    l != null && (l = "" + l, l !== n.value && (n.value = l), a.defaultValue == null && n.defaultValue !== l && (n.defaultValue = l)), u != null && (n.defaultValue = "" + u);
  }
  function rl(n) {
    var a = n.textContent;
    a === n._wrapperState.initialValue && a !== "" && a !== null && (n.value = a);
  }
  var de = { html: "http://www.w3.org/1999/xhtml", mathml: "http://www.w3.org/1998/Math/MathML", svg: "http://www.w3.org/2000/svg" };
  function De(n) {
    switch (n) {
      case "svg":
        return "http://www.w3.org/2000/svg";
      case "math":
        return "http://www.w3.org/1998/Math/MathML";
      default:
        return "http://www.w3.org/1999/xhtml";
    }
  }
  function Je(n, a) {
    return n == null || n === "http://www.w3.org/1999/xhtml" ? De(a) : n === "http://www.w3.org/2000/svg" && a === "foreignObject" ? "http://www.w3.org/1999/xhtml" : n;
  }
  var pt, Jt = function(n) {
    return typeof MSApp < "u" && MSApp.execUnsafeLocalFunction ? function(a, l, u, f) {
      MSApp.execUnsafeLocalFunction(function() {
        return n(a, l, u, f);
      });
    } : n;
  }(function(n, a) {
    if (n.namespaceURI !== de.svg || "innerHTML" in n) n.innerHTML = a;
    else {
      for (pt = pt || document.createElement("div"), pt.innerHTML = "<svg>" + a.valueOf().toString() + "</svg>", a = pt.firstChild; n.firstChild; ) n.removeChild(n.firstChild);
      for (; a.firstChild; ) n.appendChild(a.firstChild);
    }
  });
  function Ft(n, a) {
    if (a) {
      var l = n.firstChild;
      if (l && l === n.lastChild && l.nodeType === 3) {
        l.nodeValue = a;
        return;
      }
    }
    n.textContent = a;
  }
  var Ht = {
    animationIterationCount: !0,
    borderImageOutset: !0,
    borderImageSlice: !0,
    borderImageWidth: !0,
    boxFlex: !0,
    boxFlexGroup: !0,
    boxOrdinalGroup: !0,
    columnCount: !0,
    columns: !0,
    flex: !0,
    flexGrow: !0,
    flexPositive: !0,
    flexShrink: !0,
    flexNegative: !0,
    flexOrder: !0,
    gridArea: !0,
    gridRow: !0,
    gridRowEnd: !0,
    gridRowSpan: !0,
    gridRowStart: !0,
    gridColumn: !0,
    gridColumnEnd: !0,
    gridColumnSpan: !0,
    gridColumnStart: !0,
    fontWeight: !0,
    lineClamp: !0,
    lineHeight: !0,
    opacity: !0,
    order: !0,
    orphans: !0,
    tabSize: !0,
    widows: !0,
    zIndex: !0,
    zoom: !0,
    fillOpacity: !0,
    floodOpacity: !0,
    stopOpacity: !0,
    strokeDasharray: !0,
    strokeDashoffset: !0,
    strokeMiterlimit: !0,
    strokeOpacity: !0,
    strokeWidth: !0
  }, Rn = ["Webkit", "ms", "Moz", "O"];
  Object.keys(Ht).forEach(function(n) {
    Rn.forEach(function(a) {
      a = a + n.charAt(0).toUpperCase() + n.substring(1), Ht[a] = Ht[n];
    });
  });
  function Ut(n, a, l) {
    return a == null || typeof a == "boolean" || a === "" ? "" : l || typeof a != "number" || a === 0 || Ht.hasOwnProperty(n) && Ht[n] ? ("" + a).trim() : a + "px";
  }
  function Gr(n, a) {
    n = n.style;
    for (var l in a) if (a.hasOwnProperty(l)) {
      var u = l.indexOf("--") === 0, f = Ut(l, a[l], u);
      l === "float" && (l = "cssFloat"), u ? n.setProperty(l, f) : n[l] = f;
    }
  }
  var sc = p({ menuitem: !0 }, { area: !0, base: !0, br: !0, col: !0, embed: !0, hr: !0, img: !0, input: !0, keygen: !0, link: !0, meta: !0, param: !0, source: !0, track: !0, wbr: !0 });
  function pi(n, a) {
    if (a) {
      if (sc[n] && (a.children != null || a.dangerouslySetInnerHTML != null)) throw Error(h(137, n));
      if (a.dangerouslySetInnerHTML != null) {
        if (a.children != null) throw Error(h(60));
        if (!(typeof a.dangerouslySetInnerHTML == "object" && "__html" in a.dangerouslySetInnerHTML)) throw Error(h(61));
      }
      if (a.style != null && typeof a.style != "object") throw Error(h(62));
    }
  }
  function al(n, a) {
    if (n.indexOf("-") === -1) return typeof a.is == "string";
    switch (n) {
      case "annotation-xml":
      case "color-profile":
      case "font-face":
      case "font-face-src":
      case "font-face-uri":
      case "font-face-format":
      case "font-face-name":
      case "missing-glyph":
        return !1;
      default:
        return !0;
    }
  }
  function il(n) {
    return n = n.target || n.srcElement || window, n.correspondingUseElement && (n = n.correspondingUseElement), n.nodeType === 3 ? n.parentNode : n;
  }
  var Xr = null, fr = null, dr = null;
  function vi(n) {
    if (n = In(n)) {
      if (typeof Xr != "function") throw Error(h(280));
      var a = n.stateNode;
      a && (a = ta(a), Xr(n.stateNode, n.type, a));
    }
  }
  function kr(n) {
    fr ? dr ? dr.push(n) : dr = [n] : fr = n;
  }
  function uo() {
    if (fr) {
      var n = fr, a = dr;
      if (dr = fr = null, vi(n), a) for (n = 0; n < a.length; n++) vi(a[n]);
    }
  }
  function Nu(n, a) {
    return n(a);
  }
  function so(n, a, l, u, f) {
    return n(a, l, u, f);
  }
  function Mu() {
  }
  var co = Nu, _r = !1, Pt = !1;
  function Lu() {
    (fr !== null || dr !== null) && (Mu(), uo());
  }
  function Oh(n, a, l) {
    if (Pt) return n(a, l);
    Pt = !0;
    try {
      return co(n, a, l);
    } finally {
      Pt = !1, Lu();
    }
  }
  function pr(n, a) {
    var l = n.stateNode;
    if (l === null) return null;
    var u = ta(l);
    if (u === null) return null;
    l = u[a];
    e: switch (a) {
      case "onClick":
      case "onClickCapture":
      case "onDoubleClick":
      case "onDoubleClickCapture":
      case "onMouseDown":
      case "onMouseDownCapture":
      case "onMouseMove":
      case "onMouseMoveCapture":
      case "onMouseUp":
      case "onMouseUpCapture":
      case "onMouseEnter":
        (u = !u.disabled) || (n = n.type, u = !(n === "button" || n === "input" || n === "select" || n === "textarea")), n = !u;
        break e;
      default:
        n = !1;
    }
    if (n) return null;
    if (l && typeof l != "function") throw Error(h(231, a, typeof l));
    return l;
  }
  var hi = !1;
  if (A) try {
    var ll = {};
    Object.defineProperty(ll, "passive", { get: function() {
      hi = !0;
    } }), window.addEventListener("test", ll, ll), window.removeEventListener("test", ll, ll);
  } catch {
    hi = !1;
  }
  function hd(n, a, l, u, f, m, S, T, w) {
    var P = Array.prototype.slice.call(arguments, 3);
    try {
      a.apply(l, P);
    } catch (he) {
      this.onError(he);
    }
  }
  var ol = !1, fo = null, po = !1, Au = null, md = { onError: function(n) {
    ol = !0, fo = n;
  } };
  function yd(n, a, l, u, f, m, S, T, w) {
    ol = !1, fo = null, hd.apply(md, arguments);
  }
  function Dr(n, a, l, u, f, m, S, T, w) {
    if (yd.apply(this, arguments), ol) {
      if (ol) {
        var P = fo;
        ol = !1, fo = null;
      } else throw Error(h(198));
      po || (po = !0, Au = P);
    }
  }
  function Sn(n) {
    var a = n, l = n;
    if (n.alternate) for (; a.return; ) a = a.return;
    else {
      n = a;
      do
        a = n, a.flags & 1026 && (l = a.return), n = a.return;
      while (n);
    }
    return a.tag === 3 ? l : null;
  }
  function Uu(n) {
    if (n.tag === 13) {
      var a = n.memoizedState;
      if (a === null && (n = n.alternate, n !== null && (a = n.memoizedState)), a !== null) return a.dehydrated;
    }
    return null;
  }
  function zu(n) {
    if (Sn(n) !== n) throw Error(h(188));
  }
  function ba(n) {
    var a = n.alternate;
    if (!a) {
      if (a = Sn(n), a === null) throw Error(h(188));
      return a !== n ? null : n;
    }
    for (var l = n, u = a; ; ) {
      var f = l.return;
      if (f === null) break;
      var m = f.alternate;
      if (m === null) {
        if (u = f.return, u !== null) {
          l = u;
          continue;
        }
        break;
      }
      if (f.child === m.child) {
        for (m = f.child; m; ) {
          if (m === l) return zu(f), n;
          if (m === u) return zu(f), a;
          m = m.sibling;
        }
        throw Error(h(188));
      }
      if (l.return !== u.return) l = f, u = m;
      else {
        for (var S = !1, T = f.child; T; ) {
          if (T === l) {
            S = !0, l = f, u = m;
            break;
          }
          if (T === u) {
            S = !0, u = f, l = m;
            break;
          }
          T = T.sibling;
        }
        if (!S) {
          for (T = m.child; T; ) {
            if (T === l) {
              S = !0, l = m, u = f;
              break;
            }
            if (T === u) {
              S = !0, u = m, l = f;
              break;
            }
            T = T.sibling;
          }
          if (!S) throw Error(h(189));
        }
      }
      if (l.alternate !== u) throw Error(h(190));
    }
    if (l.tag !== 3) throw Error(h(188));
    return l.stateNode.current === l ? n : a;
  }
  function ju(n) {
    if (n = ba(n), !n) return null;
    for (var a = n; ; ) {
      if (a.tag === 5 || a.tag === 6) return a;
      if (a.child) a.child.return = a, a = a.child;
      else {
        if (a === n) break;
        for (; !a.sibling; ) {
          if (!a.return || a.return === n) return null;
          a = a.return;
        }
        a.sibling.return = a.return, a = a.sibling;
      }
    }
    return null;
  }
  function vo(n, a) {
    for (var l = n.alternate; a !== null; ) {
      if (a === n || a === l) return !0;
      a = a.return;
    }
    return !1;
  }
  var gd, ho, Ed, ul, cc = !1, Kn = [], Ta = null, Kr = null, Ra = null, sl = /* @__PURE__ */ new Map(), fe = /* @__PURE__ */ new Map(), cl = [], xn = "mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset submit".split(" ");
  function xa(n, a, l, u, f) {
    return { blockedOn: n, domEventName: a, eventSystemFlags: l | 16, nativeEvent: f, targetContainers: [u] };
  }
  function fl(n, a) {
    switch (n) {
      case "focusin":
      case "focusout":
        Ta = null;
        break;
      case "dragenter":
      case "dragleave":
        Kr = null;
        break;
      case "mouseover":
      case "mouseout":
        Ra = null;
        break;
      case "pointerover":
      case "pointerout":
        sl.delete(a.pointerId);
        break;
      case "gotpointercapture":
      case "lostpointercapture":
        fe.delete(a.pointerId);
    }
  }
  function mo(n, a, l, u, f, m) {
    return n === null || n.nativeEvent !== m ? (n = xa(a, l, u, f, m), a !== null && (a = In(a), a !== null && ho(a)), n) : (n.eventSystemFlags |= u, a = n.targetContainers, f !== null && a.indexOf(f) === -1 && a.push(f), n);
  }
  function An(n, a, l, u, f) {
    switch (a) {
      case "focusin":
        return Ta = mo(Ta, n, a, l, u, f), !0;
      case "dragenter":
        return Kr = mo(Kr, n, a, l, u, f), !0;
      case "mouseover":
        return Ra = mo(Ra, n, a, l, u, f), !0;
      case "pointerover":
        var m = f.pointerId;
        return sl.set(m, mo(sl.get(m) || null, n, a, l, u, f)), !0;
      case "gotpointercapture":
        return m = f.pointerId, fe.set(m, mo(fe.get(m) || null, n, a, l, u, f)), !0;
    }
    return !1;
  }
  function nn(n) {
    var a = Ri(n.target);
    if (a !== null) {
      var l = Sn(a);
      if (l !== null) {
        if (a = l.tag, a === 13) {
          if (a = Uu(l), a !== null) {
            n.blockedOn = a, ul(n.lanePriority, function() {
              g.unstable_runWithPriority(n.priority, function() {
                Ed(l);
              });
            });
            return;
          }
        } else if (a === 3 && l.stateNode.hydrate) {
          n.blockedOn = l.tag === 3 ? l.stateNode.containerInfo : null;
          return;
        }
      }
    }
    n.blockedOn = null;
  }
  function Vn(n) {
    if (n.blockedOn !== null) return !1;
    for (var a = n.targetContainers; 0 < a.length; ) {
      var l = $u(n.domEventName, n.eventSystemFlags, a[0], n.nativeEvent);
      if (l !== null) return a = In(l), a !== null && ho(a), n.blockedOn = l, !1;
      a.shift();
    }
    return !0;
  }
  function Sd(n, a, l) {
    Vn(n) && l.delete(a);
  }
  function Zn() {
    for (cc = !1; 0 < Kn.length; ) {
      var n = Kn[0];
      if (n.blockedOn !== null) {
        n = In(n.blockedOn), n !== null && gd(n);
        break;
      }
      for (var a = n.targetContainers; 0 < a.length; ) {
        var l = $u(n.domEventName, n.eventSystemFlags, a[0], n.nativeEvent);
        if (l !== null) {
          n.blockedOn = l;
          break;
        }
        a.shift();
      }
      n.blockedOn === null && Kn.shift();
    }
    Ta !== null && Vn(Ta) && (Ta = null), Kr !== null && Vn(Kr) && (Kr = null), Ra !== null && Vn(Ra) && (Ra = null), sl.forEach(Sd), fe.forEach(Sd);
  }
  function Jn(n, a) {
    n.blockedOn === a && (n.blockedOn = null, cc || (cc = !0, g.unstable_scheduleCallback(g.unstable_NormalPriority, Zn)));
  }
  function Cd(n) {
    function a(f) {
      return Jn(f, n);
    }
    if (0 < Kn.length) {
      Jn(Kn[0], n);
      for (var l = 1; l < Kn.length; l++) {
        var u = Kn[l];
        u.blockedOn === n && (u.blockedOn = null);
      }
    }
    for (Ta !== null && Jn(Ta, n), Kr !== null && Jn(Kr, n), Ra !== null && Jn(Ra, n), sl.forEach(a), fe.forEach(a), l = 0; l < cl.length; l++) u = cl[l], u.blockedOn === n && (u.blockedOn = null);
    for (; 0 < cl.length && (l = cl[0], l.blockedOn === null); ) nn(l), l.blockedOn === null && cl.shift();
  }
  function dl(n, a) {
    var l = {};
    return l[n.toLowerCase()] = a.toLowerCase(), l["Webkit" + n] = "webkit" + a, l["Moz" + n] = "moz" + a, l;
  }
  var mi = { animationend: dl("Animation", "AnimationEnd"), animationiteration: dl("Animation", "AnimationIteration"), animationstart: dl("Animation", "AnimationStart"), transitionend: dl("Transition", "TransitionEnd") }, Fu = {}, bd = {};
  A && (bd = document.createElement("div").style, "AnimationEvent" in window || (delete mi.animationend.animation, delete mi.animationiteration.animation, delete mi.animationstart.animation), "TransitionEvent" in window || delete mi.transitionend.transition);
  function Hu(n) {
    if (Fu[n]) return Fu[n];
    if (!mi[n]) return n;
    var a = mi[n], l;
    for (l in a) if (a.hasOwnProperty(l) && l in bd) return Fu[n] = a[l];
    return n;
  }
  var Td = Hu("animationend"), yo = Hu("animationiteration"), fc = Hu("animationstart"), go = Hu("transitionend"), dc = /* @__PURE__ */ new Map(), Pu = /* @__PURE__ */ new Map(), Rd = [
    "abort",
    "abort",
    Td,
    "animationEnd",
    yo,
    "animationIteration",
    fc,
    "animationStart",
    "canplay",
    "canPlay",
    "canplaythrough",
    "canPlayThrough",
    "durationchange",
    "durationChange",
    "emptied",
    "emptied",
    "encrypted",
    "encrypted",
    "ended",
    "ended",
    "error",
    "error",
    "gotpointercapture",
    "gotPointerCapture",
    "load",
    "load",
    "loadeddata",
    "loadedData",
    "loadedmetadata",
    "loadedMetadata",
    "loadstart",
    "loadStart",
    "lostpointercapture",
    "lostPointerCapture",
    "playing",
    "playing",
    "progress",
    "progress",
    "seeking",
    "seeking",
    "stalled",
    "stalled",
    "suspend",
    "suspend",
    "timeupdate",
    "timeUpdate",
    go,
    "transitionEnd",
    "waiting",
    "waiting"
  ];
  function Bu(n, a) {
    for (var l = 0; l < n.length; l += 2) {
      var u = n[l], f = n[l + 1];
      f = "on" + (f[0].toUpperCase() + f.slice(1)), Pu.set(u, a), dc.set(u, f), y(f, [u]);
    }
  }
  var xd = g.unstable_now;
  xd();
  var gt = 8;
  function yi(n) {
    if (1 & n) return gt = 15, 1;
    if (2 & n) return gt = 14, 2;
    if (4 & n) return gt = 13, 4;
    var a = 24 & n;
    return a !== 0 ? (gt = 12, a) : n & 32 ? (gt = 11, 32) : (a = 192 & n, a !== 0 ? (gt = 10, a) : n & 256 ? (gt = 9, 256) : (a = 3584 & n, a !== 0 ? (gt = 8, a) : n & 4096 ? (gt = 7, 4096) : (a = 4186112 & n, a !== 0 ? (gt = 6, a) : (a = 62914560 & n, a !== 0 ? (gt = 5, a) : n & 67108864 ? (gt = 4, 67108864) : n & 134217728 ? (gt = 3, 134217728) : (a = 805306368 & n, a !== 0 ? (gt = 2, a) : 1073741824 & n ? (gt = 1, 1073741824) : (gt = 8, n))))));
  }
  function wd(n) {
    switch (n) {
      case 99:
        return 15;
      case 98:
        return 10;
      case 97:
      case 96:
        return 8;
      case 95:
        return 2;
      default:
        return 0;
    }
  }
  function pc(n) {
    switch (n) {
      case 15:
      case 14:
        return 99;
      case 13:
      case 12:
      case 11:
      case 10:
        return 98;
      case 9:
      case 8:
      case 7:
      case 6:
      case 4:
      case 5:
        return 97;
      case 3:
      case 2:
      case 1:
        return 95;
      case 0:
        return 90;
      default:
        throw Error(h(358, n));
    }
  }
  function pl(n, a) {
    var l = n.pendingLanes;
    if (l === 0) return gt = 0;
    var u = 0, f = 0, m = n.expiredLanes, S = n.suspendedLanes, T = n.pingedLanes;
    if (m !== 0) u = m, f = gt = 15;
    else if (m = l & 134217727, m !== 0) {
      var w = m & ~S;
      w !== 0 ? (u = yi(w), f = gt) : (T &= m, T !== 0 && (u = yi(T), f = gt));
    } else m = l & ~S, m !== 0 ? (u = yi(m), f = gt) : T !== 0 && (u = yi(T), f = gt);
    if (u === 0) return 0;
    if (u = 31 - ka(u), u = l & ((0 > u ? 0 : 1 << u) << 1) - 1, a !== 0 && a !== u && !(a & S)) {
      if (yi(a), f <= gt) return a;
      gt = f;
    }
    if (a = n.entangledLanes, a !== 0) for (n = n.entanglements, a &= u; 0 < a; ) l = 31 - ka(a), f = 1 << l, u |= n[l], a &= ~f;
    return u;
  }
  function kd(n) {
    return n = n.pendingLanes & -1073741825, n !== 0 ? n : n & 1073741824 ? 1073741824 : 0;
  }
  function Vu(n, a) {
    switch (n) {
      case 15:
        return 1;
      case 14:
        return 2;
      case 12:
        return n = wa(24 & ~a), n === 0 ? Vu(10, a) : n;
      case 10:
        return n = wa(192 & ~a), n === 0 ? Vu(8, a) : n;
      case 8:
        return n = wa(3584 & ~a), n === 0 && (n = wa(4186112 & ~a), n === 0 && (n = 512)), n;
      case 2:
        return a = wa(805306368 & ~a), a === 0 && (a = 268435456), a;
    }
    throw Error(h(358, n));
  }
  function wa(n) {
    return n & -n;
  }
  function Iu(n) {
    for (var a = [], l = 0; 31 > l; l++) a.push(n);
    return a;
  }
  function Eo(n, a, l) {
    n.pendingLanes |= a;
    var u = a - 1;
    n.suspendedLanes &= u, n.pingedLanes &= u, n = n.eventTimes, a = 31 - ka(a), n[a] = l;
  }
  var ka = Math.clz32 ? Math.clz32 : vc, _d = Math.log, Nh = Math.LN2;
  function vc(n) {
    return n === 0 ? 32 : 31 - (_d(n) / Nh | 0) | 0;
  }
  var hc = g.unstable_UserBlockingPriority, Dd = g.unstable_runWithPriority, So = !0;
  function Mh(n, a, l, u) {
    _r || Mu();
    var f = Co, m = _r;
    _r = !0;
    try {
      so(f, n, a, l, u);
    } finally {
      (_r = m) || Lu();
    }
  }
  function vl(n, a, l, u) {
    Dd(hc, Co.bind(null, n, a, l, u));
  }
  function Co(n, a, l, u) {
    if (So) {
      var f;
      if ((f = (a & 4) === 0) && 0 < Kn.length && -1 < xn.indexOf(n)) n = xa(null, n, a, l, u), Kn.push(n);
      else {
        var m = $u(n, a, l, u);
        if (m === null) f && fl(n, u);
        else {
          if (f) {
            if (-1 < xn.indexOf(n)) {
              n = xa(m, n, a, l, u), Kn.push(n);
              return;
            }
            if (An(m, n, a, l, u)) return;
            fl(n, u);
          }
          es(n, a, u, null, l);
        }
      }
    }
  }
  function $u(n, a, l, u) {
    var f = il(u);
    if (f = Ri(f), f !== null) {
      var m = Sn(f);
      if (m === null) f = null;
      else {
        var S = m.tag;
        if (S === 13) {
          if (f = Uu(m), f !== null) return f;
          f = null;
        } else if (S === 3) {
          if (m.stateNode.hydrate) return m.tag === 3 ? m.stateNode.containerInfo : null;
          f = null;
        } else m !== f && (f = null);
      }
    }
    return es(n, a, u, f, l), null;
  }
  var _a = null, mc = null, Wu = null;
  function yc() {
    if (Wu) return Wu;
    var n, a = mc, l = a.length, u, f = "value" in _a ? _a.value : _a.textContent, m = f.length;
    for (n = 0; n < l && a[n] === f[n]; n++) ;
    var S = l - n;
    for (u = 1; u <= S && a[l - u] === f[m - u]; u++) ;
    return Wu = f.slice(n, 1 < u ? 1 - u : void 0);
  }
  function hl(n) {
    var a = n.keyCode;
    return "charCode" in n ? (n = n.charCode, n === 0 && a === 13 && (n = 13)) : n = a, n === 10 && (n = 13), 32 <= n || n === 13 ? n : 0;
  }
  function bo() {
    return !0;
  }
  function gc() {
    return !1;
  }
  function Un(n) {
    function a(l, u, f, m, S) {
      this._reactName = l, this._targetInst = f, this.type = u, this.nativeEvent = m, this.target = S, this.currentTarget = null;
      for (var T in n) n.hasOwnProperty(T) && (l = n[T], this[T] = l ? l(m) : m[T]);
      return this.isDefaultPrevented = (m.defaultPrevented != null ? m.defaultPrevented : m.returnValue === !1) ? bo : gc, this.isPropagationStopped = gc, this;
    }
    return p(a.prototype, { preventDefault: function() {
      this.defaultPrevented = !0;
      var l = this.nativeEvent;
      l && (l.preventDefault ? l.preventDefault() : typeof l.returnValue != "unknown" && (l.returnValue = !1), this.isDefaultPrevented = bo);
    }, stopPropagation: function() {
      var l = this.nativeEvent;
      l && (l.stopPropagation ? l.stopPropagation() : typeof l.cancelBubble != "unknown" && (l.cancelBubble = !0), this.isPropagationStopped = bo);
    }, persist: function() {
    }, isPersistent: bo }), a;
  }
  var ml = { eventPhase: 0, bubbles: 0, cancelable: 0, timeStamp: function(n) {
    return n.timeStamp || Date.now();
  }, defaultPrevented: 0, isTrusted: 0 }, yl = Un(ml), gl = p({}, ml, { view: 0, detail: 0 }), Ec = Un(gl), Yu, To, gi, qu = p({}, gl, { screenX: 0, screenY: 0, clientX: 0, clientY: 0, pageX: 0, pageY: 0, ctrlKey: 0, shiftKey: 0, altKey: 0, metaKey: 0, getModifierState: Cc, button: 0, buttons: 0, relatedTarget: function(n) {
    return n.relatedTarget === void 0 ? n.fromElement === n.srcElement ? n.toElement : n.fromElement : n.relatedTarget;
  }, movementX: function(n) {
    return "movementX" in n ? n.movementX : (n !== gi && (gi && n.type === "mousemove" ? (Yu = n.screenX - gi.screenX, To = n.screenY - gi.screenY) : To = Yu = 0, gi = n), Yu);
  }, movementY: function(n) {
    return "movementY" in n ? n.movementY : To;
  } }), Ro = Un(qu), Od = p({}, qu, { dataTransfer: 0 }), er = Un(Od), Zr = p({}, gl, { relatedTarget: 0 }), wn = Un(Zr), Da = p({}, ml, { animationName: 0, elapsedTime: 0, pseudoElement: 0 }), Nd = Un(Da), Qu = p({}, ml, { clipboardData: function(n) {
    return "clipboardData" in n ? n.clipboardData : window.clipboardData;
  } }), Lh = Un(Qu), xo = p({}, ml, { data: 0 }), Md = Un(xo), Ah = {
    Esc: "Escape",
    Spacebar: " ",
    Left: "ArrowLeft",
    Up: "ArrowUp",
    Right: "ArrowRight",
    Down: "ArrowDown",
    Del: "Delete",
    Win: "OS",
    Menu: "ContextMenu",
    Apps: "ContextMenu",
    Scroll: "ScrollLock",
    MozPrintableKey: "Unidentified"
  }, Sc = {
    8: "Backspace",
    9: "Tab",
    12: "Clear",
    13: "Enter",
    16: "Shift",
    17: "Control",
    18: "Alt",
    19: "Pause",
    20: "CapsLock",
    27: "Escape",
    32: " ",
    33: "PageUp",
    34: "PageDown",
    35: "End",
    36: "Home",
    37: "ArrowLeft",
    38: "ArrowUp",
    39: "ArrowRight",
    40: "ArrowDown",
    45: "Insert",
    46: "Delete",
    112: "F1",
    113: "F2",
    114: "F3",
    115: "F4",
    116: "F5",
    117: "F6",
    118: "F7",
    119: "F8",
    120: "F9",
    121: "F10",
    122: "F11",
    123: "F12",
    144: "NumLock",
    145: "ScrollLock",
    224: "Meta"
  }, Uh = { Alt: "altKey", Control: "ctrlKey", Meta: "metaKey", Shift: "shiftKey" };
  function zh(n) {
    var a = this.nativeEvent;
    return a.getModifierState ? a.getModifierState(n) : (n = Uh[n]) ? !!a[n] : !1;
  }
  function Cc() {
    return zh;
  }
  var Ld = p({}, gl, { key: function(n) {
    if (n.key) {
      var a = Ah[n.key] || n.key;
      if (a !== "Unidentified") return a;
    }
    return n.type === "keypress" ? (n = hl(n), n === 13 ? "Enter" : String.fromCharCode(n)) : n.type === "keydown" || n.type === "keyup" ? Sc[n.keyCode] || "Unidentified" : "";
  }, code: 0, location: 0, ctrlKey: 0, shiftKey: 0, altKey: 0, metaKey: 0, repeat: 0, locale: 0, getModifierState: Cc, charCode: function(n) {
    return n.type === "keypress" ? hl(n) : 0;
  }, keyCode: function(n) {
    return n.type === "keydown" || n.type === "keyup" ? n.keyCode : 0;
  }, which: function(n) {
    return n.type === "keypress" ? hl(n) : n.type === "keydown" || n.type === "keyup" ? n.keyCode : 0;
  } }), jh = Un(Ld), Fh = p({}, qu, { pointerId: 0, width: 0, height: 0, pressure: 0, tangentialPressure: 0, tiltX: 0, tiltY: 0, twist: 0, pointerType: 0, isPrimary: 0 }), Ad = Un(Fh), Ud = p({}, gl, { touches: 0, targetTouches: 0, changedTouches: 0, altKey: 0, metaKey: 0, ctrlKey: 0, shiftKey: 0, getModifierState: Cc }), El = Un(Ud), bc = p({}, ml, { propertyName: 0, elapsedTime: 0, pseudoElement: 0 }), zd = Un(bc), jd = p({}, qu, {
    deltaX: function(n) {
      return "deltaX" in n ? n.deltaX : "wheelDeltaX" in n ? -n.wheelDeltaX : 0;
    },
    deltaY: function(n) {
      return "deltaY" in n ? n.deltaY : "wheelDeltaY" in n ? -n.wheelDeltaY : "wheelDelta" in n ? -n.wheelDelta : 0;
    },
    deltaZ: 0,
    deltaMode: 0
  }), Hh = Un(jd), Ph = [9, 13, 27, 32], Tc = A && "CompositionEvent" in window, wo = null;
  A && "documentMode" in document && (wo = document.documentMode);
  var Bh = A && "TextEvent" in window && !wo, Fd = A && (!Tc || wo && 8 < wo && 11 >= wo), Hd = " ", Pd = !1;
  function Rc(n, a) {
    switch (n) {
      case "keyup":
        return Ph.indexOf(a.keyCode) !== -1;
      case "keydown":
        return a.keyCode !== 229;
      case "keypress":
      case "mousedown":
      case "focusout":
        return !0;
      default:
        return !1;
    }
  }
  function Bd(n) {
    return n = n.detail, typeof n == "object" && "data" in n ? n.data : null;
  }
  var Ei = !1;
  function Vh(n, a) {
    switch (n) {
      case "compositionend":
        return Bd(a);
      case "keypress":
        return a.which !== 32 ? null : (Pd = !0, Hd);
      case "textInput":
        return n = a.data, n === Hd && Pd ? null : n;
      default:
        return null;
    }
  }
  function Ih(n, a) {
    if (Ei) return n === "compositionend" || !Tc && Rc(n, a) ? (n = yc(), Wu = mc = _a = null, Ei = !1, n) : null;
    switch (n) {
      case "paste":
        return null;
      case "keypress":
        if (!(a.ctrlKey || a.altKey || a.metaKey) || a.ctrlKey && a.altKey) {
          if (a.char && 1 < a.char.length) return a.char;
          if (a.which) return String.fromCharCode(a.which);
        }
        return null;
      case "compositionend":
        return Fd && a.locale !== "ko" ? null : a.data;
      default:
        return null;
    }
  }
  var $h = { color: !0, date: !0, datetime: !0, "datetime-local": !0, email: !0, month: !0, number: !0, password: !0, range: !0, search: !0, tel: !0, text: !0, time: !0, url: !0, week: !0 };
  function Vd(n) {
    var a = n && n.nodeName && n.nodeName.toLowerCase();
    return a === "input" ? !!$h[n.type] : a === "textarea";
  }
  function Gu(n, a, l, u) {
    kr(u), a = ts(a, "onChange"), 0 < a.length && (l = new yl("onChange", "change", null, l, u), n.push({ event: l, listeners: a }));
  }
  var vr = null, Oa = null;
  function Id(n) {
    Ku(n, 0);
  }
  function Jr(n) {
    var a = Dn(n);
    if (wr(a)) return n;
  }
  function Wh(n, a) {
    if (n === "change") return a;
  }
  var $d = !1;
  if (A) {
    var xc;
    if (A) {
      var wc = "oninput" in document;
      if (!wc) {
        var Wd = document.createElement("div");
        Wd.setAttribute("oninput", "return;"), wc = typeof Wd.oninput == "function";
      }
      xc = wc;
    } else xc = !1;
    $d = xc && (!document.documentMode || 9 < document.documentMode);
  }
  function Yd() {
    vr && (vr.detachEvent("onpropertychange", kc), Oa = vr = null);
  }
  function kc(n) {
    if (n.propertyName === "value" && Jr(Oa)) {
      var a = [];
      if (Gu(a, Oa, n, il(n)), n = Id, _r) n(a);
      else {
        _r = !0;
        try {
          Nu(n, a);
        } finally {
          _r = !1, Lu();
        }
      }
    }
  }
  function Yh(n, a, l) {
    n === "focusin" ? (Yd(), vr = a, Oa = l, vr.attachEvent("onpropertychange", kc)) : n === "focusout" && Yd();
  }
  function qd(n) {
    if (n === "selectionchange" || n === "keyup" || n === "keydown") return Jr(Oa);
  }
  function kn(n, a) {
    if (n === "click") return Jr(a);
  }
  function qh(n, a) {
    if (n === "input" || n === "change") return Jr(a);
  }
  function Qd(n, a) {
    return n === a && (n !== 0 || 1 / n === 1 / a) || n !== n && a !== a;
  }
  var tr = typeof Object.is == "function" ? Object.is : Qd, Qh = Object.prototype.hasOwnProperty;
  function ko(n, a) {
    if (tr(n, a)) return !0;
    if (typeof n != "object" || n === null || typeof a != "object" || a === null) return !1;
    var l = Object.keys(n), u = Object.keys(a);
    if (l.length !== u.length) return !1;
    for (u = 0; u < l.length; u++) if (!Qh.call(a, l[u]) || !tr(n[l[u]], a[l[u]])) return !1;
    return !0;
  }
  function Gd(n) {
    for (; n && n.firstChild; ) n = n.firstChild;
    return n;
  }
  function Xd(n, a) {
    var l = Gd(n);
    n = 0;
    for (var u; l; ) {
      if (l.nodeType === 3) {
        if (u = n + l.textContent.length, n <= a && u >= a) return { node: l, offset: a - n };
        n = u;
      }
      e: {
        for (; l; ) {
          if (l.nextSibling) {
            l = l.nextSibling;
            break e;
          }
          l = l.parentNode;
        }
        l = void 0;
      }
      l = Gd(l);
    }
  }
  function _c(n, a) {
    return n && a ? n === a ? !0 : n && n.nodeType === 3 ? !1 : a && a.nodeType === 3 ? _c(n, a.parentNode) : "contains" in n ? n.contains(a) : n.compareDocumentPosition ? !!(n.compareDocumentPosition(a) & 16) : !1 : !1;
  }
  function Xu() {
    for (var n = window, a = Xn(); a instanceof n.HTMLIFrameElement; ) {
      try {
        var l = typeof a.contentWindow.location.href == "string";
      } catch {
        l = !1;
      }
      if (l) n = a.contentWindow;
      else break;
      a = Xn(n.document);
    }
    return a;
  }
  function Si(n) {
    var a = n && n.nodeName && n.nodeName.toLowerCase();
    return a && (a === "input" && (n.type === "text" || n.type === "search" || n.type === "tel" || n.type === "url" || n.type === "password") || a === "textarea" || n.contentEditable === "true");
  }
  var Kd = A && "documentMode" in document && 11 >= document.documentMode, Sl = null, _o = null, Ci = null, Na = !1;
  function bi(n, a, l) {
    var u = l.window === l ? l.document : l.nodeType === 9 ? l : l.ownerDocument;
    Na || Sl == null || Sl !== Xn(u) || (u = Sl, "selectionStart" in u && Si(u) ? u = { start: u.selectionStart, end: u.selectionEnd } : (u = (u.ownerDocument && u.ownerDocument.defaultView || window).getSelection(), u = { anchorNode: u.anchorNode, anchorOffset: u.anchorOffset, focusNode: u.focusNode, focusOffset: u.focusOffset }), Ci && ko(Ci, u) || (Ci = u, u = ts(_o, "onSelect"), 0 < u.length && (a = new yl("onSelect", "select", null, a, l), n.push({ event: a, listeners: u }), a.target = Sl)));
  }
  Bu(
    "cancel cancel click click close close contextmenu contextMenu copy copy cut cut auxclick auxClick dblclick doubleClick dragend dragEnd dragstart dragStart drop drop focusin focus focusout blur input input invalid invalid keydown keyDown keypress keyPress keyup keyUp mousedown mouseDown mouseup mouseUp paste paste pause pause play play pointercancel pointerCancel pointerdown pointerDown pointerup pointerUp ratechange rateChange reset reset seeked seeked submit submit touchcancel touchCancel touchend touchEnd touchstart touchStart volumechange volumeChange".split(" "),
    0
  ), Bu("drag drag dragenter dragEnter dragexit dragExit dragleave dragLeave dragover dragOver mousemove mouseMove mouseout mouseOut mouseover mouseOver pointermove pointerMove pointerout pointerOut pointerover pointerOver scroll scroll toggle toggle touchmove touchMove wheel wheel".split(" "), 1), Bu(Rd, 2);
  for (var Dc = "change selectionchange textInput compositionstart compositionend compositionupdate".split(" "), Oc = 0; Oc < Dc.length; Oc++) Pu.set(Dc[Oc], 0);
  D("onMouseEnter", ["mouseout", "mouseover"]), D("onMouseLeave", ["mouseout", "mouseover"]), D("onPointerEnter", ["pointerout", "pointerover"]), D("onPointerLeave", ["pointerout", "pointerover"]), y("onChange", "change click focusin focusout input keydown keyup selectionchange".split(" ")), y("onSelect", "focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" ")), y("onBeforeInput", ["compositionend", "keypress", "textInput", "paste"]), y("onCompositionEnd", "compositionend focusout keydown keypress keyup mousedown".split(" ")), y("onCompositionStart", "compositionstart focusout keydown keypress keyup mousedown".split(" ")), y("onCompositionUpdate", "compositionupdate focusout keydown keypress keyup mousedown".split(" "));
  var Cl = "abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange seeked seeking stalled suspend timeupdate volumechange waiting".split(" "), Gh = new Set("cancel close invalid load scroll toggle".split(" ").concat(Cl));
  function Nc(n, a, l) {
    var u = n.type || "unknown-event";
    n.currentTarget = l, Dr(u, a, void 0, n), n.currentTarget = null;
  }
  function Ku(n, a) {
    a = (a & 4) !== 0;
    for (var l = 0; l < n.length; l++) {
      var u = n[l], f = u.event;
      u = u.listeners;
      e: {
        var m = void 0;
        if (a) for (var S = u.length - 1; 0 <= S; S--) {
          var T = u[S], w = T.instance, P = T.currentTarget;
          if (T = T.listener, w !== m && f.isPropagationStopped()) break e;
          Nc(f, T, P), m = w;
        }
        else for (S = 0; S < u.length; S++) {
          if (T = u[S], w = T.instance, P = T.currentTarget, T = T.listener, w !== m && f.isPropagationStopped()) break e;
          Nc(f, T, P), m = w;
        }
      }
    }
    if (po) throw n = Au, po = !1, Au = null, n;
  }
  function xt(n, a) {
    var l = np(a), u = n + "__bubble";
    l.has(u) || (Ju(a, n, 2, !1), l.add(u));
  }
  var Zu = "_reactListening" + Math.random().toString(36).slice(2);
  function Mc(n) {
    n[Zu] || (n[Zu] = !0, b.forEach(function(a) {
      Gh.has(a) || ea(a, !1, n, null), ea(a, !0, n, null);
    }));
  }
  function ea(n, a, l, u) {
    var f = 4 < arguments.length && arguments[4] !== void 0 ? arguments[4] : 0, m = l;
    n === "selectionchange" && l.nodeType !== 9 && (m = l.ownerDocument);
    var S = np(m), T = n + "__" + (a ? "capture" : "bubble");
    S.has(T) || (a && (f |= 4), Ju(m, n, f, a), S.add(T));
  }
  function Ju(n, a, l, u) {
    var f = Pu.get(a);
    switch (f === void 0 ? 2 : f) {
      case 0:
        f = Mh;
        break;
      case 1:
        f = vl;
        break;
      default:
        f = Co;
    }
    l = f.bind(null, a, l, n), f = void 0, !hi || a !== "touchstart" && a !== "touchmove" && a !== "wheel" || (f = !0), u ? f !== void 0 ? n.addEventListener(a, l, { capture: !0, passive: f }) : n.addEventListener(a, l, !0) : f !== void 0 ? n.addEventListener(a, l, { passive: f }) : n.addEventListener(a, l, !1);
  }
  function es(n, a, l, u, f) {
    var m = u;
    if (!(a & 1) && !(a & 2) && u !== null) e: for (; ; ) {
      if (u === null) return;
      var S = u.tag;
      if (S === 3 || S === 4) {
        var T = u.stateNode.containerInfo;
        if (T === f || T.nodeType === 8 && T.parentNode === f) break;
        if (S === 4) for (S = u.return; S !== null; ) {
          var w = S.tag;
          if ((w === 3 || w === 4) && (w = S.stateNode.containerInfo, w === f || w.nodeType === 8 && w.parentNode === f)) return;
          S = S.return;
        }
        for (; T !== null; ) {
          if (S = Ri(T), S === null) return;
          if (w = S.tag, w === 5 || w === 6) {
            u = m = S;
            continue e;
          }
          T = T.parentNode;
        }
      }
      u = u.return;
    }
    Oh(function() {
      var P = m, he = il(l), Ie = [];
      e: {
        var K = dc.get(n);
        if (K !== void 0) {
          var ke = yl, He = n;
          switch (n) {
            case "keypress":
              if (hl(l) === 0) break e;
            case "keydown":
            case "keyup":
              ke = jh;
              break;
            case "focusin":
              He = "focus", ke = wn;
              break;
            case "focusout":
              He = "blur", ke = wn;
              break;
            case "beforeblur":
            case "afterblur":
              ke = wn;
              break;
            case "click":
              if (l.button === 2) break e;
            case "auxclick":
            case "dblclick":
            case "mousedown":
            case "mousemove":
            case "mouseup":
            case "mouseout":
            case "mouseover":
            case "contextmenu":
              ke = Ro;
              break;
            case "drag":
            case "dragend":
            case "dragenter":
            case "dragexit":
            case "dragleave":
            case "dragover":
            case "dragstart":
            case "drop":
              ke = er;
              break;
            case "touchcancel":
            case "touchend":
            case "touchmove":
            case "touchstart":
              ke = El;
              break;
            case Td:
            case yo:
            case fc:
              ke = Nd;
              break;
            case go:
              ke = zd;
              break;
            case "scroll":
              ke = Ec;
              break;
            case "wheel":
              ke = Hh;
              break;
            case "copy":
            case "cut":
            case "paste":
              ke = Lh;
              break;
            case "gotpointercapture":
            case "lostpointercapture":
            case "pointercancel":
            case "pointerdown":
            case "pointermove":
            case "pointerout":
            case "pointerover":
            case "pointerup":
              ke = Ad;
          }
          var Le = (a & 4) !== 0, M = !Le && n === "scroll", _ = Le ? K !== null ? K + "Capture" : null : K;
          Le = [];
          for (var O = P, $; O !== null; ) {
            $ = O;
            var q = $.stateNode;
            if ($.tag === 5 && q !== null && ($ = q, _ !== null && (q = pr(O, _), q != null && Le.push(Do(O, q, $)))), M) break;
            O = O.return;
          }
          0 < Le.length && (K = new ke(K, He, null, l, he), Ie.push({ event: K, listeners: Le }));
        }
      }
      if (!(a & 7)) {
        e: {
          if (K = n === "mouseover" || n === "pointerover", ke = n === "mouseout" || n === "pointerout", K && !(a & 16) && (He = l.relatedTarget || l.fromElement) && (Ri(He) || He[_n])) break e;
          if ((ke || K) && (K = he.window === he ? he : (K = he.ownerDocument) ? K.defaultView || K.parentWindow : window, ke ? (He = l.relatedTarget || l.toElement, ke = P, He = He ? Ri(He) : null, He !== null && (M = Sn(He), He !== M || He.tag !== 5 && He.tag !== 6) && (He = null)) : (ke = null, He = P), ke !== He)) {
            if (Le = Ro, q = "onMouseLeave", _ = "onMouseEnter", O = "mouse", (n === "pointerout" || n === "pointerover") && (Le = Ad, q = "onPointerLeave", _ = "onPointerEnter", O = "pointer"), M = ke == null ? K : Dn(ke), $ = He == null ? K : Dn(He), K = new Le(q, O + "leave", ke, l, he), K.target = M, K.relatedTarget = $, q = null, Ri(he) === P && (Le = new Le(_, O + "enter", He, l, he), Le.target = $, Le.relatedTarget = M, q = Le), M = q, ke && He) t: {
              for (Le = ke, _ = He, O = 0, $ = Le; $; $ = bl($)) O++;
              for ($ = 0, q = _; q; q = bl(q)) $++;
              for (; 0 < O - $; ) Le = bl(Le), O--;
              for (; 0 < $ - O; ) _ = bl(_), $--;
              for (; O--; ) {
                if (Le === _ || _ !== null && Le === _.alternate) break t;
                Le = bl(Le), _ = bl(_);
              }
              Le = null;
            }
            else Le = null;
            ke !== null && Zd(Ie, K, ke, Le, !1), He !== null && M !== null && Zd(Ie, M, He, Le, !0);
          }
        }
        e: {
          if (K = P ? Dn(P) : window, ke = K.nodeName && K.nodeName.toLowerCase(), ke === "select" || ke === "input" && K.type === "file") var qe = Wh;
          else if (Vd(K)) if ($d) qe = qh;
          else {
            qe = qd;
            var ge = Yh;
          }
          else (ke = K.nodeName) && ke.toLowerCase() === "input" && (K.type === "checkbox" || K.type === "radio") && (qe = kn);
          if (qe && (qe = qe(n, P))) {
            Gu(Ie, qe, l, he);
            break e;
          }
          ge && ge(n, K, P), n === "focusout" && (ge = K._wrapperState) && ge.controlled && K.type === "number" && ci(K, "number", K.value);
        }
        switch (ge = P ? Dn(P) : window, n) {
          case "focusin":
            (Vd(ge) || ge.contentEditable === "true") && (Sl = ge, _o = P, Ci = null);
            break;
          case "focusout":
            Ci = _o = Sl = null;
            break;
          case "mousedown":
            Na = !0;
            break;
          case "contextmenu":
          case "mouseup":
          case "dragend":
            Na = !1, bi(Ie, l, he);
            break;
          case "selectionchange":
            if (Kd) break;
          case "keydown":
          case "keyup":
            bi(Ie, l, he);
        }
        var $e;
        if (Tc) e: {
          switch (n) {
            case "compositionstart":
              var Ge = "onCompositionStart";
              break e;
            case "compositionend":
              Ge = "onCompositionEnd";
              break e;
            case "compositionupdate":
              Ge = "onCompositionUpdate";
              break e;
          }
          Ge = void 0;
        }
        else Ei ? Rc(n, l) && (Ge = "onCompositionEnd") : n === "keydown" && l.keyCode === 229 && (Ge = "onCompositionStart");
        Ge && (Fd && l.locale !== "ko" && (Ei || Ge !== "onCompositionStart" ? Ge === "onCompositionEnd" && Ei && ($e = yc()) : (_a = he, mc = "value" in _a ? _a.value : _a.textContent, Ei = !0)), ge = ts(P, Ge), 0 < ge.length && (Ge = new Md(Ge, n, null, l, he), Ie.push({ event: Ge, listeners: ge }), $e ? Ge.data = $e : ($e = Bd(l), $e !== null && (Ge.data = $e)))), ($e = Bh ? Vh(n, l) : Ih(n, l)) && (P = ts(P, "onBeforeInput"), 0 < P.length && (he = new Md(
          "onBeforeInput",
          "beforeinput",
          null,
          l,
          he
        ), Ie.push({ event: he, listeners: P }), he.data = $e));
      }
      Ku(Ie, a);
    });
  }
  function Do(n, a, l) {
    return { instance: n, listener: a, currentTarget: l };
  }
  function ts(n, a) {
    for (var l = a + "Capture", u = []; n !== null; ) {
      var f = n, m = f.stateNode;
      f.tag === 5 && m !== null && (f = m, m = pr(n, l), m != null && u.unshift(Do(n, m, f)), m = pr(n, a), m != null && u.push(Do(n, m, f))), n = n.return;
    }
    return u;
  }
  function bl(n) {
    if (n === null) return null;
    do
      n = n.return;
    while (n && n.tag !== 5);
    return n || null;
  }
  function Zd(n, a, l, u, f) {
    for (var m = a._reactName, S = []; l !== null && l !== u; ) {
      var T = l, w = T.alternate, P = T.stateNode;
      if (w !== null && w === u) break;
      T.tag === 5 && P !== null && (T = P, f ? (w = pr(l, m), w != null && S.unshift(Do(l, w, T))) : f || (w = pr(l, m), w != null && S.push(Do(l, w, T)))), l = l.return;
    }
    S.length !== 0 && n.push({ event: a, listeners: S });
  }
  function ns() {
  }
  var Lc = null, Ac = null;
  function Tl(n, a) {
    switch (n) {
      case "button":
      case "input":
      case "select":
      case "textarea":
        return !!a.autoFocus;
    }
    return !1;
  }
  function Oo(n, a) {
    return n === "textarea" || n === "option" || n === "noscript" || typeof a.children == "string" || typeof a.children == "number" || typeof a.dangerouslySetInnerHTML == "object" && a.dangerouslySetInnerHTML !== null && a.dangerouslySetInnerHTML.__html != null;
  }
  var Rl = typeof setTimeout == "function" ? setTimeout : void 0, Jd = typeof clearTimeout == "function" ? clearTimeout : void 0;
  function rs(n) {
    n.nodeType === 1 ? n.textContent = "" : n.nodeType === 9 && (n = n.body, n != null && (n.textContent = ""));
  }
  function Ma(n) {
    for (; n != null; n = n.nextSibling) {
      var a = n.nodeType;
      if (a === 1 || a === 3) break;
    }
    return n;
  }
  function ep(n) {
    n = n.previousSibling;
    for (var a = 0; n; ) {
      if (n.nodeType === 8) {
        var l = n.data;
        if (l === "$" || l === "$!" || l === "$?") {
          if (a === 0) return n;
          a--;
        } else l === "/$" && a++;
      }
      n = n.previousSibling;
    }
    return null;
  }
  var La = 0;
  function as(n) {
    return { $$typeof: Rt, toString: n, valueOf: n };
  }
  var Ti = Math.random().toString(36).slice(2), Or = "__reactFiber$" + Ti, is = "__reactProps$" + Ti, _n = "__reactContainer$" + Ti, tp = "__reactEvents$" + Ti;
  function Ri(n) {
    var a = n[Or];
    if (a) return a;
    for (var l = n.parentNode; l; ) {
      if (a = l[_n] || l[Or]) {
        if (l = a.alternate, a.child !== null || l !== null && l.child !== null) for (n = ep(n); n !== null; ) {
          if (l = n[Or]) return l;
          n = ep(n);
        }
        return a;
      }
      n = l, l = n.parentNode;
    }
    return null;
  }
  function In(n) {
    return n = n[Or] || n[_n], !n || n.tag !== 5 && n.tag !== 6 && n.tag !== 13 && n.tag !== 3 ? null : n;
  }
  function Dn(n) {
    if (n.tag === 5 || n.tag === 6) return n.stateNode;
    throw Error(h(33));
  }
  function ta(n) {
    return n[is] || null;
  }
  function np(n) {
    var a = n[tp];
    return a === void 0 && (a = n[tp] = /* @__PURE__ */ new Set()), a;
  }
  var Uc = [], Et = -1;
  function On(n) {
    return { current: n };
  }
  function Ye(n) {
    0 > Et || (n.current = Uc[Et], Uc[Et] = null, Et--);
  }
  function Ue(n, a) {
    Et++, Uc[Et] = n.current, n.current = a;
  }
  var Aa = {}, Dt = On(Aa), vn = On(!1), Ua = Aa;
  function vt(n, a) {
    var l = n.type.contextTypes;
    if (!l) return Aa;
    var u = n.stateNode;
    if (u && u.__reactInternalMemoizedUnmaskedChildContext === a) return u.__reactInternalMemoizedMaskedChildContext;
    var f = {}, m;
    for (m in l) f[m] = a[m];
    return u && (n = n.stateNode, n.__reactInternalMemoizedUnmaskedChildContext = a, n.__reactInternalMemoizedMaskedChildContext = f), f;
  }
  function hn(n) {
    return n = n.childContextTypes, n != null;
  }
  function Nr() {
    Ye(vn), Ye(Dt);
  }
  function xl(n, a, l) {
    if (Dt.current !== Aa) throw Error(h(168));
    Ue(Dt, a), Ue(vn, l);
  }
  function wl(n, a, l) {
    var u = n.stateNode;
    if (n = a.childContextTypes, typeof u.getChildContext != "function") return l;
    u = u.getChildContext();
    for (var f in u) if (!(f in n)) throw Error(h(108, Ze(a) || "Unknown", f));
    return p({}, l, u);
  }
  function nr(n) {
    return n = (n = n.stateNode) && n.__reactInternalMemoizedMergedChildContext || Aa, Ua = Dt.current, Ue(Dt, n), Ue(vn, vn.current), !0;
  }
  function rp(n, a, l) {
    var u = n.stateNode;
    if (!u) throw Error(h(169));
    l ? (n = wl(n, a, Ua), u.__reactInternalMemoizedMergedChildContext = n, Ye(vn), Ye(Dt), Ue(Dt, n)) : Ye(vn), Ue(vn, l);
  }
  var zc = null, xi = null, No = g.unstable_runWithPriority, hr = g.unstable_scheduleCallback, Mo = g.unstable_cancelCallback, Xh = g.unstable_shouldYield, za = g.unstable_requestPaint, ls = g.unstable_now, ap = g.unstable_getCurrentPriorityLevel, os = g.unstable_ImmediatePriority, ip = g.unstable_UserBlockingPriority, jc = g.unstable_NormalPriority, Fc = g.unstable_LowPriority, Hc = g.unstable_IdlePriority, Pc = {}, lp = za !== void 0 ? za : function() {
  }, Mr = null, us = null, Lo = !1, op = ls(), mn = 1e4 > op ? ls : function() {
    return ls() - op;
  };
  function kl() {
    switch (ap()) {
      case os:
        return 99;
      case ip:
        return 98;
      case jc:
        return 97;
      case Fc:
        return 96;
      case Hc:
        return 95;
      default:
        throw Error(h(332));
    }
  }
  function Bc(n) {
    switch (n) {
      case 99:
        return os;
      case 98:
        return ip;
      case 97:
        return jc;
      case 96:
        return Fc;
      case 95:
        return Hc;
      default:
        throw Error(h(332));
    }
  }
  function wi(n, a) {
    return n = Bc(n), No(n, a);
  }
  function ki(n, a, l) {
    return n = Bc(n), hr(n, a, l);
  }
  function rn() {
    if (us !== null) {
      var n = us;
      us = null, Mo(n);
    }
    na();
  }
  function na() {
    if (!Lo && Mr !== null) {
      Lo = !0;
      var n = 0;
      try {
        var a = Mr;
        wi(99, function() {
          for (; n < a.length; n++) {
            var l = a[n];
            do
              l = l(!0);
            while (l !== null);
          }
        }), Mr = null;
      } catch (l) {
        throw Mr !== null && (Mr = Mr.slice(n + 1)), hr(os, rn), l;
      } finally {
        Lo = !1;
      }
    }
  }
  var ja = z.ReactCurrentBatchConfig;
  function an(n, a) {
    if (n && n.defaultProps) {
      a = p({}, a), n = n.defaultProps;
      for (var l in n) a[l] === void 0 && (a[l] = n[l]);
      return a;
    }
    return a;
  }
  var Fa = On(null), Ha = null, Lr = null, ss = null;
  function Vc() {
    ss = Lr = Ha = null;
  }
  function cs(n) {
    var a = Fa.current;
    Ye(Fa), n.type._context._currentValue = a;
  }
  function Ic(n, a) {
    for (; n !== null; ) {
      var l = n.alternate;
      if ((n.childLanes & a) === a) {
        if (l === null || (l.childLanes & a) === a) break;
        l.childLanes |= a;
      } else n.childLanes |= a, l !== null && (l.childLanes |= a);
      n = n.return;
    }
  }
  function _i(n, a) {
    Ha = n, ss = Lr = null, n = n.dependencies, n !== null && n.firstContext !== null && (n.lanes & a && (ar = !0), n.firstContext = null);
  }
  function $n(n, a) {
    if (ss !== n && a !== !1 && a !== 0)
      if ((typeof a != "number" || a === 1073741823) && (ss = n, a = 1073741823), a = { context: n, observedBits: a, next: null }, Lr === null) {
        if (Ha === null) throw Error(h(308));
        Lr = a, Ha.dependencies = { lanes: 0, firstContext: a, responders: null };
      } else Lr = Lr.next = a;
    return n._currentValue;
  }
  var rr = !1;
  function $c(n) {
    n.updateQueue = { baseState: n.memoizedState, firstBaseUpdate: null, lastBaseUpdate: null, shared: { pending: null }, effects: null };
  }
  function up(n, a) {
    n = n.updateQueue, a.updateQueue === n && (a.updateQueue = { baseState: n.baseState, firstBaseUpdate: n.firstBaseUpdate, lastBaseUpdate: n.lastBaseUpdate, shared: n.shared, effects: n.effects });
  }
  function mr(n, a) {
    return { eventTime: n, lane: a, tag: 0, payload: null, callback: null, next: null };
  }
  function ra(n, a) {
    if (n = n.updateQueue, n !== null) {
      n = n.shared;
      var l = n.pending;
      l === null ? a.next = a : (a.next = l.next, l.next = a), n.pending = a;
    }
  }
  function sp(n, a) {
    var l = n.updateQueue, u = n.alternate;
    if (u !== null && (u = u.updateQueue, l === u)) {
      var f = null, m = null;
      if (l = l.firstBaseUpdate, l !== null) {
        do {
          var S = { eventTime: l.eventTime, lane: l.lane, tag: l.tag, payload: l.payload, callback: l.callback, next: null };
          m === null ? f = m = S : m = m.next = S, l = l.next;
        } while (l !== null);
        m === null ? f = m = a : m = m.next = a;
      } else f = m = a;
      l = { baseState: u.baseState, firstBaseUpdate: f, lastBaseUpdate: m, shared: u.shared, effects: u.effects }, n.updateQueue = l;
      return;
    }
    n = l.lastBaseUpdate, n === null ? l.firstBaseUpdate = a : n.next = a, l.lastBaseUpdate = a;
  }
  function aa(n, a, l, u) {
    var f = n.updateQueue;
    rr = !1;
    var m = f.firstBaseUpdate, S = f.lastBaseUpdate, T = f.shared.pending;
    if (T !== null) {
      f.shared.pending = null;
      var w = T, P = w.next;
      w.next = null, S === null ? m = P : S.next = P, S = w;
      var he = n.alternate;
      if (he !== null) {
        he = he.updateQueue;
        var Ie = he.lastBaseUpdate;
        Ie !== S && (Ie === null ? he.firstBaseUpdate = P : Ie.next = P, he.lastBaseUpdate = w);
      }
    }
    if (m !== null) {
      Ie = f.baseState, S = 0, he = P = w = null;
      do {
        T = m.lane;
        var K = m.eventTime;
        if ((u & T) === T) {
          he !== null && (he = he.next = {
            eventTime: K,
            lane: 0,
            tag: m.tag,
            payload: m.payload,
            callback: m.callback,
            next: null
          });
          e: {
            var ke = n, He = m;
            switch (T = a, K = l, He.tag) {
              case 1:
                if (ke = He.payload, typeof ke == "function") {
                  Ie = ke.call(K, Ie, T);
                  break e;
                }
                Ie = ke;
                break e;
              case 3:
                ke.flags = ke.flags & -4097 | 64;
              case 0:
                if (ke = He.payload, T = typeof ke == "function" ? ke.call(K, Ie, T) : ke, T == null) break e;
                Ie = p({}, Ie, T);
                break e;
              case 2:
                rr = !0;
            }
          }
          m.callback !== null && (n.flags |= 32, T = f.effects, T === null ? f.effects = [m] : T.push(m));
        } else K = { eventTime: K, lane: T, tag: m.tag, payload: m.payload, callback: m.callback, next: null }, he === null ? (P = he = K, w = Ie) : he = he.next = K, S |= T;
        if (m = m.next, m === null) {
          if (T = f.shared.pending, T === null) break;
          m = T.next, T.next = null, f.lastBaseUpdate = T, f.shared.pending = null;
        }
      } while (!0);
      he === null && (w = Ie), f.baseState = w, f.firstBaseUpdate = P, f.lastBaseUpdate = he, zi |= S, n.lanes = S, n.memoizedState = Ie;
    }
  }
  function Wc(n, a, l) {
    if (n = a.effects, a.effects = null, n !== null) for (a = 0; a < n.length; a++) {
      var u = n[a], f = u.callback;
      if (f !== null) {
        if (u.callback = null, u = l, typeof f != "function") throw Error(h(191, f));
        f.call(u);
      }
    }
  }
  var fs = new c.Component().refs;
  function Ao(n, a, l, u) {
    a = n.memoizedState, l = l(u, a), l = l == null ? a : p({}, a, l), n.memoizedState = l, n.lanes === 0 && (n.updateQueue.baseState = l);
  }
  var _l = { isMounted: function(n) {
    return (n = n._reactInternals) ? Sn(n) === n : !1;
  }, enqueueSetState: function(n, a, l) {
    n = n._reactInternals;
    var u = Wn(), f = Pr(n), m = mr(u, f);
    m.payload = a, l != null && (m.callback = l), ra(n, m), qa(n, f, u);
  }, enqueueReplaceState: function(n, a, l) {
    n = n._reactInternals;
    var u = Wn(), f = Pr(n), m = mr(u, f);
    m.tag = 1, m.payload = a, l != null && (m.callback = l), ra(n, m), qa(n, f, u);
  }, enqueueForceUpdate: function(n, a) {
    n = n._reactInternals;
    var l = Wn(), u = Pr(n), f = mr(l, u);
    f.tag = 2, a != null && (f.callback = a), ra(n, f), qa(n, u, l);
  } };
  function Uo(n, a, l, u, f, m, S) {
    return n = n.stateNode, typeof n.shouldComponentUpdate == "function" ? n.shouldComponentUpdate(u, m, S) : a.prototype && a.prototype.isPureReactComponent ? !ko(l, u) || !ko(f, m) : !0;
  }
  function Di(n, a, l) {
    var u = !1, f = Aa, m = a.contextType;
    return typeof m == "object" && m !== null ? m = $n(m) : (f = hn(a) ? Ua : Dt.current, u = a.contextTypes, m = (u = u != null) ? vt(n, f) : Aa), a = new a(l, m), n.memoizedState = a.state !== null && a.state !== void 0 ? a.state : null, a.updater = _l, n.stateNode = a, a._reactInternals = n, u && (n = n.stateNode, n.__reactInternalMemoizedUnmaskedChildContext = f, n.__reactInternalMemoizedMaskedChildContext = m), a;
  }
  function ds(n, a, l, u) {
    n = a.state, typeof a.componentWillReceiveProps == "function" && a.componentWillReceiveProps(l, u), typeof a.UNSAFE_componentWillReceiveProps == "function" && a.UNSAFE_componentWillReceiveProps(l, u), a.state !== n && _l.enqueueReplaceState(a, a.state, null);
  }
  function ps(n, a, l, u) {
    var f = n.stateNode;
    f.props = l, f.state = n.memoizedState, f.refs = fs, $c(n);
    var m = a.contextType;
    typeof m == "object" && m !== null ? f.context = $n(m) : (m = hn(a) ? Ua : Dt.current, f.context = vt(n, m)), aa(n, l, f, u), f.state = n.memoizedState, m = a.getDerivedStateFromProps, typeof m == "function" && (Ao(n, a, m, l), f.state = n.memoizedState), typeof a.getDerivedStateFromProps == "function" || typeof f.getSnapshotBeforeUpdate == "function" || typeof f.UNSAFE_componentWillMount != "function" && typeof f.componentWillMount != "function" || (a = f.state, typeof f.componentWillMount == "function" && f.componentWillMount(), typeof f.UNSAFE_componentWillMount == "function" && f.UNSAFE_componentWillMount(), a !== f.state && _l.enqueueReplaceState(f, f.state, null), aa(n, l, f, u), f.state = n.memoizedState), typeof f.componentDidMount == "function" && (n.flags |= 4);
  }
  var Oi = Array.isArray;
  function Dl(n, a, l) {
    if (n = l.ref, n !== null && typeof n != "function" && typeof n != "object") {
      if (l._owner) {
        if (l = l._owner, l) {
          if (l.tag !== 1) throw Error(h(309));
          var u = l.stateNode;
        }
        if (!u) throw Error(h(147, n));
        var f = "" + n;
        return a !== null && a.ref !== null && typeof a.ref == "function" && a.ref._stringRef === f ? a.ref : (a = function(m) {
          var S = u.refs;
          S === fs && (S = u.refs = {}), m === null ? delete S[f] : S[f] = m;
        }, a._stringRef = f, a);
      }
      if (typeof n != "string") throw Error(h(284));
      if (!l._owner) throw Error(h(290, n));
    }
    return n;
  }
  function zo(n, a) {
    if (n.type !== "textarea") throw Error(h(31, Object.prototype.toString.call(a) === "[object Object]" ? "object with keys {" + Object.keys(a).join(", ") + "}" : a));
  }
  function Yc(n) {
    function a(M, _) {
      if (n) {
        var O = M.lastEffect;
        O !== null ? (O.nextEffect = _, M.lastEffect = _) : M.firstEffect = M.lastEffect = _, _.nextEffect = null, _.flags = 8;
      }
    }
    function l(M, _) {
      if (!n) return null;
      for (; _ !== null; ) a(M, _), _ = _.sibling;
      return null;
    }
    function u(M, _) {
      for (M = /* @__PURE__ */ new Map(); _ !== null; ) _.key !== null ? M.set(_.key, _) : M.set(_.index, _), _ = _.sibling;
      return M;
    }
    function f(M, _) {
      return M = Ka(M, _), M.index = 0, M.sibling = null, M;
    }
    function m(M, _, O) {
      return M.index = O, n ? (O = M.alternate, O !== null ? (O = O.index, O < _ ? (M.flags = 2, _) : O) : (M.flags = 2, _)) : _;
    }
    function S(M) {
      return n && M.alternate === null && (M.flags = 2), M;
    }
    function T(M, _, O, $) {
      return _ === null || _.tag !== 6 ? (_ = bf(O, M.mode, $), _.return = M, _) : (_ = f(_, O), _.return = M, _);
    }
    function w(M, _, O, $) {
      return _ !== null && _.elementType === O.type ? ($ = f(_, O.props), $.ref = Dl(M, _, O), $.return = M, $) : ($ = iu(O.type, O.key, O.props, null, M.mode, $), $.ref = Dl(M, _, O), $.return = M, $);
    }
    function P(M, _, O, $) {
      return _ === null || _.tag !== 4 || _.stateNode.containerInfo !== O.containerInfo || _.stateNode.implementation !== O.implementation ? (_ = Tf(O, M.mode, $), _.return = M, _) : (_ = f(_, O.children || []), _.return = M, _);
    }
    function he(M, _, O, $, q) {
      return _ === null || _.tag !== 7 ? (_ = Br(O, M.mode, $, q), _.return = M, _) : (_ = f(_, O), _.return = M, _);
    }
    function Ie(M, _, O) {
      if (typeof _ == "string" || typeof _ == "number") return _ = bf("" + _, M.mode, O), _.return = M, _;
      if (typeof _ == "object" && _ !== null) {
        switch (_.$$typeof) {
          case le:
            return O = iu(_.type, _.key, _.props, null, M.mode, O), O.ref = Dl(M, null, _), O.return = M, O;
          case Se:
            return _ = Tf(_, M.mode, O), _.return = M, _;
        }
        if (Oi(_) || ve(_)) return _ = Br(
          _,
          M.mode,
          O,
          null
        ), _.return = M, _;
        zo(M, _);
      }
      return null;
    }
    function K(M, _, O, $) {
      var q = _ !== null ? _.key : null;
      if (typeof O == "string" || typeof O == "number") return q !== null ? null : T(M, _, "" + O, $);
      if (typeof O == "object" && O !== null) {
        switch (O.$$typeof) {
          case le:
            return O.key === q ? O.type === We ? he(M, _, O.props.children, $, q) : w(M, _, O, $) : null;
          case Se:
            return O.key === q ? P(M, _, O, $) : null;
        }
        if (Oi(O) || ve(O)) return q !== null ? null : he(M, _, O, $, null);
        zo(M, O);
      }
      return null;
    }
    function ke(M, _, O, $, q) {
      if (typeof $ == "string" || typeof $ == "number") return M = M.get(O) || null, T(_, M, "" + $, q);
      if (typeof $ == "object" && $ !== null) {
        switch ($.$$typeof) {
          case le:
            return M = M.get($.key === null ? O : $.key) || null, $.type === We ? he(_, M, $.props.children, q, $.key) : w(_, M, $, q);
          case Se:
            return M = M.get($.key === null ? O : $.key) || null, P(_, M, $, q);
        }
        if (Oi($) || ve($)) return M = M.get(O) || null, he(_, M, $, q, null);
        zo(_, $);
      }
      return null;
    }
    function He(M, _, O, $) {
      for (var q = null, qe = null, ge = _, $e = _ = 0, Ge = null; ge !== null && $e < O.length; $e++) {
        ge.index > $e ? (Ge = ge, ge = null) : Ge = ge.sibling;
        var Qe = K(M, ge, O[$e], $);
        if (Qe === null) {
          ge === null && (ge = Ge);
          break;
        }
        n && ge && Qe.alternate === null && a(M, ge), _ = m(Qe, _, $e), qe === null ? q = Qe : qe.sibling = Qe, qe = Qe, ge = Ge;
      }
      if ($e === O.length) return l(M, ge), q;
      if (ge === null) {
        for (; $e < O.length; $e++) ge = Ie(M, O[$e], $), ge !== null && (_ = m(ge, _, $e), qe === null ? q = ge : qe.sibling = ge, qe = ge);
        return q;
      }
      for (ge = u(M, ge); $e < O.length; $e++) Ge = ke(ge, M, $e, O[$e], $), Ge !== null && (n && Ge.alternate !== null && ge.delete(Ge.key === null ? $e : Ge.key), _ = m(Ge, _, $e), qe === null ? q = Ge : qe.sibling = Ge, qe = Ge);
      return n && ge.forEach(function(Za) {
        return a(M, Za);
      }), q;
    }
    function Le(M, _, O, $) {
      var q = ve(O);
      if (typeof q != "function") throw Error(h(150));
      if (O = q.call(O), O == null) throw Error(h(151));
      for (var qe = q = null, ge = _, $e = _ = 0, Ge = null, Qe = O.next(); ge !== null && !Qe.done; $e++, Qe = O.next()) {
        ge.index > $e ? (Ge = ge, ge = null) : Ge = ge.sibling;
        var Za = K(M, ge, Qe.value, $);
        if (Za === null) {
          ge === null && (ge = Ge);
          break;
        }
        n && ge && Za.alternate === null && a(M, ge), _ = m(Za, _, $e), qe === null ? q = Za : qe.sibling = Za, qe = Za, ge = Ge;
      }
      if (Qe.done) return l(M, ge), q;
      if (ge === null) {
        for (; !Qe.done; $e++, Qe = O.next()) Qe = Ie(M, Qe.value, $), Qe !== null && (_ = m(Qe, _, $e), qe === null ? q = Qe : qe.sibling = Qe, qe = Qe);
        return q;
      }
      for (ge = u(M, ge); !Qe.done; $e++, Qe = O.next()) Qe = ke(ge, M, $e, Qe.value, $), Qe !== null && (n && Qe.alternate !== null && ge.delete(Qe.key === null ? $e : Qe.key), _ = m(Qe, _, $e), qe === null ? q = Qe : qe.sibling = Qe, qe = Qe);
      return n && ge.forEach(function(ym) {
        return a(M, ym);
      }), q;
    }
    return function(M, _, O, $) {
      var q = typeof O == "object" && O !== null && O.type === We && O.key === null;
      q && (O = O.props.children);
      var qe = typeof O == "object" && O !== null;
      if (qe) switch (O.$$typeof) {
        case le:
          e: {
            for (qe = O.key, q = _; q !== null; ) {
              if (q.key === qe) {
                switch (q.tag) {
                  case 7:
                    if (O.type === We) {
                      l(M, q.sibling), _ = f(q, O.props.children), _.return = M, M = _;
                      break e;
                    }
                    break;
                  default:
                    if (q.elementType === O.type) {
                      l(M, q.sibling), _ = f(q, O.props), _.ref = Dl(M, q, O), _.return = M, M = _;
                      break e;
                    }
                }
                l(M, q);
                break;
              } else a(M, q);
              q = q.sibling;
            }
            O.type === We ? (_ = Br(O.props.children, M.mode, $, O.key), _.return = M, M = _) : ($ = iu(O.type, O.key, O.props, null, M.mode, $), $.ref = Dl(M, _, O), $.return = M, M = $);
          }
          return S(M);
        case Se:
          e: {
            for (q = O.key; _ !== null; ) {
              if (_.key === q) if (_.tag === 4 && _.stateNode.containerInfo === O.containerInfo && _.stateNode.implementation === O.implementation) {
                l(M, _.sibling), _ = f(_, O.children || []), _.return = M, M = _;
                break e;
              } else {
                l(M, _);
                break;
              }
              else a(M, _);
              _ = _.sibling;
            }
            _ = Tf(O, M.mode, $), _.return = M, M = _;
          }
          return S(M);
      }
      if (typeof O == "string" || typeof O == "number") return O = "" + O, _ !== null && _.tag === 6 ? (l(M, _.sibling), _ = f(_, O), _.return = M, M = _) : (l(M, _), _ = bf(O, M.mode, $), _.return = M, M = _), S(M);
      if (Oi(O)) return He(M, _, O, $);
      if (ve(O)) return Le(M, _, O, $);
      if (qe && zo(M, O), typeof O > "u" && !q) switch (M.tag) {
        case 1:
        case 22:
        case 0:
        case 11:
        case 15:
          throw Error(h(152, Ze(M.type) || "Component"));
      }
      return l(M, _);
    };
  }
  var jo = Yc(!0), qc = Yc(!1), Ni = {}, Ar = On(Ni), Fo = On(Ni), Ho = On(Ni);
  function Mi(n) {
    if (n === Ni) throw Error(h(174));
    return n;
  }
  function Po(n, a) {
    switch (Ue(Ho, a), Ue(Fo, n), Ue(Ar, Ni), n = a.nodeType, n) {
      case 9:
      case 11:
        a = (a = a.documentElement) ? a.namespaceURI : Je(null, "");
        break;
      default:
        n = n === 8 ? a.parentNode : a, a = n.namespaceURI || null, n = n.tagName, a = Je(a, n);
    }
    Ye(Ar), Ue(Ar, a);
  }
  function Ol() {
    Ye(Ar), Ye(Fo), Ye(Ho);
  }
  function cp(n) {
    Mi(Ho.current);
    var a = Mi(Ar.current), l = Je(a, n.type);
    a !== l && (Ue(Fo, n), Ue(Ar, l));
  }
  function Qc(n) {
    Fo.current === n && (Ye(Ar), Ye(Fo));
  }
  var Bt = On(0);
  function Bo(n) {
    for (var a = n; a !== null; ) {
      if (a.tag === 13) {
        var l = a.memoizedState;
        if (l !== null && (l = l.dehydrated, l === null || l.data === "$?" || l.data === "$!")) return a;
      } else if (a.tag === 19 && a.memoizedProps.revealOrder !== void 0) {
        if (a.flags & 64) return a;
      } else if (a.child !== null) {
        a.child.return = a, a = a.child;
        continue;
      }
      if (a === n) break;
      for (; a.sibling === null; ) {
        if (a.return === null || a.return === n) return null;
        a = a.return;
      }
      a.sibling.return = a.return, a = a.sibling;
    }
    return null;
  }
  var Ur = null, ia = null, zr = !1;
  function Gc(n, a) {
    var l = lr(5, null, null, 0);
    l.elementType = "DELETED", l.type = "DELETED", l.stateNode = a, l.return = n, l.flags = 8, n.lastEffect !== null ? (n.lastEffect.nextEffect = l, n.lastEffect = l) : n.firstEffect = n.lastEffect = l;
  }
  function fp(n, a) {
    switch (n.tag) {
      case 5:
        var l = n.type;
        return a = a.nodeType !== 1 || l.toLowerCase() !== a.nodeName.toLowerCase() ? null : a, a !== null ? (n.stateNode = a, !0) : !1;
      case 6:
        return a = n.pendingProps === "" || a.nodeType !== 3 ? null : a, a !== null ? (n.stateNode = a, !0) : !1;
      case 13:
        return !1;
      default:
        return !1;
    }
  }
  function Pa(n) {
    if (zr) {
      var a = ia;
      if (a) {
        var l = a;
        if (!fp(n, a)) {
          if (a = Ma(l.nextSibling), !a || !fp(n, a)) {
            n.flags = n.flags & -1025 | 2, zr = !1, Ur = n;
            return;
          }
          Gc(Ur, l);
        }
        Ur = n, ia = Ma(a.firstChild);
      } else n.flags = n.flags & -1025 | 2, zr = !1, Ur = n;
    }
  }
  function Vo(n) {
    for (n = n.return; n !== null && n.tag !== 5 && n.tag !== 3 && n.tag !== 13; ) n = n.return;
    Ur = n;
  }
  function Io(n) {
    if (n !== Ur) return !1;
    if (!zr) return Vo(n), zr = !0, !1;
    var a = n.type;
    if (n.tag !== 5 || a !== "head" && a !== "body" && !Oo(a, n.memoizedProps)) for (a = ia; a; ) Gc(n, a), a = Ma(a.nextSibling);
    if (Vo(n), n.tag === 13) {
      if (n = n.memoizedState, n = n !== null ? n.dehydrated : null, !n) throw Error(h(317));
      e: {
        for (n = n.nextSibling, a = 0; n; ) {
          if (n.nodeType === 8) {
            var l = n.data;
            if (l === "/$") {
              if (a === 0) {
                ia = Ma(n.nextSibling);
                break e;
              }
              a--;
            } else l !== "$" && l !== "$!" && l !== "$?" || a++;
          }
          n = n.nextSibling;
        }
        ia = null;
      }
    } else ia = Ur ? Ma(n.stateNode.nextSibling) : null;
    return !0;
  }
  function Nl() {
    ia = Ur = null, zr = !1;
  }
  var Li = [];
  function Ba() {
    for (var n = 0; n < Li.length; n++) Li[n]._workInProgressVersionPrimary = null;
    Li.length = 0;
  }
  var Ml = z.ReactCurrentDispatcher, ln = z.ReactCurrentBatchConfig, Ll = 0, Ot = null, on = null, un = null, $o = !1, Va = !1;
  function Nn() {
    throw Error(h(321));
  }
  function la(n, a) {
    if (a === null) return !1;
    for (var l = 0; l < a.length && l < n.length; l++) if (!tr(n[l], a[l])) return !1;
    return !0;
  }
  function Xc(n, a, l, u, f, m) {
    if (Ll = m, Ot = a, a.memoizedState = null, a.updateQueue = null, a.lanes = 0, Ml.current = n === null || n.memoizedState === null ? qo : Zh, n = l(u, f), Va) {
      m = 0;
      do {
        if (Va = !1, !(25 > m)) throw Error(h(301));
        m += 1, un = on = null, a.updateQueue = null, Ml.current = Jh, n = l(u, f);
      } while (Va);
    }
    if (Ml.current = ms, a = on !== null && on.next !== null, Ll = 0, un = on = Ot = null, $o = !1, a) throw Error(h(300));
    return n;
  }
  function W() {
    var n = { memoizedState: null, baseState: null, baseQueue: null, queue: null, next: null };
    return un === null ? Ot.memoizedState = un = n : un = un.next = n, un;
  }
  function qt() {
    if (on === null) {
      var n = Ot.alternate;
      n = n !== null ? n.memoizedState : null;
    } else n = on.next;
    var a = un === null ? Ot.memoizedState : un.next;
    if (a !== null) un = a, on = n;
    else {
      if (n === null) throw Error(h(310));
      on = n, n = { memoizedState: on.memoizedState, baseState: on.baseState, baseQueue: on.baseQueue, queue: on.queue, next: null }, un === null ? Ot.memoizedState = un = n : un = un.next = n;
    }
    return un;
  }
  function at(n, a) {
    return typeof a == "function" ? a(n) : a;
  }
  function oa(n) {
    var a = qt(), l = a.queue;
    if (l === null) throw Error(h(311));
    l.lastRenderedReducer = n;
    var u = on, f = u.baseQueue, m = l.pending;
    if (m !== null) {
      if (f !== null) {
        var S = f.next;
        f.next = m.next, m.next = S;
      }
      u.baseQueue = f = m, l.pending = null;
    }
    if (f !== null) {
      f = f.next, u = u.baseState;
      var T = S = m = null, w = f;
      do {
        var P = w.lane;
        if ((Ll & P) === P) T !== null && (T = T.next = { lane: 0, action: w.action, eagerReducer: w.eagerReducer, eagerState: w.eagerState, next: null }), u = w.eagerReducer === n ? w.eagerState : n(u, w.action);
        else {
          var he = {
            lane: P,
            action: w.action,
            eagerReducer: w.eagerReducer,
            eagerState: w.eagerState,
            next: null
          };
          T === null ? (S = T = he, m = u) : T = T.next = he, Ot.lanes |= P, zi |= P;
        }
        w = w.next;
      } while (w !== null && w !== f);
      T === null ? m = u : T.next = S, tr(u, a.memoizedState) || (ar = !0), a.memoizedState = u, a.baseState = m, a.baseQueue = T, l.lastRenderedState = u;
    }
    return [a.memoizedState, l.dispatch];
  }
  function Ai(n) {
    var a = qt(), l = a.queue;
    if (l === null) throw Error(h(311));
    l.lastRenderedReducer = n;
    var u = l.dispatch, f = l.pending, m = a.memoizedState;
    if (f !== null) {
      l.pending = null;
      var S = f = f.next;
      do
        m = n(m, S.action), S = S.next;
      while (S !== f);
      tr(m, a.memoizedState) || (ar = !0), a.memoizedState = m, a.baseQueue === null && (a.baseState = m), l.lastRenderedState = m;
    }
    return [m, u];
  }
  function Wo(n, a, l) {
    var u = a._getVersion;
    u = u(a._source);
    var f = a._workInProgressVersionPrimary;
    if (f !== null ? n = f === u : (n = n.mutableReadLanes, (n = (Ll & n) === n) && (a._workInProgressVersionPrimary = u, Li.push(a))), n) return l(a._source);
    throw Li.push(a), Error(h(350));
  }
  function Kc(n, a, l, u) {
    var f = Mn;
    if (f === null) throw Error(h(349));
    var m = a._getVersion, S = m(a._source), T = Ml.current, w = T.useState(function() {
      return Wo(f, a, l);
    }), P = w[1], he = w[0];
    w = un;
    var Ie = n.memoizedState, K = Ie.refs, ke = K.getSnapshot, He = Ie.source;
    Ie = Ie.subscribe;
    var Le = Ot;
    return n.memoizedState = { refs: K, source: a, subscribe: u }, T.useEffect(function() {
      K.getSnapshot = l, K.setSnapshot = P;
      var M = m(a._source);
      if (!tr(S, M)) {
        M = l(a._source), tr(he, M) || (P(M), M = Pr(Le), f.mutableReadLanes |= M & f.pendingLanes), M = f.mutableReadLanes, f.entangledLanes |= M;
        for (var _ = f.entanglements, O = M; 0 < O; ) {
          var $ = 31 - ka(O), q = 1 << $;
          _[$] |= M, O &= ~q;
        }
      }
    }, [l, a, u]), T.useEffect(function() {
      return u(a._source, function() {
        var M = K.getSnapshot, _ = K.setSnapshot;
        try {
          _(M(a._source));
          var O = Pr(Le);
          f.mutableReadLanes |= O & f.pendingLanes;
        } catch ($) {
          _(function() {
            throw $;
          });
        }
      });
    }, [a, u]), tr(ke, l) && tr(He, a) && tr(Ie, u) || (n = { pending: null, dispatch: null, lastRenderedReducer: at, lastRenderedState: he }, n.dispatch = P = tf.bind(null, Ot, n), w.queue = n, w.baseQueue = null, he = Wo(f, a, l), w.memoizedState = w.baseState = he), he;
  }
  function Zc(n, a, l) {
    var u = qt();
    return Kc(u, n, a, l);
  }
  function Al(n) {
    var a = W();
    return typeof n == "function" && (n = n()), a.memoizedState = a.baseState = n, n = a.queue = { pending: null, dispatch: null, lastRenderedReducer: at, lastRenderedState: n }, n = n.dispatch = tf.bind(null, Ot, n), [a.memoizedState, n];
  }
  function Ul(n, a, l, u) {
    return n = { tag: n, create: a, destroy: l, deps: u, next: null }, a = Ot.updateQueue, a === null ? (a = { lastEffect: null }, Ot.updateQueue = a, a.lastEffect = n.next = n) : (l = a.lastEffect, l === null ? a.lastEffect = n.next = n : (u = l.next, l.next = n, n.next = u, a.lastEffect = n)), n;
  }
  function Jc(n) {
    var a = W();
    return n = { current: n }, a.memoizedState = n;
  }
  function ua() {
    return qt().memoizedState;
  }
  function zl(n, a, l, u) {
    var f = W();
    Ot.flags |= n, f.memoizedState = Ul(1 | a, l, void 0, u === void 0 ? null : u);
  }
  function Ia(n, a, l, u) {
    var f = qt();
    u = u === void 0 ? null : u;
    var m = void 0;
    if (on !== null) {
      var S = on.memoizedState;
      if (m = S.destroy, u !== null && la(u, S.deps)) {
        Ul(a, l, m, u);
        return;
      }
    }
    Ot.flags |= n, f.memoizedState = Ul(1 | a, l, m, u);
  }
  function vs(n, a) {
    return zl(516, 4, n, a);
  }
  function Yo(n, a) {
    return Ia(516, 4, n, a);
  }
  function ef(n, a) {
    return Ia(4, 2, n, a);
  }
  function hs(n, a) {
    if (typeof a == "function") return n = n(), a(n), function() {
      a(null);
    };
    if (a != null) return n = n(), a.current = n, function() {
      a.current = null;
    };
  }
  function yr(n, a, l) {
    return l = l != null ? l.concat([n]) : null, Ia(4, 2, hs.bind(null, a, n), l);
  }
  function Nt() {
  }
  function Kh(n, a) {
    var l = qt();
    a = a === void 0 ? null : a;
    var u = l.memoizedState;
    return u !== null && a !== null && la(a, u[1]) ? u[0] : (l.memoizedState = [n, a], n);
  }
  function Tt(n, a) {
    var l = qt();
    a = a === void 0 ? null : a;
    var u = l.memoizedState;
    return u !== null && a !== null && la(a, u[1]) ? u[0] : (n = n(), l.memoizedState = [n, a], n);
  }
  function jl(n, a) {
    var l = kl();
    wi(98 > l ? 98 : l, function() {
      n(!0);
    }), wi(97 < l ? 97 : l, function() {
      var u = ln.transition;
      ln.transition = 1;
      try {
        n(!1), a();
      } finally {
        ln.transition = u;
      }
    });
  }
  function tf(n, a, l) {
    var u = Wn(), f = Pr(n), m = { lane: f, action: l, eagerReducer: null, eagerState: null, next: null }, S = a.pending;
    if (S === null ? m.next = m : (m.next = S.next, S.next = m), a.pending = m, S = n.alternate, n === Ot || S !== null && S === Ot) Va = $o = !0;
    else {
      if (n.lanes === 0 && (S === null || S.lanes === 0) && (S = a.lastRenderedReducer, S !== null)) try {
        var T = a.lastRenderedState, w = S(T, l);
        if (m.eagerReducer = S, m.eagerState = w, tr(w, T)) return;
      } catch {
      } finally {
      }
      qa(n, f, u);
    }
  }
  var ms = { readContext: $n, useCallback: Nn, useContext: Nn, useEffect: Nn, useImperativeHandle: Nn, useLayoutEffect: Nn, useMemo: Nn, useReducer: Nn, useRef: Nn, useState: Nn, useDebugValue: Nn, useDeferredValue: Nn, useTransition: Nn, useMutableSource: Nn, useOpaqueIdentifier: Nn, unstable_isNewReconciler: !1 }, qo = { readContext: $n, useCallback: function(n, a) {
    return W().memoizedState = [n, a === void 0 ? null : a], n;
  }, useContext: $n, useEffect: vs, useImperativeHandle: function(n, a, l) {
    return l = l != null ? l.concat([n]) : null, zl(4, 2, hs.bind(
      null,
      a,
      n
    ), l);
  }, useLayoutEffect: function(n, a) {
    return zl(4, 2, n, a);
  }, useMemo: function(n, a) {
    var l = W();
    return a = a === void 0 ? null : a, n = n(), l.memoizedState = [n, a], n;
  }, useReducer: function(n, a, l) {
    var u = W();
    return a = l !== void 0 ? l(a) : a, u.memoizedState = u.baseState = a, n = u.queue = { pending: null, dispatch: null, lastRenderedReducer: n, lastRenderedState: a }, n = n.dispatch = tf.bind(null, Ot, n), [u.memoizedState, n];
  }, useRef: Jc, useState: Al, useDebugValue: Nt, useDeferredValue: function(n) {
    var a = Al(n), l = a[0], u = a[1];
    return vs(function() {
      var f = ln.transition;
      ln.transition = 1;
      try {
        u(n);
      } finally {
        ln.transition = f;
      }
    }, [n]), l;
  }, useTransition: function() {
    var n = Al(!1), a = n[0];
    return n = jl.bind(null, n[1]), Jc(n), [n, a];
  }, useMutableSource: function(n, a, l) {
    var u = W();
    return u.memoizedState = { refs: { getSnapshot: a, setSnapshot: null }, source: n, subscribe: l }, Kc(u, n, a, l);
  }, useOpaqueIdentifier: function() {
    if (zr) {
      var n = !1, a = as(function() {
        throw n || (n = !0, l("r:" + (La++).toString(36))), Error(h(355));
      }), l = Al(a)[1];
      return !(Ot.mode & 2) && (Ot.flags |= 516, Ul(
        5,
        function() {
          l("r:" + (La++).toString(36));
        },
        void 0,
        null
      )), a;
    }
    return a = "r:" + (La++).toString(36), Al(a), a;
  }, unstable_isNewReconciler: !1 }, Zh = { readContext: $n, useCallback: Kh, useContext: $n, useEffect: Yo, useImperativeHandle: yr, useLayoutEffect: ef, useMemo: Tt, useReducer: oa, useRef: ua, useState: function() {
    return oa(at);
  }, useDebugValue: Nt, useDeferredValue: function(n) {
    var a = oa(at), l = a[0], u = a[1];
    return Yo(function() {
      var f = ln.transition;
      ln.transition = 1;
      try {
        u(n);
      } finally {
        ln.transition = f;
      }
    }, [n]), l;
  }, useTransition: function() {
    var n = oa(at)[0];
    return [
      ua().current,
      n
    ];
  }, useMutableSource: Zc, useOpaqueIdentifier: function() {
    return oa(at)[0];
  }, unstable_isNewReconciler: !1 }, Jh = { readContext: $n, useCallback: Kh, useContext: $n, useEffect: Yo, useImperativeHandle: yr, useLayoutEffect: ef, useMemo: Tt, useReducer: Ai, useRef: ua, useState: function() {
    return Ai(at);
  }, useDebugValue: Nt, useDeferredValue: function(n) {
    var a = Ai(at), l = a[0], u = a[1];
    return Yo(function() {
      var f = ln.transition;
      ln.transition = 1;
      try {
        u(n);
      } finally {
        ln.transition = f;
      }
    }, [n]), l;
  }, useTransition: function() {
    var n = Ai(at)[0];
    return [
      ua().current,
      n
    ];
  }, useMutableSource: Zc, useOpaqueIdentifier: function() {
    return Ai(at)[0];
  }, unstable_isNewReconciler: !1 }, em = z.ReactCurrentOwner, ar = !1;
  function zn(n, a, l, u) {
    a.child = n === null ? qc(a, null, l, u) : jo(a, n.child, l, u);
  }
  function nf(n, a, l, u, f) {
    l = l.render;
    var m = a.ref;
    return _i(a, f), u = Xc(n, a, l, u, m, f), n !== null && !ar ? (a.updateQueue = n.updateQueue, a.flags &= -517, n.lanes &= ~f, sa(n, a, f)) : (a.flags |= 1, zn(n, a, u, f), a.child);
  }
  function rf(n, a, l, u, f, m) {
    if (n === null) {
      var S = l.type;
      return typeof S == "function" && !xs(S) && S.defaultProps === void 0 && l.compare === null && l.defaultProps === void 0 ? (a.tag = 15, a.type = S, dp(n, a, S, u, f, m)) : (n = iu(l.type, null, u, a, a.mode, m), n.ref = a.ref, n.return = a, a.child = n);
    }
    return S = n.child, !(f & m) && (f = S.memoizedProps, l = l.compare, l = l !== null ? l : ko, l(f, u) && n.ref === a.ref) ? sa(n, a, m) : (a.flags |= 1, n = Ka(S, u), n.ref = a.ref, n.return = a, a.child = n);
  }
  function dp(n, a, l, u, f, m) {
    if (n !== null && ko(n.memoizedProps, u) && n.ref === a.ref) if (ar = !1, (m & f) !== 0) n.flags & 16384 && (ar = !0);
    else return a.lanes = n.lanes, sa(n, a, m);
    return af(n, a, l, u, m);
  }
  function Fl(n, a, l) {
    var u = a.pendingProps, f = u.children, m = n !== null ? n.memoizedState : null;
    if (u.mode === "hidden" || u.mode === "unstable-defer-without-hiding") if (!(a.mode & 4)) a.memoizedState = { baseLanes: 0 }, Ts(a, l);
    else if (l & 1073741824) a.memoizedState = { baseLanes: 0 }, Ts(a, m !== null ? m.baseLanes : l);
    else return n = m !== null ? m.baseLanes | l : l, a.lanes = a.childLanes = 1073741824, a.memoizedState = { baseLanes: n }, Ts(a, n), null;
    else m !== null ? (u = m.baseLanes | l, a.memoizedState = null) : u = l, Ts(a, u);
    return zn(n, a, f, l), a.child;
  }
  function pp(n, a) {
    var l = a.ref;
    (n === null && l !== null || n !== null && n.ref !== l) && (a.flags |= 128);
  }
  function af(n, a, l, u, f) {
    var m = hn(l) ? Ua : Dt.current;
    return m = vt(a, m), _i(a, f), l = Xc(n, a, l, u, m, f), n !== null && !ar ? (a.updateQueue = n.updateQueue, a.flags &= -517, n.lanes &= ~f, sa(n, a, f)) : (a.flags |= 1, zn(n, a, l, f), a.child);
  }
  function vp(n, a, l, u, f) {
    if (hn(l)) {
      var m = !0;
      nr(a);
    } else m = !1;
    if (_i(a, f), a.stateNode === null) n !== null && (n.alternate = null, a.alternate = null, a.flags |= 2), Di(a, l, u), ps(a, l, u, f), u = !0;
    else if (n === null) {
      var S = a.stateNode, T = a.memoizedProps;
      S.props = T;
      var w = S.context, P = l.contextType;
      typeof P == "object" && P !== null ? P = $n(P) : (P = hn(l) ? Ua : Dt.current, P = vt(a, P));
      var he = l.getDerivedStateFromProps, Ie = typeof he == "function" || typeof S.getSnapshotBeforeUpdate == "function";
      Ie || typeof S.UNSAFE_componentWillReceiveProps != "function" && typeof S.componentWillReceiveProps != "function" || (T !== u || w !== P) && ds(a, S, u, P), rr = !1;
      var K = a.memoizedState;
      S.state = K, aa(a, u, S, f), w = a.memoizedState, T !== u || K !== w || vn.current || rr ? (typeof he == "function" && (Ao(a, l, he, u), w = a.memoizedState), (T = rr || Uo(a, l, T, u, K, w, P)) ? (Ie || typeof S.UNSAFE_componentWillMount != "function" && typeof S.componentWillMount != "function" || (typeof S.componentWillMount == "function" && S.componentWillMount(), typeof S.UNSAFE_componentWillMount == "function" && S.UNSAFE_componentWillMount()), typeof S.componentDidMount == "function" && (a.flags |= 4)) : (typeof S.componentDidMount == "function" && (a.flags |= 4), a.memoizedProps = u, a.memoizedState = w), S.props = u, S.state = w, S.context = P, u = T) : (typeof S.componentDidMount == "function" && (a.flags |= 4), u = !1);
    } else {
      S = a.stateNode, up(n, a), T = a.memoizedProps, P = a.type === a.elementType ? T : an(a.type, T), S.props = P, Ie = a.pendingProps, K = S.context, w = l.contextType, typeof w == "object" && w !== null ? w = $n(w) : (w = hn(l) ? Ua : Dt.current, w = vt(a, w));
      var ke = l.getDerivedStateFromProps;
      (he = typeof ke == "function" || typeof S.getSnapshotBeforeUpdate == "function") || typeof S.UNSAFE_componentWillReceiveProps != "function" && typeof S.componentWillReceiveProps != "function" || (T !== Ie || K !== w) && ds(a, S, u, w), rr = !1, K = a.memoizedState, S.state = K, aa(a, u, S, f);
      var He = a.memoizedState;
      T !== Ie || K !== He || vn.current || rr ? (typeof ke == "function" && (Ao(a, l, ke, u), He = a.memoizedState), (P = rr || Uo(a, l, P, u, K, He, w)) ? (he || typeof S.UNSAFE_componentWillUpdate != "function" && typeof S.componentWillUpdate != "function" || (typeof S.componentWillUpdate == "function" && S.componentWillUpdate(
        u,
        He,
        w
      ), typeof S.UNSAFE_componentWillUpdate == "function" && S.UNSAFE_componentWillUpdate(u, He, w)), typeof S.componentDidUpdate == "function" && (a.flags |= 4), typeof S.getSnapshotBeforeUpdate == "function" && (a.flags |= 256)) : (typeof S.componentDidUpdate != "function" || T === n.memoizedProps && K === n.memoizedState || (a.flags |= 4), typeof S.getSnapshotBeforeUpdate != "function" || T === n.memoizedProps && K === n.memoizedState || (a.flags |= 256), a.memoizedProps = u, a.memoizedState = He), S.props = u, S.state = He, S.context = w, u = P) : (typeof S.componentDidUpdate != "function" || T === n.memoizedProps && K === n.memoizedState || (a.flags |= 4), typeof S.getSnapshotBeforeUpdate != "function" || T === n.memoizedProps && K === n.memoizedState || (a.flags |= 256), u = !1);
    }
    return lf(n, a, l, u, m, f);
  }
  function lf(n, a, l, u, f, m) {
    pp(n, a);
    var S = (a.flags & 64) !== 0;
    if (!u && !S) return f && rp(a, l, !1), sa(n, a, m);
    u = a.stateNode, em.current = a;
    var T = S && typeof l.getDerivedStateFromError != "function" ? null : u.render();
    return a.flags |= 1, n !== null && S ? (a.child = jo(a, n.child, null, m), a.child = jo(a, null, T, m)) : zn(n, a, T, m), a.memoizedState = u.state, f && rp(a, l, !0), a.child;
  }
  function hp(n) {
    var a = n.stateNode;
    a.pendingContext ? xl(n, a.pendingContext, a.pendingContext !== a.context) : a.context && xl(n, a.context, !1), Po(n, a.containerInfo);
  }
  var sn = { dehydrated: null, retryLane: 0 };
  function $a(n, a, l) {
    var u = a.pendingProps, f = Bt.current, m = !1, S;
    return (S = (a.flags & 64) !== 0) || (S = n !== null && n.memoizedState === null ? !1 : (f & 2) !== 0), S ? (m = !0, a.flags &= -65) : n !== null && n.memoizedState === null || u.fallback === void 0 || u.unstable_avoidThisFallback === !0 || (f |= 1), Ue(Bt, f & 1), n === null ? (u.fallback !== void 0 && Pa(a), n = u.children, f = u.fallback, m ? (n = mp(a, n, f, l), a.child.memoizedState = { baseLanes: l }, a.memoizedState = sn, n) : typeof u.unstable_expectedLoadTime == "number" ? (n = mp(a, n, f, l), a.child.memoizedState = { baseLanes: l }, a.memoizedState = sn, a.lanes = 33554432, n) : (l = Bi({ mode: "visible", children: n }, a.mode, l, null), l.return = a, a.child = l)) : n.memoizedState !== null ? m ? (u = Wa(n, a, u.children, u.fallback, l), m = a.child, f = n.child.memoizedState, m.memoizedState = f === null ? { baseLanes: l } : { baseLanes: f.baseLanes | l }, m.childLanes = n.childLanes & ~l, a.memoizedState = sn, u) : (l = yn(n, a, u.children, l), a.memoizedState = null, l) : m ? (u = Wa(n, a, u.children, u.fallback, l), m = a.child, f = n.child.memoizedState, m.memoizedState = f === null ? { baseLanes: l } : { baseLanes: f.baseLanes | l }, m.childLanes = n.childLanes & ~l, a.memoizedState = sn, u) : (l = yn(n, a, u.children, l), a.memoizedState = null, l);
  }
  function mp(n, a, l, u) {
    var f = n.mode, m = n.child;
    return a = { mode: "hidden", children: a }, !(f & 2) && m !== null ? (m.childLanes = 0, m.pendingProps = a) : m = Bi(a, f, 0, null), l = Br(l, f, u, null), m.return = n, l.return = n, m.sibling = l, n.child = m, l;
  }
  function yn(n, a, l, u) {
    var f = n.child;
    return n = f.sibling, l = Ka(f, { mode: "visible", children: l }), !(a.mode & 2) && (l.lanes = u), l.return = a, l.sibling = null, n !== null && (n.nextEffect = null, n.flags = 8, a.firstEffect = a.lastEffect = n), a.child = l;
  }
  function Wa(n, a, l, u, f) {
    var m = a.mode, S = n.child;
    n = S.sibling;
    var T = { mode: "hidden", children: l };
    return !(m & 2) && a.child !== S ? (l = a.child, l.childLanes = 0, l.pendingProps = T, S = l.lastEffect, S !== null ? (a.firstEffect = l.firstEffect, a.lastEffect = S, S.nextEffect = null) : a.firstEffect = a.lastEffect = null) : l = Ka(S, T), n !== null ? u = Ka(n, u) : (u = Br(u, m, f, null), u.flags |= 2), u.return = a, l.return = a, l.sibling = u, a.child = l, u;
  }
  function dt(n, a) {
    n.lanes |= a;
    var l = n.alternate;
    l !== null && (l.lanes |= a), Ic(n.return, a);
  }
  function Hl(n, a, l, u, f, m) {
    var S = n.memoizedState;
    S === null ? n.memoizedState = { isBackwards: a, rendering: null, renderingStartTime: 0, last: u, tail: l, tailMode: f, lastEffect: m } : (S.isBackwards = a, S.rendering = null, S.renderingStartTime = 0, S.last = u, S.tail = l, S.tailMode = f, S.lastEffect = m);
  }
  function tm(n, a, l) {
    var u = a.pendingProps, f = u.revealOrder, m = u.tail;
    if (zn(n, a, u.children, l), u = Bt.current, u & 2) u = u & 1 | 2, a.flags |= 64;
    else {
      if (n !== null && n.flags & 64) e: for (n = a.child; n !== null; ) {
        if (n.tag === 13) n.memoizedState !== null && dt(n, l);
        else if (n.tag === 19) dt(n, l);
        else if (n.child !== null) {
          n.child.return = n, n = n.child;
          continue;
        }
        if (n === a) break e;
        for (; n.sibling === null; ) {
          if (n.return === null || n.return === a) break e;
          n = n.return;
        }
        n.sibling.return = n.return, n = n.sibling;
      }
      u &= 1;
    }
    if (Ue(Bt, u), !(a.mode & 2)) a.memoizedState = null;
    else switch (f) {
      case "forwards":
        for (l = a.child, f = null; l !== null; ) n = l.alternate, n !== null && Bo(n) === null && (f = l), l = l.sibling;
        l = f, l === null ? (f = a.child, a.child = null) : (f = l.sibling, l.sibling = null), Hl(a, !1, f, l, m, a.lastEffect);
        break;
      case "backwards":
        for (l = null, f = a.child, a.child = null; f !== null; ) {
          if (n = f.alternate, n !== null && Bo(n) === null) {
            a.child = f;
            break;
          }
          n = f.sibling, f.sibling = l, l = f, f = n;
        }
        Hl(a, !0, l, null, m, a.lastEffect);
        break;
      case "together":
        Hl(a, !1, null, null, void 0, a.lastEffect);
        break;
      default:
        a.memoizedState = null;
    }
    return a.child;
  }
  function sa(n, a, l) {
    if (n !== null && (a.dependencies = n.dependencies), zi |= a.lanes, l & a.childLanes) {
      if (n !== null && a.child !== n.child) throw Error(h(153));
      if (a.child !== null) {
        for (n = a.child, l = Ka(n, n.pendingProps), a.child = l, l.return = a; n.sibling !== null; ) n = n.sibling, l = l.sibling = Ka(n, n.pendingProps), l.return = a;
        l.sibling = null;
      }
      return a.child;
    }
    return null;
  }
  var ys, Pl, yp, of;
  ys = function(n, a) {
    for (var l = a.child; l !== null; ) {
      if (l.tag === 5 || l.tag === 6) n.appendChild(l.stateNode);
      else if (l.tag !== 4 && l.child !== null) {
        l.child.return = l, l = l.child;
        continue;
      }
      if (l === a) break;
      for (; l.sibling === null; ) {
        if (l.return === null || l.return === a) return;
        l = l.return;
      }
      l.sibling.return = l.return, l = l.sibling;
    }
  }, Pl = function() {
  }, yp = function(n, a, l, u) {
    var f = n.memoizedProps;
    if (f !== u) {
      n = a.stateNode, Mi(Ar.current);
      var m = null;
      switch (l) {
        case "input":
          f = Ca(n, f), u = Ca(n, u), m = [];
          break;
        case "option":
          f = di(n, f), u = di(n, u), m = [];
          break;
        case "select":
          f = p({}, f, { value: void 0 }), u = p({}, u, { value: void 0 }), m = [];
          break;
        case "textarea":
          f = Wt(n, f), u = Wt(n, u), m = [];
          break;
        default:
          typeof f.onClick != "function" && typeof u.onClick == "function" && (n.onclick = ns);
      }
      pi(l, u);
      var S;
      l = null;
      for (P in f) if (!u.hasOwnProperty(P) && f.hasOwnProperty(P) && f[P] != null) if (P === "style") {
        var T = f[P];
        for (S in T) T.hasOwnProperty(S) && (l || (l = {}), l[S] = "");
      } else P !== "dangerouslySetInnerHTML" && P !== "children" && P !== "suppressContentEditableWarning" && P !== "suppressHydrationWarning" && P !== "autoFocus" && (C.hasOwnProperty(P) ? m || (m = []) : (m = m || []).push(P, null));
      for (P in u) {
        var w = u[P];
        if (T = f != null ? f[P] : void 0, u.hasOwnProperty(P) && w !== T && (w != null || T != null)) if (P === "style") if (T) {
          for (S in T) !T.hasOwnProperty(S) || w && w.hasOwnProperty(S) || (l || (l = {}), l[S] = "");
          for (S in w) w.hasOwnProperty(S) && T[S] !== w[S] && (l || (l = {}), l[S] = w[S]);
        } else l || (m || (m = []), m.push(P, l)), l = w;
        else P === "dangerouslySetInnerHTML" ? (w = w ? w.__html : void 0, T = T ? T.__html : void 0, w != null && T !== w && (m = m || []).push(P, w)) : P === "children" ? typeof w != "string" && typeof w != "number" || (m = m || []).push(P, "" + w) : P !== "suppressContentEditableWarning" && P !== "suppressHydrationWarning" && (C.hasOwnProperty(P) ? (w != null && P === "onScroll" && xt("scroll", n), m || T === w || (m = [])) : typeof w == "object" && w !== null && w.$$typeof === Rt ? w.toString() : (m = m || []).push(P, w));
      }
      l && (m = m || []).push(
        "style",
        l
      );
      var P = m;
      (a.updateQueue = P) && (a.flags |= 4);
    }
  }, of = function(n, a, l, u) {
    l !== u && (a.flags |= 4);
  };
  function Qo(n, a) {
    if (!zr) switch (n.tailMode) {
      case "hidden":
        a = n.tail;
        for (var l = null; a !== null; ) a.alternate !== null && (l = a), a = a.sibling;
        l === null ? n.tail = null : l.sibling = null;
        break;
      case "collapsed":
        l = n.tail;
        for (var u = null; l !== null; ) l.alternate !== null && (u = l), l = l.sibling;
        u === null ? a || n.tail === null ? n.tail = null : n.tail.sibling = null : u.sibling = null;
    }
  }
  function nm(n, a, l) {
    var u = a.pendingProps;
    switch (a.tag) {
      case 2:
      case 16:
      case 15:
      case 0:
      case 11:
      case 7:
      case 8:
      case 12:
      case 9:
      case 14:
        return null;
      case 1:
        return hn(a.type) && Nr(), null;
      case 3:
        return Ol(), Ye(vn), Ye(Dt), Ba(), u = a.stateNode, u.pendingContext && (u.context = u.pendingContext, u.pendingContext = null), (n === null || n.child === null) && (Io(a) ? a.flags |= 4 : u.hydrate || (a.flags |= 256)), Pl(a), null;
      case 5:
        Qc(a);
        var f = Mi(Ho.current);
        if (l = a.type, n !== null && a.stateNode != null) yp(n, a, l, u, f), n.ref !== a.ref && (a.flags |= 128);
        else {
          if (!u) {
            if (a.stateNode === null) throw Error(h(166));
            return null;
          }
          if (n = Mi(Ar.current), Io(a)) {
            u = a.stateNode, l = a.type;
            var m = a.memoizedProps;
            switch (u[Or] = a, u[is] = m, l) {
              case "dialog":
                xt("cancel", u), xt("close", u);
                break;
              case "iframe":
              case "object":
              case "embed":
                xt("load", u);
                break;
              case "video":
              case "audio":
                for (n = 0; n < Cl.length; n++) xt(Cl[n], u);
                break;
              case "source":
                xt("error", u);
                break;
              case "img":
              case "image":
              case "link":
                xt("error", u), xt("load", u);
                break;
              case "details":
                xt("toggle", u);
                break;
              case "input":
                io(u, m), xt("invalid", u);
                break;
              case "select":
                u._wrapperState = { wasMultiple: !!m.multiple }, xt("invalid", u);
                break;
              case "textarea":
                Ou(u, m), xt("invalid", u);
            }
            pi(l, m), n = null;
            for (var S in m) m.hasOwnProperty(S) && (f = m[S], S === "children" ? typeof f == "string" ? u.textContent !== f && (n = ["children", f]) : typeof f == "number" && u.textContent !== "" + f && (n = ["children", "" + f]) : C.hasOwnProperty(S) && f != null && S === "onScroll" && xt("scroll", u));
            switch (l) {
              case "input":
                tt(u), oo(u, m, !0);
                break;
              case "textarea":
                tt(u), rl(u);
                break;
              case "select":
              case "option":
                break;
              default:
                typeof m.onClick == "function" && (u.onclick = ns);
            }
            u = n, a.updateQueue = u, u !== null && (a.flags |= 4);
          } else {
            switch (S = f.nodeType === 9 ? f : f.ownerDocument, n === de.html && (n = De(l)), n === de.html ? l === "script" ? (n = S.createElement("div"), n.innerHTML = "<script><\/script>", n = n.removeChild(n.firstChild)) : typeof u.is == "string" ? n = S.createElement(l, { is: u.is }) : (n = S.createElement(l), l === "select" && (S = n, u.multiple ? S.multiple = !0 : u.size && (S.size = u.size))) : n = S.createElementNS(n, l), n[Or] = a, n[is] = u, ys(n, a, !1, !1), a.stateNode = n, S = al(l, u), l) {
              case "dialog":
                xt("cancel", n), xt("close", n), f = u;
                break;
              case "iframe":
              case "object":
              case "embed":
                xt("load", n), f = u;
                break;
              case "video":
              case "audio":
                for (f = 0; f < Cl.length; f++) xt(Cl[f], n);
                f = u;
                break;
              case "source":
                xt("error", n), f = u;
                break;
              case "img":
              case "image":
              case "link":
                xt("error", n), xt("load", n), f = u;
                break;
              case "details":
                xt("toggle", n), f = u;
                break;
              case "input":
                io(n, u), f = Ca(n, u), xt("invalid", n);
                break;
              case "option":
                f = di(n, u);
                break;
              case "select":
                n._wrapperState = { wasMultiple: !!u.multiple }, f = p({}, u, { value: void 0 }), xt("invalid", n);
                break;
              case "textarea":
                Ou(n, u), f = Wt(n, u), xt("invalid", n);
                break;
              default:
                f = u;
            }
            pi(l, f);
            var T = f;
            for (m in T) if (T.hasOwnProperty(m)) {
              var w = T[m];
              m === "style" ? Gr(n, w) : m === "dangerouslySetInnerHTML" ? (w = w ? w.__html : void 0, w != null && Jt(n, w)) : m === "children" ? typeof w == "string" ? (l !== "textarea" || w !== "") && Ft(n, w) : typeof w == "number" && Ft(n, "" + w) : m !== "suppressContentEditableWarning" && m !== "suppressHydrationWarning" && m !== "autoFocus" && (C.hasOwnProperty(m) ? w != null && m === "onScroll" && xt("scroll", n) : w != null && ie(n, m, w, S));
            }
            switch (l) {
              case "input":
                tt(n), oo(n, u, !1);
                break;
              case "textarea":
                tt(n), rl(n);
                break;
              case "option":
                u.value != null && n.setAttribute("value", "" + ne(u.value));
                break;
              case "select":
                n.multiple = !!u.multiple, m = u.value, m != null ? jt(n, !!u.multiple, m, !1) : u.defaultValue != null && jt(n, !!u.multiple, u.defaultValue, !0);
                break;
              default:
                typeof f.onClick == "function" && (n.onclick = ns);
            }
            Tl(l, u) && (a.flags |= 4);
          }
          a.ref !== null && (a.flags |= 128);
        }
        return null;
      case 6:
        if (n && a.stateNode != null) of(n, a, n.memoizedProps, u);
        else {
          if (typeof u != "string" && a.stateNode === null) throw Error(h(166));
          l = Mi(Ho.current), Mi(Ar.current), Io(a) ? (u = a.stateNode, l = a.memoizedProps, u[Or] = a, u.nodeValue !== l && (a.flags |= 4)) : (u = (l.nodeType === 9 ? l : l.ownerDocument).createTextNode(u), u[Or] = a, a.stateNode = u);
        }
        return null;
      case 13:
        return Ye(Bt), u = a.memoizedState, a.flags & 64 ? (a.lanes = l, a) : (u = u !== null, l = !1, n === null ? a.memoizedProps.fallback !== void 0 && Io(a) : l = n.memoizedState !== null, u && !l && a.mode & 2 && (n === null && a.memoizedProps.unstable_avoidThisFallback !== !0 || Bt.current & 1 ? cn === 0 && (cn = 3) : ((cn === 0 || cn === 3) && (cn = 4), Mn === null || !(zi & 134217727) && !(Fr & 134217727) || $l(Mn, gn))), (u || l) && (a.flags |= 4), null);
      case 4:
        return Ol(), Pl(a), n === null && Mc(a.stateNode.containerInfo), null;
      case 10:
        return cs(a), null;
      case 17:
        return hn(a.type) && Nr(), null;
      case 19:
        if (Ye(Bt), u = a.memoizedState, u === null) return null;
        if (m = (a.flags & 64) !== 0, S = u.rendering, S === null) if (m) Qo(u, !1);
        else {
          if (cn !== 0 || n !== null && n.flags & 64) for (n = a.child; n !== null; ) {
            if (S = Bo(n), S !== null) {
              for (a.flags |= 64, Qo(u, !1), m = S.updateQueue, m !== null && (a.updateQueue = m, a.flags |= 4), u.lastEffect === null && (a.firstEffect = null), a.lastEffect = u.lastEffect, u = l, l = a.child; l !== null; ) m = l, n = u, m.flags &= 2, m.nextEffect = null, m.firstEffect = null, m.lastEffect = null, S = m.alternate, S === null ? (m.childLanes = 0, m.lanes = n, m.child = null, m.memoizedProps = null, m.memoizedState = null, m.updateQueue = null, m.dependencies = null, m.stateNode = null) : (m.childLanes = S.childLanes, m.lanes = S.lanes, m.child = S.child, m.memoizedProps = S.memoizedProps, m.memoizedState = S.memoizedState, m.updateQueue = S.updateQueue, m.type = S.type, n = S.dependencies, m.dependencies = n === null ? null : { lanes: n.lanes, firstContext: n.firstContext }), l = l.sibling;
              return Ue(Bt, Bt.current & 1 | 2), a.child;
            }
            n = n.sibling;
          }
          u.tail !== null && mn() > ji && (a.flags |= 64, m = !0, Qo(u, !1), a.lanes = 33554432);
        }
        else {
          if (!m) if (n = Bo(S), n !== null) {
            if (a.flags |= 64, m = !0, l = n.updateQueue, l !== null && (a.updateQueue = l, a.flags |= 4), Qo(u, !0), u.tail === null && u.tailMode === "hidden" && !S.alternate && !zr) return a = a.lastEffect = u.lastEffect, a !== null && (a.nextEffect = null), null;
          } else 2 * mn() - u.renderingStartTime > ji && l !== 1073741824 && (a.flags |= 64, m = !0, Qo(u, !1), a.lanes = 33554432);
          u.isBackwards ? (S.sibling = a.child, a.child = S) : (l = u.last, l !== null ? l.sibling = S : a.child = S, u.last = S);
        }
        return u.tail !== null ? (l = u.tail, u.rendering = l, u.tail = l.sibling, u.lastEffect = a.lastEffect, u.renderingStartTime = mn(), l.sibling = null, a = Bt.current, Ue(Bt, m ? a & 1 | 2 : a & 1), l) : null;
      case 23:
      case 24:
        return Ef(), n !== null && n.memoizedState !== null != (a.memoizedState !== null) && u.mode !== "unstable-defer-without-hiding" && (a.flags |= 4), null;
    }
    throw Error(h(156, a.tag));
  }
  function gp(n) {
    switch (n.tag) {
      case 1:
        hn(n.type) && Nr();
        var a = n.flags;
        return a & 4096 ? (n.flags = a & -4097 | 64, n) : null;
      case 3:
        if (Ol(), Ye(vn), Ye(Dt), Ba(), a = n.flags, a & 64) throw Error(h(285));
        return n.flags = a & -4097 | 64, n;
      case 5:
        return Qc(n), null;
      case 13:
        return Ye(Bt), a = n.flags, a & 4096 ? (n.flags = a & -4097 | 64, n) : null;
      case 19:
        return Ye(Bt), null;
      case 4:
        return Ol(), null;
      case 10:
        return cs(n), null;
      case 23:
      case 24:
        return Ef(), null;
      default:
        return null;
    }
  }
  function uf(n, a) {
    try {
      var l = "", u = a;
      do
        l += Fe(u), u = u.return;
      while (u);
      var f = l;
    } catch (m) {
      f = `
Error generating stack: ` + m.message + `
` + m.stack;
    }
    return { value: n, source: a, stack: f };
  }
  function sf(n, a) {
    try {
      console.error(a.value);
    } catch (l) {
      setTimeout(function() {
        throw l;
      });
    }
  }
  var Ep = typeof WeakMap == "function" ? WeakMap : Map;
  function Sp(n, a, l) {
    l = mr(-1, l), l.tag = 3, l.payload = { element: null };
    var u = a.value;
    return l.callback = function() {
      eu || (eu = !0, vf = u), sf(n, a);
    }, l;
  }
  function Cp(n, a, l) {
    l = mr(-1, l), l.tag = 3;
    var u = n.type.getDerivedStateFromError;
    if (typeof u == "function") {
      var f = a.value;
      l.payload = function() {
        return sf(n, a), u(f);
      };
    }
    var m = n.stateNode;
    return m !== null && typeof m.componentDidCatch == "function" && (l.callback = function() {
      typeof u != "function" && (Hr === null ? Hr = /* @__PURE__ */ new Set([this]) : Hr.add(this), sf(n, a));
      var S = a.stack;
      this.componentDidCatch(a.value, { componentStack: S !== null ? S : "" });
    }), l;
  }
  var rm = typeof WeakSet == "function" ? WeakSet : Set;
  function bp(n) {
    var a = n.ref;
    if (a !== null) if (typeof a == "function") try {
      a(null);
    } catch (l) {
      Xa(n, l);
    }
    else a.current = null;
  }
  function am(n, a) {
    switch (a.tag) {
      case 0:
      case 11:
      case 15:
      case 22:
        return;
      case 1:
        if (a.flags & 256 && n !== null) {
          var l = n.memoizedProps, u = n.memoizedState;
          n = a.stateNode, a = n.getSnapshotBeforeUpdate(a.elementType === a.type ? l : an(a.type, l), u), n.__reactInternalSnapshotBeforeUpdate = a;
        }
        return;
      case 3:
        a.flags & 256 && rs(a.stateNode.containerInfo);
        return;
      case 5:
      case 6:
      case 4:
      case 17:
        return;
    }
    throw Error(h(163));
  }
  function cf(n, a, l) {
    switch (l.tag) {
      case 0:
      case 11:
      case 15:
      case 22:
        if (a = l.updateQueue, a = a !== null ? a.lastEffect : null, a !== null) {
          n = a = a.next;
          do {
            if ((n.tag & 3) === 3) {
              var u = n.create;
              n.destroy = u();
            }
            n = n.next;
          } while (n !== a);
        }
        if (a = l.updateQueue, a = a !== null ? a.lastEffect : null, a !== null) {
          n = a = a.next;
          do {
            var f = n;
            u = f.next, f = f.tag, f & 4 && f & 1 && (Cf(l, n), Ap(l, n)), n = u;
          } while (n !== a);
        }
        return;
      case 1:
        n = l.stateNode, l.flags & 4 && (a === null ? n.componentDidMount() : (u = l.elementType === l.type ? a.memoizedProps : an(l.type, a.memoizedProps), n.componentDidUpdate(
          u,
          a.memoizedState,
          n.__reactInternalSnapshotBeforeUpdate
        ))), a = l.updateQueue, a !== null && Wc(l, a, n);
        return;
      case 3:
        if (a = l.updateQueue, a !== null) {
          if (n = null, l.child !== null) switch (l.child.tag) {
            case 5:
              n = l.child.stateNode;
              break;
            case 1:
              n = l.child.stateNode;
          }
          Wc(l, a, n);
        }
        return;
      case 5:
        n = l.stateNode, a === null && l.flags & 4 && Tl(l.type, l.memoizedProps) && n.focus();
        return;
      case 6:
        return;
      case 4:
        return;
      case 12:
        return;
      case 13:
        l.memoizedState === null && (l = l.alternate, l !== null && (l = l.memoizedState, l !== null && (l = l.dehydrated, l !== null && Cd(l))));
        return;
      case 19:
      case 17:
      case 20:
      case 21:
      case 23:
      case 24:
        return;
    }
    throw Error(h(163));
  }
  function ff(n, a) {
    for (var l = n; ; ) {
      if (l.tag === 5) {
        var u = l.stateNode;
        if (a) u = u.style, typeof u.setProperty == "function" ? u.setProperty("display", "none", "important") : u.display = "none";
        else {
          u = l.stateNode;
          var f = l.memoizedProps.style;
          f = f != null && f.hasOwnProperty("display") ? f.display : null, u.style.display = Ut("display", f);
        }
      } else if (l.tag === 6) l.stateNode.nodeValue = a ? "" : l.memoizedProps;
      else if ((l.tag !== 23 && l.tag !== 24 || l.memoizedState === null || l === n) && l.child !== null) {
        l.child.return = l, l = l.child;
        continue;
      }
      if (l === n) break;
      for (; l.sibling === null; ) {
        if (l.return === null || l.return === n) return;
        l = l.return;
      }
      l.sibling.return = l.return, l = l.sibling;
    }
  }
  function Tp(n, a) {
    if (xi && typeof xi.onCommitFiberUnmount == "function") try {
      xi.onCommitFiberUnmount(zc, a);
    } catch {
    }
    switch (a.tag) {
      case 0:
      case 11:
      case 14:
      case 15:
      case 22:
        if (n = a.updateQueue, n !== null && (n = n.lastEffect, n !== null)) {
          var l = n = n.next;
          do {
            var u = l, f = u.destroy;
            if (u = u.tag, f !== void 0) if (u & 4) Cf(a, l);
            else {
              u = a;
              try {
                f();
              } catch (m) {
                Xa(u, m);
              }
            }
            l = l.next;
          } while (l !== n);
        }
        break;
      case 1:
        if (bp(a), n = a.stateNode, typeof n.componentWillUnmount == "function") try {
          n.props = a.memoizedProps, n.state = a.memoizedState, n.componentWillUnmount();
        } catch (m) {
          Xa(
            a,
            m
          );
        }
        break;
      case 5:
        bp(a);
        break;
      case 4:
        kp(n, a);
    }
  }
  function Rp(n) {
    n.alternate = null, n.child = null, n.dependencies = null, n.firstEffect = null, n.lastEffect = null, n.memoizedProps = null, n.memoizedState = null, n.pendingProps = null, n.return = null, n.updateQueue = null;
  }
  function xp(n) {
    return n.tag === 5 || n.tag === 3 || n.tag === 4;
  }
  function wp(n) {
    e: {
      for (var a = n.return; a !== null; ) {
        if (xp(a)) break e;
        a = a.return;
      }
      throw Error(h(160));
    }
    var l = a;
    switch (a = l.stateNode, l.tag) {
      case 5:
        var u = !1;
        break;
      case 3:
        a = a.containerInfo, u = !0;
        break;
      case 4:
        a = a.containerInfo, u = !0;
        break;
      default:
        throw Error(h(161));
    }
    l.flags & 16 && (Ft(a, ""), l.flags &= -17);
    e: t: for (l = n; ; ) {
      for (; l.sibling === null; ) {
        if (l.return === null || xp(l.return)) {
          l = null;
          break e;
        }
        l = l.return;
      }
      for (l.sibling.return = l.return, l = l.sibling; l.tag !== 5 && l.tag !== 6 && l.tag !== 18; ) {
        if (l.flags & 2 || l.child === null || l.tag === 4) continue t;
        l.child.return = l, l = l.child;
      }
      if (!(l.flags & 2)) {
        l = l.stateNode;
        break e;
      }
    }
    u ? Go(n, l, a) : Xo(n, l, a);
  }
  function Go(n, a, l) {
    var u = n.tag, f = u === 5 || u === 6;
    if (f) n = f ? n.stateNode : n.stateNode.instance, a ? l.nodeType === 8 ? l.parentNode.insertBefore(n, a) : l.insertBefore(n, a) : (l.nodeType === 8 ? (a = l.parentNode, a.insertBefore(n, l)) : (a = l, a.appendChild(n)), l = l._reactRootContainer, l != null || a.onclick !== null || (a.onclick = ns));
    else if (u !== 4 && (n = n.child, n !== null)) for (Go(n, a, l), n = n.sibling; n !== null; ) Go(n, a, l), n = n.sibling;
  }
  function Xo(n, a, l) {
    var u = n.tag, f = u === 5 || u === 6;
    if (f) n = f ? n.stateNode : n.stateNode.instance, a ? l.insertBefore(n, a) : l.appendChild(n);
    else if (u !== 4 && (n = n.child, n !== null)) for (Xo(n, a, l), n = n.sibling; n !== null; ) Xo(n, a, l), n = n.sibling;
  }
  function kp(n, a) {
    for (var l = a, u = !1, f, m; ; ) {
      if (!u) {
        u = l.return;
        e: for (; ; ) {
          if (u === null) throw Error(h(160));
          switch (f = u.stateNode, u.tag) {
            case 5:
              m = !1;
              break e;
            case 3:
              f = f.containerInfo, m = !0;
              break e;
            case 4:
              f = f.containerInfo, m = !0;
              break e;
          }
          u = u.return;
        }
        u = !0;
      }
      if (l.tag === 5 || l.tag === 6) {
        e: for (var S = n, T = l, w = T; ; ) if (Tp(S, w), w.child !== null && w.tag !== 4) w.child.return = w, w = w.child;
        else {
          if (w === T) break e;
          for (; w.sibling === null; ) {
            if (w.return === null || w.return === T) break e;
            w = w.return;
          }
          w.sibling.return = w.return, w = w.sibling;
        }
        m ? (S = f, T = l.stateNode, S.nodeType === 8 ? S.parentNode.removeChild(T) : S.removeChild(T)) : f.removeChild(l.stateNode);
      } else if (l.tag === 4) {
        if (l.child !== null) {
          f = l.stateNode.containerInfo, m = !0, l.child.return = l, l = l.child;
          continue;
        }
      } else if (Tp(n, l), l.child !== null) {
        l.child.return = l, l = l.child;
        continue;
      }
      if (l === a) break;
      for (; l.sibling === null; ) {
        if (l.return === null || l.return === a) return;
        l = l.return, l.tag === 4 && (u = !1);
      }
      l.sibling.return = l.return, l = l.sibling;
    }
  }
  function df(n, a) {
    switch (a.tag) {
      case 0:
      case 11:
      case 14:
      case 15:
      case 22:
        var l = a.updateQueue;
        if (l = l !== null ? l.lastEffect : null, l !== null) {
          var u = l = l.next;
          do
            (u.tag & 3) === 3 && (n = u.destroy, u.destroy = void 0, n !== void 0 && n()), u = u.next;
          while (u !== l);
        }
        return;
      case 1:
        return;
      case 5:
        if (l = a.stateNode, l != null) {
          u = a.memoizedProps;
          var f = n !== null ? n.memoizedProps : u;
          n = a.type;
          var m = a.updateQueue;
          if (a.updateQueue = null, m !== null) {
            for (l[is] = u, n === "input" && u.type === "radio" && u.name != null && lo(l, u), al(n, f), a = al(n, u), f = 0; f < m.length; f += 2) {
              var S = m[f], T = m[f + 1];
              S === "style" ? Gr(l, T) : S === "dangerouslySetInnerHTML" ? Jt(l, T) : S === "children" ? Ft(l, T) : ie(l, S, T, a);
            }
            switch (n) {
              case "input":
                tl(l, u);
                break;
              case "textarea":
                nl(l, u);
                break;
              case "select":
                n = l._wrapperState.wasMultiple, l._wrapperState.wasMultiple = !!u.multiple, m = u.value, m != null ? jt(l, !!u.multiple, m, !1) : n !== !!u.multiple && (u.defaultValue != null ? jt(l, !!u.multiple, u.defaultValue, !0) : jt(l, !!u.multiple, u.multiple ? [] : "", !1));
            }
          }
        }
        return;
      case 6:
        if (a.stateNode === null) throw Error(h(162));
        a.stateNode.nodeValue = a.memoizedProps;
        return;
      case 3:
        l = a.stateNode, l.hydrate && (l.hydrate = !1, Cd(l.containerInfo));
        return;
      case 12:
        return;
      case 13:
        a.memoizedState !== null && (Jo = mn(), ff(a.child, !0)), _p(a);
        return;
      case 19:
        _p(a);
        return;
      case 17:
        return;
      case 23:
      case 24:
        ff(a, a.memoizedState !== null);
        return;
    }
    throw Error(h(163));
  }
  function _p(n) {
    var a = n.updateQueue;
    if (a !== null) {
      n.updateQueue = null;
      var l = n.stateNode;
      l === null && (l = n.stateNode = new rm()), a.forEach(function(u) {
        var f = cm.bind(null, n, u);
        l.has(u) || (l.add(u), u.then(f, f));
      });
    }
  }
  function im(n, a) {
    return n !== null && (n = n.memoizedState, n === null || n.dehydrated !== null) ? (a = a.memoizedState, a !== null && a.dehydrated === null) : !1;
  }
  var Ko = Math.ceil, Bl = z.ReactCurrentDispatcher, Ui = z.ReactCurrentOwner, Ve = 0, Mn = null, Qt = null, gn = 0, jr = 0, Vl = On(0), cn = 0, Cn = null, gr = 0, zi = 0, Fr = 0, pf = 0, Zo = null, Jo = 0, ji = 1 / 0;
  function Il() {
    ji = mn() + 500;
  }
  var ye = null, eu = !1, vf = null, Hr = null, Ya = !1, Fi = null, tu = 90, hf = [], mf = [], ca = null, nu = 0, gs = null, Es = -1, fa = 0, Ss = 0, ru = null, Cs = !1;
  function Wn() {
    return Ve & 48 ? mn() : Es !== -1 ? Es : Es = mn();
  }
  function Pr(n) {
    if (n = n.mode, !(n & 2)) return 1;
    if (!(n & 4)) return kl() === 99 ? 1 : 2;
    if (fa === 0 && (fa = gr), ja.transition !== 0) {
      Ss !== 0 && (Ss = Zo !== null ? Zo.pendingLanes : 0), n = fa;
      var a = 4186112 & ~Ss;
      return a &= -a, a === 0 && (n = 4186112 & ~n, a = n & -n, a === 0 && (a = 8192)), a;
    }
    return n = kl(), Ve & 4 && n === 98 ? n = Vu(12, fa) : (n = wd(n), n = Vu(n, fa)), n;
  }
  function qa(n, a, l) {
    if (50 < nu) throw nu = 0, gs = null, Error(h(185));
    if (n = bs(n, a), n === null) return null;
    Eo(n, a, l), n === Mn && (Fr |= a, cn === 4 && $l(n, gn));
    var u = kl();
    a === 1 ? Ve & 8 && !(Ve & 48) ? gf(n) : (ir(n, l), Ve === 0 && (Il(), rn())) : (!(Ve & 4) || u !== 98 && u !== 99 || (ca === null ? ca = /* @__PURE__ */ new Set([n]) : ca.add(n)), ir(n, l)), Zo = n;
  }
  function bs(n, a) {
    n.lanes |= a;
    var l = n.alternate;
    for (l !== null && (l.lanes |= a), l = n, n = n.return; n !== null; ) n.childLanes |= a, l = n.alternate, l !== null && (l.childLanes |= a), l = n, n = n.return;
    return l.tag === 3 ? l.stateNode : null;
  }
  function ir(n, a) {
    for (var l = n.callbackNode, u = n.suspendedLanes, f = n.pingedLanes, m = n.expirationTimes, S = n.pendingLanes; 0 < S; ) {
      var T = 31 - ka(S), w = 1 << T, P = m[T];
      if (P === -1) {
        if (!(w & u) || w & f) {
          P = a, yi(w);
          var he = gt;
          m[T] = 10 <= he ? P + 250 : 6 <= he ? P + 5e3 : -1;
        }
      } else P <= a && (n.expiredLanes |= w);
      S &= ~w;
    }
    if (u = pl(n, n === Mn ? gn : 0), a = gt, u === 0) l !== null && (l !== Pc && Mo(l), n.callbackNode = null, n.callbackPriority = 0);
    else {
      if (l !== null) {
        if (n.callbackPriority === a) return;
        l !== Pc && Mo(l);
      }
      a === 15 ? (l = gf.bind(null, n), Mr === null ? (Mr = [l], us = hr(os, na)) : Mr.push(l), l = Pc) : a === 14 ? l = ki(99, gf.bind(null, n)) : (l = pc(a), l = ki(l, yf.bind(null, n))), n.callbackPriority = a, n.callbackNode = l;
    }
  }
  function yf(n) {
    if (Es = -1, Ss = fa = 0, Ve & 48) throw Error(h(327));
    var a = n.callbackNode;
    if (Ga() && n.callbackNode !== a) return null;
    var l = pl(n, n === Mn ? gn : 0);
    if (l === 0) return null;
    var u = l, f = Ve;
    Ve |= 16;
    var m = Wl();
    (Mn !== n || gn !== u) && (Il(), Hi(n, u));
    do
      try {
        Mp();
        break;
      } catch (T) {
        Rs(n, T);
      }
    while (!0);
    if (Vc(), Bl.current = m, Ve = f, Qt !== null ? u = 0 : (Mn = null, gn = 0, u = cn), gr & Fr) Hi(n, 0);
    else if (u !== 0) {
      if (u === 2 && (Ve |= 64, n.hydrate && (n.hydrate = !1, rs(n.containerInfo)), l = kd(n), l !== 0 && (u = au(n, l))), u === 1) throw a = Cn, Hi(n, 0), $l(n, l), ir(n, mn()), a;
      switch (n.finishedWork = n.current.alternate, n.finishedLanes = l, u) {
        case 0:
        case 1:
          throw Error(h(345));
        case 2:
          Qa(n);
          break;
        case 3:
          if ($l(n, l), (l & 62914560) === l && (u = Jo + 500 - mn(), 10 < u)) {
            if (pl(n, 0) !== 0) break;
            if (f = n.suspendedLanes, (f & l) !== l) {
              Wn(), n.pingedLanes |= n.suspendedLanes & f;
              break;
            }
            n.timeoutHandle = Rl(Qa.bind(null, n), u);
            break;
          }
          Qa(n);
          break;
        case 4:
          if ($l(n, l), (l & 4186112) === l) break;
          for (u = n.eventTimes, f = -1; 0 < l; ) {
            var S = 31 - ka(l);
            m = 1 << S, S = u[S], S > f && (f = S), l &= ~m;
          }
          if (l = f, l = mn() - l, l = (120 > l ? 120 : 480 > l ? 480 : 1080 > l ? 1080 : 1920 > l ? 1920 : 3e3 > l ? 3e3 : 4320 > l ? 4320 : 1960 * Ko(l / 1960)) - l, 10 < l) {
            n.timeoutHandle = Rl(Qa.bind(null, n), l);
            break;
          }
          Qa(n);
          break;
        case 5:
          Qa(n);
          break;
        default:
          throw Error(h(329));
      }
    }
    return ir(n, mn()), n.callbackNode === a ? yf.bind(null, n) : null;
  }
  function $l(n, a) {
    for (a &= ~pf, a &= ~Fr, n.suspendedLanes |= a, n.pingedLanes &= ~a, n = n.expirationTimes; 0 < a; ) {
      var l = 31 - ka(a), u = 1 << l;
      n[l] = -1, a &= ~u;
    }
  }
  function gf(n) {
    if (Ve & 48) throw Error(h(327));
    if (Ga(), n === Mn && n.expiredLanes & gn) {
      var a = gn, l = au(n, a);
      gr & Fr && (a = pl(n, a), l = au(n, a));
    } else a = pl(n, 0), l = au(n, a);
    if (n.tag !== 0 && l === 2 && (Ve |= 64, n.hydrate && (n.hydrate = !1, rs(n.containerInfo)), a = kd(n), a !== 0 && (l = au(n, a))), l === 1) throw l = Cn, Hi(n, 0), $l(n, a), ir(n, mn()), l;
    return n.finishedWork = n.current.alternate, n.finishedLanes = a, Qa(n), ir(n, mn()), null;
  }
  function lm() {
    if (ca !== null) {
      var n = ca;
      ca = null, n.forEach(function(a) {
        a.expiredLanes |= 24 & a.pendingLanes, ir(a, mn());
      });
    }
    rn();
  }
  function Dp(n, a) {
    var l = Ve;
    Ve |= 1;
    try {
      return n(a);
    } finally {
      Ve = l, Ve === 0 && (Il(), rn());
    }
  }
  function Op(n, a) {
    var l = Ve;
    Ve &= -2, Ve |= 8;
    try {
      return n(a);
    } finally {
      Ve = l, Ve === 0 && (Il(), rn());
    }
  }
  function Ts(n, a) {
    Ue(Vl, jr), jr |= a, gr |= a;
  }
  function Ef() {
    jr = Vl.current, Ye(Vl);
  }
  function Hi(n, a) {
    n.finishedWork = null, n.finishedLanes = 0;
    var l = n.timeoutHandle;
    if (l !== -1 && (n.timeoutHandle = -1, Jd(l)), Qt !== null) for (l = Qt.return; l !== null; ) {
      var u = l;
      switch (u.tag) {
        case 1:
          u = u.type.childContextTypes, u != null && Nr();
          break;
        case 3:
          Ol(), Ye(vn), Ye(Dt), Ba();
          break;
        case 5:
          Qc(u);
          break;
        case 4:
          Ol();
          break;
        case 13:
          Ye(Bt);
          break;
        case 19:
          Ye(Bt);
          break;
        case 10:
          cs(u);
          break;
        case 23:
        case 24:
          Ef();
      }
      l = l.return;
    }
    Mn = n, Qt = Ka(n.current, null), gn = jr = gr = a, cn = 0, Cn = null, pf = Fr = zi = 0;
  }
  function Rs(n, a) {
    do {
      var l = Qt;
      try {
        if (Vc(), Ml.current = ms, $o) {
          for (var u = Ot.memoizedState; u !== null; ) {
            var f = u.queue;
            f !== null && (f.pending = null), u = u.next;
          }
          $o = !1;
        }
        if (Ll = 0, un = on = Ot = null, Va = !1, Ui.current = null, l === null || l.return === null) {
          cn = 1, Cn = a, Qt = null;
          break;
        }
        e: {
          var m = n, S = l.return, T = l, w = a;
          if (a = gn, T.flags |= 2048, T.firstEffect = T.lastEffect = null, w !== null && typeof w == "object" && typeof w.then == "function") {
            var P = w;
            if (!(T.mode & 2)) {
              var he = T.alternate;
              he ? (T.updateQueue = he.updateQueue, T.memoizedState = he.memoizedState, T.lanes = he.lanes) : (T.updateQueue = null, T.memoizedState = null);
            }
            var Ie = (Bt.current & 1) !== 0, K = S;
            do {
              var ke;
              if (ke = K.tag === 13) {
                var He = K.memoizedState;
                if (He !== null) ke = He.dehydrated !== null;
                else {
                  var Le = K.memoizedProps;
                  ke = Le.fallback === void 0 ? !1 : Le.unstable_avoidThisFallback !== !0 ? !0 : !Ie;
                }
              }
              if (ke) {
                var M = K.updateQueue;
                if (M === null) {
                  var _ = /* @__PURE__ */ new Set();
                  _.add(P), K.updateQueue = _;
                } else M.add(P);
                if (!(K.mode & 2)) {
                  if (K.flags |= 64, T.flags |= 16384, T.flags &= -2981, T.tag === 1) if (T.alternate === null) T.tag = 17;
                  else {
                    var O = mr(-1, 1);
                    O.tag = 2, ra(T, O);
                  }
                  T.lanes |= 1;
                  break e;
                }
                w = void 0, T = a;
                var $ = m.pingCache;
                if ($ === null ? ($ = m.pingCache = new Ep(), w = /* @__PURE__ */ new Set(), $.set(P, w)) : (w = $.get(P), w === void 0 && (w = /* @__PURE__ */ new Set(), $.set(P, w))), !w.has(T)) {
                  w.add(T);
                  var q = sm.bind(null, m, P, T);
                  P.then(q, q);
                }
                K.flags |= 4096, K.lanes = a;
                break e;
              }
              K = K.return;
            } while (K !== null);
            w = Error((Ze(T.type) || "A React component") + ` suspended while rendering, but no fallback UI was specified.

Add a <Suspense fallback=...> component higher in the tree to provide a loading indicator or placeholder to display.`);
          }
          cn !== 5 && (cn = 2), w = uf(w, T), K = S;
          do {
            switch (K.tag) {
              case 3:
                m = w, K.flags |= 4096, a &= -a, K.lanes |= a;
                var qe = Sp(K, m, a);
                sp(K, qe);
                break e;
              case 1:
                m = w;
                var ge = K.type, $e = K.stateNode;
                if (!(K.flags & 64) && (typeof ge.getDerivedStateFromError == "function" || $e !== null && typeof $e.componentDidCatch == "function" && (Hr === null || !Hr.has($e)))) {
                  K.flags |= 4096, a &= -a, K.lanes |= a;
                  var Ge = Cp(K, m, a);
                  sp(K, Ge);
                  break e;
                }
            }
            K = K.return;
          } while (K !== null);
        }
        Lp(l);
      } catch (Qe) {
        a = Qe, Qt === l && l !== null && (Qt = l = l.return);
        continue;
      }
      break;
    } while (!0);
  }
  function Wl() {
    var n = Bl.current;
    return Bl.current = ms, n === null ? ms : n;
  }
  function au(n, a) {
    var l = Ve;
    Ve |= 16;
    var u = Wl();
    Mn === n && gn === a || Hi(n, a);
    do
      try {
        Np();
        break;
      } catch (f) {
        Rs(n, f);
      }
    while (!0);
    if (Vc(), Ve = l, Bl.current = u, Qt !== null) throw Error(h(261));
    return Mn = null, gn = 0, cn;
  }
  function Np() {
    for (; Qt !== null; ) Sf(Qt);
  }
  function Mp() {
    for (; Qt !== null && !Xh(); ) Sf(Qt);
  }
  function Sf(n) {
    var a = zp(n.alternate, n, jr);
    n.memoizedProps = n.pendingProps, a === null ? Lp(n) : Qt = a, Ui.current = null;
  }
  function Lp(n) {
    var a = n;
    do {
      var l = a.alternate;
      if (n = a.return, a.flags & 2048) {
        if (l = gp(a), l !== null) {
          l.flags &= 2047, Qt = l;
          return;
        }
        n !== null && (n.firstEffect = n.lastEffect = null, n.flags |= 2048);
      } else {
        if (l = nm(l, a, jr), l !== null) {
          Qt = l;
          return;
        }
        if (l = a, l.tag !== 24 && l.tag !== 23 || l.memoizedState === null || jr & 1073741824 || !(l.mode & 4)) {
          for (var u = 0, f = l.child; f !== null; ) u |= f.lanes | f.childLanes, f = f.sibling;
          l.childLanes = u;
        }
        n !== null && !(n.flags & 2048) && (n.firstEffect === null && (n.firstEffect = a.firstEffect), a.lastEffect !== null && (n.lastEffect !== null && (n.lastEffect.nextEffect = a.firstEffect), n.lastEffect = a.lastEffect), 1 < a.flags && (n.lastEffect !== null ? n.lastEffect.nextEffect = a : n.firstEffect = a, n.lastEffect = a));
      }
      if (a = a.sibling, a !== null) {
        Qt = a;
        return;
      }
      Qt = a = n;
    } while (a !== null);
    cn === 0 && (cn = 5);
  }
  function Qa(n) {
    var a = kl();
    return wi(99, om.bind(null, n, a)), null;
  }
  function om(n, a) {
    do
      Ga();
    while (Fi !== null);
    if (Ve & 48) throw Error(h(327));
    var l = n.finishedWork;
    if (l === null) return null;
    if (n.finishedWork = null, n.finishedLanes = 0, l === n.current) throw Error(h(177));
    n.callbackNode = null;
    var u = l.lanes | l.childLanes, f = u, m = n.pendingLanes & ~f;
    n.pendingLanes = f, n.suspendedLanes = 0, n.pingedLanes = 0, n.expiredLanes &= f, n.mutableReadLanes &= f, n.entangledLanes &= f, f = n.entanglements;
    for (var S = n.eventTimes, T = n.expirationTimes; 0 < m; ) {
      var w = 31 - ka(m), P = 1 << w;
      f[w] = 0, S[w] = -1, T[w] = -1, m &= ~P;
    }
    if (ca !== null && !(u & 24) && ca.has(n) && ca.delete(n), n === Mn && (Qt = Mn = null, gn = 0), 1 < l.flags ? l.lastEffect !== null ? (l.lastEffect.nextEffect = l, u = l.firstEffect) : u = l : u = l.firstEffect, u !== null) {
      if (f = Ve, Ve |= 32, Ui.current = null, Lc = So, S = Xu(), Si(S)) {
        if ("selectionStart" in S) T = { start: S.selectionStart, end: S.selectionEnd };
        else e: if (T = (T = S.ownerDocument) && T.defaultView || window, (P = T.getSelection && T.getSelection()) && P.rangeCount !== 0) {
          T = P.anchorNode, m = P.anchorOffset, w = P.focusNode, P = P.focusOffset;
          try {
            T.nodeType, w.nodeType;
          } catch {
            T = null;
            break e;
          }
          var he = 0, Ie = -1, K = -1, ke = 0, He = 0, Le = S, M = null;
          t: for (; ; ) {
            for (var _; Le !== T || m !== 0 && Le.nodeType !== 3 || (Ie = he + m), Le !== w || P !== 0 && Le.nodeType !== 3 || (K = he + P), Le.nodeType === 3 && (he += Le.nodeValue.length), (_ = Le.firstChild) !== null; )
              M = Le, Le = _;
            for (; ; ) {
              if (Le === S) break t;
              if (M === T && ++ke === m && (Ie = he), M === w && ++He === P && (K = he), (_ = Le.nextSibling) !== null) break;
              Le = M, M = Le.parentNode;
            }
            Le = _;
          }
          T = Ie === -1 || K === -1 ? null : { start: Ie, end: K };
        } else T = null;
        T = T || { start: 0, end: 0 };
      } else T = null;
      Ac = { focusedElem: S, selectionRange: T }, So = !1, ru = null, Cs = !1, ye = u;
      do
        try {
          um();
        } catch (Qe) {
          if (ye === null) throw Error(h(330));
          Xa(ye, Qe), ye = ye.nextEffect;
        }
      while (ye !== null);
      ru = null, ye = u;
      do
        try {
          for (S = n; ye !== null; ) {
            var O = ye.flags;
            if (O & 16 && Ft(ye.stateNode, ""), O & 128) {
              var $ = ye.alternate;
              if ($ !== null) {
                var q = $.ref;
                q !== null && (typeof q == "function" ? q(null) : q.current = null);
              }
            }
            switch (O & 1038) {
              case 2:
                wp(ye), ye.flags &= -3;
                break;
              case 6:
                wp(ye), ye.flags &= -3, df(ye.alternate, ye);
                break;
              case 1024:
                ye.flags &= -1025;
                break;
              case 1028:
                ye.flags &= -1025, df(ye.alternate, ye);
                break;
              case 4:
                df(ye.alternate, ye);
                break;
              case 8:
                T = ye, kp(S, T);
                var qe = T.alternate;
                Rp(T), qe !== null && Rp(qe);
            }
            ye = ye.nextEffect;
          }
        } catch (Qe) {
          if (ye === null) throw Error(h(330));
          Xa(ye, Qe), ye = ye.nextEffect;
        }
      while (ye !== null);
      if (q = Ac, $ = Xu(), O = q.focusedElem, S = q.selectionRange, $ !== O && O && O.ownerDocument && _c(O.ownerDocument.documentElement, O)) {
        for (S !== null && Si(O) && ($ = S.start, q = S.end, q === void 0 && (q = $), "selectionStart" in O ? (O.selectionStart = $, O.selectionEnd = Math.min(q, O.value.length)) : (q = ($ = O.ownerDocument || document) && $.defaultView || window, q.getSelection && (q = q.getSelection(), T = O.textContent.length, qe = Math.min(S.start, T), S = S.end === void 0 ? qe : Math.min(S.end, T), !q.extend && qe > S && (T = S, S = qe, qe = T), T = Xd(O, qe), m = Xd(O, S), T && m && (q.rangeCount !== 1 || q.anchorNode !== T.node || q.anchorOffset !== T.offset || q.focusNode !== m.node || q.focusOffset !== m.offset) && ($ = $.createRange(), $.setStart(T.node, T.offset), q.removeAllRanges(), qe > S ? (q.addRange($), q.extend(m.node, m.offset)) : ($.setEnd(m.node, m.offset), q.addRange($)))))), $ = [], q = O; q = q.parentNode; ) q.nodeType === 1 && $.push({ element: q, left: q.scrollLeft, top: q.scrollTop });
        for (typeof O.focus == "function" && O.focus(), O = 0; O < $.length; O++) q = $[O], q.element.scrollLeft = q.left, q.element.scrollTop = q.top;
      }
      So = !!Lc, Ac = Lc = null, n.current = l, ye = u;
      do
        try {
          for (O = n; ye !== null; ) {
            var ge = ye.flags;
            if (ge & 36 && cf(O, ye.alternate, ye), ge & 128) {
              $ = void 0;
              var $e = ye.ref;
              if ($e !== null) {
                var Ge = ye.stateNode;
                switch (ye.tag) {
                  case 5:
                    $ = Ge;
                    break;
                  default:
                    $ = Ge;
                }
                typeof $e == "function" ? $e($) : $e.current = $;
              }
            }
            ye = ye.nextEffect;
          }
        } catch (Qe) {
          if (ye === null) throw Error(h(330));
          Xa(ye, Qe), ye = ye.nextEffect;
        }
      while (ye !== null);
      ye = null, lp(), Ve = f;
    } else n.current = l;
    if (Ya) Ya = !1, Fi = n, tu = a;
    else for (ye = u; ye !== null; ) a = ye.nextEffect, ye.nextEffect = null, ye.flags & 8 && (ge = ye, ge.sibling = null, ge.stateNode = null), ye = a;
    if (u = n.pendingLanes, u === 0 && (Hr = null), u === 1 ? n === gs ? nu++ : (nu = 0, gs = n) : nu = 0, l = l.stateNode, xi && typeof xi.onCommitFiberRoot == "function") try {
      xi.onCommitFiberRoot(zc, l, void 0, (l.current.flags & 64) === 64);
    } catch {
    }
    if (ir(n, mn()), eu) throw eu = !1, n = vf, vf = null, n;
    return Ve & 8 || rn(), null;
  }
  function um() {
    for (; ye !== null; ) {
      var n = ye.alternate;
      Cs || ru === null || (ye.flags & 8 ? vo(ye, ru) && (Cs = !0) : ye.tag === 13 && im(n, ye) && vo(ye, ru) && (Cs = !0));
      var a = ye.flags;
      a & 256 && am(n, ye), !(a & 512) || Ya || (Ya = !0, ki(97, function() {
        return Ga(), null;
      })), ye = ye.nextEffect;
    }
  }
  function Ga() {
    if (tu !== 90) {
      var n = 97 < tu ? 97 : tu;
      return tu = 90, wi(n, Up);
    }
    return !1;
  }
  function Ap(n, a) {
    hf.push(a, n), Ya || (Ya = !0, ki(97, function() {
      return Ga(), null;
    }));
  }
  function Cf(n, a) {
    mf.push(a, n), Ya || (Ya = !0, ki(97, function() {
      return Ga(), null;
    }));
  }
  function Up() {
    if (Fi === null) return !1;
    var n = Fi;
    if (Fi = null, Ve & 48) throw Error(h(331));
    var a = Ve;
    Ve |= 32;
    var l = mf;
    mf = [];
    for (var u = 0; u < l.length; u += 2) {
      var f = l[u], m = l[u + 1], S = f.destroy;
      if (f.destroy = void 0, typeof S == "function") try {
        S();
      } catch (w) {
        if (m === null) throw Error(h(330));
        Xa(m, w);
      }
    }
    for (l = hf, hf = [], u = 0; u < l.length; u += 2) {
      f = l[u], m = l[u + 1];
      try {
        var T = f.create;
        f.destroy = T();
      } catch (w) {
        if (m === null) throw Error(h(330));
        Xa(m, w);
      }
    }
    for (T = n.current.firstEffect; T !== null; ) n = T.nextEffect, T.nextEffect = null, T.flags & 8 && (T.sibling = null, T.stateNode = null), T = n;
    return Ve = a, rn(), !0;
  }
  function Pi(n, a, l) {
    a = uf(l, a), a = Sp(n, a, 1), ra(n, a), a = Wn(), n = bs(n, 1), n !== null && (Eo(n, 1, a), ir(n, a));
  }
  function Xa(n, a) {
    if (n.tag === 3) Pi(n, n, a);
    else for (var l = n.return; l !== null; ) {
      if (l.tag === 3) {
        Pi(l, n, a);
        break;
      } else if (l.tag === 1) {
        var u = l.stateNode;
        if (typeof l.type.getDerivedStateFromError == "function" || typeof u.componentDidCatch == "function" && (Hr === null || !Hr.has(u))) {
          n = uf(a, n);
          var f = Cp(l, n, 1);
          if (ra(l, f), f = Wn(), l = bs(l, 1), l !== null) Eo(l, 1, f), ir(l, f);
          else if (typeof u.componentDidCatch == "function" && (Hr === null || !Hr.has(u))) try {
            u.componentDidCatch(a, n);
          } catch {
          }
          break;
        }
      }
      l = l.return;
    }
  }
  function sm(n, a, l) {
    var u = n.pingCache;
    u !== null && u.delete(a), a = Wn(), n.pingedLanes |= n.suspendedLanes & l, Mn === n && (gn & l) === l && (cn === 4 || cn === 3 && (gn & 62914560) === gn && 500 > mn() - Jo ? Hi(n, 0) : pf |= l), ir(n, a);
  }
  function cm(n, a) {
    var l = n.stateNode;
    l !== null && l.delete(a), a = 0, a === 0 && (a = n.mode, a & 2 ? a & 4 ? (fa === 0 && (fa = gr), a = wa(62914560 & ~fa), a === 0 && (a = 4194304)) : a = kl() === 99 ? 1 : 2 : a = 1), l = Wn(), n = bs(n, a), n !== null && (Eo(n, a, l), ir(n, l));
  }
  var zp;
  zp = function(n, a, l) {
    var u = a.lanes;
    if (n !== null) if (n.memoizedProps !== a.pendingProps || vn.current) ar = !0;
    else if (l & u) ar = !!(n.flags & 16384);
    else {
      switch (ar = !1, a.tag) {
        case 3:
          hp(a), Nl();
          break;
        case 5:
          cp(a);
          break;
        case 1:
          hn(a.type) && nr(a);
          break;
        case 4:
          Po(a, a.stateNode.containerInfo);
          break;
        case 10:
          u = a.memoizedProps.value;
          var f = a.type._context;
          Ue(Fa, f._currentValue), f._currentValue = u;
          break;
        case 13:
          if (a.memoizedState !== null)
            return l & a.child.childLanes ? $a(n, a, l) : (Ue(Bt, Bt.current & 1), a = sa(n, a, l), a !== null ? a.sibling : null);
          Ue(Bt, Bt.current & 1);
          break;
        case 19:
          if (u = (l & a.childLanes) !== 0, n.flags & 64) {
            if (u) return tm(n, a, l);
            a.flags |= 64;
          }
          if (f = a.memoizedState, f !== null && (f.rendering = null, f.tail = null, f.lastEffect = null), Ue(Bt, Bt.current), u) break;
          return null;
        case 23:
        case 24:
          return a.lanes = 0, Fl(n, a, l);
      }
      return sa(n, a, l);
    }
    else ar = !1;
    switch (a.lanes = 0, a.tag) {
      case 2:
        if (u = a.type, n !== null && (n.alternate = null, a.alternate = null, a.flags |= 2), n = a.pendingProps, f = vt(a, Dt.current), _i(a, l), f = Xc(null, a, u, n, f, l), a.flags |= 1, typeof f == "object" && f !== null && typeof f.render == "function" && f.$$typeof === void 0) {
          if (a.tag = 1, a.memoizedState = null, a.updateQueue = null, hn(u)) {
            var m = !0;
            nr(a);
          } else m = !1;
          a.memoizedState = f.state !== null && f.state !== void 0 ? f.state : null, $c(a);
          var S = u.getDerivedStateFromProps;
          typeof S == "function" && Ao(a, u, S, n), f.updater = _l, a.stateNode = f, f._reactInternals = a, ps(a, u, n, l), a = lf(null, a, u, !0, m, l);
        } else a.tag = 0, zn(null, a, f, l), a = a.child;
        return a;
      case 16:
        f = a.elementType;
        e: {
          switch (n !== null && (n.alternate = null, a.alternate = null, a.flags |= 2), n = a.pendingProps, m = f._init, f = m(f._payload), a.type = f, m = a.tag = dm(f), n = an(f, n), m) {
            case 0:
              a = af(null, a, f, n, l);
              break e;
            case 1:
              a = vp(null, a, f, n, l);
              break e;
            case 11:
              a = nf(null, a, f, n, l);
              break e;
            case 14:
              a = rf(null, a, f, an(f.type, n), u, l);
              break e;
          }
          throw Error(h(306, f, ""));
        }
        return a;
      case 0:
        return u = a.type, f = a.pendingProps, f = a.elementType === u ? f : an(u, f), af(n, a, u, f, l);
      case 1:
        return u = a.type, f = a.pendingProps, f = a.elementType === u ? f : an(u, f), vp(n, a, u, f, l);
      case 3:
        if (hp(a), u = a.updateQueue, n === null || u === null) throw Error(h(282));
        if (u = a.pendingProps, f = a.memoizedState, f = f !== null ? f.element : null, up(n, a), aa(a, u, null, l), u = a.memoizedState.element, u === f) Nl(), a = sa(n, a, l);
        else {
          if (f = a.stateNode, (m = f.hydrate) && (ia = Ma(a.stateNode.containerInfo.firstChild), Ur = a, m = zr = !0), m) {
            if (n = f.mutableSourceEagerHydrationData, n != null) for (f = 0; f < n.length; f += 2) m = n[f], m._workInProgressVersionPrimary = n[f + 1], Li.push(m);
            for (l = qc(a, null, u, l), a.child = l; l; ) l.flags = l.flags & -3 | 1024, l = l.sibling;
          } else zn(n, a, u, l), Nl();
          a = a.child;
        }
        return a;
      case 5:
        return cp(a), n === null && Pa(a), u = a.type, f = a.pendingProps, m = n !== null ? n.memoizedProps : null, S = f.children, Oo(u, f) ? S = null : m !== null && Oo(u, m) && (a.flags |= 16), pp(n, a), zn(n, a, S, l), a.child;
      case 6:
        return n === null && Pa(a), null;
      case 13:
        return $a(n, a, l);
      case 4:
        return Po(a, a.stateNode.containerInfo), u = a.pendingProps, n === null ? a.child = jo(a, null, u, l) : zn(n, a, u, l), a.child;
      case 11:
        return u = a.type, f = a.pendingProps, f = a.elementType === u ? f : an(u, f), nf(n, a, u, f, l);
      case 7:
        return zn(n, a, a.pendingProps, l), a.child;
      case 8:
        return zn(
          n,
          a,
          a.pendingProps.children,
          l
        ), a.child;
      case 12:
        return zn(n, a, a.pendingProps.children, l), a.child;
      case 10:
        e: {
          u = a.type._context, f = a.pendingProps, S = a.memoizedProps, m = f.value;
          var T = a.type._context;
          if (Ue(Fa, T._currentValue), T._currentValue = m, S !== null) if (T = S.value, m = tr(T, m) ? 0 : (typeof u._calculateChangedBits == "function" ? u._calculateChangedBits(T, m) : 1073741823) | 0, m === 0) {
            if (S.children === f.children && !vn.current) {
              a = sa(n, a, l);
              break e;
            }
          } else for (T = a.child, T !== null && (T.return = a); T !== null; ) {
            var w = T.dependencies;
            if (w !== null) {
              S = T.child;
              for (var P = w.firstContext; P !== null; ) {
                if (P.context === u && P.observedBits & m) {
                  T.tag === 1 && (P = mr(-1, l & -l), P.tag = 2, ra(T, P)), T.lanes |= l, P = T.alternate, P !== null && (P.lanes |= l), Ic(T.return, l), w.lanes |= l;
                  break;
                }
                P = P.next;
              }
            } else S = T.tag === 10 && T.type === a.type ? null : T.child;
            if (S !== null) S.return = T;
            else for (S = T; S !== null; ) {
              if (S === a) {
                S = null;
                break;
              }
              if (T = S.sibling, T !== null) {
                T.return = S.return, S = T;
                break;
              }
              S = S.return;
            }
            T = S;
          }
          zn(n, a, f.children, l), a = a.child;
        }
        return a;
      case 9:
        return f = a.type, m = a.pendingProps, u = m.children, _i(a, l), f = $n(
          f,
          m.unstable_observedBits
        ), u = u(f), a.flags |= 1, zn(n, a, u, l), a.child;
      case 14:
        return f = a.type, m = an(f, a.pendingProps), m = an(f.type, m), rf(n, a, f, m, u, l);
      case 15:
        return dp(n, a, a.type, a.pendingProps, u, l);
      case 17:
        return u = a.type, f = a.pendingProps, f = a.elementType === u ? f : an(u, f), n !== null && (n.alternate = null, a.alternate = null, a.flags |= 2), a.tag = 1, hn(u) ? (n = !0, nr(a)) : n = !1, _i(a, l), Di(a, u, f), ps(a, u, f, l), lf(null, a, u, !0, n, l);
      case 19:
        return tm(n, a, l);
      case 23:
        return Fl(n, a, l);
      case 24:
        return Fl(n, a, l);
    }
    throw Error(h(156, a.tag));
  };
  function fm(n, a, l, u) {
    this.tag = n, this.key = l, this.sibling = this.child = this.return = this.stateNode = this.type = this.elementType = null, this.index = 0, this.ref = null, this.pendingProps = a, this.dependencies = this.memoizedState = this.updateQueue = this.memoizedProps = null, this.mode = u, this.flags = 0, this.lastEffect = this.firstEffect = this.nextEffect = null, this.childLanes = this.lanes = 0, this.alternate = null;
  }
  function lr(n, a, l, u) {
    return new fm(n, a, l, u);
  }
  function xs(n) {
    return n = n.prototype, !(!n || !n.isReactComponent);
  }
  function dm(n) {
    if (typeof n == "function") return xs(n) ? 1 : 0;
    if (n != null) {
      if (n = n.$$typeof, n === rt) return 11;
      if (n === Be) return 14;
    }
    return 2;
  }
  function Ka(n, a) {
    var l = n.alternate;
    return l === null ? (l = lr(n.tag, a, n.key, n.mode), l.elementType = n.elementType, l.type = n.type, l.stateNode = n.stateNode, l.alternate = n, n.alternate = l) : (l.pendingProps = a, l.type = n.type, l.flags = 0, l.nextEffect = null, l.firstEffect = null, l.lastEffect = null), l.childLanes = n.childLanes, l.lanes = n.lanes, l.child = n.child, l.memoizedProps = n.memoizedProps, l.memoizedState = n.memoizedState, l.updateQueue = n.updateQueue, a = n.dependencies, l.dependencies = a === null ? null : { lanes: a.lanes, firstContext: a.firstContext }, l.sibling = n.sibling, l.index = n.index, l.ref = n.ref, l;
  }
  function iu(n, a, l, u, f, m) {
    var S = 2;
    if (u = n, typeof n == "function") xs(n) && (S = 1);
    else if (typeof n == "string") S = 5;
    else e: switch (n) {
      case We:
        return Br(l.children, f, m, a);
      case Z:
        S = 8, f |= 16;
        break;
      case Ae:
        S = 8, f |= 1;
        break;
      case lt:
        return n = lr(12, l, a, f | 8), n.elementType = lt, n.type = lt, n.lanes = m, n;
      case ut:
        return n = lr(13, l, a, f), n.type = ut, n.elementType = ut, n.lanes = m, n;
      case st:
        return n = lr(19, l, a, f), n.elementType = st, n.lanes = m, n;
      case F:
        return Bi(l, f, m, a);
      case te:
        return n = lr(24, l, a, f), n.elementType = te, n.lanes = m, n;
      default:
        if (typeof n == "object" && n !== null) switch (n.$$typeof) {
          case it:
            S = 10;
            break e;
          case ot:
            S = 9;
            break e;
          case rt:
            S = 11;
            break e;
          case Be:
            S = 14;
            break e;
          case mt:
            S = 16, u = null;
            break e;
          case Ke:
            S = 22;
            break e;
        }
        throw Error(h(130, n == null ? n : typeof n, ""));
    }
    return a = lr(S, l, a, f), a.elementType = n, a.type = u, a.lanes = m, a;
  }
  function Br(n, a, l, u) {
    return n = lr(7, n, u, a), n.lanes = l, n;
  }
  function Bi(n, a, l, u) {
    return n = lr(23, n, u, a), n.elementType = F, n.lanes = l, n;
  }
  function bf(n, a, l) {
    return n = lr(6, n, null, a), n.lanes = l, n;
  }
  function Tf(n, a, l) {
    return a = lr(4, n.children !== null ? n.children : [], n.key, a), a.lanes = l, a.stateNode = { containerInfo: n.containerInfo, pendingChildren: null, implementation: n.implementation }, a;
  }
  function pm(n, a, l) {
    this.tag = a, this.containerInfo = n, this.finishedWork = this.pingCache = this.current = this.pendingChildren = null, this.timeoutHandle = -1, this.pendingContext = this.context = null, this.hydrate = l, this.callbackNode = null, this.callbackPriority = 0, this.eventTimes = Iu(0), this.expirationTimes = Iu(-1), this.entangledLanes = this.finishedLanes = this.mutableReadLanes = this.expiredLanes = this.pingedLanes = this.suspendedLanes = this.pendingLanes = 0, this.entanglements = Iu(0), this.mutableSourceEagerHydrationData = null;
  }
  function ws(n, a, l) {
    var u = 3 < arguments.length && arguments[3] !== void 0 ? arguments[3] : null;
    return { $$typeof: Se, key: u == null ? null : "" + u, children: n, containerInfo: a, implementation: l };
  }
  function ks(n, a, l, u) {
    var f = a.current, m = Wn(), S = Pr(f);
    e: if (l) {
      l = l._reactInternals;
      t: {
        if (Sn(l) !== l || l.tag !== 1) throw Error(h(170));
        var T = l;
        do {
          switch (T.tag) {
            case 3:
              T = T.stateNode.context;
              break t;
            case 1:
              if (hn(T.type)) {
                T = T.stateNode.__reactInternalMemoizedMergedChildContext;
                break t;
              }
          }
          T = T.return;
        } while (T !== null);
        throw Error(h(171));
      }
      if (l.tag === 1) {
        var w = l.type;
        if (hn(w)) {
          l = wl(l, w, T);
          break e;
        }
      }
      l = T;
    } else l = Aa;
    return a.context === null ? a.context = l : a.pendingContext = l, a = mr(m, S), a.payload = { element: n }, u = u === void 0 ? null : u, u !== null && (a.callback = u), ra(f, a), qa(f, S, m), S;
  }
  function _s(n) {
    if (n = n.current, !n.child) return null;
    switch (n.child.tag) {
      case 5:
        return n.child.stateNode;
      default:
        return n.child.stateNode;
    }
  }
  function jp(n, a) {
    if (n = n.memoizedState, n !== null && n.dehydrated !== null) {
      var l = n.retryLane;
      n.retryLane = l !== 0 && l < a ? l : a;
    }
  }
  function Ds(n, a) {
    jp(n, a), (n = n.alternate) && jp(n, a);
  }
  function Fp() {
    return null;
  }
  function Rf(n, a, l) {
    var u = l != null && l.hydrationOptions != null && l.hydrationOptions.mutableSources || null;
    if (l = new pm(n, a, l != null && l.hydrate === !0), a = lr(3, null, null, a === 2 ? 7 : a === 1 ? 3 : 0), l.current = a, a.stateNode = l, $c(a), n[_n] = l.current, Mc(n.nodeType === 8 ? n.parentNode : n), u) for (n = 0; n < u.length; n++) {
      a = u[n];
      var f = a._getVersion;
      f = f(a._source), l.mutableSourceEagerHydrationData == null ? l.mutableSourceEagerHydrationData = [a, f] : l.mutableSourceEagerHydrationData.push(a, f);
    }
    this._internalRoot = l;
  }
  Rf.prototype.render = function(n) {
    ks(n, this._internalRoot, null, null);
  }, Rf.prototype.unmount = function() {
    var n = this._internalRoot, a = n.containerInfo;
    ks(null, n, null, function() {
      a[_n] = null;
    });
  };
  function lu(n) {
    return !(!n || n.nodeType !== 1 && n.nodeType !== 9 && n.nodeType !== 11 && (n.nodeType !== 8 || n.nodeValue !== " react-mount-point-unstable "));
  }
  function vm(n, a) {
    if (a || (a = n ? n.nodeType === 9 ? n.documentElement : n.firstChild : null, a = !(!a || a.nodeType !== 1 || !a.hasAttribute("data-reactroot"))), !a) for (var l; l = n.lastChild; ) n.removeChild(l);
    return new Rf(n, 0, a ? { hydrate: !0 } : void 0);
  }
  function Os(n, a, l, u, f) {
    var m = l._reactRootContainer;
    if (m) {
      var S = m._internalRoot;
      if (typeof f == "function") {
        var T = f;
        f = function() {
          var P = _s(S);
          T.call(P);
        };
      }
      ks(a, S, n, f);
    } else {
      if (m = l._reactRootContainer = vm(l, u), S = m._internalRoot, typeof f == "function") {
        var w = f;
        f = function() {
          var P = _s(S);
          w.call(P);
        };
      }
      Op(function() {
        ks(a, S, n, f);
      });
    }
    return _s(S);
  }
  gd = function(n) {
    if (n.tag === 13) {
      var a = Wn();
      qa(n, 4, a), Ds(n, 4);
    }
  }, ho = function(n) {
    if (n.tag === 13) {
      var a = Wn();
      qa(n, 67108864, a), Ds(n, 67108864);
    }
  }, Ed = function(n) {
    if (n.tag === 13) {
      var a = Wn(), l = Pr(n);
      qa(n, l, a), Ds(n, l);
    }
  }, ul = function(n, a) {
    return a();
  }, Xr = function(n, a, l) {
    switch (a) {
      case "input":
        if (tl(n, l), a = l.name, l.type === "radio" && a != null) {
          for (l = n; l.parentNode; ) l = l.parentNode;
          for (l = l.querySelectorAll("input[name=" + JSON.stringify("" + a) + '][type="radio"]'), a = 0; a < l.length; a++) {
            var u = l[a];
            if (u !== n && u.form === n.form) {
              var f = ta(u);
              if (!f) throw Error(h(90));
              wr(u), tl(u, f);
            }
          }
        }
        break;
      case "textarea":
        nl(n, l);
        break;
      case "select":
        a = l.value, a != null && jt(n, !!l.multiple, a, !1);
    }
  }, Nu = Dp, so = function(n, a, l, u, f) {
    var m = Ve;
    Ve |= 4;
    try {
      return wi(98, n.bind(null, a, l, u, f));
    } finally {
      Ve = m, Ve === 0 && (Il(), rn());
    }
  }, Mu = function() {
    !(Ve & 49) && (lm(), Ga());
  }, co = function(n, a) {
    var l = Ve;
    Ve |= 2;
    try {
      return n(a);
    } finally {
      Ve = l, Ve === 0 && (Il(), rn());
    }
  };
  function Hp(n, a) {
    var l = 2 < arguments.length && arguments[2] !== void 0 ? arguments[2] : null;
    if (!lu(a)) throw Error(h(200));
    return ws(n, a, null, l);
  }
  var hm = { Events: [In, Dn, ta, kr, uo, Ga, { current: !1 }] }, ou = { findFiberByHostInstance: Ri, bundleType: 0, version: "17.0.2", rendererPackageName: "react-dom" }, mm = { bundleType: ou.bundleType, version: ou.version, rendererPackageName: ou.rendererPackageName, rendererConfig: ou.rendererConfig, overrideHookState: null, overrideHookStateDeletePath: null, overrideHookStateRenamePath: null, overrideProps: null, overridePropsDeletePath: null, overridePropsRenamePath: null, setSuspenseHandler: null, scheduleUpdate: null, currentDispatcherRef: z.ReactCurrentDispatcher, findHostInstanceByFiber: function(n) {
    return n = ju(n), n === null ? null : n.stateNode;
  }, findFiberByHostInstance: ou.findFiberByHostInstance || Fp, findHostInstancesForRefresh: null, scheduleRefresh: null, scheduleRoot: null, setRefreshHandler: null, getCurrentFiber: null };
  if (typeof __REACT_DEVTOOLS_GLOBAL_HOOK__ < "u") {
    var Ns = __REACT_DEVTOOLS_GLOBAL_HOOK__;
    if (!Ns.isDisabled && Ns.supportsFiber) try {
      zc = Ns.inject(mm), xi = Ns;
    } catch {
    }
  }
  return Rr.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED = hm, Rr.createPortal = Hp, Rr.findDOMNode = function(n) {
    if (n == null) return null;
    if (n.nodeType === 1) return n;
    var a = n._reactInternals;
    if (a === void 0)
      throw typeof n.render == "function" ? Error(h(188)) : Error(h(268, Object.keys(n)));
    return n = ju(a), n = n === null ? null : n.stateNode, n;
  }, Rr.flushSync = function(n, a) {
    var l = Ve;
    if (l & 48) return n(a);
    Ve |= 1;
    try {
      if (n) return wi(99, n.bind(null, a));
    } finally {
      Ve = l, rn();
    }
  }, Rr.hydrate = function(n, a, l) {
    if (!lu(a)) throw Error(h(200));
    return Os(null, n, a, !0, l);
  }, Rr.render = function(n, a, l) {
    if (!lu(a)) throw Error(h(200));
    return Os(null, n, a, !1, l);
  }, Rr.unmountComponentAtNode = function(n) {
    if (!lu(n)) throw Error(h(40));
    return n._reactRootContainer ? (Op(function() {
      Os(null, null, n, !1, function() {
        n._reactRootContainer = null, n[_n] = null;
      });
    }), !0) : !1;
  }, Rr.unstable_batchedUpdates = Dp, Rr.unstable_createPortal = function(n, a) {
    return Hp(n, a, 2 < arguments.length && arguments[2] !== void 0 ? arguments[2] : null);
  }, Rr.unstable_renderSubtreeIntoContainer = function(n, a, l, u) {
    if (!lu(l)) throw Error(h(200));
    if (n == null || n._reactInternals === void 0) throw Error(h(38));
    return Os(n, a, l, !1, u);
  }, Rr.version = "17.0.2", Rr;
}
var xr = {}, gh = { exports: {} }, ya = {};
/** @license React v0.20.2
 * scheduler-tracing.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
var mb;
function g_() {
  if (mb) return ya;
  mb = 1;
  var c = 0;
  return ya.__interactionsRef = null, ya.__subscriberRef = null, ya.unstable_clear = function(p) {
    return p();
  }, ya.unstable_getCurrent = function() {
    return null;
  }, ya.unstable_getThreadID = function() {
    return ++c;
  }, ya.unstable_subscribe = function() {
  }, ya.unstable_trace = function(p, g, h) {
    return h();
  }, ya.unstable_unsubscribe = function() {
  }, ya.unstable_wrap = function(p) {
    return p;
  }, ya;
}
var Qg = {};
/** @license React v0.20.2
 * scheduler-tracing.development.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
var yb;
function E_() {
  return yb || (yb = 1, function(c) {
     true && function() {
      var p = 0, g = 0, h = 0;
      c.__interactionsRef = null, c.__subscriberRef = null, c.__interactionsRef = {
        current: /* @__PURE__ */ new Set()
      }, c.__subscriberRef = {
        current: null
      };
      function b(we) {
        var ee = c.__interactionsRef.current;
        c.__interactionsRef.current = /* @__PURE__ */ new Set();
        try {
          return we();
        } finally {
          c.__interactionsRef.current = ee;
        }
      }
      function C() {
        return c.__interactionsRef.current;
      }
      function y() {
        return ++h;
      }
      function D(we, ee, ie) {
        var z = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : p, le = {
          __count: 1,
          id: g++,
          name: we,
          timestamp: ee
        }, Se = c.__interactionsRef.current, We = new Set(Se);
        We.add(le), c.__interactionsRef.current = We;
        var Ae = c.__subscriberRef.current, lt;
        try {
          Ae !== null && Ae.onInteractionTraced(le);
        } finally {
          try {
            Ae !== null && Ae.onWorkStarted(We, z);
          } finally {
            try {
              lt = ie();
            } finally {
              c.__interactionsRef.current = Se;
              try {
                Ae !== null && Ae.onWorkStopped(We, z);
              } finally {
                le.__count--, Ae !== null && le.__count === 0 && Ae.onInteractionScheduledWorkCompleted(le);
              }
            }
          }
        }
        return lt;
      }
      function A(we) {
        var ee = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : p, ie = c.__interactionsRef.current, z = c.__subscriberRef.current;
        z !== null && z.onWorkScheduled(ie, ee), ie.forEach(function(We) {
          We.__count++;
        });
        var le = !1;
        function Se() {
          var We = c.__interactionsRef.current;
          c.__interactionsRef.current = ie, z = c.__subscriberRef.current;
          try {
            var Ae;
            try {
              z !== null && z.onWorkStarted(ie, ee);
            } finally {
              try {
                Ae = we.apply(void 0, arguments);
              } finally {
                c.__interactionsRef.current = We, z !== null && z.onWorkStopped(ie, ee);
              }
            }
            return Ae;
          } finally {
            le || (le = !0, ie.forEach(function(lt) {
              lt.__count--, z !== null && lt.__count === 0 && z.onInteractionScheduledWorkCompleted(lt);
            }));
          }
        }
        return Se.cancel = function() {
          z = c.__subscriberRef.current;
          try {
            z !== null && z.onWorkCanceled(ie, ee);
          } finally {
            ie.forEach(function(Ae) {
              Ae.__count--, z && Ae.__count === 0 && z.onInteractionScheduledWorkCompleted(Ae);
            });
          }
        }, Se;
      }
      var L = null;
      L = /* @__PURE__ */ new Set();
      function I(we) {
        L.add(we), L.size === 1 && (c.__subscriberRef.current = {
          onInteractionScheduledWorkCompleted: re,
          onInteractionTraced: Y,
          onWorkCanceled: _e,
          onWorkScheduled: ue,
          onWorkStarted: Te,
          onWorkStopped: ce
        });
      }
      function B(we) {
        L.delete(we), L.size === 0 && (c.__subscriberRef.current = null);
      }
      function Y(we) {
        var ee = !1, ie = null;
        if (L.forEach(function(z) {
          try {
            z.onInteractionTraced(we);
          } catch (le) {
            ee || (ee = !0, ie = le);
          }
        }), ee)
          throw ie;
      }
      function re(we) {
        var ee = !1, ie = null;
        if (L.forEach(function(z) {
          try {
            z.onInteractionScheduledWorkCompleted(we);
          } catch (le) {
            ee || (ee = !0, ie = le);
          }
        }), ee)
          throw ie;
      }
      function ue(we, ee) {
        var ie = !1, z = null;
        if (L.forEach(function(le) {
          try {
            le.onWorkScheduled(we, ee);
          } catch (Se) {
            ie || (ie = !0, z = Se);
          }
        }), ie)
          throw z;
      }
      function Te(we, ee) {
        var ie = !1, z = null;
        if (L.forEach(function(le) {
          try {
            le.onWorkStarted(we, ee);
          } catch (Se) {
            ie || (ie = !0, z = Se);
          }
        }), ie)
          throw z;
      }
      function ce(we, ee) {
        var ie = !1, z = null;
        if (L.forEach(function(le) {
          try {
            le.onWorkStopped(we, ee);
          } catch (Se) {
            ie || (ie = !0, z = Se);
          }
        }), ie)
          throw z;
      }
      function _e(we, ee) {
        var ie = !1, z = null;
        if (L.forEach(function(le) {
          try {
            le.onWorkCanceled(we, ee);
          } catch (Se) {
            ie || (ie = !0, z = Se);
          }
        }), ie)
          throw z;
      }
      c.unstable_clear = b, c.unstable_getCurrent = C, c.unstable_getThreadID = y, c.unstable_subscribe = I, c.unstable_trace = D, c.unstable_unsubscribe = B, c.unstable_wrap = A;
    }();
  }(Qg)), Qg;
}
var gb;
function S_() {
  return gb || (gb = 1,  false ? 0 : gh.exports = E_()), gh.exports;
}
/** @license React v17.0.2
 * react-dom.development.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
var Eb;
function C_() {
  return Eb || (Eb = 1,  true && function() {
    var c = (react__WEBPACK_IMPORTED_MODULE_1___default()), p = f0(), g = Kb(), h = S_(), b = c.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED;
    function C(e) {
      {
        for (var t = arguments.length, r = new Array(t > 1 ? t - 1 : 0), i = 1; i < t; i++)
          r[i - 1] = arguments[i];
        D("warn", e, r);
      }
    }
    function y(e) {
      {
        for (var t = arguments.length, r = new Array(t > 1 ? t - 1 : 0), i = 1; i < t; i++)
          r[i - 1] = arguments[i];
        D("error", e, r);
      }
    }
    function D(e, t, r) {
      {
        var i = b.ReactDebugCurrentFrame, o = i.getStackAddendum();
        o !== "" && (t += "%s", r = r.concat([o]));
        var s = r.map(function(d) {
          return "" + d;
        });
        s.unshift("Warning: " + t), Function.prototype.apply.call(console[e], console, s);
      }
    }
    if (!c)
      throw Error("ReactDOM was loaded before React. Make sure you load the React package before loading ReactDOM.");
    var A = 0, L = 1, I = 2, B = 3, Y = 4, re = 5, ue = 6, Te = 7, ce = 8, _e = 9, we = 10, ee = 11, ie = 12, z = 13, le = 14, Se = 15, We = 16, Ae = 17, lt = 18, it = 19, ot = 20, rt = 21, ut = 22, st = 23, Be = 24, mt = !0, Ke = !1, Rt = !1, Z = !1, F = /* @__PURE__ */ new Set(), te = {}, G = {};
    function oe(e, t) {
      ve(e, t), ve(e + "Capture", t);
    }
    function ve(e, t) {
      te[e] && y("EventRegistry: More than one plugin attempted to publish the same registration name, `%s`.", e), te[e] = t;
      {
        var r = e.toLowerCase();
        G[r] = e, e === "onDoubleClick" && (G.ondblclick = e);
      }
      for (var i = 0; i < t.length; i++)
        F.add(t[i]);
    }
    var Re = typeof window < "u" && typeof window.document < "u" && typeof window.document.createElement < "u", Oe = 0, xe = 1, Ne = 2, Fe = 3, Ze = 4, ne = 5, At = 6, Yt = ":A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD", tt = Yt + "\\-.0-9\\u00B7\\u0300-\\u036F\\u203F-\\u2040", wr = "data-reactroot", Xn = new RegExp("^[" + Yt + "][" + tt + "]*$"), Ca = Object.prototype.hasOwnProperty, io = {}, lo = {};
    function tl(e) {
      return Ca.call(lo, e) ? !0 : Ca.call(io, e) ? !1 : Xn.test(e) ? (lo[e] = !0, !0) : (io[e] = !0, y("Invalid attribute name: `%s`", e), !1);
    }
    function oo(e, t, r) {
      return t !== null ? t.type === Oe : r ? !1 : e.length > 2 && (e[0] === "o" || e[0] === "O") && (e[1] === "n" || e[1] === "N");
    }
    function ci(e, t, r, i) {
      if (r !== null && r.type === Oe)
        return !1;
      switch (typeof t) {
        case "function":
        case "symbol":
          return !0;
        case "boolean": {
          if (i)
            return !1;
          if (r !== null)
            return !r.acceptsBooleans;
          var o = e.toLowerCase().slice(0, 5);
          return o !== "data-" && o !== "aria-";
        }
        default:
          return !1;
      }
    }
    function fi(e, t, r, i) {
      if (t === null || typeof t > "u" || ci(e, t, r, i))
        return !0;
      if (i)
        return !1;
      if (r !== null)
        switch (r.type) {
          case Fe:
            return !t;
          case Ze:
            return t === !1;
          case ne:
            return isNaN(t);
          case At:
            return isNaN(t) || t < 1;
        }
      return !1;
    }
    function di(e) {
      return Wt.hasOwnProperty(e) ? Wt[e] : null;
    }
    function jt(e, t, r, i, o, s, d) {
      this.acceptsBooleans = t === Ne || t === Fe || t === Ze, this.attributeName = i, this.attributeNamespace = o, this.mustUseProperty = r, this.propertyName = e, this.type = t, this.sanitizeURL = s, this.removeEmptyString = d;
    }
    var Wt = {}, Ou = [
      "children",
      "dangerouslySetInnerHTML",
      // TODO: This prevents the assignment of defaultValue to regular
      // elements (not just inputs). Now that ReactDOMInput assigns to the
      // defaultValue property -- do we need this?
      "defaultValue",
      "defaultChecked",
      "innerHTML",
      "suppressContentEditableWarning",
      "suppressHydrationWarning",
      "style"
    ];
    Ou.forEach(function(e) {
      Wt[e] = new jt(
        e,
        Oe,
        !1,
        // mustUseProperty
        e,
        // attributeName
        null,
        // attributeNamespace
        !1,
        // sanitizeURL
        !1
      );
    }), [["acceptCharset", "accept-charset"], ["className", "class"], ["htmlFor", "for"], ["httpEquiv", "http-equiv"]].forEach(function(e) {
      var t = e[0], r = e[1];
      Wt[t] = new jt(
        t,
        xe,
        !1,
        // mustUseProperty
        r,
        // attributeName
        null,
        // attributeNamespace
        !1,
        // sanitizeURL
        !1
      );
    }), ["contentEditable", "draggable", "spellCheck", "value"].forEach(function(e) {
      Wt[e] = new jt(
        e,
        Ne,
        !1,
        // mustUseProperty
        e.toLowerCase(),
        // attributeName
        null,
        // attributeNamespace
        !1,
        // sanitizeURL
        !1
      );
    }), ["autoReverse", "externalResourcesRequired", "focusable", "preserveAlpha"].forEach(function(e) {
      Wt[e] = new jt(
        e,
        Ne,
        !1,
        // mustUseProperty
        e,
        // attributeName
        null,
        // attributeNamespace
        !1,
        // sanitizeURL
        !1
      );
    }), [
      "allowFullScreen",
      "async",
      // Note: there is a special case that prevents it from being written to the DOM
      // on the client side because the browsers are inconsistent. Instead we call focus().
      "autoFocus",
      "autoPlay",
      "controls",
      "default",
      "defer",
      "disabled",
      "disablePictureInPicture",
      "disableRemotePlayback",
      "formNoValidate",
      "hidden",
      "loop",
      "noModule",
      "noValidate",
      "open",
      "playsInline",
      "readOnly",
      "required",
      "reversed",
      "scoped",
      "seamless",
      // Microdata
      "itemScope"
    ].forEach(function(e) {
      Wt[e] = new jt(
        e,
        Fe,
        !1,
        // mustUseProperty
        e.toLowerCase(),
        // attributeName
        null,
        // attributeNamespace
        !1,
        // sanitizeURL
        !1
      );
    }), [
      "checked",
      // Note: `option.selected` is not updated if `select.multiple` is
      // disabled with `removeAttribute`. We have special logic for handling this.
      "multiple",
      "muted",
      "selected"
      // NOTE: if you add a camelCased prop to this list,
      // you'll need to set attributeName to name.toLowerCase()
      // instead in the assignment below.
    ].forEach(function(e) {
      Wt[e] = new jt(
        e,
        Fe,
        !0,
        // mustUseProperty
        e,
        // attributeName
        null,
        // attributeNamespace
        !1,
        // sanitizeURL
        !1
      );
    }), [
      "capture",
      "download"
      // NOTE: if you add a camelCased prop to this list,
      // you'll need to set attributeName to name.toLowerCase()
      // instead in the assignment below.
    ].forEach(function(e) {
      Wt[e] = new jt(
        e,
        Ze,
        !1,
        // mustUseProperty
        e,
        // attributeName
        null,
        // attributeNamespace
        !1,
        // sanitizeURL
        !1
      );
    }), [
      "cols",
      "rows",
      "size",
      "span"
      // NOTE: if you add a camelCased prop to this list,
      // you'll need to set attributeName to name.toLowerCase()
      // instead in the assignment below.
    ].forEach(function(e) {
      Wt[e] = new jt(
        e,
        At,
        !1,
        // mustUseProperty
        e,
        // attributeName
        null,
        // attributeNamespace
        !1,
        // sanitizeURL
        !1
      );
    }), ["rowSpan", "start"].forEach(function(e) {
      Wt[e] = new jt(
        e,
        ne,
        !1,
        // mustUseProperty
        e.toLowerCase(),
        // attributeName
        null,
        // attributeNamespace
        !1,
        // sanitizeURL
        !1
      );
    });
    var nl = /[\-\:]([a-z])/g, rl = function(e) {
      return e[1].toUpperCase();
    };
    [
      "accent-height",
      "alignment-baseline",
      "arabic-form",
      "baseline-shift",
      "cap-height",
      "clip-path",
      "clip-rule",
      "color-interpolation",
      "color-interpolation-filters",
      "color-profile",
      "color-rendering",
      "dominant-baseline",
      "enable-background",
      "fill-opacity",
      "fill-rule",
      "flood-color",
      "flood-opacity",
      "font-family",
      "font-size",
      "font-size-adjust",
      "font-stretch",
      "font-style",
      "font-variant",
      "font-weight",
      "glyph-name",
      "glyph-orientation-horizontal",
      "glyph-orientation-vertical",
      "horiz-adv-x",
      "horiz-origin-x",
      "image-rendering",
      "letter-spacing",
      "lighting-color",
      "marker-end",
      "marker-mid",
      "marker-start",
      "overline-position",
      "overline-thickness",
      "paint-order",
      "panose-1",
      "pointer-events",
      "rendering-intent",
      "shape-rendering",
      "stop-color",
      "stop-opacity",
      "strikethrough-position",
      "strikethrough-thickness",
      "stroke-dasharray",
      "stroke-dashoffset",
      "stroke-linecap",
      "stroke-linejoin",
      "stroke-miterlimit",
      "stroke-opacity",
      "stroke-width",
      "text-anchor",
      "text-decoration",
      "text-rendering",
      "underline-position",
      "underline-thickness",
      "unicode-bidi",
      "unicode-range",
      "units-per-em",
      "v-alphabetic",
      "v-hanging",
      "v-ideographic",
      "v-mathematical",
      "vector-effect",
      "vert-adv-y",
      "vert-origin-x",
      "vert-origin-y",
      "word-spacing",
      "writing-mode",
      "xmlns:xlink",
      "x-height"
      // NOTE: if you add a camelCased prop to this list,
      // you'll need to set attributeName to name.toLowerCase()
      // instead in the assignment below.
    ].forEach(function(e) {
      var t = e.replace(nl, rl);
      Wt[t] = new jt(
        t,
        xe,
        !1,
        // mustUseProperty
        e,
        null,
        // attributeNamespace
        !1,
        // sanitizeURL
        !1
      );
    }), [
      "xlink:actuate",
      "xlink:arcrole",
      "xlink:role",
      "xlink:show",
      "xlink:title",
      "xlink:type"
      // NOTE: if you add a camelCased prop to this list,
      // you'll need to set attributeName to name.toLowerCase()
      // instead in the assignment below.
    ].forEach(function(e) {
      var t = e.replace(nl, rl);
      Wt[t] = new jt(
        t,
        xe,
        !1,
        // mustUseProperty
        e,
        "http://www.w3.org/1999/xlink",
        !1,
        // sanitizeURL
        !1
      );
    }), [
      "xml:base",
      "xml:lang",
      "xml:space"
      // NOTE: if you add a camelCased prop to this list,
      // you'll need to set attributeName to name.toLowerCase()
      // instead in the assignment below.
    ].forEach(function(e) {
      var t = e.replace(nl, rl);
      Wt[t] = new jt(
        t,
        xe,
        !1,
        // mustUseProperty
        e,
        "http://www.w3.org/XML/1998/namespace",
        !1,
        // sanitizeURL
        !1
      );
    }), ["tabIndex", "crossOrigin"].forEach(function(e) {
      Wt[e] = new jt(
        e,
        xe,
        !1,
        // mustUseProperty
        e.toLowerCase(),
        // attributeName
        null,
        // attributeNamespace
        !1,
        // sanitizeURL
        !1
      );
    });
    var de = "xlinkHref";
    Wt[de] = new jt(
      "xlinkHref",
      xe,
      !1,
      // mustUseProperty
      "xlink:href",
      "http://www.w3.org/1999/xlink",
      !0,
      // sanitizeURL
      !1
    ), ["src", "href", "action", "formAction"].forEach(function(e) {
      Wt[e] = new jt(
        e,
        xe,
        !1,
        // mustUseProperty
        e.toLowerCase(),
        // attributeName
        null,
        // attributeNamespace
        !0,
        // sanitizeURL
        !0
      );
    });
    var De = /^[\u0000-\u001F ]*j[\r\n\t]*a[\r\n\t]*v[\r\n\t]*a[\r\n\t]*s[\r\n\t]*c[\r\n\t]*r[\r\n\t]*i[\r\n\t]*p[\r\n\t]*t[\r\n\t]*\:/i, Je = !1;
    function pt(e) {
      !Je && De.test(e) && (Je = !0, y("A future version of React will block javascript: URLs as a security precaution. Use event handlers instead if you can. If you need to generate unsafe HTML try using dangerouslySetInnerHTML instead. React was passed %s.", JSON.stringify(e)));
    }
    function Jt(e, t, r, i) {
      if (i.mustUseProperty) {
        var o = i.propertyName;
        return e[o];
      } else {
        i.sanitizeURL && pt("" + r);
        var s = i.attributeName, d = null;
        if (i.type === Ze) {
          if (e.hasAttribute(s)) {
            var v = e.getAttribute(s);
            return v === "" ? !0 : fi(t, r, i, !1) ? v : v === "" + r ? r : v;
          }
        } else if (e.hasAttribute(s)) {
          if (fi(t, r, i, !1))
            return e.getAttribute(s);
          if (i.type === Fe)
            return r;
          d = e.getAttribute(s);
        }
        return fi(t, r, i, !1) ? d === null ? r : d : d === "" + r ? r : d;
      }
    }
    function Ft(e, t, r) {
      {
        if (!tl(t))
          return;
        if (WT(r))
          return r;
        if (!e.hasAttribute(t))
          return r === void 0 ? void 0 : null;
        var i = e.getAttribute(t);
        return i === "" + r ? r : i;
      }
    }
    function Ht(e, t, r, i) {
      var o = di(t);
      if (!oo(t, o, i)) {
        if (fi(t, r, o, i) && (r = null), i || o === null) {
          if (tl(t)) {
            var s = t;
            r === null ? e.removeAttribute(s) : e.setAttribute(s, "" + r);
          }
          return;
        }
        var d = o.mustUseProperty;
        if (d) {
          var v = o.propertyName;
          if (r === null) {
            var E = o.type;
            e[v] = E === Fe ? !1 : "";
          } else
            e[v] = r;
          return;
        }
        var R = o.attributeName, x = o.attributeNamespace;
        if (r === null)
          e.removeAttribute(R);
        else {
          var U = o.type, k;
          U === Fe || U === Ze && r === !0 ? k = "" : (k = "" + r, o.sanitizeURL && pt(k.toString())), x ? e.setAttributeNS(x, R, k) : e.setAttribute(R, k);
        }
      }
    }
    var Rn = 60103, Ut = 60106, Gr = 60107, sc = 60108, pi = 60114, al = 60109, il = 60110, Xr = 60112, fr = 60113, dr = 60120, vi = 60115, kr = 60116, uo = 60121, Nu = 60119, so = 60128, Mu = 60129, co = 60130, _r = 60131;
    if (typeof Symbol == "function" && Symbol.for) {
      var Pt = Symbol.for;
      Rn = Pt("react.element"), Ut = Pt("react.portal"), Gr = Pt("react.fragment"), sc = Pt("react.strict_mode"), pi = Pt("react.profiler"), al = Pt("react.provider"), il = Pt("react.context"), Xr = Pt("react.forward_ref"), fr = Pt("react.suspense"), dr = Pt("react.suspense_list"), vi = Pt("react.memo"), kr = Pt("react.lazy"), uo = Pt("react.block"), Pt("react.server.block"), Pt("react.fundamental"), Nu = Pt("react.scope"), so = Pt("react.opaque.id"), Mu = Pt("react.debug_trace_mode"), co = Pt("react.offscreen"), _r = Pt("react.legacy_hidden");
    }
    var Lu = typeof Symbol == "function" && Symbol.iterator, Oh = "@@iterator";
    function pr(e) {
      if (e === null || typeof e != "object")
        return null;
      var t = Lu && e[Lu] || e[Oh];
      return typeof t == "function" ? t : null;
    }
    var hi = 0, ll, hd, ol, fo, po, Au, md;
    function yd() {
    }
    yd.__reactDisabledLog = !0;
    function Dr() {
      {
        if (hi === 0) {
          ll = console.log, hd = console.info, ol = console.warn, fo = console.error, po = console.group, Au = console.groupCollapsed, md = console.groupEnd;
          var e = {
            configurable: !0,
            enumerable: !0,
            value: yd,
            writable: !0
          };
          Object.defineProperties(console, {
            info: e,
            log: e,
            warn: e,
            error: e,
            group: e,
            groupCollapsed: e,
            groupEnd: e
          });
        }
        hi++;
      }
    }
    function Sn() {
      {
        if (hi--, hi === 0) {
          var e = {
            configurable: !0,
            enumerable: !0,
            writable: !0
          };
          Object.defineProperties(console, {
            log: p({}, e, {
              value: ll
            }),
            info: p({}, e, {
              value: hd
            }),
            warn: p({}, e, {
              value: ol
            }),
            error: p({}, e, {
              value: fo
            }),
            group: p({}, e, {
              value: po
            }),
            groupCollapsed: p({}, e, {
              value: Au
            }),
            groupEnd: p({}, e, {
              value: md
            })
          });
        }
        hi < 0 && y("disabledDepth fell below zero. This is a bug in React. Please file an issue.");
      }
    }
    var Uu = b.ReactCurrentDispatcher, zu;
    function ba(e, t, r) {
      {
        if (zu === void 0)
          try {
            throw Error();
          } catch (o) {
            var i = o.stack.trim().match(/\n( *(at )?)/);
            zu = i && i[1] || "";
          }
        return `
` + zu + e;
      }
    }
    var ju = !1, vo;
    {
      var gd = typeof WeakMap == "function" ? WeakMap : Map;
      vo = new gd();
    }
    function ho(e, t) {
      if (!e || ju)
        return "";
      {
        var r = vo.get(e);
        if (r !== void 0)
          return r;
      }
      var i;
      ju = !0;
      var o = Error.prepareStackTrace;
      Error.prepareStackTrace = void 0;
      var s;
      s = Uu.current, Uu.current = null, Dr();
      try {
        if (t) {
          var d = function() {
            throw Error();
          };
          if (Object.defineProperty(d.prototype, "props", {
            set: function() {
              throw Error();
            }
          }), typeof Reflect == "object" && Reflect.construct) {
            try {
              Reflect.construct(d, []);
            } catch (Q) {
              i = Q;
            }
            Reflect.construct(e, [], d);
          } else {
            try {
              d.call();
            } catch (Q) {
              i = Q;
            }
            e.call(d.prototype);
          }
        } else {
          try {
            throw Error();
          } catch (Q) {
            i = Q;
          }
          e();
        }
      } catch (Q) {
        if (Q && i && typeof Q.stack == "string") {
          for (var v = Q.stack.split(`
`), E = i.stack.split(`
`), R = v.length - 1, x = E.length - 1; R >= 1 && x >= 0 && v[R] !== E[x]; )
            x--;
          for (; R >= 1 && x >= 0; R--, x--)
            if (v[R] !== E[x]) {
              if (R !== 1 || x !== 1)
                do
                  if (R--, x--, x < 0 || v[R] !== E[x]) {
                    var U = `
` + v[R].replace(" at new ", " at ");
                    return typeof e == "function" && vo.set(e, U), U;
                  }
                while (R >= 1 && x >= 0);
              break;
            }
        }
      } finally {
        ju = !1, Uu.current = s, Sn(), Error.prepareStackTrace = o;
      }
      var k = e ? e.displayName || e.name : "", H = k ? ba(k) : "";
      return typeof e == "function" && vo.set(e, H), H;
    }
    function Ed(e, t, r) {
      return ho(e, !0);
    }
    function ul(e, t, r) {
      return ho(e, !1);
    }
    function cc(e) {
      var t = e.prototype;
      return !!(t && t.isReactComponent);
    }
    function Kn(e, t, r) {
      if (e == null)
        return "";
      if (typeof e == "function")
        return ho(e, cc(e));
      if (typeof e == "string")
        return ba(e);
      switch (e) {
        case fr:
          return ba("Suspense");
        case dr:
          return ba("SuspenseList");
      }
      if (typeof e == "object")
        switch (e.$$typeof) {
          case Xr:
            return ul(e.render);
          case vi:
            return Kn(e.type, t, r);
          case uo:
            return ul(e._render);
          case kr: {
            var i = e, o = i._payload, s = i._init;
            try {
              return Kn(s(o), t, r);
            } catch {
            }
          }
        }
      return "";
    }
    function Ta(e) {
      switch (e._debugOwner && e._debugOwner.type, e._debugSource, e.tag) {
        case re:
          return ba(e.type);
        case We:
          return ba("Lazy");
        case z:
          return ba("Suspense");
        case it:
          return ba("SuspenseList");
        case A:
        case I:
        case Se:
          return ul(e.type);
        case ee:
          return ul(e.type.render);
        case ut:
          return ul(e.type._render);
        case L:
          return Ed(e.type);
        default:
          return "";
      }
    }
    function Kr(e) {
      try {
        var t = "", r = e;
        do
          t += Ta(r), r = r.return;
        while (r);
        return t;
      } catch (i) {
        return `
Error generating stack: ` + i.message + `
` + i.stack;
      }
    }
    function Ra(e, t, r) {
      var i = t.displayName || t.name || "";
      return e.displayName || (i !== "" ? r + "(" + i + ")" : r);
    }
    function sl(e) {
      return e.displayName || "Context";
    }
    function fe(e) {
      if (e == null)
        return null;
      if (typeof e.tag == "number" && y("Received an unexpected object in getComponentName(). This is likely a bug in React. Please file an issue."), typeof e == "function")
        return e.displayName || e.name || null;
      if (typeof e == "string")
        return e;
      switch (e) {
        case Gr:
          return "Fragment";
        case Ut:
          return "Portal";
        case pi:
          return "Profiler";
        case sc:
          return "StrictMode";
        case fr:
          return "Suspense";
        case dr:
          return "SuspenseList";
      }
      if (typeof e == "object")
        switch (e.$$typeof) {
          case il:
            var t = e;
            return sl(t) + ".Consumer";
          case al:
            var r = e;
            return sl(r._context) + ".Provider";
          case Xr:
            return Ra(e, e.render, "ForwardRef");
          case vi:
            return fe(e.type);
          case uo:
            return fe(e._render);
          case kr: {
            var i = e, o = i._payload, s = i._init;
            try {
              return fe(s(o));
            } catch {
              return null;
            }
          }
        }
      return null;
    }
    var cl = b.ReactDebugCurrentFrame, xn = null, xa = !1;
    function fl() {
      {
        if (xn === null)
          return null;
        var e = xn._debugOwner;
        if (e !== null && typeof e < "u")
          return fe(e.type);
      }
      return null;
    }
    function mo() {
      return xn === null ? "" : Kr(xn);
    }
    function An() {
      cl.getCurrentStack = null, xn = null, xa = !1;
    }
    function nn(e) {
      cl.getCurrentStack = mo, xn = e, xa = !1;
    }
    function Vn(e) {
      xa = e;
    }
    function Sd() {
      return xa;
    }
    function Zn(e) {
      return "" + e;
    }
    function Jn(e) {
      switch (typeof e) {
        case "boolean":
        case "number":
        case "object":
        case "string":
        case "undefined":
          return e;
        default:
          return "";
      }
    }
    var Cd = {
      button: !0,
      checkbox: !0,
      image: !0,
      hidden: !0,
      radio: !0,
      reset: !0,
      submit: !0
    };
    function dl(e, t) {
      Cd[t.type] || t.onChange || t.onInput || t.readOnly || t.disabled || t.value == null || y("You provided a `value` prop to a form field without an `onChange` handler. This will render a read-only field. If the field should be mutable use `defaultValue`. Otherwise, set either `onChange` or `readOnly`."), t.onChange || t.readOnly || t.disabled || t.checked == null || y("You provided a `checked` prop to a form field without an `onChange` handler. This will render a read-only field. If the field should be mutable use `defaultChecked`. Otherwise, set either `onChange` or `readOnly`.");
    }
    function mi(e) {
      var t = e.type, r = e.nodeName;
      return r && r.toLowerCase() === "input" && (t === "checkbox" || t === "radio");
    }
    function Fu(e) {
      return e._valueTracker;
    }
    function bd(e) {
      e._valueTracker = null;
    }
    function Hu(e) {
      var t = "";
      return e && (mi(e) ? t = e.checked ? "true" : "false" : t = e.value), t;
    }
    function Td(e) {
      var t = mi(e) ? "checked" : "value", r = Object.getOwnPropertyDescriptor(e.constructor.prototype, t), i = "" + e[t];
      if (!(e.hasOwnProperty(t) || typeof r > "u" || typeof r.get != "function" || typeof r.set != "function")) {
        var o = r.get, s = r.set;
        Object.defineProperty(e, t, {
          configurable: !0,
          get: function() {
            return o.call(this);
          },
          set: function(v) {
            i = "" + v, s.call(this, v);
          }
        }), Object.defineProperty(e, t, {
          enumerable: r.enumerable
        });
        var d = {
          getValue: function() {
            return i;
          },
          setValue: function(v) {
            i = "" + v;
          },
          stopTracking: function() {
            bd(e), delete e[t];
          }
        };
        return d;
      }
    }
    function yo(e) {
      Fu(e) || (e._valueTracker = Td(e));
    }
    function fc(e) {
      if (!e)
        return !1;
      var t = Fu(e);
      if (!t)
        return !0;
      var r = t.getValue(), i = Hu(e);
      return i !== r ? (t.setValue(i), !0) : !1;
    }
    function go(e) {
      if (e = e || (typeof document < "u" ? document : void 0), typeof e > "u")
        return null;
      try {
        return e.activeElement || e.body;
      } catch {
        return e.body;
      }
    }
    var dc = !1, Pu = !1, Rd = !1, Bu = !1;
    function xd(e) {
      var t = e.type === "checkbox" || e.type === "radio";
      return t ? e.checked != null : e.value != null;
    }
    function gt(e, t) {
      var r = e, i = t.checked, o = p({}, t, {
        defaultChecked: void 0,
        defaultValue: void 0,
        value: void 0,
        checked: i ?? r._wrapperState.initialChecked
      });
      return o;
    }
    function yi(e, t) {
      dl("input", t), t.checked !== void 0 && t.defaultChecked !== void 0 && !Pu && (y("%s contains an input of type %s with both checked and defaultChecked props. Input elements must be either controlled or uncontrolled (specify either the checked prop, or the defaultChecked prop, but not both). Decide between using a controlled or uncontrolled input element and remove one of these props. More info: https://reactjs.org/link/controlled-components", fl() || "A component", t.type), Pu = !0), t.value !== void 0 && t.defaultValue !== void 0 && !dc && (y("%s contains an input of type %s with both value and defaultValue props. Input elements must be either controlled or uncontrolled (specify either the value prop, or the defaultValue prop, but not both). Decide between using a controlled or uncontrolled input element and remove one of these props. More info: https://reactjs.org/link/controlled-components", fl() || "A component", t.type), dc = !0);
      var r = e, i = t.defaultValue == null ? "" : t.defaultValue;
      r._wrapperState = {
        initialChecked: t.checked != null ? t.checked : t.defaultChecked,
        initialValue: Jn(t.value != null ? t.value : i),
        controlled: xd(t)
      };
    }
    function wd(e, t) {
      var r = e, i = t.checked;
      i != null && Ht(r, "checked", i, !1);
    }
    function pc(e, t) {
      var r = e;
      {
        var i = xd(t);
        !r._wrapperState.controlled && i && !Bu && (y("A component is changing an uncontrolled input to be controlled. This is likely caused by the value changing from undefined to a defined value, which should not happen. Decide between using a controlled or uncontrolled input element for the lifetime of the component. More info: https://reactjs.org/link/controlled-components"), Bu = !0), r._wrapperState.controlled && !i && !Rd && (y("A component is changing a controlled input to be uncontrolled. This is likely caused by the value changing from a defined to undefined, which should not happen. Decide between using a controlled or uncontrolled input element for the lifetime of the component. More info: https://reactjs.org/link/controlled-components"), Rd = !0);
      }
      wd(e, t);
      var o = Jn(t.value), s = t.type;
      if (o != null)
        s === "number" ? (o === 0 && r.value === "" || // We explicitly want to coerce to number here if possible.
        // eslint-disable-next-line
        r.value != o) && (r.value = Zn(o)) : r.value !== Zn(o) && (r.value = Zn(o));
      else if (s === "submit" || s === "reset") {
        r.removeAttribute("value");
        return;
      }
      t.hasOwnProperty("value") ? wa(r, t.type, o) : t.hasOwnProperty("defaultValue") && wa(r, t.type, Jn(t.defaultValue)), t.checked == null && t.defaultChecked != null && (r.defaultChecked = !!t.defaultChecked);
    }
    function pl(e, t, r) {
      var i = e;
      if (t.hasOwnProperty("value") || t.hasOwnProperty("defaultValue")) {
        var o = t.type, s = o === "submit" || o === "reset";
        if (s && (t.value === void 0 || t.value === null))
          return;
        var d = Zn(i._wrapperState.initialValue);
        r || d !== i.value && (i.value = d), i.defaultValue = d;
      }
      var v = i.name;
      v !== "" && (i.name = ""), i.defaultChecked = !i.defaultChecked, i.defaultChecked = !!i._wrapperState.initialChecked, v !== "" && (i.name = v);
    }
    function kd(e, t) {
      var r = e;
      pc(r, t), Vu(r, t);
    }
    function Vu(e, t) {
      var r = t.name;
      if (t.type === "radio" && r != null) {
        for (var i = e; i.parentNode; )
          i = i.parentNode;
        for (var o = i.querySelectorAll("input[name=" + JSON.stringify("" + r) + '][type="radio"]'), s = 0; s < o.length; s++) {
          var d = o[s];
          if (!(d === e || d.form !== e.form)) {
            var v = Kp(d);
            if (!v)
              throw Error("ReactDOMInput: Mixing React and non-React radio inputs with the same `name` is not supported.");
            fc(d), pc(d, v);
          }
        }
      }
    }
    function wa(e, t, r) {
      // Focused number inputs synchronize on blur. See ChangeEventPlugin.js
      (t !== "number" || go(e.ownerDocument) !== e) && (r == null ? e.defaultValue = Zn(e._wrapperState.initialValue) : e.defaultValue !== Zn(r) && (e.defaultValue = Zn(r)));
    }
    var Iu = !1, Eo = !1;
    function ka(e) {
      var t = "";
      return c.Children.forEach(e, function(r) {
        r != null && (t += r);
      }), t;
    }
    function _d(e, t) {
      typeof t.children == "object" && t.children !== null && c.Children.forEach(t.children, function(r) {
        r != null && (typeof r == "string" || typeof r == "number" || typeof r.type == "string" && (Eo || (Eo = !0, y("Only strings and numbers are supported as <option> children."))));
      }), t.selected != null && !Iu && (y("Use the `defaultValue` or `value` props on <select> instead of setting `selected` on <option>."), Iu = !0);
    }
    function Nh(e, t) {
      t.value != null && e.setAttribute("value", Zn(Jn(t.value)));
    }
    function vc(e, t) {
      var r = p({
        children: void 0
      }, t), i = ka(t.children);
      return i && (r.children = i), r;
    }
    var hc;
    hc = !1;
    function Dd() {
      var e = fl();
      return e ? `

Check the render method of \`` + e + "`." : "";
    }
    var So = ["value", "defaultValue"];
    function Mh(e) {
      {
        dl("select", e);
        for (var t = 0; t < So.length; t++) {
          var r = So[t];
          if (e[r] != null) {
            var i = Array.isArray(e[r]);
            e.multiple && !i ? y("The `%s` prop supplied to <select> must be an array if `multiple` is true.%s", r, Dd()) : !e.multiple && i && y("The `%s` prop supplied to <select> must be a scalar value if `multiple` is false.%s", r, Dd());
          }
        }
      }
    }
    function vl(e, t, r, i) {
      var o = e.options;
      if (t) {
        for (var s = r, d = {}, v = 0; v < s.length; v++)
          d["$" + s[v]] = !0;
        for (var E = 0; E < o.length; E++) {
          var R = d.hasOwnProperty("$" + o[E].value);
          o[E].selected !== R && (o[E].selected = R), R && i && (o[E].defaultSelected = !0);
        }
      } else {
        for (var x = Zn(Jn(r)), U = null, k = 0; k < o.length; k++) {
          if (o[k].value === x) {
            o[k].selected = !0, i && (o[k].defaultSelected = !0);
            return;
          }
          U === null && !o[k].disabled && (U = o[k]);
        }
        U !== null && (U.selected = !0);
      }
    }
    function Co(e, t) {
      return p({}, t, {
        value: void 0
      });
    }
    function $u(e, t) {
      var r = e;
      Mh(t), r._wrapperState = {
        wasMultiple: !!t.multiple
      }, t.value !== void 0 && t.defaultValue !== void 0 && !hc && (y("Select elements must be either controlled or uncontrolled (specify either the value prop, or the defaultValue prop, but not both). Decide between using a controlled or uncontrolled select element and remove one of these props. More info: https://reactjs.org/link/controlled-components"), hc = !0);
    }
    function _a(e, t) {
      var r = e;
      r.multiple = !!t.multiple;
      var i = t.value;
      i != null ? vl(r, !!t.multiple, i, !1) : t.defaultValue != null && vl(r, !!t.multiple, t.defaultValue, !0);
    }
    function mc(e, t) {
      var r = e, i = r._wrapperState.wasMultiple;
      r._wrapperState.wasMultiple = !!t.multiple;
      var o = t.value;
      o != null ? vl(r, !!t.multiple, o, !1) : i !== !!t.multiple && (t.defaultValue != null ? vl(r, !!t.multiple, t.defaultValue, !0) : vl(r, !!t.multiple, t.multiple ? [] : "", !1));
    }
    function Wu(e, t) {
      var r = e, i = t.value;
      i != null && vl(r, !!t.multiple, i, !1);
    }
    var yc = !1;
    function hl(e, t) {
      var r = e;
      if (t.dangerouslySetInnerHTML != null)
        throw Error("`dangerouslySetInnerHTML` does not make sense on <textarea>.");
      var i = p({}, t, {
        value: void 0,
        defaultValue: void 0,
        children: Zn(r._wrapperState.initialValue)
      });
      return i;
    }
    function bo(e, t) {
      var r = e;
      dl("textarea", t), t.value !== void 0 && t.defaultValue !== void 0 && !yc && (y("%s contains a textarea with both value and defaultValue props. Textarea elements must be either controlled or uncontrolled (specify either the value prop, or the defaultValue prop, but not both). Decide between using a controlled or uncontrolled textarea and remove one of these props. More info: https://reactjs.org/link/controlled-components", fl() || "A component"), yc = !0);
      var i = t.value;
      if (i == null) {
        var o = t.children, s = t.defaultValue;
        if (o != null) {
          y("Use the `defaultValue` or `value` props instead of setting children on <textarea>.");
          {
            if (s != null)
              throw Error("If you supply `defaultValue` on a <textarea>, do not pass children.");
            if (Array.isArray(o)) {
              if (!(o.length <= 1))
                throw Error("<textarea> can only have at most one child.");
              o = o[0];
            }
            s = o;
          }
        }
        s == null && (s = ""), i = s;
      }
      r._wrapperState = {
        initialValue: Jn(i)
      };
    }
    function gc(e, t) {
      var r = e, i = Jn(t.value), o = Jn(t.defaultValue);
      if (i != null) {
        var s = Zn(i);
        s !== r.value && (r.value = s), t.defaultValue == null && r.defaultValue !== s && (r.defaultValue = s);
      }
      o != null && (r.defaultValue = Zn(o));
    }
    function Un(e, t) {
      var r = e, i = r.textContent;
      i === r._wrapperState.initialValue && i !== "" && i !== null && (r.value = i);
    }
    function ml(e, t) {
      gc(e, t);
    }
    var yl = "http://www.w3.org/1999/xhtml", gl = "http://www.w3.org/1998/Math/MathML", Ec = "http://www.w3.org/2000/svg", Yu = {
      html: yl,
      mathml: gl,
      svg: Ec
    };
    function To(e) {
      switch (e) {
        case "svg":
          return Ec;
        case "math":
          return gl;
        default:
          return yl;
      }
    }
    function gi(e, t) {
      return e == null || e === yl ? To(t) : e === Ec && t === "foreignObject" ? yl : e;
    }
    var qu = function(e) {
      return typeof MSApp < "u" && MSApp.execUnsafeLocalFunction ? function(t, r, i, o) {
        MSApp.execUnsafeLocalFunction(function() {
          return e(t, r, i, o);
        });
      } : e;
    }, Ro, Od = qu(function(e, t) {
      if (e.namespaceURI === Yu.svg && !("innerHTML" in e)) {
        Ro = Ro || document.createElement("div"), Ro.innerHTML = "<svg>" + t.valueOf().toString() + "</svg>";
        for (var r = Ro.firstChild; e.firstChild; )
          e.removeChild(e.firstChild);
        for (; r.firstChild; )
          e.appendChild(r.firstChild);
        return;
      }
      e.innerHTML = t;
    }), er = 1, Zr = 3, wn = 8, Da = 9, Nd = 11, Qu = function(e, t) {
      if (t) {
        var r = e.firstChild;
        if (r && r === e.lastChild && r.nodeType === Zr) {
          r.nodeValue = t;
          return;
        }
      }
      e.textContent = t;
    }, Lh = {
      animation: ["animationDelay", "animationDirection", "animationDuration", "animationFillMode", "animationIterationCount", "animationName", "animationPlayState", "animationTimingFunction"],
      background: ["backgroundAttachment", "backgroundClip", "backgroundColor", "backgroundImage", "backgroundOrigin", "backgroundPositionX", "backgroundPositionY", "backgroundRepeat", "backgroundSize"],
      backgroundPosition: ["backgroundPositionX", "backgroundPositionY"],
      border: ["borderBottomColor", "borderBottomStyle", "borderBottomWidth", "borderImageOutset", "borderImageRepeat", "borderImageSlice", "borderImageSource", "borderImageWidth", "borderLeftColor", "borderLeftStyle", "borderLeftWidth", "borderRightColor", "borderRightStyle", "borderRightWidth", "borderTopColor", "borderTopStyle", "borderTopWidth"],
      borderBlockEnd: ["borderBlockEndColor", "borderBlockEndStyle", "borderBlockEndWidth"],
      borderBlockStart: ["borderBlockStartColor", "borderBlockStartStyle", "borderBlockStartWidth"],
      borderBottom: ["borderBottomColor", "borderBottomStyle", "borderBottomWidth"],
      borderColor: ["borderBottomColor", "borderLeftColor", "borderRightColor", "borderTopColor"],
      borderImage: ["borderImageOutset", "borderImageRepeat", "borderImageSlice", "borderImageSource", "borderImageWidth"],
      borderInlineEnd: ["borderInlineEndColor", "borderInlineEndStyle", "borderInlineEndWidth"],
      borderInlineStart: ["borderInlineStartColor", "borderInlineStartStyle", "borderInlineStartWidth"],
      borderLeft: ["borderLeftColor", "borderLeftStyle", "borderLeftWidth"],
      borderRadius: ["borderBottomLeftRadius", "borderBottomRightRadius", "borderTopLeftRadius", "borderTopRightRadius"],
      borderRight: ["borderRightColor", "borderRightStyle", "borderRightWidth"],
      borderStyle: ["borderBottomStyle", "borderLeftStyle", "borderRightStyle", "borderTopStyle"],
      borderTop: ["borderTopColor", "borderTopStyle", "borderTopWidth"],
      borderWidth: ["borderBottomWidth", "borderLeftWidth", "borderRightWidth", "borderTopWidth"],
      columnRule: ["columnRuleColor", "columnRuleStyle", "columnRuleWidth"],
      columns: ["columnCount", "columnWidth"],
      flex: ["flexBasis", "flexGrow", "flexShrink"],
      flexFlow: ["flexDirection", "flexWrap"],
      font: ["fontFamily", "fontFeatureSettings", "fontKerning", "fontLanguageOverride", "fontSize", "fontSizeAdjust", "fontStretch", "fontStyle", "fontVariant", "fontVariantAlternates", "fontVariantCaps", "fontVariantEastAsian", "fontVariantLigatures", "fontVariantNumeric", "fontVariantPosition", "fontWeight", "lineHeight"],
      fontVariant: ["fontVariantAlternates", "fontVariantCaps", "fontVariantEastAsian", "fontVariantLigatures", "fontVariantNumeric", "fontVariantPosition"],
      gap: ["columnGap", "rowGap"],
      grid: ["gridAutoColumns", "gridAutoFlow", "gridAutoRows", "gridTemplateAreas", "gridTemplateColumns", "gridTemplateRows"],
      gridArea: ["gridColumnEnd", "gridColumnStart", "gridRowEnd", "gridRowStart"],
      gridColumn: ["gridColumnEnd", "gridColumnStart"],
      gridColumnGap: ["columnGap"],
      gridGap: ["columnGap", "rowGap"],
      gridRow: ["gridRowEnd", "gridRowStart"],
      gridRowGap: ["rowGap"],
      gridTemplate: ["gridTemplateAreas", "gridTemplateColumns", "gridTemplateRows"],
      listStyle: ["listStyleImage", "listStylePosition", "listStyleType"],
      margin: ["marginBottom", "marginLeft", "marginRight", "marginTop"],
      marker: ["markerEnd", "markerMid", "markerStart"],
      mask: ["maskClip", "maskComposite", "maskImage", "maskMode", "maskOrigin", "maskPositionX", "maskPositionY", "maskRepeat", "maskSize"],
      maskPosition: ["maskPositionX", "maskPositionY"],
      outline: ["outlineColor", "outlineStyle", "outlineWidth"],
      overflow: ["overflowX", "overflowY"],
      padding: ["paddingBottom", "paddingLeft", "paddingRight", "paddingTop"],
      placeContent: ["alignContent", "justifyContent"],
      placeItems: ["alignItems", "justifyItems"],
      placeSelf: ["alignSelf", "justifySelf"],
      textDecoration: ["textDecorationColor", "textDecorationLine", "textDecorationStyle"],
      textEmphasis: ["textEmphasisColor", "textEmphasisStyle"],
      transition: ["transitionDelay", "transitionDuration", "transitionProperty", "transitionTimingFunction"],
      wordWrap: ["overflowWrap"]
    }, xo = {
      animationIterationCount: !0,
      borderImageOutset: !0,
      borderImageSlice: !0,
      borderImageWidth: !0,
      boxFlex: !0,
      boxFlexGroup: !0,
      boxOrdinalGroup: !0,
      columnCount: !0,
      columns: !0,
      flex: !0,
      flexGrow: !0,
      flexPositive: !0,
      flexShrink: !0,
      flexNegative: !0,
      flexOrder: !0,
      gridArea: !0,
      gridRow: !0,
      gridRowEnd: !0,
      gridRowSpan: !0,
      gridRowStart: !0,
      gridColumn: !0,
      gridColumnEnd: !0,
      gridColumnSpan: !0,
      gridColumnStart: !0,
      fontWeight: !0,
      lineClamp: !0,
      lineHeight: !0,
      opacity: !0,
      order: !0,
      orphans: !0,
      tabSize: !0,
      widows: !0,
      zIndex: !0,
      zoom: !0,
      // SVG-related properties
      fillOpacity: !0,
      floodOpacity: !0,
      stopOpacity: !0,
      strokeDasharray: !0,
      strokeDashoffset: !0,
      strokeMiterlimit: !0,
      strokeOpacity: !0,
      strokeWidth: !0
    };
    function Md(e, t) {
      return e + t.charAt(0).toUpperCase() + t.substring(1);
    }
    var Ah = ["Webkit", "ms", "Moz", "O"];
    Object.keys(xo).forEach(function(e) {
      Ah.forEach(function(t) {
        xo[Md(t, e)] = xo[e];
      });
    });
    function Sc(e, t, r) {
      var i = t == null || typeof t == "boolean" || t === "";
      return i ? "" : !r && typeof t == "number" && t !== 0 && !(xo.hasOwnProperty(e) && xo[e]) ? t + "px" : ("" + t).trim();
    }
    var Uh = /([A-Z])/g, zh = /^ms-/;
    function Cc(e) {
      return e.replace(Uh, "-$1").toLowerCase().replace(zh, "-ms-");
    }
    var Ld = function() {
    };
    {
      var jh = /^(?:webkit|moz|o)[A-Z]/, Fh = /^-ms-/, Ad = /-(.)/g, Ud = /;\s*$/, El = {}, bc = {}, zd = !1, jd = !1, Hh = function(e) {
        return e.replace(Ad, function(t, r) {
          return r.toUpperCase();
        });
      }, Ph = function(e) {
        El.hasOwnProperty(e) && El[e] || (El[e] = !0, y(
          "Unsupported style property %s. Did you mean %s?",
          e,
          // As Andi Smith suggests
          // (http://www.andismith.com/blog/2012/02/modernizr-prefixed/), an `-ms` prefix
          // is converted to lowercase `ms`.
          Hh(e.replace(Fh, "ms-"))
        ));
      }, Tc = function(e) {
        El.hasOwnProperty(e) && El[e] || (El[e] = !0, y("Unsupported vendor-prefixed style property %s. Did you mean %s?", e, e.charAt(0).toUpperCase() + e.slice(1)));
      }, wo = function(e, t) {
        bc.hasOwnProperty(t) && bc[t] || (bc[t] = !0, y(`Style property values shouldn't contain a semicolon. Try "%s: %s" instead.`, e, t.replace(Ud, "")));
      }, Bh = function(e, t) {
        zd || (zd = !0, y("`NaN` is an invalid value for the `%s` css style property.", e));
      }, Fd = function(e, t) {
        jd || (jd = !0, y("`Infinity` is an invalid value for the `%s` css style property.", e));
      };
      Ld = function(e, t) {
        e.indexOf("-") > -1 ? Ph(e) : jh.test(e) ? Tc(e) : Ud.test(t) && wo(e, t), typeof t == "number" && (isNaN(t) ? Bh(e, t) : isFinite(t) || Fd(e, t));
      };
    }
    var Hd = Ld;
    function Pd(e) {
      {
        var t = "", r = "";
        for (var i in e)
          if (e.hasOwnProperty(i)) {
            var o = e[i];
            if (o != null) {
              var s = i.indexOf("--") === 0;
              t += r + (s ? i : Cc(i)) + ":", t += Sc(i, o, s), r = ";";
            }
          }
        return t || null;
      }
    }
    function Rc(e, t) {
      var r = e.style;
      for (var i in t)
        if (t.hasOwnProperty(i)) {
          var o = i.indexOf("--") === 0;
          o || Hd(i, t[i]);
          var s = Sc(i, t[i], o);
          i === "float" && (i = "cssFloat"), o ? r.setProperty(i, s) : r[i] = s;
        }
    }
    function Bd(e) {
      return e == null || typeof e == "boolean" || e === "";
    }
    function Ei(e) {
      var t = {};
      for (var r in e)
        for (var i = Lh[r] || [r], o = 0; o < i.length; o++)
          t[i[o]] = r;
      return t;
    }
    function Vh(e, t) {
      {
        if (!t)
          return;
        var r = Ei(e), i = Ei(t), o = {};
        for (var s in r) {
          var d = r[s], v = i[s];
          if (v && d !== v) {
            var E = d + "," + v;
            if (o[E])
              continue;
            o[E] = !0, y("%s a style property during rerender (%s) when a conflicting property is set (%s) can lead to styling bugs. To avoid this, don't mix shorthand and non-shorthand properties for the same value; instead, replace the shorthand with separate values.", Bd(e[d]) ? "Removing" : "Updating", d, v);
          }
        }
      }
    }
    var Ih = {
      area: !0,
      base: !0,
      br: !0,
      col: !0,
      embed: !0,
      hr: !0,
      img: !0,
      input: !0,
      keygen: !0,
      link: !0,
      meta: !0,
      param: !0,
      source: !0,
      track: !0,
      wbr: !0
      // NOTE: menuitem's close tag should be omitted, but that causes problems.
    }, $h = p({
      menuitem: !0
    }, Ih), Vd = "__html";
    function Gu(e, t) {
      if (t) {
        if ($h[e] && !(t.children == null && t.dangerouslySetInnerHTML == null))
          throw Error(e + " is a void element tag and must neither have `children` nor use `dangerouslySetInnerHTML`.");
        if (t.dangerouslySetInnerHTML != null) {
          if (t.children != null)
            throw Error("Can only set one of `children` or `props.dangerouslySetInnerHTML`.");
          if (!(typeof t.dangerouslySetInnerHTML == "object" && Vd in t.dangerouslySetInnerHTML))
            throw Error("`props.dangerouslySetInnerHTML` must be in the form `{__html: ...}`. Please visit https://reactjs.org/link/dangerously-set-inner-html for more information.");
        }
        if (!t.suppressContentEditableWarning && t.contentEditable && t.children != null && y("A component is `contentEditable` and contains `children` managed by React. It is now your responsibility to guarantee that none of those nodes are unexpectedly modified or duplicated. This is probably not intentional."), !(t.style == null || typeof t.style == "object"))
          throw Error("The `style` prop expects a mapping from style properties to values, not a string. For example, style={{marginRight: spacing + 'em'}} when using JSX.");
      }
    }
    function vr(e, t) {
      if (e.indexOf("-") === -1)
        return typeof t.is == "string";
      switch (e) {
        case "annotation-xml":
        case "color-profile":
        case "font-face":
        case "font-face-src":
        case "font-face-uri":
        case "font-face-format":
        case "font-face-name":
        case "missing-glyph":
          return !1;
        default:
          return !0;
      }
    }
    var Oa = {
      // HTML
      accept: "accept",
      acceptcharset: "acceptCharset",
      "accept-charset": "acceptCharset",
      accesskey: "accessKey",
      action: "action",
      allowfullscreen: "allowFullScreen",
      alt: "alt",
      as: "as",
      async: "async",
      autocapitalize: "autoCapitalize",
      autocomplete: "autoComplete",
      autocorrect: "autoCorrect",
      autofocus: "autoFocus",
      autoplay: "autoPlay",
      autosave: "autoSave",
      capture: "capture",
      cellpadding: "cellPadding",
      cellspacing: "cellSpacing",
      challenge: "challenge",
      charset: "charSet",
      checked: "checked",
      children: "children",
      cite: "cite",
      class: "className",
      classid: "classID",
      classname: "className",
      cols: "cols",
      colspan: "colSpan",
      content: "content",
      contenteditable: "contentEditable",
      contextmenu: "contextMenu",
      controls: "controls",
      controlslist: "controlsList",
      coords: "coords",
      crossorigin: "crossOrigin",
      dangerouslysetinnerhtml: "dangerouslySetInnerHTML",
      data: "data",
      datetime: "dateTime",
      default: "default",
      defaultchecked: "defaultChecked",
      defaultvalue: "defaultValue",
      defer: "defer",
      dir: "dir",
      disabled: "disabled",
      disablepictureinpicture: "disablePictureInPicture",
      disableremoteplayback: "disableRemotePlayback",
      download: "download",
      draggable: "draggable",
      enctype: "encType",
      enterkeyhint: "enterKeyHint",
      for: "htmlFor",
      form: "form",
      formmethod: "formMethod",
      formaction: "formAction",
      formenctype: "formEncType",
      formnovalidate: "formNoValidate",
      formtarget: "formTarget",
      frameborder: "frameBorder",
      headers: "headers",
      height: "height",
      hidden: "hidden",
      high: "high",
      href: "href",
      hreflang: "hrefLang",
      htmlfor: "htmlFor",
      httpequiv: "httpEquiv",
      "http-equiv": "httpEquiv",
      icon: "icon",
      id: "id",
      innerhtml: "innerHTML",
      inputmode: "inputMode",
      integrity: "integrity",
      is: "is",
      itemid: "itemID",
      itemprop: "itemProp",
      itemref: "itemRef",
      itemscope: "itemScope",
      itemtype: "itemType",
      keyparams: "keyParams",
      keytype: "keyType",
      kind: "kind",
      label: "label",
      lang: "lang",
      list: "list",
      loop: "loop",
      low: "low",
      manifest: "manifest",
      marginwidth: "marginWidth",
      marginheight: "marginHeight",
      max: "max",
      maxlength: "maxLength",
      media: "media",
      mediagroup: "mediaGroup",
      method: "method",
      min: "min",
      minlength: "minLength",
      multiple: "multiple",
      muted: "muted",
      name: "name",
      nomodule: "noModule",
      nonce: "nonce",
      novalidate: "noValidate",
      open: "open",
      optimum: "optimum",
      pattern: "pattern",
      placeholder: "placeholder",
      playsinline: "playsInline",
      poster: "poster",
      preload: "preload",
      profile: "profile",
      radiogroup: "radioGroup",
      readonly: "readOnly",
      referrerpolicy: "referrerPolicy",
      rel: "rel",
      required: "required",
      reversed: "reversed",
      role: "role",
      rows: "rows",
      rowspan: "rowSpan",
      sandbox: "sandbox",
      scope: "scope",
      scoped: "scoped",
      scrolling: "scrolling",
      seamless: "seamless",
      selected: "selected",
      shape: "shape",
      size: "size",
      sizes: "sizes",
      span: "span",
      spellcheck: "spellCheck",
      src: "src",
      srcdoc: "srcDoc",
      srclang: "srcLang",
      srcset: "srcSet",
      start: "start",
      step: "step",
      style: "style",
      summary: "summary",
      tabindex: "tabIndex",
      target: "target",
      title: "title",
      type: "type",
      usemap: "useMap",
      value: "value",
      width: "width",
      wmode: "wmode",
      wrap: "wrap",
      // SVG
      about: "about",
      accentheight: "accentHeight",
      "accent-height": "accentHeight",
      accumulate: "accumulate",
      additive: "additive",
      alignmentbaseline: "alignmentBaseline",
      "alignment-baseline": "alignmentBaseline",
      allowreorder: "allowReorder",
      alphabetic: "alphabetic",
      amplitude: "amplitude",
      arabicform: "arabicForm",
      "arabic-form": "arabicForm",
      ascent: "ascent",
      attributename: "attributeName",
      attributetype: "attributeType",
      autoreverse: "autoReverse",
      azimuth: "azimuth",
      basefrequency: "baseFrequency",
      baselineshift: "baselineShift",
      "baseline-shift": "baselineShift",
      baseprofile: "baseProfile",
      bbox: "bbox",
      begin: "begin",
      bias: "bias",
      by: "by",
      calcmode: "calcMode",
      capheight: "capHeight",
      "cap-height": "capHeight",
      clip: "clip",
      clippath: "clipPath",
      "clip-path": "clipPath",
      clippathunits: "clipPathUnits",
      cliprule: "clipRule",
      "clip-rule": "clipRule",
      color: "color",
      colorinterpolation: "colorInterpolation",
      "color-interpolation": "colorInterpolation",
      colorinterpolationfilters: "colorInterpolationFilters",
      "color-interpolation-filters": "colorInterpolationFilters",
      colorprofile: "colorProfile",
      "color-profile": "colorProfile",
      colorrendering: "colorRendering",
      "color-rendering": "colorRendering",
      contentscripttype: "contentScriptType",
      contentstyletype: "contentStyleType",
      cursor: "cursor",
      cx: "cx",
      cy: "cy",
      d: "d",
      datatype: "datatype",
      decelerate: "decelerate",
      descent: "descent",
      diffuseconstant: "diffuseConstant",
      direction: "direction",
      display: "display",
      divisor: "divisor",
      dominantbaseline: "dominantBaseline",
      "dominant-baseline": "dominantBaseline",
      dur: "dur",
      dx: "dx",
      dy: "dy",
      edgemode: "edgeMode",
      elevation: "elevation",
      enablebackground: "enableBackground",
      "enable-background": "enableBackground",
      end: "end",
      exponent: "exponent",
      externalresourcesrequired: "externalResourcesRequired",
      fill: "fill",
      fillopacity: "fillOpacity",
      "fill-opacity": "fillOpacity",
      fillrule: "fillRule",
      "fill-rule": "fillRule",
      filter: "filter",
      filterres: "filterRes",
      filterunits: "filterUnits",
      floodopacity: "floodOpacity",
      "flood-opacity": "floodOpacity",
      floodcolor: "floodColor",
      "flood-color": "floodColor",
      focusable: "focusable",
      fontfamily: "fontFamily",
      "font-family": "fontFamily",
      fontsize: "fontSize",
      "font-size": "fontSize",
      fontsizeadjust: "fontSizeAdjust",
      "font-size-adjust": "fontSizeAdjust",
      fontstretch: "fontStretch",
      "font-stretch": "fontStretch",
      fontstyle: "fontStyle",
      "font-style": "fontStyle",
      fontvariant: "fontVariant",
      "font-variant": "fontVariant",
      fontweight: "fontWeight",
      "font-weight": "fontWeight",
      format: "format",
      from: "from",
      fx: "fx",
      fy: "fy",
      g1: "g1",
      g2: "g2",
      glyphname: "glyphName",
      "glyph-name": "glyphName",
      glyphorientationhorizontal: "glyphOrientationHorizontal",
      "glyph-orientation-horizontal": "glyphOrientationHorizontal",
      glyphorientationvertical: "glyphOrientationVertical",
      "glyph-orientation-vertical": "glyphOrientationVertical",
      glyphref: "glyphRef",
      gradienttransform: "gradientTransform",
      gradientunits: "gradientUnits",
      hanging: "hanging",
      horizadvx: "horizAdvX",
      "horiz-adv-x": "horizAdvX",
      horizoriginx: "horizOriginX",
      "horiz-origin-x": "horizOriginX",
      ideographic: "ideographic",
      imagerendering: "imageRendering",
      "image-rendering": "imageRendering",
      in2: "in2",
      in: "in",
      inlist: "inlist",
      intercept: "intercept",
      k1: "k1",
      k2: "k2",
      k3: "k3",
      k4: "k4",
      k: "k",
      kernelmatrix: "kernelMatrix",
      kernelunitlength: "kernelUnitLength",
      kerning: "kerning",
      keypoints: "keyPoints",
      keysplines: "keySplines",
      keytimes: "keyTimes",
      lengthadjust: "lengthAdjust",
      letterspacing: "letterSpacing",
      "letter-spacing": "letterSpacing",
      lightingcolor: "lightingColor",
      "lighting-color": "lightingColor",
      limitingconeangle: "limitingConeAngle",
      local: "local",
      markerend: "markerEnd",
      "marker-end": "markerEnd",
      markerheight: "markerHeight",
      markermid: "markerMid",
      "marker-mid": "markerMid",
      markerstart: "markerStart",
      "marker-start": "markerStart",
      markerunits: "markerUnits",
      markerwidth: "markerWidth",
      mask: "mask",
      maskcontentunits: "maskContentUnits",
      maskunits: "maskUnits",
      mathematical: "mathematical",
      mode: "mode",
      numoctaves: "numOctaves",
      offset: "offset",
      opacity: "opacity",
      operator: "operator",
      order: "order",
      orient: "orient",
      orientation: "orientation",
      origin: "origin",
      overflow: "overflow",
      overlineposition: "overlinePosition",
      "overline-position": "overlinePosition",
      overlinethickness: "overlineThickness",
      "overline-thickness": "overlineThickness",
      paintorder: "paintOrder",
      "paint-order": "paintOrder",
      panose1: "panose1",
      "panose-1": "panose1",
      pathlength: "pathLength",
      patterncontentunits: "patternContentUnits",
      patterntransform: "patternTransform",
      patternunits: "patternUnits",
      pointerevents: "pointerEvents",
      "pointer-events": "pointerEvents",
      points: "points",
      pointsatx: "pointsAtX",
      pointsaty: "pointsAtY",
      pointsatz: "pointsAtZ",
      prefix: "prefix",
      preservealpha: "preserveAlpha",
      preserveaspectratio: "preserveAspectRatio",
      primitiveunits: "primitiveUnits",
      property: "property",
      r: "r",
      radius: "radius",
      refx: "refX",
      refy: "refY",
      renderingintent: "renderingIntent",
      "rendering-intent": "renderingIntent",
      repeatcount: "repeatCount",
      repeatdur: "repeatDur",
      requiredextensions: "requiredExtensions",
      requiredfeatures: "requiredFeatures",
      resource: "resource",
      restart: "restart",
      result: "result",
      results: "results",
      rotate: "rotate",
      rx: "rx",
      ry: "ry",
      scale: "scale",
      security: "security",
      seed: "seed",
      shaperendering: "shapeRendering",
      "shape-rendering": "shapeRendering",
      slope: "slope",
      spacing: "spacing",
      specularconstant: "specularConstant",
      specularexponent: "specularExponent",
      speed: "speed",
      spreadmethod: "spreadMethod",
      startoffset: "startOffset",
      stddeviation: "stdDeviation",
      stemh: "stemh",
      stemv: "stemv",
      stitchtiles: "stitchTiles",
      stopcolor: "stopColor",
      "stop-color": "stopColor",
      stopopacity: "stopOpacity",
      "stop-opacity": "stopOpacity",
      strikethroughposition: "strikethroughPosition",
      "strikethrough-position": "strikethroughPosition",
      strikethroughthickness: "strikethroughThickness",
      "strikethrough-thickness": "strikethroughThickness",
      string: "string",
      stroke: "stroke",
      strokedasharray: "strokeDasharray",
      "stroke-dasharray": "strokeDasharray",
      strokedashoffset: "strokeDashoffset",
      "stroke-dashoffset": "strokeDashoffset",
      strokelinecap: "strokeLinecap",
      "stroke-linecap": "strokeLinecap",
      strokelinejoin: "strokeLinejoin",
      "stroke-linejoin": "strokeLinejoin",
      strokemiterlimit: "strokeMiterlimit",
      "stroke-miterlimit": "strokeMiterlimit",
      strokewidth: "strokeWidth",
      "stroke-width": "strokeWidth",
      strokeopacity: "strokeOpacity",
      "stroke-opacity": "strokeOpacity",
      suppresscontenteditablewarning: "suppressContentEditableWarning",
      suppresshydrationwarning: "suppressHydrationWarning",
      surfacescale: "surfaceScale",
      systemlanguage: "systemLanguage",
      tablevalues: "tableValues",
      targetx: "targetX",
      targety: "targetY",
      textanchor: "textAnchor",
      "text-anchor": "textAnchor",
      textdecoration: "textDecoration",
      "text-decoration": "textDecoration",
      textlength: "textLength",
      textrendering: "textRendering",
      "text-rendering": "textRendering",
      to: "to",
      transform: "transform",
      typeof: "typeof",
      u1: "u1",
      u2: "u2",
      underlineposition: "underlinePosition",
      "underline-position": "underlinePosition",
      underlinethickness: "underlineThickness",
      "underline-thickness": "underlineThickness",
      unicode: "unicode",
      unicodebidi: "unicodeBidi",
      "unicode-bidi": "unicodeBidi",
      unicoderange: "unicodeRange",
      "unicode-range": "unicodeRange",
      unitsperem: "unitsPerEm",
      "units-per-em": "unitsPerEm",
      unselectable: "unselectable",
      valphabetic: "vAlphabetic",
      "v-alphabetic": "vAlphabetic",
      values: "values",
      vectoreffect: "vectorEffect",
      "vector-effect": "vectorEffect",
      version: "version",
      vertadvy: "vertAdvY",
      "vert-adv-y": "vertAdvY",
      vertoriginx: "vertOriginX",
      "vert-origin-x": "vertOriginX",
      vertoriginy: "vertOriginY",
      "vert-origin-y": "vertOriginY",
      vhanging: "vHanging",
      "v-hanging": "vHanging",
      videographic: "vIdeographic",
      "v-ideographic": "vIdeographic",
      viewbox: "viewBox",
      viewtarget: "viewTarget",
      visibility: "visibility",
      vmathematical: "vMathematical",
      "v-mathematical": "vMathematical",
      vocab: "vocab",
      widths: "widths",
      wordspacing: "wordSpacing",
      "word-spacing": "wordSpacing",
      writingmode: "writingMode",
      "writing-mode": "writingMode",
      x1: "x1",
      x2: "x2",
      x: "x",
      xchannelselector: "xChannelSelector",
      xheight: "xHeight",
      "x-height": "xHeight",
      xlinkactuate: "xlinkActuate",
      "xlink:actuate": "xlinkActuate",
      xlinkarcrole: "xlinkArcrole",
      "xlink:arcrole": "xlinkArcrole",
      xlinkhref: "xlinkHref",
      "xlink:href": "xlinkHref",
      xlinkrole: "xlinkRole",
      "xlink:role": "xlinkRole",
      xlinkshow: "xlinkShow",
      "xlink:show": "xlinkShow",
      xlinktitle: "xlinkTitle",
      "xlink:title": "xlinkTitle",
      xlinktype: "xlinkType",
      "xlink:type": "xlinkType",
      xmlbase: "xmlBase",
      "xml:base": "xmlBase",
      xmllang: "xmlLang",
      "xml:lang": "xmlLang",
      xmlns: "xmlns",
      "xml:space": "xmlSpace",
      xmlnsxlink: "xmlnsXlink",
      "xmlns:xlink": "xmlnsXlink",
      xmlspace: "xmlSpace",
      y1: "y1",
      y2: "y2",
      y: "y",
      ychannelselector: "yChannelSelector",
      z: "z",
      zoomandpan: "zoomAndPan"
    }, Id = {
      "aria-current": 0,
      // state
      "aria-details": 0,
      "aria-disabled": 0,
      // state
      "aria-hidden": 0,
      // state
      "aria-invalid": 0,
      // state
      "aria-keyshortcuts": 0,
      "aria-label": 0,
      "aria-roledescription": 0,
      // Widget Attributes
      "aria-autocomplete": 0,
      "aria-checked": 0,
      "aria-expanded": 0,
      "aria-haspopup": 0,
      "aria-level": 0,
      "aria-modal": 0,
      "aria-multiline": 0,
      "aria-multiselectable": 0,
      "aria-orientation": 0,
      "aria-placeholder": 0,
      "aria-pressed": 0,
      "aria-readonly": 0,
      "aria-required": 0,
      "aria-selected": 0,
      "aria-sort": 0,
      "aria-valuemax": 0,
      "aria-valuemin": 0,
      "aria-valuenow": 0,
      "aria-valuetext": 0,
      // Live Region Attributes
      "aria-atomic": 0,
      "aria-busy": 0,
      "aria-live": 0,
      "aria-relevant": 0,
      // Drag-and-Drop Attributes
      "aria-dropeffect": 0,
      "aria-grabbed": 0,
      // Relationship Attributes
      "aria-activedescendant": 0,
      "aria-colcount": 0,
      "aria-colindex": 0,
      "aria-colspan": 0,
      "aria-controls": 0,
      "aria-describedby": 0,
      "aria-errormessage": 0,
      "aria-flowto": 0,
      "aria-labelledby": 0,
      "aria-owns": 0,
      "aria-posinset": 0,
      "aria-rowcount": 0,
      "aria-rowindex": 0,
      "aria-rowspan": 0,
      "aria-setsize": 0
    }, Jr = {}, Wh = new RegExp("^(aria)-[" + tt + "]*$"), $d = new RegExp("^(aria)[A-Z][" + tt + "]*$"), xc = Object.prototype.hasOwnProperty;
    function wc(e, t) {
      {
        if (xc.call(Jr, t) && Jr[t])
          return !0;
        if ($d.test(t)) {
          var r = "aria-" + t.slice(4).toLowerCase(), i = Id.hasOwnProperty(r) ? r : null;
          if (i == null)
            return y("Invalid ARIA attribute `%s`. ARIA attributes follow the pattern aria-* and must be lowercase.", t), Jr[t] = !0, !0;
          if (t !== i)
            return y("Invalid ARIA attribute `%s`. Did you mean `%s`?", t, i), Jr[t] = !0, !0;
        }
        if (Wh.test(t)) {
          var o = t.toLowerCase(), s = Id.hasOwnProperty(o) ? o : null;
          if (s == null)
            return Jr[t] = !0, !1;
          if (t !== s)
            return y("Unknown ARIA attribute `%s`. Did you mean `%s`?", t, s), Jr[t] = !0, !0;
        }
      }
      return !0;
    }
    function Wd(e, t) {
      {
        var r = [];
        for (var i in t) {
          var o = wc(e, i);
          o || r.push(i);
        }
        var s = r.map(function(d) {
          return "`" + d + "`";
        }).join(", ");
        r.length === 1 ? y("Invalid aria prop %s on <%s> tag. For details, see https://reactjs.org/link/invalid-aria-props", s, e) : r.length > 1 && y("Invalid aria props %s on <%s> tag. For details, see https://reactjs.org/link/invalid-aria-props", s, e);
      }
    }
    function Yd(e, t) {
      vr(e, t) || Wd(e, t);
    }
    var kc = !1;
    function Yh(e, t) {
      {
        if (e !== "input" && e !== "textarea" && e !== "select")
          return;
        t != null && t.value === null && !kc && (kc = !0, e === "select" && t.multiple ? y("`value` prop on `%s` should not be null. Consider using an empty array when `multiple` is set to `true` to clear the component or `undefined` for uncontrolled components.", e) : y("`value` prop on `%s` should not be null. Consider using an empty string to clear the component or `undefined` for uncontrolled components.", e));
      }
    }
    var qd = function() {
    };
    {
      var kn = {}, qh = Object.prototype.hasOwnProperty, Qd = /^on./, tr = /^on[^A-Z]/, Qh = new RegExp("^(aria)-[" + tt + "]*$"), ko = new RegExp("^(aria)[A-Z][" + tt + "]*$");
      qd = function(e, t, r, i) {
        if (qh.call(kn, t) && kn[t])
          return !0;
        var o = t.toLowerCase();
        if (o === "onfocusin" || o === "onfocusout")
          return y("React uses onFocus and onBlur instead of onFocusIn and onFocusOut. All React events are normalized to bubble, so onFocusIn and onFocusOut are not needed/supported by React."), kn[t] = !0, !0;
        if (i != null) {
          var s = i.registrationNameDependencies, d = i.possibleRegistrationNames;
          if (s.hasOwnProperty(t))
            return !0;
          var v = d.hasOwnProperty(o) ? d[o] : null;
          if (v != null)
            return y("Invalid event handler property `%s`. Did you mean `%s`?", t, v), kn[t] = !0, !0;
          if (Qd.test(t))
            return y("Unknown event handler property `%s`. It will be ignored.", t), kn[t] = !0, !0;
        } else if (Qd.test(t))
          return tr.test(t) && y("Invalid event handler property `%s`. React events use the camelCase naming convention, for example `onClick`.", t), kn[t] = !0, !0;
        if (Qh.test(t) || ko.test(t))
          return !0;
        if (o === "innerhtml")
          return y("Directly setting property `innerHTML` is not permitted. For more information, lookup documentation on `dangerouslySetInnerHTML`."), kn[t] = !0, !0;
        if (o === "aria")
          return y("The `aria` attribute is reserved for future use in React. Pass individual `aria-` attributes instead."), kn[t] = !0, !0;
        if (o === "is" && r !== null && r !== void 0 && typeof r != "string")
          return y("Received a `%s` for a string attribute `is`. If this is expected, cast the value to a string.", typeof r), kn[t] = !0, !0;
        if (typeof r == "number" && isNaN(r))
          return y("Received NaN for the `%s` attribute. If this is expected, cast the value to a string.", t), kn[t] = !0, !0;
        var E = di(t), R = E !== null && E.type === Oe;
        if (Oa.hasOwnProperty(o)) {
          var x = Oa[o];
          if (x !== t)
            return y("Invalid DOM property `%s`. Did you mean `%s`?", t, x), kn[t] = !0, !0;
        } else if (!R && t !== o)
          return y("React does not recognize the `%s` prop on a DOM element. If you intentionally want it to appear in the DOM as a custom attribute, spell it as lowercase `%s` instead. If you accidentally passed it from a parent component, remove it from the DOM element.", t, o), kn[t] = !0, !0;
        return typeof r == "boolean" && ci(t, r, E, !1) ? (r ? y('Received `%s` for a non-boolean attribute `%s`.\n\nIf you want to write it to the DOM, pass a string instead: %s="%s" or %s={value.toString()}.', r, t, t, r, t) : y('Received `%s` for a non-boolean attribute `%s`.\n\nIf you want to write it to the DOM, pass a string instead: %s="%s" or %s={value.toString()}.\n\nIf you used to conditionally omit it with %s={condition && value}, pass %s={condition ? value : undefined} instead.', r, t, t, r, t, t, t), kn[t] = !0, !0) : R ? !0 : ci(t, r, E, !1) ? (kn[t] = !0, !1) : ((r === "false" || r === "true") && E !== null && E.type === Fe && (y("Received the string `%s` for the boolean attribute `%s`. %s Did you mean %s={%s}?", r, t, r === "false" ? "The browser will interpret it as a truthy value." : 'Although this works, it will not work as expected if you pass the string "false".', t, r), kn[t] = !0), !0);
      };
    }
    var Gd = function(e, t, r) {
      {
        var i = [];
        for (var o in t) {
          var s = qd(e, o, t[o], r);
          s || i.push(o);
        }
        var d = i.map(function(v) {
          return "`" + v + "`";
        }).join(", ");
        i.length === 1 ? y("Invalid value for prop %s on <%s> tag. Either remove it from the element, or pass a string or number value to keep it in the DOM. For details, see https://reactjs.org/link/attribute-behavior ", d, e) : i.length > 1 && y("Invalid values for props %s on <%s> tag. Either remove them from the element, or pass a string or number value to keep them in the DOM. For details, see https://reactjs.org/link/attribute-behavior ", d, e);
      }
    };
    function Xd(e, t, r) {
      vr(e, t) || Gd(e, t, r);
    }
    var _c = 1, Xu = 2, Si = 4, Kd = 16, Sl = _c | Xu | Si;
    function _o(e) {
      var t = e.target || e.srcElement || window;
      return t.correspondingUseElement && (t = t.correspondingUseElement), t.nodeType === Zr ? t.parentNode : t;
    }
    var Ci = null, Na = null, bi = null;
    function Dc(e) {
      var t = Yl(e);
      if (t) {
        if (typeof Ci != "function")
          throw Error("setRestoreImplementation() needs to be called to handle a target for controlled events. This error is likely caused by a bug in React. Please file an issue.");
        var r = t.stateNode;
        if (r) {
          var i = Kp(r);
          Ci(t.stateNode, t.type, i);
        }
      }
    }
    function Oc(e) {
      Ci = e;
    }
    function Cl(e) {
      Na ? bi ? bi.push(e) : bi = [e] : Na = e;
    }
    function Gh() {
      return Na !== null || bi !== null;
    }
    function Nc() {
      if (Na) {
        var e = Na, t = bi;
        if (Na = null, bi = null, Dc(e), t)
          for (var r = 0; r < t.length; r++)
            Dc(t[r]);
      }
    }
    var Ku = function(e, t) {
      return e(t);
    }, xt = function(e, t, r, i, o) {
      return e(t, r, i, o);
    }, Zu = function() {
    }, Mc = Ku, ea = !1, Ju = !1;
    function es() {
      var e = Gh();
      e && (Zu(), Nc());
    }
    function Do(e, t) {
      if (ea)
        return e(t);
      ea = !0;
      try {
        return Ku(e, t);
      } finally {
        ea = !1, es();
      }
    }
    function ts(e, t, r) {
      if (Ju)
        return e(t, r);
      Ju = !0;
      try {
        return Mc(e, t, r);
      } finally {
        Ju = !1, es();
      }
    }
    function bl(e, t, r, i, o) {
      var s = ea;
      ea = !0;
      try {
        return xt(e, t, r, i, o);
      } finally {
        ea = s, ea || es();
      }
    }
    function Zd(e) {
      ea || Zu();
    }
    function ns(e, t, r, i) {
      Ku = e, xt = t, Zu = r, Mc = i;
    }
    function Lc(e) {
      return e === "button" || e === "input" || e === "select" || e === "textarea";
    }
    function Ac(e, t, r) {
      switch (e) {
        case "onClick":
        case "onClickCapture":
        case "onDoubleClick":
        case "onDoubleClickCapture":
        case "onMouseDown":
        case "onMouseDownCapture":
        case "onMouseMove":
        case "onMouseMoveCapture":
        case "onMouseUp":
        case "onMouseUpCapture":
        case "onMouseEnter":
          return !!(r.disabled && Lc(t));
        default:
          return !1;
      }
    }
    function Tl(e, t) {
      var r = e.stateNode;
      if (r === null)
        return null;
      var i = Kp(r);
      if (i === null)
        return null;
      var o = i[t];
      if (Ac(t, e.type, i))
        return null;
      if (!(!o || typeof o == "function"))
        throw Error("Expected `" + t + "` listener to be a function, instead got a value of `" + typeof o + "` type.");
      return o;
    }
    var Oo = !1;
    if (Re)
      try {
        var Rl = {};
        Object.defineProperty(Rl, "passive", {
          get: function() {
            Oo = !0;
          }
        }), window.addEventListener("test", Rl, Rl), window.removeEventListener("test", Rl, Rl);
      } catch {
        Oo = !1;
      }
    function Jd(e, t, r, i, o, s, d, v, E) {
      var R = Array.prototype.slice.call(arguments, 3);
      try {
        t.apply(r, R);
      } catch (x) {
        this.onError(x);
      }
    }
    var rs = Jd;
    if (typeof window < "u" && typeof window.dispatchEvent == "function" && typeof document < "u" && typeof document.createEvent == "function") {
      var Ma = document.createElement("react");
      rs = function(t, r, i, o, s, d, v, E, R) {
        if (!(typeof document < "u"))
          throw Error("The `document` global was defined when React was initialized, but is not defined anymore. This can happen in a test environment if a component schedules an update from an asynchronous callback, but the test has already finished running. To solve this, you can either unmount the component at the end of your test (and ensure that any asynchronous operations get canceled in `componentWillUnmount`), or you can change the test itself to be asynchronous.");
        var x = document.createEvent("Event"), U = !1, k = !0, H = window.event, Q = Object.getOwnPropertyDescriptor(window, "event");
        function se() {
          Ma.removeEventListener(V, Xe, !1), typeof window.event < "u" && window.hasOwnProperty("event") && (window.event = H);
        }
        var Me = Array.prototype.slice.call(arguments, 3);
        function Xe() {
          U = !0, se(), r.apply(i, Me), k = !1;
        }
        var je, ft = !1, kt = !1;
        function j(N) {
          if (je = N.error, ft = !0, je === null && N.colno === 0 && N.lineno === 0 && (kt = !0), N.defaultPrevented && je != null && typeof je == "object")
            try {
              je._suppressLogging = !0;
            } catch {
            }
        }
        var V = "react-" + (t || "invokeguardedcallback");
        if (window.addEventListener("error", j), Ma.addEventListener(V, Xe, !1), x.initEvent(V, !1, !1), Ma.dispatchEvent(x), Q && Object.defineProperty(window, "event", Q), U && k && (ft ? kt && (je = new Error("A cross-origin error was thrown. React doesn't have access to the actual error object in development. See https://reactjs.org/link/crossorigin-error for more information.")) : je = new Error(`An error was thrown inside one of your components, but React doesn't know what it was. This is likely due to browser flakiness. React does its best to preserve the "Pause on exceptions" behavior of the DevTools, which requires some DEV-mode only tricks. It's possible that these don't work in your browser. Try triggering the error in production mode, or switching to a modern browser. If you suspect that this is actually an issue with React, please file an issue.`), this.onError(je)), window.removeEventListener("error", j), !U)
          return se(), Jd.apply(this, arguments);
      };
    }
    var ep = rs, La = !1, as = null, Ti = !1, Or = null, is = {
      onError: function(e) {
        La = !0, as = e;
      }
    };
    function _n(e, t, r, i, o, s, d, v, E) {
      La = !1, as = null, ep.apply(is, arguments);
    }
    function tp(e, t, r, i, o, s, d, v, E) {
      if (_n.apply(this, arguments), La) {
        var R = Dn();
        Ti || (Ti = !0, Or = R);
      }
    }
    function Ri() {
      if (Ti) {
        var e = Or;
        throw Ti = !1, Or = null, e;
      }
    }
    function In() {
      return La;
    }
    function Dn() {
      if (La) {
        var e = as;
        return La = !1, as = null, e;
      } else
        throw Error("clearCaughtError was called but no error was captured. This error is likely caused by a bug in React. Please file an issue.");
    }
    function ta(e) {
      return e._reactInternals;
    }
    function np(e) {
      return e._reactInternals !== void 0;
    }
    function Uc(e, t) {
      e._reactInternals = t;
    }
    var Et = (
      /*                      */
      0
    ), On = (
      /*                */
      1
    ), Ye = (
      /*                    */
      2
    ), Ue = (
      /*                       */
      4
    ), Aa = (
      /*           */
      6
    ), Dt = (
      /*                     */
      8
    ), vn = (
      /*                 */
      16
    ), Ua = (
      /*                     */
      32
    ), vt = (
      /*                   */
      64
    ), hn = (
      /*                          */
      128
    ), Nr = (
      /*                     */
      256
    ), xl = (
      /*                      */
      512
    ), wl = (
      /*     */
      8192
    ), nr = (
      /*                    */
      1024
    ), rp = (
      /*           */
      1028
    ), zc = (
      /*          */
      932
    ), xi = (
      /*               */
      2047
    ), No = (
      /*                   */
      2048
    ), hr = (
      /*                */
      4096
    ), Mo = (
      /* */
      16384
    ), Xh = b.ReactCurrentOwner;
    function za(e) {
      var t = e, r = e;
      if (e.alternate)
        for (; t.return; )
          t = t.return;
      else {
        var i = t;
        do
          t = i, (t.flags & (Ye | nr)) !== Et && (r = t.return), i = t.return;
        while (i);
      }
      return t.tag === B ? r : null;
    }
    function ls(e) {
      if (e.tag === z) {
        var t = e.memoizedState;
        if (t === null) {
          var r = e.alternate;
          r !== null && (t = r.memoizedState);
        }
        if (t !== null)
          return t.dehydrated;
      }
      return null;
    }
    function ap(e) {
      return e.tag === B ? e.stateNode.containerInfo : null;
    }
    function os(e) {
      return za(e) === e;
    }
    function ip(e) {
      {
        var t = Xh.current;
        if (t !== null && t.tag === L) {
          var r = t, i = r.stateNode;
          i._warnedAboutRefsInRender || y("%s is accessing isMounted inside its render() function. render() should be a pure function of props and state. It should never access something that requires stale data from the previous render, such as refs. Move this logic to componentDidMount and componentDidUpdate instead.", fe(r.type) || "A component"), i._warnedAboutRefsInRender = !0;
        }
      }
      var o = ta(e);
      return o ? za(o) === o : !1;
    }
    function jc(e) {
      if (za(e) !== e)
        throw Error("Unable to find node on an unmounted component.");
    }
    function Fc(e) {
      var t = e.alternate;
      if (!t) {
        var r = za(e);
        if (r === null)
          throw Error("Unable to find node on an unmounted component.");
        return r !== e ? null : e;
      }
      for (var i = e, o = t; ; ) {
        var s = i.return;
        if (s === null)
          break;
        var d = s.alternate;
        if (d === null) {
          var v = s.return;
          if (v !== null) {
            i = o = v;
            continue;
          }
          break;
        }
        if (s.child === d.child) {
          for (var E = s.child; E; ) {
            if (E === i)
              return jc(s), e;
            if (E === o)
              return jc(s), t;
            E = E.sibling;
          }
          throw Error("Unable to find node on an unmounted component.");
        }
        if (i.return !== o.return)
          i = s, o = d;
        else {
          for (var R = !1, x = s.child; x; ) {
            if (x === i) {
              R = !0, i = s, o = d;
              break;
            }
            if (x === o) {
              R = !0, o = s, i = d;
              break;
            }
            x = x.sibling;
          }
          if (!R) {
            for (x = d.child; x; ) {
              if (x === i) {
                R = !0, i = d, o = s;
                break;
              }
              if (x === o) {
                R = !0, o = d, i = s;
                break;
              }
              x = x.sibling;
            }
            if (!R)
              throw Error("Child was not found in either parent set. This indicates a bug in React related to the return pointer. Please file an issue.");
          }
        }
        if (i.alternate !== o)
          throw Error("Return fibers should always be each others' alternates. This error is likely caused by a bug in React. Please file an issue.");
      }
      if (i.tag !== B)
        throw Error("Unable to find node on an unmounted component.");
      return i.stateNode.current === i ? e : t;
    }
    function Hc(e) {
      var t = Fc(e);
      if (!t)
        return null;
      for (var r = t; ; ) {
        if (r.tag === re || r.tag === ue)
          return r;
        if (r.child) {
          r.child.return = r, r = r.child;
          continue;
        }
        if (r === t)
          return null;
        for (; !r.sibling; ) {
          if (!r.return || r.return === t)
            return null;
          r = r.return;
        }
        r.sibling.return = r.return, r = r.sibling;
      }
      return null;
    }
    function Pc(e) {
      var t = Fc(e);
      if (!t)
        return null;
      for (var r = t; ; ) {
        if (r.tag === re || r.tag === ue || Ke)
          return r;
        if (r.child && r.tag !== Y) {
          r.child.return = r, r = r.child;
          continue;
        }
        if (r === t)
          return null;
        for (; !r.sibling; ) {
          if (!r.return || r.return === t)
            return null;
          r = r.return;
        }
        r.sibling.return = r.return, r = r.sibling;
      }
      return null;
    }
    function lp(e, t) {
      for (var r = t, i = e.alternate; r !== null; ) {
        if (r === e || r === i)
          return !0;
        r = r.return;
      }
      return !1;
    }
    var Mr;
    function us(e) {
      Mr = e;
    }
    var Lo;
    function op(e) {
      Lo = e;
    }
    var mn;
    function kl(e) {
      mn = e;
    }
    var Bc;
    function wi(e) {
      Bc = e;
    }
    var ki = !1, rn = [], na = null, ja = null, an = null, Fa = /* @__PURE__ */ new Map(), Ha = /* @__PURE__ */ new Map(), Lr = [];
    function ss() {
      return rn.length > 0;
    }
    var Vc = [
      "mousedown",
      "mouseup",
      "touchcancel",
      "touchend",
      "touchstart",
      "auxclick",
      "dblclick",
      "pointercancel",
      "pointerdown",
      "pointerup",
      "dragend",
      "dragstart",
      "drop",
      "compositionend",
      "compositionstart",
      "keydown",
      "keypress",
      "keyup",
      "input",
      "textInput",
      // Intentionally camelCase
      "copy",
      "cut",
      "paste",
      "click",
      "change",
      "contextmenu",
      "reset",
      "submit"
    ];
    function cs(e) {
      return Vc.indexOf(e) > -1;
    }
    function Ic(e, t, r, i, o) {
      return {
        blockedOn: e,
        domEventName: t,
        eventSystemFlags: r | Kd,
        nativeEvent: o,
        targetContainers: [i]
      };
    }
    function _i(e, t, r, i, o) {
      var s = Ic(e, t, r, i, o);
      rn.push(s);
    }
    function $n(e, t) {
      switch (e) {
        case "focusin":
        case "focusout":
          na = null;
          break;
        case "dragenter":
        case "dragleave":
          ja = null;
          break;
        case "mouseover":
        case "mouseout":
          an = null;
          break;
        case "pointerover":
        case "pointerout": {
          var r = t.pointerId;
          Fa.delete(r);
          break;
        }
        case "gotpointercapture":
        case "lostpointercapture": {
          var i = t.pointerId;
          Ha.delete(i);
          break;
        }
      }
    }
    function rr(e, t, r, i, o, s) {
      if (e === null || e.nativeEvent !== s) {
        var d = Ic(t, r, i, o, s);
        if (t !== null) {
          var v = Yl(t);
          v !== null && Lo(v);
        }
        return d;
      }
      e.eventSystemFlags |= i;
      var E = e.targetContainers;
      return o !== null && E.indexOf(o) === -1 && E.push(o), e;
    }
    function $c(e, t, r, i, o) {
      switch (t) {
        case "focusin": {
          var s = o;
          return na = rr(na, e, t, r, i, s), !0;
        }
        case "dragenter": {
          var d = o;
          return ja = rr(ja, e, t, r, i, d), !0;
        }
        case "mouseover": {
          var v = o;
          return an = rr(an, e, t, r, i, v), !0;
        }
        case "pointerover": {
          var E = o, R = E.pointerId;
          return Fa.set(R, rr(Fa.get(R) || null, e, t, r, i, E)), !0;
        }
        case "gotpointercapture": {
          var x = o, U = x.pointerId;
          return Ha.set(U, rr(Ha.get(U) || null, e, t, r, i, x)), !0;
        }
      }
      return !1;
    }
    function up(e) {
      var t = cu(e.target);
      if (t !== null) {
        var r = za(t);
        if (r !== null) {
          var i = r.tag;
          if (i === z) {
            var o = ls(r);
            if (o !== null) {
              e.blockedOn = o, Bc(e.lanePriority, function() {
                g.unstable_runWithPriority(e.priority, function() {
                  mn(r);
                });
              });
              return;
            }
          } else if (i === B) {
            var s = r.stateNode;
            if (s.hydrate) {
              e.blockedOn = ap(r);
              return;
            }
          }
        }
      }
      e.blockedOn = null;
    }
    function mr(e) {
      if (e.blockedOn !== null)
        return !1;
      for (var t = e.targetContainers; t.length > 0; ) {
        var r = t[0], i = Xo(e.domEventName, e.eventSystemFlags, r, e.nativeEvent);
        if (i !== null) {
          var o = Yl(i);
          return o !== null && Lo(o), e.blockedOn = i, !1;
        }
        t.shift();
      }
      return !0;
    }
    function ra(e, t, r) {
      mr(e) && r.delete(t);
    }
    function sp() {
      for (ki = !1; rn.length > 0; ) {
        var e = rn[0];
        if (e.blockedOn !== null) {
          var t = Yl(e.blockedOn);
          t !== null && Mr(t);
          break;
        }
        for (var r = e.targetContainers; r.length > 0; ) {
          var i = r[0], o = Xo(e.domEventName, e.eventSystemFlags, i, e.nativeEvent);
          if (o !== null) {
            e.blockedOn = o;
            break;
          }
          r.shift();
        }
        e.blockedOn === null && rn.shift();
      }
      na !== null && mr(na) && (na = null), ja !== null && mr(ja) && (ja = null), an !== null && mr(an) && (an = null), Fa.forEach(ra), Ha.forEach(ra);
    }
    function aa(e, t) {
      e.blockedOn === t && (e.blockedOn = null, ki || (ki = !0, g.unstable_scheduleCallback(g.unstable_NormalPriority, sp)));
    }
    function Wc(e) {
      if (rn.length > 0) {
        aa(rn[0], e);
        for (var t = 1; t < rn.length; t++) {
          var r = rn[t];
          r.blockedOn === e && (r.blockedOn = null);
        }
      }
      na !== null && aa(na, e), ja !== null && aa(ja, e), an !== null && aa(an, e);
      var i = function(v) {
        return aa(v, e);
      };
      Fa.forEach(i), Ha.forEach(i);
      for (var o = 0; o < Lr.length; o++) {
        var s = Lr[o];
        s.blockedOn === e && (s.blockedOn = null);
      }
      for (; Lr.length > 0; ) {
        var d = Lr[0];
        if (d.blockedOn !== null)
          break;
        up(d), d.blockedOn === null && Lr.shift();
      }
    }
    var fs = 0, Ao = 1, _l = 2;
    function Uo(e, t) {
      var r = {};
      return r[e.toLowerCase()] = t.toLowerCase(), r["Webkit" + e] = "webkit" + t, r["Moz" + e] = "moz" + t, r;
    }
    var Di = {
      animationend: Uo("Animation", "AnimationEnd"),
      animationiteration: Uo("Animation", "AnimationIteration"),
      animationstart: Uo("Animation", "AnimationStart"),
      transitionend: Uo("Transition", "TransitionEnd")
    }, ds = {}, ps = {};
    Re && (ps = document.createElement("div").style, "AnimationEvent" in window || (delete Di.animationend.animation, delete Di.animationiteration.animation, delete Di.animationstart.animation), "TransitionEvent" in window || delete Di.transitionend.transition);
    function Oi(e) {
      if (ds[e])
        return ds[e];
      if (!Di[e])
        return e;
      var t = Di[e];
      for (var r in t)
        if (t.hasOwnProperty(r) && r in ps)
          return ds[e] = t[r];
      return e;
    }
    var Dl = Oi("animationend"), zo = Oi("animationiteration"), Yc = Oi("animationstart"), jo = Oi("transitionend"), qc = /* @__PURE__ */ new Map(), Ni = /* @__PURE__ */ new Map(), Ar = [
      "cancel",
      "cancel",
      "click",
      "click",
      "close",
      "close",
      "contextmenu",
      "contextMenu",
      "copy",
      "copy",
      "cut",
      "cut",
      "auxclick",
      "auxClick",
      "dblclick",
      "doubleClick",
      // Careful!
      "dragend",
      "dragEnd",
      "dragstart",
      "dragStart",
      "drop",
      "drop",
      "focusin",
      "focus",
      // Careful!
      "focusout",
      "blur",
      // Careful!
      "input",
      "input",
      "invalid",
      "invalid",
      "keydown",
      "keyDown",
      "keypress",
      "keyPress",
      "keyup",
      "keyUp",
      "mousedown",
      "mouseDown",
      "mouseup",
      "mouseUp",
      "paste",
      "paste",
      "pause",
      "pause",
      "play",
      "play",
      "pointercancel",
      "pointerCancel",
      "pointerdown",
      "pointerDown",
      "pointerup",
      "pointerUp",
      "ratechange",
      "rateChange",
      "reset",
      "reset",
      "seeked",
      "seeked",
      "submit",
      "submit",
      "touchcancel",
      "touchCancel",
      "touchend",
      "touchEnd",
      "touchstart",
      "touchStart",
      "volumechange",
      "volumeChange"
    ], Fo = ["change", "selectionchange", "textInput", "compositionstart", "compositionend", "compositionupdate"], Ho = ["drag", "drag", "dragenter", "dragEnter", "dragexit", "dragExit", "dragleave", "dragLeave", "dragover", "dragOver", "mousemove", "mouseMove", "mouseout", "mouseOut", "mouseover", "mouseOver", "pointermove", "pointerMove", "pointerout", "pointerOut", "pointerover", "pointerOver", "scroll", "scroll", "toggle", "toggle", "touchmove", "touchMove", "wheel", "wheel"], Mi = ["abort", "abort", Dl, "animationEnd", zo, "animationIteration", Yc, "animationStart", "canplay", "canPlay", "canplaythrough", "canPlayThrough", "durationchange", "durationChange", "emptied", "emptied", "encrypted", "encrypted", "ended", "ended", "error", "error", "gotpointercapture", "gotPointerCapture", "load", "load", "loadeddata", "loadedData", "loadedmetadata", "loadedMetadata", "loadstart", "loadStart", "lostpointercapture", "lostPointerCapture", "playing", "playing", "progress", "progress", "seeking", "seeking", "stalled", "stalled", "suspend", "suspend", "timeupdate", "timeUpdate", jo, "transitionEnd", "waiting", "waiting"];
    function Po(e, t) {
      for (var r = 0; r < e.length; r += 2) {
        var i = e[r], o = e[r + 1], s = o[0].toUpperCase() + o.slice(1), d = "on" + s;
        Ni.set(i, t), qc.set(i, d), oe(d, [i]);
      }
    }
    function Ol(e, t) {
      for (var r = 0; r < e.length; r++)
        Ni.set(e[r], t);
    }
    function cp(e) {
      var t = Ni.get(e);
      return t === void 0 ? _l : t;
    }
    function Qc() {
      Po(Ar, fs), Po(Ho, Ao), Po(Mi, _l), Ol(Fo, fs);
    }
    var Bt = g.unstable_now;
    if (!(h.__interactionsRef != null && h.__interactionsRef.current != null))
      throw Error("It is not supported to run the profiling version of a renderer (for example, `react-dom/profiling`) without also replacing the `scheduler/tracing` module with `scheduler/tracing-profiling`. Your bundler might have a setting for aliasing both modules. Learn more at https://reactjs.org/link/profiling");
    var Bo = 99, Ur = 98, ia = 97, zr = 96, Gc = 95, fp = 90;
    Bt();
    var Pa = 15, Vo = 14, Io = 13, Nl = 12, Li = 11, Ba = 10, Ml = 9, ln = 8, Ll = 7, Ot = 6, on = 5, un = 4, $o = 3, Va = 2, Nn = 1, la = 0, Xc = 31, W = (
      /*                        */
      0
    ), qt = (
      /*                          */
      0
    ), at = (
      /*                        */
      1
    ), oa = (
      /*                 */
      2
    ), Ai = (
      /*      */
      4
    ), Wo = (
      /*                    */
      24
    ), Kc = (
      /*           */
      32
    ), Zc = (
      /*                  */
      192
    ), Al = (
      /*            */
      256
    ), Ul = (
      /*                   */
      3584
    ), Jc = (
      /*                */
      4096
    ), ua = (
      /*                       */
      4186112
    ), zl = (
      /*                            */
      62914560
    ), Ia = (
      /*                  */
      33554432
    ), vs = (
      /*          */
      67108864
    ), Yo = (
      /*                                 */
      134217727
    ), ef = (
      /*               */
      134217728
    ), hs = (
      /*                             */
      805306368
    ), yr = (
      /*                   */
      1073741824
    ), Nt = -1;
    function Kh(e) {
    }
    var Tt = ln;
    function jl(e) {
      if ((at & e) !== W)
        return Tt = Pa, at;
      if ((oa & e) !== W)
        return Tt = Vo, oa;
      if ((Ai & e) !== W)
        return Tt = Io, Ai;
      var t = Wo & e;
      if (t !== W)
        return Tt = Nl, t;
      if ((e & Kc) !== W)
        return Tt = Li, Kc;
      var r = Zc & e;
      if (r !== W)
        return Tt = Ba, r;
      if ((e & Al) !== W)
        return Tt = Ml, Al;
      var i = Ul & e;
      if (i !== W)
        return Tt = ln, i;
      if ((e & Jc) !== W)
        return Tt = Ll, Jc;
      var o = ua & e;
      if (o !== W)
        return Tt = Ot, o;
      var s = zl & e;
      if (s !== W)
        return Tt = on, s;
      if (e & vs)
        return Tt = un, vs;
      if ((e & ef) !== W)
        return Tt = $o, ef;
      var d = hs & e;
      return d !== W ? (Tt = Va, d) : (yr & e) !== W ? (Tt = Nn, yr) : (y("Should have found matching lanes. This is a bug in React."), Tt = ln, e);
    }
    function tf(e) {
      switch (e) {
        case Bo:
          return Pa;
        case Ur:
          return Ba;
        case ia:
        case zr:
          return ln;
        case Gc:
          return Va;
        default:
          return la;
      }
    }
    function ms(e) {
      switch (e) {
        case Pa:
        case Vo:
          return Bo;
        case Io:
        case Nl:
        case Li:
        case Ba:
          return Ur;
        case Ml:
        case ln:
        case Ll:
        case Ot:
        case un:
        case on:
          return ia;
        case $o:
        case Va:
        case Nn:
          return Gc;
        case la:
          return fp;
        default:
          throw Error("Invalid update priority: " + e + ". This is a bug in React.");
      }
    }
    function qo(e, t) {
      var r = e.pendingLanes;
      if (r === W)
        return Tt = la, W;
      var i = W, o = la, s = e.expiredLanes, d = e.suspendedLanes, v = e.pingedLanes;
      if (s !== W)
        i = s, o = Tt = Pa;
      else {
        var E = r & Yo;
        if (E !== W) {
          var R = E & ~d;
          if (R !== W)
            i = jl(R), o = Tt;
          else {
            var x = E & v;
            x !== W && (i = jl(x), o = Tt);
          }
        } else {
          var U = r & ~d;
          U !== W ? (i = jl(U), o = Tt) : v !== W && (i = jl(v), o = Tt);
        }
      }
      if (i === W)
        return W;
      if (i = r & hp(i), t !== W && t !== i && // If we already suspended with a delay, then interrupting is fine. Don't
      // bother waiting until the root is complete.
      (t & d) === W) {
        jl(t);
        var k = Tt;
        if (o <= k)
          return t;
        Tt = o;
      }
      var H = e.entangledLanes;
      if (H !== W)
        for (var Q = e.entanglements, se = i & H; se > 0; ) {
          var Me = $a(se), Xe = 1 << Me;
          i |= Q[Me], se &= ~Xe;
        }
      return i;
    }
    function Zh(e, t) {
      for (var r = e.eventTimes, i = Nt; t > 0; ) {
        var o = $a(t), s = 1 << o, d = r[o];
        d > i && (i = d), t &= ~s;
      }
      return i;
    }
    function Jh(e, t) {
      jl(e);
      var r = Tt;
      return r >= Ba ? t + 250 : r >= Ot ? t + 5e3 : Nt;
    }
    function em(e, t) {
      for (var r = e.pendingLanes, i = e.suspendedLanes, o = e.pingedLanes, s = e.expirationTimes, d = r; d > 0; ) {
        var v = $a(d), E = 1 << v, R = s[v];
        R === Nt ? ((E & i) === W || (E & o) !== W) && (s[v] = Jh(E, t)) : R <= t && (e.expiredLanes |= E), d &= ~E;
      }
    }
    function ar(e) {
      var t = e.pendingLanes & ~yr;
      return t !== W ? t : t & yr ? yr : W;
    }
    function zn() {
      return Tt;
    }
    function nf(e) {
      return (e & Yo) !== W;
    }
    function rf(e) {
      return (e & zl) === e;
    }
    function dp(e) {
      return (e & ua) === e;
    }
    function Fl(e, t) {
      switch (e) {
        case la:
          break;
        case Pa:
          return at;
        case Vo:
          return oa;
        case Nl: {
          var r = sn(Wo & ~t);
          return r === qt ? Fl(Ba, t) : r;
        }
        case Ba: {
          var i = sn(Zc & ~t);
          return i === qt ? Fl(ln, t) : i;
        }
        case ln: {
          var o = sn(Ul & ~t);
          return o === qt && (o = sn(ua & ~t), o === qt && (o = sn(Ul))), o;
        }
        case Ot:
        case on:
          break;
        case Va:
          var s = sn(hs & ~t);
          return s === qt && (s = sn(hs)), s;
      }
      throw Error("Invalid update priority: " + e + ". This is a bug in React.");
    }
    function pp(e, t) {
      var r = sn(ua & ~t);
      return r === qt && (r = sn(ua & ~e), r === qt && (r = sn(ua))), r;
    }
    function af(e) {
      var t = sn(zl & ~e);
      return t === qt && (t = sn(zl)), t;
    }
    function vp(e) {
      return e & -e;
    }
    function lf(e) {
      var t = 31 - Ep(e);
      return t < 0 ? W : 1 << t;
    }
    function hp(e) {
      return (lf(e) << 1) - 1;
    }
    function sn(e) {
      return vp(e);
    }
    function $a(e) {
      return 31 - Ep(e);
    }
    function mp(e) {
      return $a(e);
    }
    function yn(e, t) {
      return (e & t) !== W;
    }
    function Wa(e, t) {
      return (e & t) === t;
    }
    function dt(e, t) {
      return e | t;
    }
    function Hl(e, t) {
      return e & ~t;
    }
    function tm(e) {
      return e;
    }
    function sa(e, t) {
      return e !== qt && e < t ? e : t;
    }
    function ys(e) {
      for (var t = [], r = 0; r < Xc; r++)
        t.push(e);
      return t;
    }
    function Pl(e, t, r) {
      e.pendingLanes |= t;
      var i = t - 1;
      e.suspendedLanes &= i, e.pingedLanes &= i;
      var o = e.eventTimes, s = mp(t);
      o[s] = r;
    }
    function yp(e, t) {
      e.suspendedLanes |= t, e.pingedLanes &= ~t;
      for (var r = e.expirationTimes, i = t; i > 0; ) {
        var o = $a(i), s = 1 << o;
        r[o] = Nt, i &= ~s;
      }
    }
    function of(e, t, r) {
      e.pingedLanes |= e.suspendedLanes & t;
    }
    function Qo(e) {
      e.expiredLanes |= Wo & e.pendingLanes;
    }
    function nm(e) {
      return (e & Wo) !== W;
    }
    function gp(e, t) {
      e.mutableReadLanes |= t & e.pendingLanes;
    }
    function uf(e, t) {
      var r = e.pendingLanes & ~t;
      e.pendingLanes = t, e.suspendedLanes = 0, e.pingedLanes = 0, e.expiredLanes &= t, e.mutableReadLanes &= t, e.entangledLanes &= t;
      for (var i = e.entanglements, o = e.eventTimes, s = e.expirationTimes, d = r; d > 0; ) {
        var v = $a(d), E = 1 << v;
        i[v] = W, o[v] = Nt, s[v] = Nt, d &= ~E;
      }
    }
    function sf(e, t) {
      e.entangledLanes |= t;
      for (var r = e.entanglements, i = t; i > 0; ) {
        var o = $a(i), s = 1 << o;
        r[o] |= t, i &= ~s;
      }
    }
    var Ep = Math.clz32 ? Math.clz32 : rm, Sp = Math.log, Cp = Math.LN2;
    function rm(e) {
      return e === 0 ? 32 : 31 - (Sp(e) / Cp | 0) | 0;
    }
    var bp = g.unstable_UserBlockingPriority, am = g.unstable_runWithPriority, cf = !0;
    function ff(e) {
      cf = !!e;
    }
    function Tp() {
      return cf;
    }
    function Rp(e, t, r) {
      var i = cp(t), o;
      switch (i) {
        case fs:
          o = xp;
          break;
        case Ao:
          o = wp;
          break;
        case _l:
        default:
          o = Go;
          break;
      }
      return o.bind(null, t, r, e);
    }
    function xp(e, t, r, i) {
      Zd(i.timeStamp), bl(Go, e, t, r, i);
    }
    function wp(e, t, r, i) {
      am(bp, Go.bind(null, e, t, r, i));
    }
    function Go(e, t, r, i) {
      if (cf) {
        var o = !0;
        if (o = (t & Si) === 0, o && ss() && cs(e)) {
          _i(
            null,
            // Flags that we're not actually blocked on anything as far as we know.
            e,
            t,
            r,
            i
          );
          return;
        }
        var s = Xo(e, t, r, i);
        if (s === null) {
          o && $n(e, i);
          return;
        }
        if (o) {
          if (cs(e)) {
            _i(s, e, t, r, i);
            return;
          }
          if ($c(s, e, t, r, i))
            return;
          $n(e, i);
        }
        N0(e, t, i, null, r);
      }
    }
    function Xo(e, t, r, i) {
      var o = _o(i), s = cu(o);
      if (s !== null) {
        var d = za(s);
        if (d === null)
          s = null;
        else {
          var v = d.tag;
          if (v === z) {
            var E = ls(d);
            if (E !== null)
              return E;
            s = null;
          } else if (v === B) {
            var R = d.stateNode;
            if (R.hydrate)
              return ap(d);
            s = null;
          } else d !== s && (s = null);
        }
      }
      return N0(e, t, i, s, r), null;
    }
    function kp(e, t, r) {
      return e.addEventListener(t, r, !1), r;
    }
    function df(e, t, r) {
      return e.addEventListener(t, r, !0), r;
    }
    function _p(e, t, r, i) {
      return e.addEventListener(t, r, {
        capture: !0,
        passive: i
      }), r;
    }
    function im(e, t, r, i) {
      return e.addEventListener(t, r, {
        passive: i
      }), r;
    }
    var Ko = null, Bl = null, Ui = null;
    function Ve(e) {
      return Ko = e, Bl = gn(), !0;
    }
    function Mn() {
      Ko = null, Bl = null, Ui = null;
    }
    function Qt() {
      if (Ui)
        return Ui;
      var e, t = Bl, r = t.length, i, o = gn(), s = o.length;
      for (e = 0; e < r && t[e] === o[e]; e++)
        ;
      var d = r - e;
      for (i = 1; i <= d && t[r - i] === o[s - i]; i++)
        ;
      var v = i > 1 ? 1 - i : void 0;
      return Ui = o.slice(e, v), Ui;
    }
    function gn() {
      return "value" in Ko ? Ko.value : Ko.textContent;
    }
    function jr(e) {
      var t, r = e.keyCode;
      return "charCode" in e ? (t = e.charCode, t === 0 && r === 13 && (t = 13)) : t = r, t === 10 && (t = 13), t >= 32 || t === 13 ? t : 0;
    }
    function Vl() {
      return !0;
    }
    function cn() {
      return !1;
    }
    function Cn(e) {
      function t(r, i, o, s, d) {
        this._reactName = r, this._targetInst = o, this.type = i, this.nativeEvent = s, this.target = d, this.currentTarget = null;
        for (var v in e)
          if (e.hasOwnProperty(v)) {
            var E = e[v];
            E ? this[v] = E(s) : this[v] = s[v];
          }
        var R = s.defaultPrevented != null ? s.defaultPrevented : s.returnValue === !1;
        return R ? this.isDefaultPrevented = Vl : this.isDefaultPrevented = cn, this.isPropagationStopped = cn, this;
      }
      return p(t.prototype, {
        preventDefault: function() {
          this.defaultPrevented = !0;
          var r = this.nativeEvent;
          r && (r.preventDefault ? r.preventDefault() : typeof r.returnValue != "unknown" && (r.returnValue = !1), this.isDefaultPrevented = Vl);
        },
        stopPropagation: function() {
          var r = this.nativeEvent;
          r && (r.stopPropagation ? r.stopPropagation() : typeof r.cancelBubble != "unknown" && (r.cancelBubble = !0), this.isPropagationStopped = Vl);
        },
        /**
         * We release all dispatched `SyntheticEvent`s after each event loop, adding
         * them back into the pool. This allows a way to hold onto a reference that
         * won't be added back into the pool.
         */
        persist: function() {
        },
        /**
         * Checks if this event should be released back into the pool.
         *
         * @return {boolean} True if this should not be released, false otherwise.
         */
        isPersistent: Vl
      }), t;
    }
    var gr = {
      eventPhase: 0,
      bubbles: 0,
      cancelable: 0,
      timeStamp: function(e) {
        return e.timeStamp || Date.now();
      },
      defaultPrevented: 0,
      isTrusted: 0
    }, zi = Cn(gr), Fr = p({}, gr, {
      view: 0,
      detail: 0
    }), pf = Cn(Fr), Zo, Jo, ji;
    function Il(e) {
      e !== ji && (ji && e.type === "mousemove" ? (Zo = e.screenX - ji.screenX, Jo = e.screenY - ji.screenY) : (Zo = 0, Jo = 0), ji = e);
    }
    var ye = p({}, Fr, {
      screenX: 0,
      screenY: 0,
      clientX: 0,
      clientY: 0,
      pageX: 0,
      pageY: 0,
      ctrlKey: 0,
      shiftKey: 0,
      altKey: 0,
      metaKey: 0,
      getModifierState: Pr,
      button: 0,
      buttons: 0,
      relatedTarget: function(e) {
        return e.relatedTarget === void 0 ? e.fromElement === e.srcElement ? e.toElement : e.fromElement : e.relatedTarget;
      },
      movementX: function(e) {
        return "movementX" in e ? e.movementX : (Il(e), Zo);
      },
      movementY: function(e) {
        return "movementY" in e ? e.movementY : Jo;
      }
    }), eu = Cn(ye), vf = p({}, ye, {
      dataTransfer: 0
    }), Hr = Cn(vf), Ya = p({}, Fr, {
      relatedTarget: 0
    }), Fi = Cn(Ya), tu = p({}, gr, {
      animationName: 0,
      elapsedTime: 0,
      pseudoElement: 0
    }), hf = Cn(tu), mf = p({}, gr, {
      clipboardData: function(e) {
        return "clipboardData" in e ? e.clipboardData : window.clipboardData;
      }
    }), ca = Cn(mf), nu = p({}, gr, {
      data: 0
    }), gs = Cn(nu), Es = gs, fa = {
      Esc: "Escape",
      Spacebar: " ",
      Left: "ArrowLeft",
      Up: "ArrowUp",
      Right: "ArrowRight",
      Down: "ArrowDown",
      Del: "Delete",
      Win: "OS",
      Menu: "ContextMenu",
      Apps: "ContextMenu",
      Scroll: "ScrollLock",
      MozPrintableKey: "Unidentified"
    }, Ss = {
      8: "Backspace",
      9: "Tab",
      12: "Clear",
      13: "Enter",
      16: "Shift",
      17: "Control",
      18: "Alt",
      19: "Pause",
      20: "CapsLock",
      27: "Escape",
      32: " ",
      33: "PageUp",
      34: "PageDown",
      35: "End",
      36: "Home",
      37: "ArrowLeft",
      38: "ArrowUp",
      39: "ArrowRight",
      40: "ArrowDown",
      45: "Insert",
      46: "Delete",
      112: "F1",
      113: "F2",
      114: "F3",
      115: "F4",
      116: "F5",
      117: "F6",
      118: "F7",
      119: "F8",
      120: "F9",
      121: "F10",
      122: "F11",
      123: "F12",
      144: "NumLock",
      145: "ScrollLock",
      224: "Meta"
    };
    function ru(e) {
      if (e.key) {
        var t = fa[e.key] || e.key;
        if (t !== "Unidentified")
          return t;
      }
      if (e.type === "keypress") {
        var r = jr(e);
        return r === 13 ? "Enter" : String.fromCharCode(r);
      }
      return e.type === "keydown" || e.type === "keyup" ? Ss[e.keyCode] || "Unidentified" : "";
    }
    var Cs = {
      Alt: "altKey",
      Control: "ctrlKey",
      Meta: "metaKey",
      Shift: "shiftKey"
    };
    function Wn(e) {
      var t = this, r = t.nativeEvent;
      if (r.getModifierState)
        return r.getModifierState(e);
      var i = Cs[e];
      return i ? !!r[i] : !1;
    }
    function Pr(e) {
      return Wn;
    }
    var qa = p({}, Fr, {
      key: ru,
      code: 0,
      location: 0,
      ctrlKey: 0,
      shiftKey: 0,
      altKey: 0,
      metaKey: 0,
      repeat: 0,
      locale: 0,
      getModifierState: Pr,
      // Legacy Interface
      charCode: function(e) {
        return e.type === "keypress" ? jr(e) : 0;
      },
      keyCode: function(e) {
        return e.type === "keydown" || e.type === "keyup" ? e.keyCode : 0;
      },
      which: function(e) {
        return e.type === "keypress" ? jr(e) : e.type === "keydown" || e.type === "keyup" ? e.keyCode : 0;
      }
    }), bs = Cn(qa), ir = p({}, ye, {
      pointerId: 0,
      width: 0,
      height: 0,
      pressure: 0,
      tangentialPressure: 0,
      tiltX: 0,
      tiltY: 0,
      twist: 0,
      pointerType: 0,
      isPrimary: 0
    }), yf = Cn(ir), $l = p({}, Fr, {
      touches: 0,
      targetTouches: 0,
      changedTouches: 0,
      altKey: 0,
      metaKey: 0,
      ctrlKey: 0,
      shiftKey: 0,
      getModifierState: Pr
    }), gf = Cn($l), lm = p({}, gr, {
      propertyName: 0,
      elapsedTime: 0,
      pseudoElement: 0
    }), Dp = Cn(lm), Op = p({}, ye, {
      deltaX: function(e) {
        return "deltaX" in e ? e.deltaX : (
          // Fallback to `wheelDeltaX` for Webkit and normalize (right is positive).
          "wheelDeltaX" in e ? -e.wheelDeltaX : 0
        );
      },
      deltaY: function(e) {
        return "deltaY" in e ? e.deltaY : (
          // Fallback to `wheelDeltaY` for Webkit and normalize (down is positive).
          "wheelDeltaY" in e ? -e.wheelDeltaY : (
            // Fallback to `wheelDelta` for IE<9 and normalize (down is positive).
            "wheelDelta" in e ? -e.wheelDelta : 0
          )
        );
      },
      deltaZ: 0,
      // Browsers without "deltaMode" is reporting in raw wheel delta where one
      // notch on the scroll is always +/- 120, roughly equivalent to pixels.
      // A good approximation of DOM_DELTA_LINE (1) is 5% of viewport size or
      // ~40 pixels, for DOM_DELTA_SCREEN (2) it is 87.5% of viewport size.
      deltaMode: 0
    }), Ts = Cn(Op), Ef = [9, 13, 27, 32], Hi = 229, Rs = Re && "CompositionEvent" in window, Wl = null;
    Re && "documentMode" in document && (Wl = document.documentMode);
    var au = Re && "TextEvent" in window && !Wl, Np = Re && (!Rs || Wl && Wl > 8 && Wl <= 11), Mp = 32, Sf = String.fromCharCode(Mp);
    function Lp() {
      oe("onBeforeInput", ["compositionend", "keypress", "textInput", "paste"]), oe("onCompositionEnd", ["compositionend", "focusout", "keydown", "keypress", "keyup", "mousedown"]), oe("onCompositionStart", ["compositionstart", "focusout", "keydown", "keypress", "keyup", "mousedown"]), oe("onCompositionUpdate", ["compositionupdate", "focusout", "keydown", "keypress", "keyup", "mousedown"]);
    }
    var Qa = !1;
    function om(e) {
      return (e.ctrlKey || e.altKey || e.metaKey) && // ctrlKey && altKey is equivalent to AltGr, and is not a command.
      !(e.ctrlKey && e.altKey);
    }
    function um(e) {
      switch (e) {
        case "compositionstart":
          return "onCompositionStart";
        case "compositionend":
          return "onCompositionEnd";
        case "compositionupdate":
          return "onCompositionUpdate";
      }
    }
    function Ga(e, t) {
      return e === "keydown" && t.keyCode === Hi;
    }
    function Ap(e, t) {
      switch (e) {
        case "keyup":
          return Ef.indexOf(t.keyCode) !== -1;
        case "keydown":
          return t.keyCode !== Hi;
        case "keypress":
        case "mousedown":
        case "focusout":
          return !0;
        default:
          return !1;
      }
    }
    function Cf(e) {
      var t = e.detail;
      return typeof t == "object" && "data" in t ? t.data : null;
    }
    function Up(e) {
      return e.locale === "ko";
    }
    var Pi = !1;
    function Xa(e, t, r, i, o) {
      var s, d;
      if (Rs ? s = um(t) : Pi ? Ap(t, i) && (s = "onCompositionEnd") : Ga(t, i) && (s = "onCompositionStart"), !s)
        return null;
      Np && !Up(i) && (!Pi && s === "onCompositionStart" ? Pi = Ve(o) : s === "onCompositionEnd" && Pi && (d = Qt()));
      var v = Pp(r, s);
      if (v.length > 0) {
        var E = new gs(s, t, null, i, o);
        if (e.push({
          event: E,
          listeners: v
        }), d)
          E.data = d;
        else {
          var R = Cf(i);
          R !== null && (E.data = R);
        }
      }
    }
    function sm(e, t) {
      switch (e) {
        case "compositionend":
          return Cf(t);
        case "keypress":
          var r = t.which;
          return r !== Mp ? null : (Qa = !0, Sf);
        case "textInput":
          var i = t.data;
          return i === Sf && Qa ? null : i;
        default:
          return null;
      }
    }
    function cm(e, t) {
      if (Pi) {
        if (e === "compositionend" || !Rs && Ap(e, t)) {
          var r = Qt();
          return Mn(), Pi = !1, r;
        }
        return null;
      }
      switch (e) {
        case "paste":
          return null;
        case "keypress":
          if (!om(t)) {
            if (t.char && t.char.length > 1)
              return t.char;
            if (t.which)
              return String.fromCharCode(t.which);
          }
          return null;
        case "compositionend":
          return Np && !Up(t) ? null : t.data;
        default:
          return null;
      }
    }
    function zp(e, t, r, i, o) {
      var s;
      if (au ? s = sm(t, i) : s = cm(t, i), !s)
        return null;
      var d = Pp(r, "onBeforeInput");
      if (d.length > 0) {
        var v = new Es("onBeforeInput", "beforeinput", null, i, o);
        e.push({
          event: v,
          listeners: d
        }), v.data = s;
      }
    }
    function fm(e, t, r, i, o, s, d) {
      Xa(e, t, r, i, o), zp(e, t, r, i, o);
    }
    var lr = {
      color: !0,
      date: !0,
      datetime: !0,
      "datetime-local": !0,
      email: !0,
      month: !0,
      number: !0,
      password: !0,
      range: !0,
      search: !0,
      tel: !0,
      text: !0,
      time: !0,
      url: !0,
      week: !0
    };
    function xs(e) {
      var t = e && e.nodeName && e.nodeName.toLowerCase();
      return t === "input" ? !!lr[e.type] : t === "textarea";
    }
    /**
     * Checks if an event is supported in the current execution environment.
     *
     * NOTE: This will not work correctly for non-generic events such as `change`,
     * `reset`, `load`, `error`, and `select`.
     *
     * Borrows from Modernizr.
     *
     * @param {string} eventNameSuffix Event name, e.g. "click".
     * @return {boolean} True if the event is supported.
     * @internal
     * @license Modernizr 3.0.0pre (Custom Build) | MIT
     */
    function dm(e) {
      if (!Re)
        return !1;
      var t = "on" + e, r = t in document;
      if (!r) {
        var i = document.createElement("div");
        i.setAttribute(t, "return;"), r = typeof i[t] == "function";
      }
      return r;
    }
    function Ka() {
      oe("onChange", ["change", "click", "focusin", "focusout", "input", "keydown", "keyup", "selectionchange"]);
    }
    function iu(e, t, r, i) {
      Cl(i);
      var o = Pp(t, "onChange");
      if (o.length > 0) {
        var s = new zi("onChange", "change", null, r, i);
        e.push({
          event: s,
          listeners: o
        });
      }
    }
    var Br = null, Bi = null;
    function bf(e) {
      var t = e.nodeName && e.nodeName.toLowerCase();
      return t === "select" || t === "input" && e.type === "file";
    }
    function Tf(e) {
      var t = [];
      iu(t, Bi, e, _o(e)), Do(pm, t);
    }
    function pm(e) {
      x0(e, 0);
    }
    function ws(e) {
      var t = Us(e);
      if (fc(t))
        return e;
    }
    function ks(e, t) {
      if (e === "change")
        return t;
    }
    var _s = !1;
    Re && (_s = dm("input") && (!document.documentMode || document.documentMode > 9));
    function jp(e, t) {
      Br = e, Bi = t, Br.attachEvent("onpropertychange", Fp);
    }
    function Ds() {
      Br && (Br.detachEvent("onpropertychange", Fp), Br = null, Bi = null);
    }
    function Fp(e) {
      e.propertyName === "value" && ws(Bi) && Tf(e);
    }
    function Rf(e, t, r) {
      e === "focusin" ? (Ds(), jp(t, r)) : e === "focusout" && Ds();
    }
    function lu(e, t) {
      if (e === "selectionchange" || e === "keyup" || e === "keydown")
        return ws(Bi);
    }
    function vm(e) {
      var t = e.nodeName;
      return t && t.toLowerCase() === "input" && (e.type === "checkbox" || e.type === "radio");
    }
    function Os(e, t) {
      if (e === "click")
        return ws(t);
    }
    function Hp(e, t) {
      if (e === "input" || e === "change")
        return ws(t);
    }
    function hm(e) {
      var t = e._wrapperState;
      !t || !t.controlled || e.type !== "number" || wa(e, "number", e.value);
    }
    function ou(e, t, r, i, o, s, d) {
      var v = r ? Us(r) : window, E, R;
      if (bf(v) ? E = ks : xs(v) ? _s ? E = Hp : (E = lu, R = Rf) : vm(v) && (E = Os), E) {
        var x = E(t, r);
        if (x) {
          iu(e, x, i, o);
          return;
        }
      }
      R && R(t, v, r), t === "focusout" && hm(v);
    }
    function mm() {
      ve("onMouseEnter", ["mouseout", "mouseover"]), ve("onMouseLeave", ["mouseout", "mouseover"]), ve("onPointerEnter", ["pointerout", "pointerover"]), ve("onPointerLeave", ["pointerout", "pointerover"]);
    }
    function Ns(e, t, r, i, o, s, d) {
      var v = t === "mouseover" || t === "pointerover", E = t === "mouseout" || t === "pointerout";
      if (v && !(s & Kd)) {
        var R = i.relatedTarget || i.fromElement;
        if (R && (cu(R) || Xp(R)))
          return;
      }
      if (!(!E && !v)) {
        var x;
        if (o.window === o)
          x = o;
        else {
          var U = o.ownerDocument;
          U ? x = U.defaultView || U.parentWindow : x = window;
        }
        var k, H;
        if (E) {
          var Q = i.relatedTarget || i.toElement;
          if (k = r, H = Q ? cu(Q) : null, H !== null) {
            var se = za(H);
            (H !== se || H.tag !== re && H.tag !== ue) && (H = null);
          }
        } else
          k = null, H = r;
        if (k !== H) {
          var Me = eu, Xe = "onMouseLeave", je = "onMouseEnter", ft = "mouse";
          (t === "pointerout" || t === "pointerover") && (Me = yf, Xe = "onPointerLeave", je = "onPointerEnter", ft = "pointer");
          var kt = k == null ? x : Us(k), j = H == null ? x : Us(H), V = new Me(Xe, ft + "leave", k, i, o);
          V.target = kt, V.relatedTarget = j;
          var N = null, ae = cu(o);
          if (ae === r) {
            var pe = new Me(je, ft + "enter", H, i, o);
            pe.target = j, pe.relatedTarget = kt, N = pe;
          }
          U1(e, V, N, k, H);
        }
      }
    }
    function n(e, t) {
      return e === t && (e !== 0 || 1 / e === 1 / t) || e !== e && t !== t;
    }
    var a = typeof Object.is == "function" ? Object.is : n, l = Object.prototype.hasOwnProperty;
    function u(e, t) {
      if (a(e, t))
        return !0;
      if (typeof e != "object" || e === null || typeof t != "object" || t === null)
        return !1;
      var r = Object.keys(e), i = Object.keys(t);
      if (r.length !== i.length)
        return !1;
      for (var o = 0; o < r.length; o++)
        if (!l.call(t, r[o]) || !a(e[r[o]], t[r[o]]))
          return !1;
      return !0;
    }
    function f(e) {
      for (; e && e.firstChild; )
        e = e.firstChild;
      return e;
    }
    function m(e) {
      for (; e; ) {
        if (e.nextSibling)
          return e.nextSibling;
        e = e.parentNode;
      }
    }
    function S(e, t) {
      for (var r = f(e), i = 0, o = 0; r; ) {
        if (r.nodeType === Zr) {
          if (o = i + r.textContent.length, i <= t && o >= t)
            return {
              node: r,
              offset: t - i
            };
          i = o;
        }
        r = f(m(r));
      }
    }
    function T(e) {
      var t = e.ownerDocument, r = t && t.defaultView || window, i = r.getSelection && r.getSelection();
      if (!i || i.rangeCount === 0)
        return null;
      var o = i.anchorNode, s = i.anchorOffset, d = i.focusNode, v = i.focusOffset;
      try {
        o.nodeType, d.nodeType;
      } catch {
        return null;
      }
      return w(e, o, s, d, v);
    }
    function w(e, t, r, i, o) {
      var s = 0, d = -1, v = -1, E = 0, R = 0, x = e, U = null;
      e: for (; ; ) {
        for (var k = null; x === t && (r === 0 || x.nodeType === Zr) && (d = s + r), x === i && (o === 0 || x.nodeType === Zr) && (v = s + o), x.nodeType === Zr && (s += x.nodeValue.length), (k = x.firstChild) !== null; )
          U = x, x = k;
        for (; ; ) {
          if (x === e)
            break e;
          if (U === t && ++E === r && (d = s), U === i && ++R === o && (v = s), (k = x.nextSibling) !== null)
            break;
          x = U, U = x.parentNode;
        }
        x = k;
      }
      return d === -1 || v === -1 ? null : {
        start: d,
        end: v
      };
    }
    function P(e, t) {
      var r = e.ownerDocument || document, i = r && r.defaultView || window;
      if (i.getSelection) {
        var o = i.getSelection(), s = e.textContent.length, d = Math.min(t.start, s), v = t.end === void 0 ? d : Math.min(t.end, s);
        if (!o.extend && d > v) {
          var E = v;
          v = d, d = E;
        }
        var R = S(e, d), x = S(e, v);
        if (R && x) {
          if (o.rangeCount === 1 && o.anchorNode === R.node && o.anchorOffset === R.offset && o.focusNode === x.node && o.focusOffset === x.offset)
            return;
          var U = r.createRange();
          U.setStart(R.node, R.offset), o.removeAllRanges(), d > v ? (o.addRange(U), o.extend(x.node, x.offset)) : (U.setEnd(x.node, x.offset), o.addRange(U));
        }
      }
    }
    function he(e) {
      return e && e.nodeType === Zr;
    }
    function Ie(e, t) {
      return !e || !t ? !1 : e === t ? !0 : he(e) ? !1 : he(t) ? Ie(e, t.parentNode) : "contains" in e ? e.contains(t) : e.compareDocumentPosition ? !!(e.compareDocumentPosition(t) & 16) : !1;
    }
    function K(e) {
      return e && e.ownerDocument && Ie(e.ownerDocument.documentElement, e);
    }
    function ke(e) {
      try {
        return typeof e.contentWindow.location.href == "string";
      } catch {
        return !1;
      }
    }
    function He() {
      for (var e = window, t = go(); t instanceof e.HTMLIFrameElement; ) {
        if (ke(t))
          e = t.contentWindow;
        else
          return t;
        t = go(e.document);
      }
      return t;
    }
    function Le(e) {
      var t = e && e.nodeName && e.nodeName.toLowerCase();
      return t && (t === "input" && (e.type === "text" || e.type === "search" || e.type === "tel" || e.type === "url" || e.type === "password") || t === "textarea" || e.contentEditable === "true");
    }
    function M() {
      var e = He();
      return {
        focusedElem: e,
        selectionRange: Le(e) ? O(e) : null
      };
    }
    function _(e) {
      var t = He(), r = e.focusedElem, i = e.selectionRange;
      if (t !== r && K(r)) {
        i !== null && Le(r) && $(r, i);
        for (var o = [], s = r; s = s.parentNode; )
          s.nodeType === er && o.push({
            element: s,
            left: s.scrollLeft,
            top: s.scrollTop
          });
        typeof r.focus == "function" && r.focus();
        for (var d = 0; d < o.length; d++) {
          var v = o[d];
          v.element.scrollLeft = v.left, v.element.scrollTop = v.top;
        }
      }
    }
    function O(e) {
      var t;
      return "selectionStart" in e ? t = {
        start: e.selectionStart,
        end: e.selectionEnd
      } : t = T(e), t || {
        start: 0,
        end: 0
      };
    }
    function $(e, t) {
      var r = t.start, i = t.end;
      i === void 0 && (i = r), "selectionStart" in e ? (e.selectionStart = r, e.selectionEnd = Math.min(i, e.value.length)) : P(e, t);
    }
    var q = Re && "documentMode" in document && document.documentMode <= 11;
    function qe() {
      oe("onSelect", ["focusout", "contextmenu", "dragend", "focusin", "keydown", "keyup", "mousedown", "mouseup", "selectionchange"]);
    }
    var ge = null, $e = null, Ge = null, Qe = !1;
    function Za(e) {
      if ("selectionStart" in e && Le(e))
        return {
          start: e.selectionStart,
          end: e.selectionEnd
        };
      var t = e.ownerDocument && e.ownerDocument.defaultView || window, r = t.getSelection();
      return {
        anchorNode: r.anchorNode,
        anchorOffset: r.anchorOffset,
        focusNode: r.focusNode,
        focusOffset: r.focusOffset
      };
    }
    function ym(e) {
      return e.window === e ? e.document : e.nodeType === Da ? e : e.ownerDocument;
    }
    function T0(e, t, r) {
      var i = ym(r);
      if (!(Qe || ge == null || ge !== go(i))) {
        var o = Za(ge);
        if (!Ge || !u(Ge, o)) {
          Ge = o;
          var s = Pp($e, "onSelect");
          if (s.length > 0) {
            var d = new zi("onSelect", "select", null, t, r);
            e.push({
              event: d,
              listeners: s
            }), d.target = ge;
          }
        }
      }
    }
    function k1(e, t, r, i, o, s, d) {
      var v = r ? Us(r) : window;
      switch (t) {
        case "focusin":
          (xs(v) || v.contentEditable === "true") && (ge = v, $e = r, Ge = null);
          break;
        case "focusout":
          ge = null, $e = null, Ge = null;
          break;
        case "mousedown":
          Qe = !0;
          break;
        case "contextmenu":
        case "mouseup":
        case "dragend":
          Qe = !1, T0(e, i, o);
          break;
        case "selectionchange":
          if (q)
            break;
        case "keydown":
        case "keyup":
          T0(e, i, o);
      }
    }
    function _1(e, t, r, i, o, s, d) {
      var v = qc.get(t);
      if (v !== void 0) {
        var E = zi, R = t;
        switch (t) {
          case "keypress":
            if (jr(i) === 0)
              return;
          case "keydown":
          case "keyup":
            E = bs;
            break;
          case "focusin":
            R = "focus", E = Fi;
            break;
          case "focusout":
            R = "blur", E = Fi;
            break;
          case "beforeblur":
          case "afterblur":
            E = Fi;
            break;
          case "click":
            if (i.button === 2)
              return;
          case "auxclick":
          case "dblclick":
          case "mousedown":
          case "mousemove":
          case "mouseup":
          case "mouseout":
          case "mouseover":
          case "contextmenu":
            E = eu;
            break;
          case "drag":
          case "dragend":
          case "dragenter":
          case "dragexit":
          case "dragleave":
          case "dragover":
          case "dragstart":
          case "drop":
            E = Hr;
            break;
          case "touchcancel":
          case "touchend":
          case "touchmove":
          case "touchstart":
            E = gf;
            break;
          case Dl:
          case zo:
          case Yc:
            E = hf;
            break;
          case jo:
            E = Dp;
            break;
          case "scroll":
            E = pf;
            break;
          case "wheel":
            E = Ts;
            break;
          case "copy":
          case "cut":
          case "paste":
            E = ca;
            break;
          case "gotpointercapture":
          case "lostpointercapture":
          case "pointercancel":
          case "pointerdown":
          case "pointermove":
          case "pointerout":
          case "pointerover":
          case "pointerup":
            E = yf;
            break;
        }
        var x = (s & Si) !== 0;
        {
          var U = !x && // TODO: ideally, we'd eventually add all events from
          // nonDelegatedEvents list in DOMPluginEventSystem.
          // Then we can remove this special list.
          // This is a breaking change that can wait until React 18.
          t === "scroll", k = L1(r, v, i.type, x, U);
          if (k.length > 0) {
            var H = new E(v, R, null, i, o);
            e.push({
              event: H,
              listeners: k
            });
          }
        }
      }
    }
    Qc(), mm(), Ka(), qe(), Lp();
    function D1(e, t, r, i, o, s, d) {
      _1(e, t, r, i, o, s);
      var v = (s & Sl) === 0;
      v && (Ns(e, t, r, i, o, s), ou(e, t, r, i, o), k1(e, t, r, i, o), fm(e, t, r, i, o));
    }
    var xf = ["abort", "canplay", "canplaythrough", "durationchange", "emptied", "encrypted", "ended", "error", "loadeddata", "loadedmetadata", "loadstart", "pause", "play", "playing", "progress", "ratechange", "seeked", "seeking", "stalled", "suspend", "timeupdate", "volumechange", "waiting"], O1 = new Set(["cancel", "close", "invalid", "load", "scroll", "toggle"].concat(xf));
    function R0(e, t, r) {
      var i = e.type || "unknown-event";
      e.currentTarget = r, tp(i, t, void 0, e), e.currentTarget = null;
    }
    function N1(e, t, r) {
      var i;
      if (r)
        for (var o = t.length - 1; o >= 0; o--) {
          var s = t[o], d = s.instance, v = s.currentTarget, E = s.listener;
          if (d !== i && e.isPropagationStopped())
            return;
          R0(e, E, v), i = d;
        }
      else
        for (var R = 0; R < t.length; R++) {
          var x = t[R], U = x.instance, k = x.currentTarget, H = x.listener;
          if (U !== i && e.isPropagationStopped())
            return;
          R0(e, H, k), i = U;
        }
    }
    function x0(e, t) {
      for (var r = (t & Si) !== 0, i = 0; i < e.length; i++) {
        var o = e[i], s = o.event, d = o.listeners;
        N1(s, d, r);
      }
      Ri();
    }
    function M1(e, t, r, i, o) {
      var s = _o(r), d = [];
      D1(d, e, i, r, s, t), x0(d, t);
    }
    function zt(e, t) {
      var r = !1, i = aE(t), o = L0(e, r);
      i.has(o) || (D0(t, e, Xu, r), i.add(o));
    }
    var w0 = "_reactListening" + Math.random().toString(36).slice(2);
    function k0(e) {
      {
        if (e[w0])
          return;
        e[w0] = !0, F.forEach(function(t) {
          O1.has(t) || _0(t, !1, e, null), _0(t, !0, e, null);
        });
      }
    }
    function _0(e, t, r, i) {
      var o = arguments.length > 4 && arguments[4] !== void 0 ? arguments[4] : 0, s = r;
      e === "selectionchange" && r.nodeType !== Da && (s = r.ownerDocument);
      var d = aE(s), v = L0(e, t);
      d.has(v) || (t && (o |= Si), D0(s, e, o, t), d.add(v));
    }
    function D0(e, t, r, i, o) {
      var s = Rp(e, t, r), d = void 0;
      Oo && (t === "touchstart" || t === "touchmove" || t === "wheel") && (d = !0), e = e, i ? d !== void 0 ? _p(e, t, s, d) : df(e, t, s) : d !== void 0 ? im(e, t, s, d) : kp(e, t, s);
    }
    function O0(e, t) {
      return e === t || e.nodeType === wn && e.parentNode === t;
    }
    function N0(e, t, r, i, o) {
      var s = i;
      if (!(t & _c) && !(t & Xu)) {
        var d = o;
        if (i !== null) {
          var v = i;
          e: for (; ; ) {
            if (v === null)
              return;
            var E = v.tag;
            if (E === B || E === Y) {
              var R = v.stateNode.containerInfo;
              if (O0(R, d))
                break;
              if (E === Y)
                for (var x = v.return; x !== null; ) {
                  var U = x.tag;
                  if (U === B || U === Y) {
                    var k = x.stateNode.containerInfo;
                    if (O0(k, d))
                      return;
                  }
                  x = x.return;
                }
              for (; R !== null; ) {
                var H = cu(R);
                if (H === null)
                  return;
                var Q = H.tag;
                if (Q === re || Q === ue) {
                  v = s = H;
                  continue e;
                }
                R = R.parentNode;
              }
            }
            v = v.return;
          }
        }
      }
      ts(function() {
        return M1(e, t, r, s);
      });
    }
    function wf(e, t, r) {
      return {
        instance: e,
        listener: t,
        currentTarget: r
      };
    }
    function L1(e, t, r, i, o) {
      for (var s = t !== null ? t + "Capture" : null, d = i ? s : t, v = [], E = e, R = null; E !== null; ) {
        var x = E, U = x.stateNode, k = x.tag;
        if (k === re && U !== null && (R = U, d !== null)) {
          var H = Tl(E, d);
          H != null && v.push(wf(E, H, R));
        }
        if (o)
          break;
        E = E.return;
      }
      return v;
    }
    function Pp(e, t) {
      for (var r = t + "Capture", i = [], o = e; o !== null; ) {
        var s = o, d = s.stateNode, v = s.tag;
        if (v === re && d !== null) {
          var E = d, R = Tl(o, r);
          R != null && i.unshift(wf(o, R, E));
          var x = Tl(o, t);
          x != null && i.push(wf(o, x, E));
        }
        o = o.return;
      }
      return i;
    }
    function Ms(e) {
      if (e === null)
        return null;
      do
        e = e.return;
      while (e && e.tag !== re);
      return e || null;
    }
    function A1(e, t) {
      for (var r = e, i = t, o = 0, s = r; s; s = Ms(s))
        o++;
      for (var d = 0, v = i; v; v = Ms(v))
        d++;
      for (; o - d > 0; )
        r = Ms(r), o--;
      for (; d - o > 0; )
        i = Ms(i), d--;
      for (var E = o; E--; ) {
        if (r === i || i !== null && r === i.alternate)
          return r;
        r = Ms(r), i = Ms(i);
      }
      return null;
    }
    function M0(e, t, r, i, o) {
      for (var s = t._reactName, d = [], v = r; v !== null && v !== i; ) {
        var E = v, R = E.alternate, x = E.stateNode, U = E.tag;
        if (R !== null && R === i)
          break;
        if (U === re && x !== null) {
          var k = x;
          if (o) {
            var H = Tl(v, s);
            H != null && d.unshift(wf(v, H, k));
          } else if (!o) {
            var Q = Tl(v, s);
            Q != null && d.push(wf(v, Q, k));
          }
        }
        v = v.return;
      }
      d.length !== 0 && e.push({
        event: t,
        listeners: d
      });
    }
    function U1(e, t, r, i, o) {
      var s = i && o ? A1(i, o) : null;
      i !== null && M0(e, t, i, s, !1), o !== null && r !== null && M0(e, r, o, s, !0);
    }
    function L0(e, t) {
      return e + "__" + (t ? "capture" : "bubble");
    }
    var or = !1, kf = "dangerouslySetInnerHTML", Bp = "suppressContentEditableWarning", _f = "suppressHydrationWarning", A0 = "autoFocus", uu = "children", su = "style", Vp = "__html", Ls = Yu.html, gm, Df, Ip, $p, Of, U0, Wp, z0, Nf, j0;
    {
      gm = {
        // There are working polyfills for <dialog>. Let people use it.
        dialog: !0,
        // Electron ships a custom <webview> tag to display external web content in
        // an isolated frame and process.
        // This tag is not present in non Electron environments such as JSDom which
        // is often used for testing purposes.
        // @see https://electronjs.org/docs/api/webview-tag
        webview: !0
      }, Ip = function(e, t) {
        Yd(e, t), Yh(e, t), Xd(e, t, {
          registrationNameDependencies: te,
          possibleRegistrationNames: G
        });
      }, z0 = Re && !document.documentMode;
      var z1 = /\r\n?/g, j1 = /\u0000|\uFFFD/g;
      Nf = function(e) {
        var t = typeof e == "string" ? e : "" + e;
        return t.replace(z1, `
`).replace(j1, "");
      }, $p = function(e, t) {
        if (!or) {
          var r = Nf(t), i = Nf(e);
          i !== r && (or = !0, y('Text content did not match. Server: "%s" Client: "%s"', i, r));
        }
      }, Of = function(e, t, r) {
        if (!or) {
          var i = Nf(r), o = Nf(t);
          o !== i && (or = !0, y("Prop `%s` did not match. Server: %s Client: %s", e, JSON.stringify(o), JSON.stringify(i)));
        }
      }, U0 = function(e) {
        if (!or) {
          or = !0;
          var t = [];
          e.forEach(function(r) {
            t.push(r);
          }), y("Extra attributes from the server: %s", t);
        }
      }, Wp = function(e, t) {
        t === !1 ? y("Expected `%s` listener to be a function, instead got `false`.\n\nIf you used to conditionally omit it with %s={condition && value}, pass %s={condition ? value : undefined} instead.", e, e, e) : y("Expected `%s` listener to be a function, instead got a value of `%s` type.", e, typeof t);
      }, j0 = function(e, t) {
        var r = e.namespaceURI === Ls ? e.ownerDocument.createElement(e.tagName) : e.ownerDocument.createElementNS(e.namespaceURI, e.tagName);
        return r.innerHTML = t, r.innerHTML;
      };
    }
    function F0(e) {
      return e.nodeType === Da ? e : e.ownerDocument;
    }
    function F1() {
    }
    function Yp(e) {
      e.onclick = F1;
    }
    function H1(e, t, r, i, o) {
      for (var s in i)
        if (i.hasOwnProperty(s)) {
          var d = i[s];
          if (s === su)
            d && Object.freeze(d), Rc(t, d);
          else if (s === kf) {
            var v = d ? d[Vp] : void 0;
            v != null && Od(t, v);
          } else if (s === uu)
            if (typeof d == "string") {
              var E = e !== "textarea" || d !== "";
              E && Qu(t, d);
            } else typeof d == "number" && Qu(t, "" + d);
          else s === Bp || s === _f || s === A0 || (te.hasOwnProperty(s) ? d != null && (typeof d != "function" && Wp(s, d), s === "onScroll" && zt("scroll", t)) : d != null && Ht(t, s, d, o));
        }
    }
    function P1(e, t, r, i) {
      for (var o = 0; o < t.length; o += 2) {
        var s = t[o], d = t[o + 1];
        s === su ? Rc(e, d) : s === kf ? Od(e, d) : s === uu ? Qu(e, d) : Ht(e, s, d, i);
      }
    }
    function B1(e, t, r, i) {
      var o, s = F0(r), d, v = i;
      if (v === Ls && (v = To(e)), v === Ls) {
        if (o = vr(e, t), !o && e !== e.toLowerCase() && y("<%s /> is using incorrect casing. Use PascalCase for React components, or lowercase for HTML elements.", e), e === "script") {
          var E = s.createElement("div");
          E.innerHTML = "<script><\/script>";
          var R = E.firstChild;
          d = E.removeChild(R);
        } else if (typeof t.is == "string")
          d = s.createElement(e, {
            is: t.is
          });
        else if (d = s.createElement(e), e === "select") {
          var x = d;
          t.multiple ? x.multiple = !0 : t.size && (x.size = t.size);
        }
      } else
        d = s.createElementNS(v, e);
      return v === Ls && !o && Object.prototype.toString.call(d) === "[object HTMLUnknownElement]" && !Object.prototype.hasOwnProperty.call(gm, e) && (gm[e] = !0, y("The tag <%s> is unrecognized in this browser. If you meant to render a React component, start its name with an uppercase letter.", e)), d;
    }
    function V1(e, t) {
      return F0(t).createTextNode(e);
    }
    function I1(e, t, r, i) {
      var o = vr(t, r);
      Ip(t, r);
      var s;
      switch (t) {
        case "dialog":
          zt("cancel", e), zt("close", e), s = r;
          break;
        case "iframe":
        case "object":
        case "embed":
          zt("load", e), s = r;
          break;
        case "video":
        case "audio":
          for (var d = 0; d < xf.length; d++)
            zt(xf[d], e);
          s = r;
          break;
        case "source":
          zt("error", e), s = r;
          break;
        case "img":
        case "image":
        case "link":
          zt("error", e), zt("load", e), s = r;
          break;
        case "details":
          zt("toggle", e), s = r;
          break;
        case "input":
          yi(e, r), s = gt(e, r), zt("invalid", e);
          break;
        case "option":
          _d(e, r), s = vc(e, r);
          break;
        case "select":
          $u(e, r), s = Co(e, r), zt("invalid", e);
          break;
        case "textarea":
          bo(e, r), s = hl(e, r), zt("invalid", e);
          break;
        default:
          s = r;
      }
      switch (Gu(t, s), H1(t, e, i, s, o), t) {
        case "input":
          yo(e), pl(e, r, !1);
          break;
        case "textarea":
          yo(e), Un(e);
          break;
        case "option":
          Nh(e, r);
          break;
        case "select":
          _a(e, r);
          break;
        default:
          typeof s.onClick == "function" && Yp(e);
          break;
      }
    }
    function $1(e, t, r, i, o) {
      Ip(t, i);
      var s = null, d, v;
      switch (t) {
        case "input":
          d = gt(e, r), v = gt(e, i), s = [];
          break;
        case "option":
          d = vc(e, r), v = vc(e, i), s = [];
          break;
        case "select":
          d = Co(e, r), v = Co(e, i), s = [];
          break;
        case "textarea":
          d = hl(e, r), v = hl(e, i), s = [];
          break;
        default:
          d = r, v = i, typeof d.onClick != "function" && typeof v.onClick == "function" && Yp(e);
          break;
      }
      Gu(t, v);
      var E, R, x = null;
      for (E in d)
        if (!(v.hasOwnProperty(E) || !d.hasOwnProperty(E) || d[E] == null))
          if (E === su) {
            var U = d[E];
            for (R in U)
              U.hasOwnProperty(R) && (x || (x = {}), x[R] = "");
          } else E === kf || E === uu || E === Bp || E === _f || E === A0 || (te.hasOwnProperty(E) ? s || (s = []) : (s = s || []).push(E, null));
      for (E in v) {
        var k = v[E], H = d != null ? d[E] : void 0;
        if (!(!v.hasOwnProperty(E) || k === H || k == null && H == null))
          if (E === su)
            if (k && Object.freeze(k), H) {
              for (R in H)
                H.hasOwnProperty(R) && (!k || !k.hasOwnProperty(R)) && (x || (x = {}), x[R] = "");
              for (R in k)
                k.hasOwnProperty(R) && H[R] !== k[R] && (x || (x = {}), x[R] = k[R]);
            } else
              x || (s || (s = []), s.push(E, x)), x = k;
          else if (E === kf) {
            var Q = k ? k[Vp] : void 0, se = H ? H[Vp] : void 0;
            Q != null && se !== Q && (s = s || []).push(E, Q);
          } else E === uu ? (typeof k == "string" || typeof k == "number") && (s = s || []).push(E, "" + k) : E === Bp || E === _f || (te.hasOwnProperty(E) ? (k != null && (typeof k != "function" && Wp(E, k), E === "onScroll" && zt("scroll", e)), !s && H !== k && (s = [])) : typeof k == "object" && k !== null && k.$$typeof === so ? k.toString() : (s = s || []).push(E, k));
      }
      return x && (Vh(x, v[su]), (s = s || []).push(su, x)), s;
    }
    function W1(e, t, r, i, o) {
      r === "input" && o.type === "radio" && o.name != null && wd(e, o);
      var s = vr(r, i), d = vr(r, o);
      switch (P1(e, t, s, d), r) {
        case "input":
          pc(e, o);
          break;
        case "textarea":
          gc(e, o);
          break;
        case "select":
          mc(e, o);
          break;
      }
    }
    function Y1(e) {
      {
        var t = e.toLowerCase();
        return Oa.hasOwnProperty(t) && Oa[t] || null;
      }
    }
    function q1(e, t, r, i, o) {
      var s, d;
      switch (Df = r[_f] === !0, s = vr(t, r), Ip(t, r), t) {
        case "dialog":
          zt("cancel", e), zt("close", e);
          break;
        case "iframe":
        case "object":
        case "embed":
          zt("load", e);
          break;
        case "video":
        case "audio":
          for (var v = 0; v < xf.length; v++)
            zt(xf[v], e);
          break;
        case "source":
          zt("error", e);
          break;
        case "img":
        case "image":
        case "link":
          zt("error", e), zt("load", e);
          break;
        case "details":
          zt("toggle", e);
          break;
        case "input":
          yi(e, r), zt("invalid", e);
          break;
        case "option":
          _d(e, r);
          break;
        case "select":
          $u(e, r), zt("invalid", e);
          break;
        case "textarea":
          bo(e, r), zt("invalid", e);
          break;
      }
      Gu(t, r);
      {
        d = /* @__PURE__ */ new Set();
        for (var E = e.attributes, R = 0; R < E.length; R++) {
          var x = E[R].name.toLowerCase();
          switch (x) {
            case "data-reactroot":
              break;
            case "value":
              break;
            case "checked":
              break;
            case "selected":
              break;
            default:
              d.add(E[R].name);
          }
        }
      }
      var U = null;
      for (var k in r)
        if (r.hasOwnProperty(k)) {
          var H = r[k];
          if (k === uu)
            typeof H == "string" ? e.textContent !== H && (Df || $p(e.textContent, H), U = [uu, H]) : typeof H == "number" && e.textContent !== "" + H && (Df || $p(e.textContent, H), U = [uu, "" + H]);
          else if (te.hasOwnProperty(k))
            H != null && (typeof H != "function" && Wp(k, H), k === "onScroll" && zt("scroll", e));
          else if (
            // Convince Flow we've calculated it (it's DEV-only in this method.)
            typeof s == "boolean"
          ) {
            var Q = void 0, se = di(k);
            if (!Df) {
              if (!(k === Bp || k === _f || // Controlled attributes are not validated
              // TODO: Only ignore them on controlled tags.
              k === "value" || k === "checked" || k === "selected")) {
                if (k === kf) {
                  var Me = e.innerHTML, Xe = H ? H[Vp] : void 0;
                  if (Xe != null) {
                    var je = j0(e, Xe);
                    je !== Me && Of(k, Me, je);
                  }
                } else if (k === su) {
                  if (d.delete(k), z0) {
                    var ft = Pd(H);
                    Q = e.getAttribute("style"), ft !== Q && Of(k, Q, ft);
                  }
                } else if (s)
                  d.delete(k.toLowerCase()), Q = Ft(e, k, H), H !== Q && Of(k, Q, H);
                else if (!oo(k, se, s) && !fi(k, H, se, s)) {
                  var kt = !1;
                  if (se !== null)
                    d.delete(se.attributeName), Q = Jt(e, k, H, se);
                  else {
                    var j = i;
                    if (j === Ls && (j = To(t)), j === Ls)
                      d.delete(k.toLowerCase());
                    else {
                      var V = Y1(k);
                      V !== null && V !== k && (kt = !0, d.delete(V)), d.delete(k);
                    }
                    Q = Ft(e, k, H);
                  }
                  H !== Q && !kt && Of(k, Q, H);
                }
              }
            }
          }
        }
      switch (d.size > 0 && !Df && U0(d), t) {
        case "input":
          yo(e), pl(e, r, !0);
          break;
        case "textarea":
          yo(e), Un(e);
          break;
        case "select":
        case "option":
          break;
        default:
          typeof r.onClick == "function" && Yp(e);
          break;
      }
      return U;
    }
    function Q1(e, t) {
      var r = e.nodeValue !== t;
      return r;
    }
    function H0(e, t) {
      $p(e.nodeValue, t);
    }
    function P0(e, t) {
      {
        if (or)
          return;
        or = !0, y("Did not expect server HTML to contain a <%s> in <%s>.", t.nodeName.toLowerCase(), e.nodeName.toLowerCase());
      }
    }
    function B0(e, t) {
      {
        if (or)
          return;
        or = !0, y('Did not expect server HTML to contain the text node "%s" in <%s>.', t.nodeValue, e.nodeName.toLowerCase());
      }
    }
    function V0(e, t, r) {
      {
        if (or)
          return;
        or = !0, y("Expected server HTML to contain a matching <%s> in <%s>.", t, e.nodeName.toLowerCase());
      }
    }
    function I0(e, t) {
      {
        if (t === "" || or)
          return;
        or = !0, y('Expected server HTML to contain a matching text node for "%s" in <%s>.', t, e.nodeName.toLowerCase());
      }
    }
    function G1(e, t, r) {
      switch (t) {
        case "input":
          kd(e, r);
          return;
        case "textarea":
          ml(e, r);
          return;
        case "select":
          Wu(e, r);
          return;
      }
    }
    var Mf = function() {
    }, Lf = function() {
    };
    {
      var X1 = ["address", "applet", "area", "article", "aside", "base", "basefont", "bgsound", "blockquote", "body", "br", "button", "caption", "center", "col", "colgroup", "dd", "details", "dir", "div", "dl", "dt", "embed", "fieldset", "figcaption", "figure", "footer", "form", "frame", "frameset", "h1", "h2", "h3", "h4", "h5", "h6", "head", "header", "hgroup", "hr", "html", "iframe", "img", "input", "isindex", "li", "link", "listing", "main", "marquee", "menu", "menuitem", "meta", "nav", "noembed", "noframes", "noscript", "object", "ol", "p", "param", "plaintext", "pre", "script", "section", "select", "source", "style", "summary", "table", "tbody", "td", "template", "textarea", "tfoot", "th", "thead", "title", "tr", "track", "ul", "wbr", "xmp"], $0 = [
        "applet",
        "caption",
        "html",
        "table",
        "td",
        "th",
        "marquee",
        "object",
        "template",
        // https://html.spec.whatwg.org/multipage/syntax.html#html-integration-point
        // TODO: Distinguish by namespace here -- for <title>, including it here
        // errs on the side of fewer warnings
        "foreignObject",
        "desc",
        "title"
      ], K1 = $0.concat(["button"]), Z1 = ["dd", "dt", "li", "option", "optgroup", "p", "rp", "rt"], W0 = {
        current: null,
        formTag: null,
        aTagInScope: null,
        buttonTagInScope: null,
        nobrTagInScope: null,
        pTagInButtonScope: null,
        listItemTagAutoclosing: null,
        dlItemTagAutoclosing: null
      };
      Lf = function(e, t) {
        var r = p({}, e || W0), i = {
          tag: t
        };
        return $0.indexOf(t) !== -1 && (r.aTagInScope = null, r.buttonTagInScope = null, r.nobrTagInScope = null), K1.indexOf(t) !== -1 && (r.pTagInButtonScope = null), X1.indexOf(t) !== -1 && t !== "address" && t !== "div" && t !== "p" && (r.listItemTagAutoclosing = null, r.dlItemTagAutoclosing = null), r.current = i, t === "form" && (r.formTag = i), t === "a" && (r.aTagInScope = i), t === "button" && (r.buttonTagInScope = i), t === "nobr" && (r.nobrTagInScope = i), t === "p" && (r.pTagInButtonScope = i), t === "li" && (r.listItemTagAutoclosing = i), (t === "dd" || t === "dt") && (r.dlItemTagAutoclosing = i), r;
      };
      var J1 = function(e, t) {
        switch (t) {
          case "select":
            return e === "option" || e === "optgroup" || e === "#text";
          case "optgroup":
            return e === "option" || e === "#text";
          case "option":
            return e === "#text";
          case "tr":
            return e === "th" || e === "td" || e === "style" || e === "script" || e === "template";
          case "tbody":
          case "thead":
          case "tfoot":
            return e === "tr" || e === "style" || e === "script" || e === "template";
          case "colgroup":
            return e === "col" || e === "template";
          case "table":
            return e === "caption" || e === "colgroup" || e === "tbody" || e === "tfoot" || e === "thead" || e === "style" || e === "script" || e === "template";
          case "head":
            return e === "base" || e === "basefont" || e === "bgsound" || e === "link" || e === "meta" || e === "title" || e === "noscript" || e === "noframes" || e === "style" || e === "script" || e === "template";
          case "html":
            return e === "head" || e === "body" || e === "frameset";
          case "frameset":
            return e === "frame";
          case "#document":
            return e === "html";
        }
        switch (e) {
          case "h1":
          case "h2":
          case "h3":
          case "h4":
          case "h5":
          case "h6":
            return t !== "h1" && t !== "h2" && t !== "h3" && t !== "h4" && t !== "h5" && t !== "h6";
          case "rp":
          case "rt":
            return Z1.indexOf(t) === -1;
          case "body":
          case "caption":
          case "col":
          case "colgroup":
          case "frameset":
          case "frame":
          case "head":
          case "html":
          case "tbody":
          case "td":
          case "tfoot":
          case "th":
          case "thead":
          case "tr":
            return t == null;
        }
        return !0;
      }, eT = function(e, t) {
        switch (e) {
          case "address":
          case "article":
          case "aside":
          case "blockquote":
          case "center":
          case "details":
          case "dialog":
          case "dir":
          case "div":
          case "dl":
          case "fieldset":
          case "figcaption":
          case "figure":
          case "footer":
          case "header":
          case "hgroup":
          case "main":
          case "menu":
          case "nav":
          case "ol":
          case "p":
          case "section":
          case "summary":
          case "ul":
          case "pre":
          case "listing":
          case "table":
          case "hr":
          case "xmp":
          case "h1":
          case "h2":
          case "h3":
          case "h4":
          case "h5":
          case "h6":
            return t.pTagInButtonScope;
          case "form":
            return t.formTag || t.pTagInButtonScope;
          case "li":
            return t.listItemTagAutoclosing;
          case "dd":
          case "dt":
            return t.dlItemTagAutoclosing;
          case "button":
            return t.buttonTagInScope;
          case "a":
            return t.aTagInScope;
          case "nobr":
            return t.nobrTagInScope;
        }
        return null;
      }, Y0 = {};
      Mf = function(e, t, r) {
        r = r || W0;
        var i = r.current, o = i && i.tag;
        t != null && (e != null && y("validateDOMNesting: when childText is passed, childTag should be null"), e = "#text");
        var s = J1(e, o) ? null : i, d = s ? null : eT(e, r), v = s || d;
        if (v) {
          var E = v.tag, R = !!s + "|" + e + "|" + E;
          if (!Y0[R]) {
            Y0[R] = !0;
            var x = e, U = "";
            if (e === "#text" ? /\S/.test(t) ? x = "Text nodes" : (x = "Whitespace text nodes", U = " Make sure you don't have any extra whitespace between tags on each line of your source code.") : x = "<" + e + ">", s) {
              var k = "";
              E === "table" && e === "tr" && (k += " Add a <tbody>, <thead> or <tfoot> to your code to match the DOM tree generated by the browser."), y("validateDOMNesting(...): %s cannot appear as a child of <%s>.%s%s", x, E, U, k);
            } else
              y("validateDOMNesting(...): %s cannot appear as a descendant of <%s>.", x, E);
          }
        }
      };
    }
    var As;
    As = "suppressHydrationWarning";
    var q0 = "$", Q0 = "/$", Em = "$?", Sm = "$!", tT = "style", Cm = null, bm = null;
    function G0(e, t) {
      switch (e) {
        case "button":
        case "input":
        case "select":
        case "textarea":
          return !!t.autoFocus;
      }
      return !1;
    }
    function nT(e) {
      var t, r, i = e.nodeType;
      switch (i) {
        case Da:
        case Nd: {
          t = i === Da ? "#document" : "#fragment";
          var o = e.documentElement;
          r = o ? o.namespaceURI : gi(null, "");
          break;
        }
        default: {
          var s = i === wn ? e.parentNode : e, d = s.namespaceURI || null;
          t = s.tagName, r = gi(d, t);
          break;
        }
      }
      {
        var v = t.toLowerCase(), E = Lf(null, v);
        return {
          namespace: r,
          ancestorInfo: E
        };
      }
    }
    function rT(e, t, r) {
      {
        var i = e, o = gi(i.namespace, t), s = Lf(i.ancestorInfo, t);
        return {
          namespace: o,
          ancestorInfo: s
        };
      }
    }
    function OD(e) {
      return e;
    }
    function aT(e) {
      Cm = Tp(), bm = M();
      var t = null;
      return ff(!1), t;
    }
    function iT(e) {
      _(bm), ff(Cm), Cm = null, bm = null;
    }
    function lT(e, t, r, i, o) {
      var s;
      {
        var d = i;
        if (Mf(e, null, d.ancestorInfo), typeof t.children == "string" || typeof t.children == "number") {
          var v = "" + t.children, E = Lf(d.ancestorInfo, e);
          Mf(null, v, E);
        }
        s = d.namespace;
      }
      var R = B1(e, t, r, s);
      return Gp(o, R), wm(R, t), R;
    }
    function oT(e, t) {
      e.appendChild(t);
    }
    function uT(e, t, r, i, o) {
      return I1(e, t, r, i), G0(t, r);
    }
    function sT(e, t, r, i, o, s) {
      {
        var d = s;
        if (typeof i.children != typeof r.children && (typeof i.children == "string" || typeof i.children == "number")) {
          var v = "" + i.children, E = Lf(d.ancestorInfo, t);
          Mf(null, v, E);
        }
      }
      return $1(e, t, r, i);
    }
    function Tm(e, t) {
      return e === "textarea" || e === "option" || e === "noscript" || typeof t.children == "string" || typeof t.children == "number" || typeof t.dangerouslySetInnerHTML == "object" && t.dangerouslySetInnerHTML !== null && t.dangerouslySetInnerHTML.__html != null;
    }
    function cT(e, t, r, i) {
      {
        var o = r;
        Mf(null, e, o.ancestorInfo);
      }
      var s = V1(e, t);
      return Gp(i, s), s;
    }
    var X0 = typeof setTimeout == "function" ? setTimeout : void 0, fT = typeof clearTimeout == "function" ? clearTimeout : void 0, Rm = -1;
    function dT(e, t, r, i) {
      G0(t, r) && e.focus();
    }
    function pT(e, t, r, i, o, s) {
      wm(e, o), W1(e, t, r, i, o);
    }
    function K0(e) {
      Qu(e, "");
    }
    function vT(e, t, r) {
      e.nodeValue = r;
    }
    function hT(e, t) {
      e.appendChild(t);
    }
    function mT(e, t) {
      var r;
      e.nodeType === wn ? (r = e.parentNode, r.insertBefore(t, e)) : (r = e, r.appendChild(t));
      var i = e._reactRootContainer;
      i == null && r.onclick === null && Yp(r);
    }
    function yT(e, t, r) {
      e.insertBefore(t, r);
    }
    function gT(e, t, r) {
      e.nodeType === wn ? e.parentNode.insertBefore(t, r) : e.insertBefore(t, r);
    }
    function ET(e, t) {
      e.removeChild(t);
    }
    function ST(e, t) {
      e.nodeType === wn ? e.parentNode.removeChild(t) : e.removeChild(t);
    }
    function CT(e) {
      e = e;
      var t = e.style;
      typeof t.setProperty == "function" ? t.setProperty("display", "none", "important") : t.display = "none";
    }
    function bT(e) {
      e.nodeValue = "";
    }
    function TT(e, t) {
      e = e;
      var r = t[tT], i = r != null && r.hasOwnProperty("display") ? r.display : null;
      e.style.display = Sc("display", i);
    }
    function RT(e, t) {
      e.nodeValue = t;
    }
    function xm(e) {
      if (e.nodeType === er)
        e.textContent = "";
      else if (e.nodeType === Da) {
        var t = e.body;
        t != null && (t.textContent = "");
      }
    }
    function xT(e, t, r) {
      return e.nodeType !== er || t.toLowerCase() !== e.nodeName.toLowerCase() ? null : e;
    }
    function wT(e, t) {
      return t === "" || e.nodeType !== Zr ? null : e;
    }
    function kT(e) {
      return e.data === Em;
    }
    function _T(e) {
      return e.data === Sm;
    }
    function Z0(e) {
      for (; e != null; e = e.nextSibling) {
        var t = e.nodeType;
        if (t === er || t === Zr)
          break;
      }
      return e;
    }
    function qp(e) {
      return Z0(e.nextSibling);
    }
    function J0(e) {
      return Z0(e.firstChild);
    }
    function DT(e, t, r, i, o, s) {
      Gp(s, e), wm(e, r);
      var d;
      {
        var v = o;
        d = v.namespace;
      }
      return q1(e, t, r, d);
    }
    function OT(e, t, r) {
      return Gp(r, e), Q1(e, t);
    }
    function NT(e) {
      for (var t = e.nextSibling, r = 0; t; ) {
        if (t.nodeType === wn) {
          var i = t.data;
          if (i === Q0) {
            if (r === 0)
              return qp(t);
            r--;
          } else (i === q0 || i === Sm || i === Em) && r++;
        }
        t = t.nextSibling;
      }
      return null;
    }
    function eE(e) {
      for (var t = e.previousSibling, r = 0; t; ) {
        if (t.nodeType === wn) {
          var i = t.data;
          if (i === q0 || i === Sm || i === Em) {
            if (r === 0)
              return t;
            r--;
          } else i === Q0 && r++;
        }
        t = t.previousSibling;
      }
      return null;
    }
    function MT(e) {
      Wc(e);
    }
    function LT(e) {
      Wc(e);
    }
    function AT(e, t, r) {
      H0(t, r);
    }
    function UT(e, t, r, i, o) {
      t[As] !== !0 && H0(i, o);
    }
    function zT(e, t) {
      t.nodeType === er ? P0(e, t) : t.nodeType === wn || B0(e, t);
    }
    function jT(e, t, r, i) {
      t[As] !== !0 && (i.nodeType === er ? P0(r, i) : i.nodeType === wn || B0(r, i));
    }
    function FT(e, t, r) {
      V0(e, t);
    }
    function HT(e, t) {
      I0(e, t);
    }
    function PT(e, t, r, i, o) {
      t[As] !== !0 && V0(r, i);
    }
    function BT(e, t, r, i) {
      t[As] !== !0 && I0(r, i);
    }
    function VT(e, t, r) {
      t[As];
    }
    var IT = 0;
    function $T(e) {
      var t = "r:" + (IT++).toString(36);
      return {
        toString: function() {
          return e(), t;
        },
        valueOf: function() {
          return e(), t;
        }
      };
    }
    function WT(e) {
      return e !== null && typeof e == "object" && e.$$typeof === so;
    }
    function YT(e) {
      return {
        $$typeof: so,
        toString: e,
        valueOf: e
      };
    }
    function qT(e) {
      k0(e);
    }
    var Qp = Math.random().toString(36).slice(2), Af = "__reactFiber$" + Qp, tE = "__reactProps$" + Qp, Uf = "__reactContainer$" + Qp, nE = "__reactEvents$" + Qp;
    function Gp(e, t) {
      t[Af] = e;
    }
    function QT(e, t) {
      t[Uf] = e;
    }
    function rE(e) {
      e[Uf] = null;
    }
    function Xp(e) {
      return !!e[Uf];
    }
    function cu(e) {
      var t = e[Af];
      if (t)
        return t;
      for (var r = e.parentNode; r; ) {
        if (t = r[Uf] || r[Af], t) {
          var i = t.alternate;
          if (t.child !== null || i !== null && i.child !== null)
            for (var o = eE(e); o !== null; ) {
              var s = o[Af];
              if (s)
                return s;
              o = eE(o);
            }
          return t;
        }
        e = r, r = e.parentNode;
      }
      return null;
    }
    function Yl(e) {
      var t = e[Af] || e[Uf];
      return t && (t.tag === re || t.tag === ue || t.tag === z || t.tag === B) ? t : null;
    }
    function Us(e) {
      if (e.tag === re || e.tag === ue)
        return e.stateNode;
      throw Error("getNodeFromInstance: Invalid argument.");
    }
    function Kp(e) {
      return e[tE] || null;
    }
    function wm(e, t) {
      e[tE] = t;
    }
    function aE(e) {
      var t = e[nE];
      return t === void 0 && (t = e[nE] = /* @__PURE__ */ new Set()), t;
    }
    var iE = {}, lE = b.ReactDebugCurrentFrame;
    function Zp(e) {
      if (e) {
        var t = e._owner, r = Kn(e.type, e._source, t ? t.type : null);
        lE.setExtraStackFrame(r);
      } else
        lE.setExtraStackFrame(null);
    }
    function da(e, t, r, i, o) {
      {
        var s = Function.call.bind(Object.prototype.hasOwnProperty);
        for (var d in e)
          if (s(e, d)) {
            var v = void 0;
            try {
              if (typeof e[d] != "function") {
                var E = Error((i || "React class") + ": " + r + " type `" + d + "` is invalid; it must be a function, usually from the `prop-types` package, but received `" + typeof e[d] + "`.This often happens because of typos such as `PropTypes.function` instead of `PropTypes.func`.");
                throw E.name = "Invariant Violation", E;
              }
              v = e[d](t, d, i, r, null, "SECRET_DO_NOT_PASS_THIS_OR_YOU_WILL_BE_FIRED");
            } catch (R) {
              v = R;
            }
            v && !(v instanceof Error) && (Zp(o), y("%s: type specification of %s `%s` is invalid; the type checker function must return `null` or an `Error` but returned a %s. You may have forgotten to pass an argument to the type checker creator (arrayOf, instanceOf, objectOf, oneOf, oneOfType, and shape all require an argument).", i || "React class", r, d, typeof v), Zp(null)), v instanceof Error && !(v.message in iE) && (iE[v.message] = !0, Zp(o), y("Failed %s type: %s", r, v.message), Zp(null));
          }
      }
    }
    var km = [], Jp;
    Jp = [];
    var Vi = -1;
    function ql(e) {
      return {
        current: e
      };
    }
    function jn(e, t) {
      if (Vi < 0) {
        y("Unexpected pop.");
        return;
      }
      t !== Jp[Vi] && y("Unexpected Fiber popped."), e.current = km[Vi], km[Vi] = null, Jp[Vi] = null, Vi--;
    }
    function Fn(e, t, r) {
      Vi++, km[Vi] = e.current, Jp[Vi] = r, e.current = t;
    }
    var _m;
    _m = {};
    var Er = {};
    Object.freeze(Er);
    var Ii = ql(Er), Ja = ql(!1), Dm = Er;
    function zs(e, t, r) {
      return r && ei(t) ? Dm : Ii.current;
    }
    function oE(e, t, r) {
      {
        var i = e.stateNode;
        i.__reactInternalMemoizedUnmaskedChildContext = t, i.__reactInternalMemoizedMaskedChildContext = r;
      }
    }
    function js(e, t) {
      {
        var r = e.type, i = r.contextTypes;
        if (!i)
          return Er;
        var o = e.stateNode;
        if (o && o.__reactInternalMemoizedUnmaskedChildContext === t)
          return o.__reactInternalMemoizedMaskedChildContext;
        var s = {};
        for (var d in i)
          s[d] = t[d];
        {
          var v = fe(r) || "Unknown";
          da(i, s, "context", v);
        }
        return o && oE(e, t, s), s;
      }
    }
    function ev() {
      return Ja.current;
    }
    function ei(e) {
      {
        var t = e.childContextTypes;
        return t != null;
      }
    }
    function tv(e) {
      jn(Ja, e), jn(Ii, e);
    }
    function Om(e) {
      jn(Ja, e), jn(Ii, e);
    }
    function uE(e, t, r) {
      {
        if (Ii.current !== Er)
          throw Error("Unexpected context found on stack. This error is likely caused by a bug in React. Please file an issue.");
        Fn(Ii, t, e), Fn(Ja, r, e);
      }
    }
    function sE(e, t, r) {
      {
        var i = e.stateNode, o = t.childContextTypes;
        if (typeof i.getChildContext != "function") {
          {
            var s = fe(t) || "Unknown";
            _m[s] || (_m[s] = !0, y("%s.childContextTypes is specified but there is no getChildContext() method on the instance. You can either define getChildContext() on %s or remove childContextTypes from it.", s, s));
          }
          return r;
        }
        var d = i.getChildContext();
        for (var v in d)
          if (!(v in o))
            throw Error((fe(t) || "Unknown") + '.getChildContext(): key "' + v + '" is not defined in childContextTypes.');
        {
          var E = fe(t) || "Unknown";
          da(o, d, "child context", E);
        }
        return p({}, r, d);
      }
    }
    function nv(e) {
      {
        var t = e.stateNode, r = t && t.__reactInternalMemoizedMergedChildContext || Er;
        return Dm = Ii.current, Fn(Ii, r, e), Fn(Ja, Ja.current, e), !0;
      }
    }
    function cE(e, t, r) {
      {
        var i = e.stateNode;
        if (!i)
          throw Error("Expected to have an instance by this point. This error is likely caused by a bug in React. Please file an issue.");
        if (r) {
          var o = sE(e, t, Dm);
          i.__reactInternalMemoizedMergedChildContext = o, jn(Ja, e), jn(Ii, e), Fn(Ii, o, e), Fn(Ja, r, e);
        } else
          jn(Ja, e), Fn(Ja, r, e);
      }
    }
    function GT(e) {
      {
        if (!(os(e) && e.tag === L))
          throw Error("Expected subtree parent to be a mounted class component. This error is likely caused by a bug in React. Please file an issue.");
        var t = e;
        do {
          switch (t.tag) {
            case B:
              return t.stateNode.context;
            case L: {
              var r = t.type;
              if (ei(r))
                return t.stateNode.__reactInternalMemoizedMergedChildContext;
              break;
            }
          }
          t = t.return;
        } while (t !== null);
        throw Error("Found unexpected detached subtree parent. This error is likely caused by a bug in React. Please file an issue.");
      }
    }
    var Nm = 0, fE = 1, dE = 2, rv = null, ti = null, Fs = !1, XT = typeof __REACT_DEVTOOLS_GLOBAL_HOOK__ < "u";
    function KT(e) {
      if (typeof __REACT_DEVTOOLS_GLOBAL_HOOK__ > "u")
        return !1;
      var t = __REACT_DEVTOOLS_GLOBAL_HOOK__;
      if (t.isDisabled)
        return !0;
      if (!t.supportsFiber)
        return y("The installed version of React DevTools is too old and will not work with the current version of React. Please update React DevTools. https://reactjs.org/link/react-devtools"), !0;
      try {
        rv = t.inject(e), ti = t;
      } catch (r) {
        y("React instrumentation encountered an error: %s.", r);
      }
      return !0;
    }
    function ZT(e, t) {
      if (ti && typeof ti.onScheduleFiberRoot == "function")
        try {
          ti.onScheduleFiberRoot(rv, e, t);
        } catch (r) {
          Fs || (Fs = !0, y("React instrumentation encountered an error: %s", r));
        }
    }
    function JT(e, t) {
      if (ti && typeof ti.onCommitFiberRoot == "function")
        try {
          var r = (e.current.flags & vt) === vt;
          mt && ti.onCommitFiberRoot(rv, e, t, r);
        } catch (i) {
          Fs || (Fs = !0, y("React instrumentation encountered an error: %s", i));
        }
    }
    function eR(e) {
      if (ti && typeof ti.onCommitFiberUnmount == "function")
        try {
          ti.onCommitFiberUnmount(rv, e);
        } catch (t) {
          Fs || (Fs = !0, y("React instrumentation encountered an error: %s", t));
        }
    }
    var tR = g.unstable_runWithPriority, Mm = g.unstable_scheduleCallback, pE = g.unstable_cancelCallback, nR = g.unstable_shouldYield, vE = g.unstable_requestPaint, Lm = g.unstable_now, rR = g.unstable_getCurrentPriorityLevel, av = g.unstable_ImmediatePriority, hE = g.unstable_UserBlockingPriority, mE = g.unstable_NormalPriority, yE = g.unstable_LowPriority, gE = g.unstable_IdlePriority;
    if (!(h.__interactionsRef != null && h.__interactionsRef.current != null))
      throw Error("It is not supported to run the profiling version of a renderer (for example, `react-dom/profiling`) without also replacing the `scheduler/tracing` module with `scheduler/tracing-profiling`. Your bundler might have a setting for aliasing both modules. Learn more at https://reactjs.org/link/profiling");
    var EE = {}, Vr = 99, fu = 98, $i = 97, SE = 96, CE = 95, Am = 90, aR = nR, iR = (
      // Fall back gracefully if we're running an older version of Scheduler.
      vE !== void 0 ? vE : function() {
      }
    ), Wi = null, iv = null, Um = !1, bE = Lm(), Hn = bE < 1e4 ? Lm : function() {
      return Lm() - bE;
    };
    function Hs() {
      switch (rR()) {
        case av:
          return Vr;
        case hE:
          return fu;
        case mE:
          return $i;
        case yE:
          return SE;
        case gE:
          return CE;
        default:
          throw Error("Unknown priority level.");
      }
    }
    function TE(e) {
      switch (e) {
        case Vr:
          return av;
        case fu:
          return hE;
        case $i:
          return mE;
        case SE:
          return yE;
        case CE:
          return gE;
        default:
          throw Error("Unknown priority level.");
      }
    }
    function du(e, t) {
      var r = TE(e);
      return tR(r, t);
    }
    function Ql(e, t, r) {
      var i = TE(e);
      return Mm(i, t, r);
    }
    function lR(e) {
      return Wi === null ? (Wi = [e], iv = Mm(av, xE)) : Wi.push(e), EE;
    }
    function RE(e) {
      e !== EE && pE(e);
    }
    function ni() {
      if (iv !== null) {
        var e = iv;
        iv = null, pE(e);
      }
      xE();
    }
    function xE() {
      if (!Um && Wi !== null) {
        Um = !0;
        var e = 0;
        try {
          var t = !0, r = Wi;
          du(Vr, function() {
            for (; e < r.length; e++) {
              var i = r[e];
              do
                i = i(t);
              while (i !== null);
            }
          }), Wi = null;
        } catch (i) {
          throw Wi !== null && (Wi = Wi.slice(e + 1)), Mm(av, ni), i;
        } finally {
          Um = !1;
        }
      }
    }
    var wE = "17.0.2", Vt = 0, Gt = 1, ur = 2, pu = 4, Sr = 8, oR = 16, uR = b.ReactCurrentBatchConfig, sR = 0;
    function cR() {
      return uR.transition;
    }
    var pa = {
      recordUnsafeLifecycleWarnings: function(e, t) {
      },
      flushPendingUnsafeLifecycleWarnings: function() {
      },
      recordLegacyContextWarning: function(e, t) {
      },
      flushLegacyContextWarning: function() {
      },
      discardPendingWarnings: function() {
      }
    };
    {
      var fR = function(e) {
        for (var t = null, r = e; r !== null; )
          r.mode & Gt && (t = r), r = r.return;
        return t;
      }, vu = function(e) {
        var t = [];
        return e.forEach(function(r) {
          t.push(r);
        }), t.sort().join(", ");
      }, zf = [], jf = [], Ff = [], Hf = [], Pf = [], Bf = [], hu = /* @__PURE__ */ new Set();
      pa.recordUnsafeLifecycleWarnings = function(e, t) {
        hu.has(e.type) || (typeof t.componentWillMount == "function" && // Don't warn about react-lifecycles-compat polyfilled components.
        t.componentWillMount.__suppressDeprecationWarning !== !0 && zf.push(e), e.mode & Gt && typeof t.UNSAFE_componentWillMount == "function" && jf.push(e), typeof t.componentWillReceiveProps == "function" && t.componentWillReceiveProps.__suppressDeprecationWarning !== !0 && Ff.push(e), e.mode & Gt && typeof t.UNSAFE_componentWillReceiveProps == "function" && Hf.push(e), typeof t.componentWillUpdate == "function" && t.componentWillUpdate.__suppressDeprecationWarning !== !0 && Pf.push(e), e.mode & Gt && typeof t.UNSAFE_componentWillUpdate == "function" && Bf.push(e));
      }, pa.flushPendingUnsafeLifecycleWarnings = function() {
        var e = /* @__PURE__ */ new Set();
        zf.length > 0 && (zf.forEach(function(k) {
          e.add(fe(k.type) || "Component"), hu.add(k.type);
        }), zf = []);
        var t = /* @__PURE__ */ new Set();
        jf.length > 0 && (jf.forEach(function(k) {
          t.add(fe(k.type) || "Component"), hu.add(k.type);
        }), jf = []);
        var r = /* @__PURE__ */ new Set();
        Ff.length > 0 && (Ff.forEach(function(k) {
          r.add(fe(k.type) || "Component"), hu.add(k.type);
        }), Ff = []);
        var i = /* @__PURE__ */ new Set();
        Hf.length > 0 && (Hf.forEach(function(k) {
          i.add(fe(k.type) || "Component"), hu.add(k.type);
        }), Hf = []);
        var o = /* @__PURE__ */ new Set();
        Pf.length > 0 && (Pf.forEach(function(k) {
          o.add(fe(k.type) || "Component"), hu.add(k.type);
        }), Pf = []);
        var s = /* @__PURE__ */ new Set();
        if (Bf.length > 0 && (Bf.forEach(function(k) {
          s.add(fe(k.type) || "Component"), hu.add(k.type);
        }), Bf = []), t.size > 0) {
          var d = vu(t);
          y(`Using UNSAFE_componentWillMount in strict mode is not recommended and may indicate bugs in your code. See https://reactjs.org/link/unsafe-component-lifecycles for details.

* Move code with side effects to componentDidMount, and set initial state in the constructor.

Please update the following components: %s`, d);
        }
        if (i.size > 0) {
          var v = vu(i);
          y(`Using UNSAFE_componentWillReceiveProps in strict mode is not recommended and may indicate bugs in your code. See https://reactjs.org/link/unsafe-component-lifecycles for details.

* Move data fetching code or side effects to componentDidUpdate.
* If you're updating state whenever props change, refactor your code to use memoization techniques or move it to static getDerivedStateFromProps. Learn more at: https://reactjs.org/link/derived-state

Please update the following components: %s`, v);
        }
        if (s.size > 0) {
          var E = vu(s);
          y(`Using UNSAFE_componentWillUpdate in strict mode is not recommended and may indicate bugs in your code. See https://reactjs.org/link/unsafe-component-lifecycles for details.

* Move data fetching code or side effects to componentDidUpdate.

Please update the following components: %s`, E);
        }
        if (e.size > 0) {
          var R = vu(e);
          C(`componentWillMount has been renamed, and is not recommended for use. See https://reactjs.org/link/unsafe-component-lifecycles for details.

* Move code with side effects to componentDidMount, and set initial state in the constructor.
* Rename componentWillMount to UNSAFE_componentWillMount to suppress this warning in non-strict mode. In React 18.x, only the UNSAFE_ name will work. To rename all deprecated lifecycles to their new names, you can run \`npx react-codemod rename-unsafe-lifecycles\` in your project source folder.

Please update the following components: %s`, R);
        }
        if (r.size > 0) {
          var x = vu(r);
          C(`componentWillReceiveProps has been renamed, and is not recommended for use. See https://reactjs.org/link/unsafe-component-lifecycles for details.

* Move data fetching code or side effects to componentDidUpdate.
* If you're updating state whenever props change, refactor your code to use memoization techniques or move it to static getDerivedStateFromProps. Learn more at: https://reactjs.org/link/derived-state
* Rename componentWillReceiveProps to UNSAFE_componentWillReceiveProps to suppress this warning in non-strict mode. In React 18.x, only the UNSAFE_ name will work. To rename all deprecated lifecycles to their new names, you can run \`npx react-codemod rename-unsafe-lifecycles\` in your project source folder.

Please update the following components: %s`, x);
        }
        if (o.size > 0) {
          var U = vu(o);
          C(`componentWillUpdate has been renamed, and is not recommended for use. See https://reactjs.org/link/unsafe-component-lifecycles for details.

* Move data fetching code or side effects to componentDidUpdate.
* Rename componentWillUpdate to UNSAFE_componentWillUpdate to suppress this warning in non-strict mode. In React 18.x, only the UNSAFE_ name will work. To rename all deprecated lifecycles to their new names, you can run \`npx react-codemod rename-unsafe-lifecycles\` in your project source folder.

Please update the following components: %s`, U);
        }
      };
      var lv = /* @__PURE__ */ new Map(), kE = /* @__PURE__ */ new Set();
      pa.recordLegacyContextWarning = function(e, t) {
        var r = fR(e);
        if (r === null) {
          y("Expected to find a StrictMode component in a strict mode tree. This error is likely caused by a bug in React. Please file an issue.");
          return;
        }
        if (!kE.has(e.type)) {
          var i = lv.get(r);
          (e.type.contextTypes != null || e.type.childContextTypes != null || t !== null && typeof t.getChildContext == "function") && (i === void 0 && (i = [], lv.set(r, i)), i.push(e));
        }
      }, pa.flushLegacyContextWarning = function() {
        lv.forEach(function(e, t) {
          if (e.length !== 0) {
            var r = e[0], i = /* @__PURE__ */ new Set();
            e.forEach(function(s) {
              i.add(fe(s.type) || "Component"), kE.add(s.type);
            });
            var o = vu(i);
            try {
              nn(r), y(`Legacy context API has been detected within a strict-mode tree.

The old API will be supported in all 16.x releases, but applications using it should migrate to the new version.

Please update the following components: %s

Learn more about this warning here: https://reactjs.org/link/legacy-context`, o);
            } finally {
              An();
            }
          }
        });
      }, pa.discardPendingWarnings = function() {
        zf = [], jf = [], Ff = [], Hf = [], Pf = [], Bf = [], lv = /* @__PURE__ */ new Map();
      };
    }
    function va(e, t) {
      if (e && e.defaultProps) {
        var r = p({}, t), i = e.defaultProps;
        for (var o in i)
          r[o] === void 0 && (r[o] = i[o]);
        return r;
      }
      return t;
    }
    var ov = 1073741823, zm = ql(null), jm;
    jm = {};
    var uv = null, Ps = null, sv = null, cv = !1;
    function fv() {
      uv = null, Ps = null, sv = null, cv = !1;
    }
    function _E() {
      cv = !0;
    }
    function DE() {
      cv = !1;
    }
    function OE(e, t) {
      var r = e.type._context;
      Fn(zm, r._currentValue, e), r._currentValue = t, r._currentRenderer !== void 0 && r._currentRenderer !== null && r._currentRenderer !== jm && y("Detected multiple renderers concurrently rendering the same context provider. This is currently unsupported."), r._currentRenderer = jm;
    }
    function Fm(e) {
      var t = zm.current;
      jn(zm, e);
      var r = e.type._context;
      r._currentValue = t;
    }
    function dR(e, t, r) {
      if (a(r, t))
        return 0;
      var i = typeof e._calculateChangedBits == "function" ? e._calculateChangedBits(r, t) : ov;
      return (i & ov) !== i && y("calculateChangedBits: Expected the return value to be a 31-bit integer. Instead received: %s", i), i | 0;
    }
    function NE(e, t) {
      for (var r = e; r !== null; ) {
        var i = r.alternate;
        if (!Wa(r.childLanes, t))
          r.childLanes = dt(r.childLanes, t), i !== null && (i.childLanes = dt(i.childLanes, t));
        else if (i !== null && !Wa(i.childLanes, t))
          i.childLanes = dt(i.childLanes, t);
        else
          break;
        r = r.return;
      }
    }
    function pR(e, t, r, i) {
      var o = e.child;
      for (o !== null && (o.return = e); o !== null; ) {
        var s = void 0, d = o.dependencies;
        if (d !== null) {
          s = o.child;
          for (var v = d.firstContext; v !== null; ) {
            if (v.context === t && v.observedBits & r) {
              if (o.tag === L) {
                var E = Gl(Nt, sn(i));
                E.tag = dv, Xl(o, E);
              }
              o.lanes = dt(o.lanes, i);
              var R = o.alternate;
              R !== null && (R.lanes = dt(R.lanes, i)), NE(o.return, i), d.lanes = dt(d.lanes, i);
              break;
            }
            v = v.next;
          }
        } else o.tag === we ? s = o.type === e.type ? null : o.child : s = o.child;
        if (s !== null)
          s.return = o;
        else
          for (s = o; s !== null; ) {
            if (s === e) {
              s = null;
              break;
            }
            var x = s.sibling;
            if (x !== null) {
              x.return = s.return, s = x;
              break;
            }
            s = s.return;
          }
        o = s;
      }
    }
    function Bs(e, t) {
      uv = e, Ps = null, sv = null;
      var r = e.dependencies;
      if (r !== null) {
        var i = r.firstContext;
        i !== null && (yn(r.lanes, t) && Yy(), r.firstContext = null);
      }
    }
    function fn(e, t) {
      if (cv && y("Context can only be read while React is rendering. In classes, you can read it in the render method or getDerivedStateFromProps. In function components, you can read it directly in the function body, but not inside Hooks like useReducer() or useMemo()."), sv !== e) {
        if (!(t === !1 || t === 0)) {
          var r;
          typeof t != "number" || t === ov ? (sv = e, r = ov) : r = t;
          var i = {
            context: e,
            observedBits: r,
            next: null
          };
          if (Ps === null) {
            if (uv === null)
              throw Error("Context can only be read while React is rendering. In classes, you can read it in the render method or getDerivedStateFromProps. In function components, you can read it directly in the function body, but not inside Hooks like useReducer() or useMemo().");
            Ps = i, uv.dependencies = {
              lanes: W,
              firstContext: i,
              responders: null
            };
          } else
            Ps = Ps.next = i;
        }
      }
      return e._currentValue;
    }
    var ME = 0, LE = 1, dv = 2, Hm = 3, pv = !1, Pm, vv;
    Pm = !1, vv = null;
    function Bm(e) {
      var t = {
        baseState: e.memoizedState,
        firstBaseUpdate: null,
        lastBaseUpdate: null,
        shared: {
          pending: null
        },
        effects: null
      };
      e.updateQueue = t;
    }
    function AE(e, t) {
      var r = t.updateQueue, i = e.updateQueue;
      if (r === i) {
        var o = {
          baseState: i.baseState,
          firstBaseUpdate: i.firstBaseUpdate,
          lastBaseUpdate: i.lastBaseUpdate,
          shared: i.shared,
          effects: i.effects
        };
        t.updateQueue = o;
      }
    }
    function Gl(e, t) {
      var r = {
        eventTime: e,
        lane: t,
        tag: ME,
        payload: null,
        callback: null,
        next: null
      };
      return r;
    }
    function Xl(e, t) {
      var r = e.updateQueue;
      if (r !== null) {
        var i = r.shared, o = i.pending;
        o === null ? t.next = t : (t.next = o.next, o.next = t), i.pending = t, vv === i && !Pm && (y("An update (setState, replaceState, or forceUpdate) was scheduled from inside an update function. Update functions should be pure, with zero side-effects. Consider using componentDidUpdate or a callback."), Pm = !0);
      }
    }
    function UE(e, t) {
      var r = e.updateQueue, i = e.alternate;
      if (i !== null) {
        var o = i.updateQueue;
        if (r === o) {
          var s = null, d = null, v = r.firstBaseUpdate;
          if (v !== null) {
            var E = v;
            do {
              var R = {
                eventTime: E.eventTime,
                lane: E.lane,
                tag: E.tag,
                payload: E.payload,
                callback: E.callback,
                next: null
              };
              d === null ? s = d = R : (d.next = R, d = R), E = E.next;
            } while (E !== null);
            d === null ? s = d = t : (d.next = t, d = t);
          } else
            s = d = t;
          r = {
            baseState: o.baseState,
            firstBaseUpdate: s,
            lastBaseUpdate: d,
            shared: o.shared,
            effects: o.effects
          }, e.updateQueue = r;
          return;
        }
      }
      var x = r.lastBaseUpdate;
      x === null ? r.firstBaseUpdate = t : x.next = t, r.lastBaseUpdate = t;
    }
    function vR(e, t, r, i, o, s) {
      switch (r.tag) {
        case LE: {
          var d = r.payload;
          if (typeof d == "function") {
            _E();
            var v = d.call(s, i, o);
            {
              if (e.mode & Gt) {
                Dr();
                try {
                  d.call(s, i, o);
                } finally {
                  Sn();
                }
              }
              DE();
            }
            return v;
          }
          return d;
        }
        case Hm:
          e.flags = e.flags & ~hr | vt;
        case ME: {
          var E = r.payload, R;
          if (typeof E == "function") {
            _E(), R = E.call(s, i, o);
            {
              if (e.mode & Gt) {
                Dr();
                try {
                  E.call(s, i, o);
                } finally {
                  Sn();
                }
              }
              DE();
            }
          } else
            R = E;
          return R == null ? i : p({}, i, R);
        }
        case dv:
          return pv = !0, i;
      }
      return i;
    }
    function Vf(e, t, r, i) {
      var o = e.updateQueue;
      pv = !1, vv = o.shared;
      var s = o.firstBaseUpdate, d = o.lastBaseUpdate, v = o.shared.pending;
      if (v !== null) {
        o.shared.pending = null;
        var E = v, R = E.next;
        E.next = null, d === null ? s = R : d.next = R, d = E;
        var x = e.alternate;
        if (x !== null) {
          var U = x.updateQueue, k = U.lastBaseUpdate;
          k !== d && (k === null ? U.firstBaseUpdate = R : k.next = R, U.lastBaseUpdate = E);
        }
      }
      if (s !== null) {
        var H = o.baseState, Q = W, se = null, Me = null, Xe = null, je = s;
        do {
          var ft = je.lane, kt = je.eventTime;
          if (Wa(i, ft)) {
            if (Xe !== null) {
              var V = {
                eventTime: kt,
                // This update is going to be committed so we never want uncommit
                // it. Using NoLane works because 0 is a subset of all bitmasks, so
                // this will never be skipped by the check above.
                lane: qt,
                tag: je.tag,
                payload: je.payload,
                callback: je.callback,
                next: null
              };
              Xe = Xe.next = V;
            }
            H = vR(e, o, je, H, t, r);
            var N = je.callback;
            if (N !== null) {
              e.flags |= Ua;
              var ae = o.effects;
              ae === null ? o.effects = [je] : ae.push(je);
            }
          } else {
            var j = {
              eventTime: kt,
              lane: ft,
              tag: je.tag,
              payload: je.payload,
              callback: je.callback,
              next: null
            };
            Xe === null ? (Me = Xe = j, se = H) : Xe = Xe.next = j, Q = dt(Q, ft);
          }
          if (je = je.next, je === null) {
            if (v = o.shared.pending, v === null)
              break;
            var pe = v, be = pe.next;
            pe.next = null, je = be, o.lastBaseUpdate = pe, o.shared.pending = null;
          }
        } while (!0);
        Xe === null && (se = H), o.baseState = se, o.firstBaseUpdate = Me, o.lastBaseUpdate = Xe, yg(Q), e.lanes = Q, e.memoizedState = H;
      }
      vv = null;
    }
    function hR(e, t) {
      if (typeof e != "function")
        throw Error("Invalid argument passed as callback. Expected a function. Instead received: " + e);
      e.call(t);
    }
    function zE() {
      pv = !1;
    }
    function hv() {
      return pv;
    }
    function jE(e, t, r) {
      var i = t.effects;
      if (t.effects = null, i !== null)
        for (var o = 0; o < i.length; o++) {
          var s = i[o], d = s.callback;
          d !== null && (s.callback = null, hR(d, r));
        }
    }
    var Vm = {}, mR = Array.isArray, FE = new c.Component().refs, Im, $m, Wm, Ym, qm, HE, mv, Qm, Gm, Xm;
    {
      Im = /* @__PURE__ */ new Set(), $m = /* @__PURE__ */ new Set(), Wm = /* @__PURE__ */ new Set(), Ym = /* @__PURE__ */ new Set(), Qm = /* @__PURE__ */ new Set(), qm = /* @__PURE__ */ new Set(), Gm = /* @__PURE__ */ new Set(), Xm = /* @__PURE__ */ new Set();
      var PE = /* @__PURE__ */ new Set();
      mv = function(e, t) {
        if (!(e === null || typeof e == "function")) {
          var r = t + "_" + e;
          PE.has(r) || (PE.add(r), y("%s(...): Expected the last optional `callback` argument to be a function. Instead received: %s.", t, e));
        }
      }, HE = function(e, t) {
        if (t === void 0) {
          var r = fe(e) || "Component";
          qm.has(r) || (qm.add(r), y("%s.getDerivedStateFromProps(): A valid state object (or null) must be returned. You have returned undefined.", r));
        }
      }, Object.defineProperty(Vm, "_processChildContext", {
        enumerable: !1,
        value: function() {
          throw Error("_processChildContext is not available in React 16+. This likely means you have multiple copies of React and are attempting to nest a React 15 tree inside a React 16 tree using unstable_renderSubtreeIntoContainer, which isn't supported. Try to make sure you have only one copy of React (and ideally, switch to ReactDOM.createPortal).");
        }
      }), Object.freeze(Vm);
    }
    function yv(e, t, r, i) {
      var o = e.memoizedState;
      if (e.mode & Gt) {
        Dr();
        try {
          r(i, o);
        } finally {
          Sn();
        }
      }
      var s = r(i, o);
      HE(t, s);
      var d = s == null ? o : p({}, o, s);
      if (e.memoizedState = d, e.lanes === W) {
        var v = e.updateQueue;
        v.baseState = d;
      }
    }
    var Km = {
      isMounted: ip,
      enqueueSetState: function(e, t, r) {
        var i = ta(e), o = br(), s = eo(i), d = Gl(o, s);
        d.payload = t, r != null && (mv(r, "setState"), d.callback = r), Xl(i, d), Bn(i, s, o);
      },
      enqueueReplaceState: function(e, t, r) {
        var i = ta(e), o = br(), s = eo(i), d = Gl(o, s);
        d.tag = LE, d.payload = t, r != null && (mv(r, "replaceState"), d.callback = r), Xl(i, d), Bn(i, s, o);
      },
      enqueueForceUpdate: function(e, t) {
        var r = ta(e), i = br(), o = eo(r), s = Gl(i, o);
        s.tag = dv, t != null && (mv(t, "forceUpdate"), s.callback = t), Xl(r, s), Bn(r, o, i);
      }
    };
    function BE(e, t, r, i, o, s, d) {
      var v = e.stateNode;
      if (typeof v.shouldComponentUpdate == "function") {
        if (e.mode & Gt) {
          Dr();
          try {
            v.shouldComponentUpdate(i, s, d);
          } finally {
            Sn();
          }
        }
        var E = v.shouldComponentUpdate(i, s, d);
        return E === void 0 && y("%s.shouldComponentUpdate(): Returned undefined instead of a boolean value. Make sure to return true or false.", fe(t) || "Component"), E;
      }
      return t.prototype && t.prototype.isPureReactComponent ? !u(r, i) || !u(o, s) : !0;
    }
    function yR(e, t, r) {
      var i = e.stateNode;
      {
        var o = fe(t) || "Component", s = i.render;
        s || (t.prototype && typeof t.prototype.render == "function" ? y("%s(...): No `render` method found on the returned component instance: did you accidentally return an object from the constructor?", o) : y("%s(...): No `render` method found on the returned component instance: you may have forgotten to define `render`.", o)), i.getInitialState && !i.getInitialState.isReactClassApproved && !i.state && y("getInitialState was defined on %s, a plain JavaScript class. This is only supported for classes created using React.createClass. Did you mean to define a state property instead?", o), i.getDefaultProps && !i.getDefaultProps.isReactClassApproved && y("getDefaultProps was defined on %s, a plain JavaScript class. This is only supported for classes created using React.createClass. Use a static property to define defaultProps instead.", o), i.propTypes && y("propTypes was defined as an instance property on %s. Use a static property to define propTypes instead.", o), i.contextType && y("contextType was defined as an instance property on %s. Use a static property to define contextType instead.", o), i.contextTypes && y("contextTypes was defined as an instance property on %s. Use a static property to define contextTypes instead.", o), t.contextType && t.contextTypes && !Gm.has(t) && (Gm.add(t), y("%s declares both contextTypes and contextType static properties. The legacy contextTypes property will be ignored.", o)), typeof i.componentShouldUpdate == "function" && y("%s has a method called componentShouldUpdate(). Did you mean shouldComponentUpdate()? The name is phrased as a question because the function is expected to return a value.", o), t.prototype && t.prototype.isPureReactComponent && typeof i.shouldComponentUpdate < "u" && y("%s has a method called shouldComponentUpdate(). shouldComponentUpdate should not be used when extending React.PureComponent. Please extend React.Component if shouldComponentUpdate is used.", fe(t) || "A pure component"), typeof i.componentDidUnmount == "function" && y("%s has a method called componentDidUnmount(). But there is no such lifecycle method. Did you mean componentWillUnmount()?", o), typeof i.componentDidReceiveProps == "function" && y("%s has a method called componentDidReceiveProps(). But there is no such lifecycle method. If you meant to update the state in response to changing props, use componentWillReceiveProps(). If you meant to fetch data or run side-effects or mutations after React has updated the UI, use componentDidUpdate().", o), typeof i.componentWillRecieveProps == "function" && y("%s has a method called componentWillRecieveProps(). Did you mean componentWillReceiveProps()?", o), typeof i.UNSAFE_componentWillRecieveProps == "function" && y("%s has a method called UNSAFE_componentWillRecieveProps(). Did you mean UNSAFE_componentWillReceiveProps()?", o);
        var d = i.props !== r;
        i.props !== void 0 && d && y("%s(...): When calling super() in `%s`, make sure to pass up the same props that your component's constructor was passed.", o, o), i.defaultProps && y("Setting defaultProps as an instance property on %s is not supported and will be ignored. Instead, define defaultProps as a static property on %s.", o, o), typeof i.getSnapshotBeforeUpdate == "function" && typeof i.componentDidUpdate != "function" && !Wm.has(t) && (Wm.add(t), y("%s: getSnapshotBeforeUpdate() should be used with componentDidUpdate(). This component defines getSnapshotBeforeUpdate() only.", fe(t))), typeof i.getDerivedStateFromProps == "function" && y("%s: getDerivedStateFromProps() is defined as an instance method and will be ignored. Instead, declare it as a static method.", o), typeof i.getDerivedStateFromError == "function" && y("%s: getDerivedStateFromError() is defined as an instance method and will be ignored. Instead, declare it as a static method.", o), typeof t.getSnapshotBeforeUpdate == "function" && y("%s: getSnapshotBeforeUpdate() is defined as a static method and will be ignored. Instead, declare it as an instance method.", o);
        var v = i.state;
        v && (typeof v != "object" || mR(v)) && y("%s.state: must be set to an object or null", o), typeof i.getChildContext == "function" && typeof t.childContextTypes != "object" && y("%s.getChildContext(): childContextTypes must be defined in order to use getChildContext().", o);
      }
    }
    function VE(e, t) {
      t.updater = Km, e.stateNode = t, Uc(t, e), t._reactInternalInstance = Vm;
    }
    function IE(e, t, r) {
      var i = !1, o = Er, s = Er, d = t.contextType;
      if ("contextType" in t) {
        var v = (
          // Allow null for conditional declaration
          d === null || d !== void 0 && d.$$typeof === il && d._context === void 0
        );
        if (!v && !Xm.has(t)) {
          Xm.add(t);
          var E = "";
          d === void 0 ? E = " However, it is set to undefined. This can be caused by a typo or by mixing up named and default imports. This can also happen due to a circular dependency, so try moving the createContext() call to a separate file." : typeof d != "object" ? E = " However, it is set to a " + typeof d + "." : d.$$typeof === al ? E = " Did you accidentally pass the Context.Provider instead?" : d._context !== void 0 ? E = " Did you accidentally pass the Context.Consumer instead?" : E = " However, it is set to an object with keys {" + Object.keys(d).join(", ") + "}.", y("%s defines an invalid contextType. contextType should point to the Context object returned by React.createContext().%s", fe(t) || "Component", E);
        }
      }
      if (typeof d == "object" && d !== null)
        s = fn(d);
      else {
        o = zs(e, t, !0);
        var R = t.contextTypes;
        i = R != null, s = i ? js(e, o) : Er;
      }
      if (e.mode & Gt) {
        Dr();
        try {
          new t(r, s);
        } finally {
          Sn();
        }
      }
      var x = new t(r, s), U = e.memoizedState = x.state !== null && x.state !== void 0 ? x.state : null;
      VE(e, x);
      {
        if (typeof t.getDerivedStateFromProps == "function" && U === null) {
          var k = fe(t) || "Component";
          $m.has(k) || ($m.add(k), y("`%s` uses `getDerivedStateFromProps` but its initial state is %s. This is not recommended. Instead, define the initial state by assigning an object to `this.state` in the constructor of `%s`. This ensures that `getDerivedStateFromProps` arguments have a consistent shape.", k, x.state === null ? "null" : "undefined", k));
        }
        if (typeof t.getDerivedStateFromProps == "function" || typeof x.getSnapshotBeforeUpdate == "function") {
          var H = null, Q = null, se = null;
          if (typeof x.componentWillMount == "function" && x.componentWillMount.__suppressDeprecationWarning !== !0 ? H = "componentWillMount" : typeof x.UNSAFE_componentWillMount == "function" && (H = "UNSAFE_componentWillMount"), typeof x.componentWillReceiveProps == "function" && x.componentWillReceiveProps.__suppressDeprecationWarning !== !0 ? Q = "componentWillReceiveProps" : typeof x.UNSAFE_componentWillReceiveProps == "function" && (Q = "UNSAFE_componentWillReceiveProps"), typeof x.componentWillUpdate == "function" && x.componentWillUpdate.__suppressDeprecationWarning !== !0 ? se = "componentWillUpdate" : typeof x.UNSAFE_componentWillUpdate == "function" && (se = "UNSAFE_componentWillUpdate"), H !== null || Q !== null || se !== null) {
            var Me = fe(t) || "Component", Xe = typeof t.getDerivedStateFromProps == "function" ? "getDerivedStateFromProps()" : "getSnapshotBeforeUpdate()";
            Ym.has(Me) || (Ym.add(Me), y(`Unsafe legacy lifecycles will not be called for components using new component APIs.

%s uses %s but also contains the following legacy lifecycles:%s%s%s

The above lifecycles should be removed. Learn more about this warning here:
https://reactjs.org/link/unsafe-component-lifecycles`, Me, Xe, H !== null ? `
  ` + H : "", Q !== null ? `
  ` + Q : "", se !== null ? `
  ` + se : ""));
          }
        }
      }
      return i && oE(e, o, s), x;
    }
    function gR(e, t) {
      var r = t.state;
      typeof t.componentWillMount == "function" && t.componentWillMount(), typeof t.UNSAFE_componentWillMount == "function" && t.UNSAFE_componentWillMount(), r !== t.state && (y("%s.componentWillMount(): Assigning directly to this.state is deprecated (except inside a component's constructor). Use setState instead.", fe(e.type) || "Component"), Km.enqueueReplaceState(t, t.state, null));
    }
    function $E(e, t, r, i) {
      var o = t.state;
      if (typeof t.componentWillReceiveProps == "function" && t.componentWillReceiveProps(r, i), typeof t.UNSAFE_componentWillReceiveProps == "function" && t.UNSAFE_componentWillReceiveProps(r, i), t.state !== o) {
        {
          var s = fe(e.type) || "Component";
          Im.has(s) || (Im.add(s), y("%s.componentWillReceiveProps(): Assigning directly to this.state is deprecated (except inside a component's constructor). Use setState instead.", s));
        }
        Km.enqueueReplaceState(t, t.state, null);
      }
    }
    function Zm(e, t, r, i) {
      yR(e, t, r);
      var o = e.stateNode;
      o.props = r, o.state = e.memoizedState, o.refs = FE, Bm(e);
      var s = t.contextType;
      if (typeof s == "object" && s !== null)
        o.context = fn(s);
      else {
        var d = zs(e, t, !0);
        o.context = js(e, d);
      }
      {
        if (o.state === r) {
          var v = fe(t) || "Component";
          Qm.has(v) || (Qm.add(v), y("%s: It is not recommended to assign props directly to state because updates to props won't be reflected in state. In most cases, it is better to use props directly.", v));
        }
        e.mode & Gt && pa.recordLegacyContextWarning(e, o), pa.recordUnsafeLifecycleWarnings(e, o);
      }
      Vf(e, r, o, i), o.state = e.memoizedState;
      var E = t.getDerivedStateFromProps;
      typeof E == "function" && (yv(e, t, E, r), o.state = e.memoizedState), typeof t.getDerivedStateFromProps != "function" && typeof o.getSnapshotBeforeUpdate != "function" && (typeof o.UNSAFE_componentWillMount == "function" || typeof o.componentWillMount == "function") && (gR(e, o), Vf(e, r, o, i), o.state = e.memoizedState), typeof o.componentDidMount == "function" && (e.flags |= Ue);
    }
    function ER(e, t, r, i) {
      var o = e.stateNode, s = e.memoizedProps;
      o.props = s;
      var d = o.context, v = t.contextType, E = Er;
      if (typeof v == "object" && v !== null)
        E = fn(v);
      else {
        var R = zs(e, t, !0);
        E = js(e, R);
      }
      var x = t.getDerivedStateFromProps, U = typeof x == "function" || typeof o.getSnapshotBeforeUpdate == "function";
      !U && (typeof o.UNSAFE_componentWillReceiveProps == "function" || typeof o.componentWillReceiveProps == "function") && (s !== r || d !== E) && $E(e, o, r, E), zE();
      var k = e.memoizedState, H = o.state = k;
      if (Vf(e, r, o, i), H = e.memoizedState, s === r && k === H && !ev() && !hv())
        return typeof o.componentDidMount == "function" && (e.flags |= Ue), !1;
      typeof x == "function" && (yv(e, t, x, r), H = e.memoizedState);
      var Q = hv() || BE(e, t, s, r, k, H, E);
      return Q ? (!U && (typeof o.UNSAFE_componentWillMount == "function" || typeof o.componentWillMount == "function") && (typeof o.componentWillMount == "function" && o.componentWillMount(), typeof o.UNSAFE_componentWillMount == "function" && o.UNSAFE_componentWillMount()), typeof o.componentDidMount == "function" && (e.flags |= Ue)) : (typeof o.componentDidMount == "function" && (e.flags |= Ue), e.memoizedProps = r, e.memoizedState = H), o.props = r, o.state = H, o.context = E, Q;
    }
    function SR(e, t, r, i, o) {
      var s = t.stateNode;
      AE(e, t);
      var d = t.memoizedProps, v = t.type === t.elementType ? d : va(t.type, d);
      s.props = v;
      var E = t.pendingProps, R = s.context, x = r.contextType, U = Er;
      if (typeof x == "object" && x !== null)
        U = fn(x);
      else {
        var k = zs(t, r, !0);
        U = js(t, k);
      }
      var H = r.getDerivedStateFromProps, Q = typeof H == "function" || typeof s.getSnapshotBeforeUpdate == "function";
      !Q && (typeof s.UNSAFE_componentWillReceiveProps == "function" || typeof s.componentWillReceiveProps == "function") && (d !== E || R !== U) && $E(t, s, i, U), zE();
      var se = t.memoizedState, Me = s.state = se;
      if (Vf(t, i, s, o), Me = t.memoizedState, d === E && se === Me && !ev() && !hv())
        return typeof s.componentDidUpdate == "function" && (d !== e.memoizedProps || se !== e.memoizedState) && (t.flags |= Ue), typeof s.getSnapshotBeforeUpdate == "function" && (d !== e.memoizedProps || se !== e.memoizedState) && (t.flags |= Nr), !1;
      typeof H == "function" && (yv(t, r, H, i), Me = t.memoizedState);
      var Xe = hv() || BE(t, r, v, i, se, Me, U);
      return Xe ? (!Q && (typeof s.UNSAFE_componentWillUpdate == "function" || typeof s.componentWillUpdate == "function") && (typeof s.componentWillUpdate == "function" && s.componentWillUpdate(i, Me, U), typeof s.UNSAFE_componentWillUpdate == "function" && s.UNSAFE_componentWillUpdate(i, Me, U)), typeof s.componentDidUpdate == "function" && (t.flags |= Ue), typeof s.getSnapshotBeforeUpdate == "function" && (t.flags |= Nr)) : (typeof s.componentDidUpdate == "function" && (d !== e.memoizedProps || se !== e.memoizedState) && (t.flags |= Ue), typeof s.getSnapshotBeforeUpdate == "function" && (d !== e.memoizedProps || se !== e.memoizedState) && (t.flags |= Nr), t.memoizedProps = i, t.memoizedState = Me), s.props = i, s.state = Me, s.context = U, Xe;
    }
    var Jm, ey, ty, ny, ry, WE = function(e, t) {
    };
    Jm = !1, ey = !1, ty = {}, ny = {}, ry = {}, WE = function(e, t) {
      if (!(e === null || typeof e != "object") && !(!e._store || e._store.validated || e.key != null)) {
        if (typeof e._store != "object")
          throw Error("React Component in warnForMissingKey should have a _store. This error is likely caused by a bug in React. Please file an issue.");
        e._store.validated = !0;
        var r = fe(t.type) || "Component";
        ny[r] || (ny[r] = !0, y('Each child in a list should have a unique "key" prop. See https://reactjs.org/link/warning-keys for more information.'));
      }
    };
    var gv = Array.isArray;
    function If(e, t, r) {
      var i = r.ref;
      if (i !== null && typeof i != "function" && typeof i != "object") {
        if ((e.mode & Gt || Z) && // We warn in ReactElement.js if owner and self are equal for string refs
        // because these cannot be automatically converted to an arrow function
        // using a codemod. Therefore, we don't have to warn about string refs again.
        !(r._owner && r._self && r._owner.stateNode !== r._self)) {
          var o = fe(e.type) || "Component";
          ty[o] || (y('A string ref, "%s", has been found within a strict mode tree. String refs are a source of potential bugs and should be avoided. We recommend using useRef() or createRef() instead. Learn more about using refs safely here: https://reactjs.org/link/strict-mode-string-ref', i), ty[o] = !0);
        }
        if (r._owner) {
          var s = r._owner, d;
          if (s) {
            var v = s;
            if (v.tag !== L)
              throw Error("Function components cannot have string refs. We recommend using useRef() instead. Learn more about using refs safely here: https://reactjs.org/link/strict-mode-string-ref");
            d = v.stateNode;
          }
          if (!d)
            throw Error("Missing owner for string ref " + i + ". This error is likely caused by a bug in React. Please file an issue.");
          var E = "" + i;
          if (t !== null && t.ref !== null && typeof t.ref == "function" && t.ref._stringRef === E)
            return t.ref;
          var R = function(x) {
            var U = d.refs;
            U === FE && (U = d.refs = {}), x === null ? delete U[E] : U[E] = x;
          };
          return R._stringRef = E, R;
        } else {
          if (typeof i != "string")
            throw Error("Expected ref to be a function, a string, an object returned by React.createRef(), or null.");
          if (!r._owner)
            throw Error("Element ref was specified as a string (" + i + `) but no owner was set. This could happen for one of the following reasons:
1. You may be adding a ref to a function component
2. You may be adding a ref to a component that was not created inside a component's render method
3. You have multiple copies of React loaded
See https://reactjs.org/link/refs-must-have-owner for more information.`);
        }
      }
      return i;
    }
    function Ev(e, t) {
      if (e.type !== "textarea")
        throw Error("Objects are not valid as a React child (found: " + (Object.prototype.toString.call(t) === "[object Object]" ? "object with keys {" + Object.keys(t).join(", ") + "}" : t) + "). If you meant to render a collection of children, use an array instead.");
    }
    function Sv(e) {
      {
        var t = fe(e.type) || "Component";
        if (ry[t])
          return;
        ry[t] = !0, y("Functions are not valid as a React child. This may happen if you return a Component instead of <Component /> from render. Or maybe you meant to call this function rather than return it.");
      }
    }
    function YE(e) {
      function t(j, V) {
        if (e) {
          var N = j.lastEffect;
          N !== null ? (N.nextEffect = V, j.lastEffect = V) : j.firstEffect = j.lastEffect = V, V.nextEffect = null, V.flags = Dt;
        }
      }
      function r(j, V) {
        if (!e)
          return null;
        for (var N = V; N !== null; )
          t(j, N), N = N.sibling;
        return null;
      }
      function i(j, V) {
        for (var N = /* @__PURE__ */ new Map(), ae = V; ae !== null; )
          ae.key !== null ? N.set(ae.key, ae) : N.set(ae.index, ae), ae = ae.sibling;
        return N;
      }
      function o(j, V) {
        var N = wu(j, V);
        return N.index = 0, N.sibling = null, N;
      }
      function s(j, V, N) {
        if (j.index = N, !e)
          return V;
        var ae = j.alternate;
        if (ae !== null) {
          var pe = ae.index;
          return pe < V ? (j.flags = Ye, V) : pe;
        } else
          return j.flags = Ye, V;
      }
      function d(j) {
        return e && j.alternate === null && (j.flags = Ye), j;
      }
      function v(j, V, N, ae) {
        if (V === null || V.tag !== ue) {
          var pe = Ng(N, j.mode, ae);
          return pe.return = j, pe;
        } else {
          var be = o(V, N);
          return be.return = j, be;
        }
      }
      function E(j, V, N, ae) {
        if (V !== null && (V.elementType === N.type || // Keep this check inline so it only runs on the false path:
        wC(V, N))) {
          var pe = o(V, N.props);
          return pe.ref = If(j, V, N), pe.return = j, pe._debugSource = N._source, pe._debugOwner = N._owner, pe;
        }
        var be = Dg(N, j.mode, ae);
        return be.ref = If(j, V, N), be.return = j, be;
      }
      function R(j, V, N, ae) {
        if (V === null || V.tag !== Y || V.stateNode.containerInfo !== N.containerInfo || V.stateNode.implementation !== N.implementation) {
          var pe = Mg(N, j.mode, ae);
          return pe.return = j, pe;
        } else {
          var be = o(V, N.children || []);
          return be.return = j, be;
        }
      }
      function x(j, V, N, ae, pe) {
        if (V === null || V.tag !== Te) {
          var be = ku(N, j.mode, ae, pe);
          return be.return = j, be;
        } else {
          var ct = o(V, N);
          return ct.return = j, ct;
        }
      }
      function U(j, V, N) {
        if (typeof V == "string" || typeof V == "number") {
          var ae = Ng("" + V, j.mode, N);
          return ae.return = j, ae;
        }
        if (typeof V == "object" && V !== null) {
          switch (V.$$typeof) {
            case Rn: {
              var pe = Dg(V, j.mode, N);
              return pe.ref = If(j, null, V), pe.return = j, pe;
            }
            case Ut: {
              var be = Mg(V, j.mode, N);
              return be.return = j, be;
            }
          }
          if (gv(V) || pr(V)) {
            var ct = ku(V, j.mode, N, null);
            return ct.return = j, ct;
          }
          Ev(j, V);
        }
        return typeof V == "function" && Sv(j), null;
      }
      function k(j, V, N, ae) {
        var pe = V !== null ? V.key : null;
        if (typeof N == "string" || typeof N == "number")
          return pe !== null ? null : v(j, V, "" + N, ae);
        if (typeof N == "object" && N !== null) {
          switch (N.$$typeof) {
            case Rn:
              return N.key === pe ? N.type === Gr ? x(j, V, N.props.children, ae, pe) : E(j, V, N, ae) : null;
            case Ut:
              return N.key === pe ? R(j, V, N, ae) : null;
          }
          if (gv(N) || pr(N))
            return pe !== null ? null : x(j, V, N, ae, null);
          Ev(j, N);
        }
        return typeof N == "function" && Sv(j), null;
      }
      function H(j, V, N, ae, pe) {
        if (typeof ae == "string" || typeof ae == "number") {
          var be = j.get(N) || null;
          return v(V, be, "" + ae, pe);
        }
        if (typeof ae == "object" && ae !== null) {
          switch (ae.$$typeof) {
            case Rn: {
              var ct = j.get(ae.key === null ? N : ae.key) || null;
              return ae.type === Gr ? x(V, ct, ae.props.children, pe, ae.key) : E(V, ct, ae, pe);
            }
            case Ut: {
              var Mt = j.get(ae.key === null ? N : ae.key) || null;
              return R(V, Mt, ae, pe);
            }
          }
          if (gv(ae) || pr(ae)) {
            var It = j.get(N) || null;
            return x(V, It, ae, pe, null);
          }
          Ev(V, ae);
        }
        return typeof ae == "function" && Sv(V), null;
      }
      function Q(j, V, N) {
        {
          if (typeof j != "object" || j === null)
            return V;
          switch (j.$$typeof) {
            case Rn:
            case Ut:
              WE(j, N);
              var ae = j.key;
              if (typeof ae != "string")
                break;
              if (V === null) {
                V = /* @__PURE__ */ new Set(), V.add(ae);
                break;
              }
              if (!V.has(ae)) {
                V.add(ae);
                break;
              }
              y("Encountered two children with the same key, `%s`. Keys should be unique so that components maintain their identity across updates. Non-unique keys may cause children to be duplicated and/or omitted — the behavior is unsupported and could change in a future version.", ae);
              break;
          }
        }
        return V;
      }
      function se(j, V, N, ae) {
        for (var pe = null, be = 0; be < N.length; be++) {
          var ct = N[be];
          pe = Q(ct, pe, j);
        }
        for (var Mt = null, It = null, St = V, dn = 0, ht = 0, $t = null; St !== null && ht < N.length; ht++) {
          St.index > ht ? ($t = St, St = null) : $t = St.sibling;
          var Tn = k(j, St, N[ht], ae);
          if (Tn === null) {
            St === null && (St = $t);
            break;
          }
          e && St && Tn.alternate === null && t(j, St), dn = s(Tn, dn, ht), It === null ? Mt = Tn : It.sibling = Tn, It = Tn, St = $t;
        }
        if (ht === N.length)
          return r(j, St), Mt;
        if (St === null) {
          for (; ht < N.length; ht++) {
            var en = U(j, N[ht], ae);
            en !== null && (dn = s(en, dn, ht), It === null ? Mt = en : It.sibling = en, It = en);
          }
          return Mt;
        }
        for (var ui = i(j, St); ht < N.length; ht++) {
          var tn = H(ui, j, ht, N[ht], ae);
          tn !== null && (e && tn.alternate !== null && ui.delete(tn.key === null ? ht : tn.key), dn = s(tn, dn, ht), It === null ? Mt = tn : It.sibling = tn, It = tn);
        }
        return e && ui.forEach(function(si) {
          return t(j, si);
        }), Mt;
      }
      function Me(j, V, N, ae) {
        var pe = pr(N);
        if (typeof pe != "function")
          throw Error("An object is not an iterable. This error is likely caused by a bug in React. Please file an issue.");
        {
          typeof Symbol == "function" && // $FlowFixMe Flow doesn't know about toStringTag
          N[Symbol.toStringTag] === "Generator" && (ey || y("Using Generators as children is unsupported and will likely yield unexpected results because enumerating a generator mutates it. You may convert it to an array with `Array.from()` or the `[...spread]` operator before rendering. Keep in mind you might need to polyfill these features for older browsers."), ey = !0), N.entries === pe && (Jm || y("Using Maps as children is not supported. Use an array of keyed ReactElements instead."), Jm = !0);
          var be = pe.call(N);
          if (be)
            for (var ct = null, Mt = be.next(); !Mt.done; Mt = be.next()) {
              var It = Mt.value;
              ct = Q(It, ct, j);
            }
        }
        var St = pe.call(N);
        if (St == null)
          throw Error("An iterable object provided no iterator.");
        for (var dn = null, ht = null, $t = V, Tn = 0, en = 0, ui = null, tn = St.next(); $t !== null && !tn.done; en++, tn = St.next()) {
          $t.index > en ? (ui = $t, $t = null) : ui = $t.sibling;
          var si = k(j, $t, tn.value, ae);
          if (si === null) {
            $t === null && ($t = ui);
            break;
          }
          e && $t && si.alternate === null && t(j, $t), Tn = s(si, Tn, en), ht === null ? dn = si : ht.sibling = si, ht = si, $t = ui;
        }
        if (tn.done)
          return r(j, $t), dn;
        if ($t === null) {
          for (; !tn.done; en++, tn = St.next()) {
            var _u = U(j, tn.value, ae);
            _u !== null && (Tn = s(_u, Tn, en), ht === null ? dn = _u : ht.sibling = _u, ht = _u);
          }
          return dn;
        }
        for (var Hg = i(j, $t); !tn.done; en++, tn = St.next()) {
          var ro = H(Hg, j, en, tn.value, ae);
          ro !== null && (e && ro.alternate !== null && Hg.delete(ro.key === null ? en : ro.key), Tn = s(ro, Tn, en), ht === null ? dn = ro : ht.sibling = ro, ht = ro);
        }
        return e && Hg.forEach(function(Ek) {
          return t(j, Ek);
        }), dn;
      }
      function Xe(j, V, N, ae) {
        if (V !== null && V.tag === ue) {
          r(j, V.sibling);
          var pe = o(V, N);
          return pe.return = j, pe;
        }
        r(j, V);
        var be = Ng(N, j.mode, ae);
        return be.return = j, be;
      }
      function je(j, V, N, ae) {
        for (var pe = N.key, be = V; be !== null; ) {
          if (be.key === pe) {
            switch (be.tag) {
              case Te: {
                if (N.type === Gr) {
                  r(j, be.sibling);
                  var ct = o(be, N.props.children);
                  return ct.return = j, ct._debugSource = N._source, ct._debugOwner = N._owner, ct;
                }
                break;
              }
              case ut:
              default: {
                if (be.elementType === N.type || // Keep this check inline so it only runs on the false path:
                wC(be, N)) {
                  r(j, be.sibling);
                  var Mt = o(be, N.props);
                  return Mt.ref = If(j, be, N), Mt.return = j, Mt._debugSource = N._source, Mt._debugOwner = N._owner, Mt;
                }
                break;
              }
            }
            r(j, be);
            break;
          } else
            t(j, be);
          be = be.sibling;
        }
        if (N.type === Gr) {
          var It = ku(N.props.children, j.mode, ae, N.key);
          return It.return = j, It;
        } else {
          var St = Dg(N, j.mode, ae);
          return St.ref = If(j, V, N), St.return = j, St;
        }
      }
      function ft(j, V, N, ae) {
        for (var pe = N.key, be = V; be !== null; ) {
          if (be.key === pe)
            if (be.tag === Y && be.stateNode.containerInfo === N.containerInfo && be.stateNode.implementation === N.implementation) {
              r(j, be.sibling);
              var ct = o(be, N.children || []);
              return ct.return = j, ct;
            } else {
              r(j, be);
              break;
            }
          else
            t(j, be);
          be = be.sibling;
        }
        var Mt = Mg(N, j.mode, ae);
        return Mt.return = j, Mt;
      }
      function kt(j, V, N, ae) {
        var pe = typeof N == "object" && N !== null && N.type === Gr && N.key === null;
        pe && (N = N.props.children);
        var be = typeof N == "object" && N !== null;
        if (be)
          switch (N.$$typeof) {
            case Rn:
              return d(je(j, V, N, ae));
            case Ut:
              return d(ft(j, V, N, ae));
          }
        if (typeof N == "string" || typeof N == "number")
          return d(Xe(j, V, "" + N, ae));
        if (gv(N))
          return se(j, V, N, ae);
        if (pr(N))
          return Me(j, V, N, ae);
        if (be && Ev(j, N), typeof N == "function" && Sv(j), typeof N > "u" && !pe)
          switch (j.tag) {
            case L: {
              var ct = j.stateNode;
              if (ct.render._isMockFunction)
                break;
            }
            case ut:
            case A:
            case ee:
            case Se:
              throw Error((fe(j.type) || "Component") + "(...): Nothing was returned from render. This usually means a return statement is missing. Or, to render nothing, return null.");
          }
        return r(j, V);
      }
      return kt;
    }
    var Cv = YE(!0), qE = YE(!1);
    function CR(e, t) {
      if (!(e === null || t.child === e.child))
        throw Error("Resuming work not yet implemented.");
      if (t.child !== null) {
        var r = t.child, i = wu(r, r.pendingProps);
        for (t.child = i, i.return = t; r.sibling !== null; )
          r = r.sibling, i = i.sibling = wu(r, r.pendingProps), i.return = t;
        i.sibling = null;
      }
    }
    function bR(e, t) {
      for (var r = e.child; r !== null; )
        Uw(r, t), r = r.sibling;
    }
    var $f = {}, Kl = ql($f), Wf = ql($f), bv = ql($f);
    function Tv(e) {
      if (e === $f)
        throw Error("Expected host context to exist. This error is likely caused by a bug in React. Please file an issue.");
      return e;
    }
    function QE() {
      var e = Tv(bv.current);
      return e;
    }
    function ay(e, t) {
      Fn(bv, t, e), Fn(Wf, e, e), Fn(Kl, $f, e);
      var r = nT(t);
      jn(Kl, e), Fn(Kl, r, e);
    }
    function Vs(e) {
      jn(Kl, e), jn(Wf, e), jn(bv, e);
    }
    function iy() {
      var e = Tv(Kl.current);
      return e;
    }
    function GE(e) {
      Tv(bv.current);
      var t = Tv(Kl.current), r = rT(t, e.type);
      t !== r && (Fn(Wf, e, e), Fn(Kl, r, e));
    }
    function ly(e) {
      Wf.current === e && (jn(Kl, e), jn(Wf, e));
    }
    var TR = 0, XE = 1, oy = 1, Yf = 2, ha = ql(TR);
    function Rv(e, t) {
      return (e & t) !== 0;
    }
    function qf(e) {
      return e & XE;
    }
    function uy(e, t) {
      return e & XE | t;
    }
    function RR(e, t) {
      return e | t;
    }
    function mu(e, t) {
      Fn(ha, t, e);
    }
    function Is(e) {
      jn(ha, e);
    }
    function xR(e, t) {
      var r = e.memoizedState;
      if (r !== null)
        return r.dehydrated !== null;
      var i = e.memoizedProps;
      return i.fallback === void 0 ? !1 : i.unstable_avoidThisFallback !== !0 ? !0 : !t;
    }
    function xv(e) {
      for (var t = e; t !== null; ) {
        if (t.tag === z) {
          var r = t.memoizedState;
          if (r !== null) {
            var i = r.dehydrated;
            if (i === null || kT(i) || _T(i))
              return t;
          }
        } else if (t.tag === it && // revealOrder undefined can't be trusted because it don't
        // keep track of whether it suspended or not.
        t.memoizedProps.revealOrder !== void 0) {
          var o = (t.flags & vt) !== Et;
          if (o)
            return t;
        } else if (t.child !== null) {
          t.child.return = t, t = t.child;
          continue;
        }
        if (t === e)
          return null;
        for (; t.sibling === null; ) {
          if (t.return === null || t.return === e)
            return null;
          t = t.return;
        }
        t.sibling.return = t.return, t = t.sibling;
      }
      return null;
    }
    var sy = (
      /*  */
      0
    ), $s = (
      /* */
      1
    ), Ws = (
      /*    */
      2
    ), Qf = (
      /*   */
      4
    ), Ir = null, yu = null, Zl = !1;
    function wR(e) {
      var t = e.stateNode.containerInfo;
      return yu = J0(t), Ir = e, Zl = !0, !0;
    }
    function KE(e, t) {
      switch (e.tag) {
        case B:
          zT(e.stateNode.containerInfo, t);
          break;
        case re:
          jT(e.type, e.memoizedProps, e.stateNode, t);
          break;
      }
      var r = Bw();
      r.stateNode = t, r.return = e, r.flags = Dt, e.lastEffect !== null ? (e.lastEffect.nextEffect = r, e.lastEffect = r) : e.firstEffect = e.lastEffect = r;
    }
    function ZE(e, t) {
      switch (t.flags = t.flags & ~nr | Ye, e.tag) {
        case B: {
          var r = e.stateNode.containerInfo;
          switch (t.tag) {
            case re:
              var i = t.type;
              t.pendingProps, FT(r, i);
              break;
            case ue:
              var o = t.pendingProps;
              HT(r, o);
              break;
          }
          break;
        }
        case re: {
          var s = e.type, d = e.memoizedProps, v = e.stateNode;
          switch (t.tag) {
            case re:
              var E = t.type;
              t.pendingProps, PT(s, d, v, E);
              break;
            case ue:
              var R = t.pendingProps;
              BT(s, d, v, R);
              break;
            case z:
              VT(s, d);
              break;
          }
          break;
        }
        default:
          return;
      }
    }
    function JE(e, t) {
      switch (e.tag) {
        case re: {
          var r = e.type;
          e.pendingProps;
          var i = xT(t, r);
          return i !== null ? (e.stateNode = i, !0) : !1;
        }
        case ue: {
          var o = e.pendingProps, s = wT(t, o);
          return s !== null ? (e.stateNode = s, !0) : !1;
        }
        case z:
          return !1;
        default:
          return !1;
      }
    }
    function cy(e) {
      if (Zl) {
        var t = yu;
        if (!t) {
          ZE(Ir, e), Zl = !1, Ir = e;
          return;
        }
        var r = t;
        if (!JE(e, t)) {
          if (t = qp(r), !t || !JE(e, t)) {
            ZE(Ir, e), Zl = !1, Ir = e;
            return;
          }
          KE(Ir, r);
        }
        Ir = e, yu = J0(t);
      }
    }
    function kR(e, t, r) {
      var i = e.stateNode, o = DT(i, e.type, e.memoizedProps, t, r, e);
      return e.updateQueue = o, o !== null;
    }
    function _R(e) {
      var t = e.stateNode, r = e.memoizedProps, i = OT(t, r, e);
      if (i) {
        var o = Ir;
        if (o !== null)
          switch (o.tag) {
            case B: {
              var s = o.stateNode.containerInfo;
              AT(s, t, r);
              break;
            }
            case re: {
              var d = o.type, v = o.memoizedProps, E = o.stateNode;
              UT(d, v, E, t, r);
              break;
            }
          }
      }
      return i;
    }
    function DR(e) {
      var t = e.memoizedState, r = t !== null ? t.dehydrated : null;
      if (!r)
        throw Error("Expected to have a hydrated suspense instance. This error is likely caused by a bug in React. Please file an issue.");
      return NT(r);
    }
    function eS(e) {
      for (var t = e.return; t !== null && t.tag !== re && t.tag !== B && t.tag !== z; )
        t = t.return;
      Ir = t;
    }
    function wv(e) {
      if (e !== Ir)
        return !1;
      if (!Zl)
        return eS(e), Zl = !0, !1;
      var t = e.type;
      if (e.tag !== re || t !== "head" && t !== "body" && !Tm(t, e.memoizedProps))
        for (var r = yu; r; )
          KE(e, r), r = qp(r);
      return eS(e), e.tag === z ? yu = DR(e) : yu = Ir ? qp(e.stateNode) : null, !0;
    }
    function fy() {
      Ir = null, yu = null, Zl = !1;
    }
    function dy() {
      return Zl;
    }
    var Gf = [], py;
    py = {};
    function OR(e) {
      Gf.push(e);
    }
    function vy() {
      for (var e = 0; e < Gf.length; e++) {
        var t = Gf[e];
        t._workInProgressVersionPrimary = null;
      }
      Gf.length = 0;
    }
    function NR(e) {
      return e._workInProgressVersionPrimary;
    }
    function tS(e, t) {
      e._workInProgressVersionPrimary = t, Gf.push(e);
    }
    function MR(e) {
      e._currentPrimaryRenderer == null ? e._currentPrimaryRenderer = py : e._currentPrimaryRenderer !== py && y("Detected multiple renderers concurrently rendering the same mutable source. This is currently unsupported.");
    }
    var me = b.ReactCurrentDispatcher, $r = b.ReactCurrentBatchConfig, hy, my;
    my = {}, hy = /* @__PURE__ */ new Set();
    var Xf = W, _t = null, Pn = null, bn = null, kv = !1, Kf = !1, LR = 25, X = null, Wr = null, Jl = -1, yy = !1;
    function wt() {
      {
        var e = X;
        Wr === null ? Wr = [e] : Wr.push(e);
      }
    }
    function Ee() {
      {
        var e = X;
        Wr !== null && (Jl++, Wr[Jl] !== e && AR(e));
      }
    }
    function Zf(e) {
      e != null && !Array.isArray(e) && y("%s received a final argument that is not an array (instead, received `%s`). When specified, the final argument must be an array.", X, typeof e);
    }
    function AR(e) {
      {
        var t = fe(_t.type);
        if (!hy.has(t) && (hy.add(t), Wr !== null)) {
          for (var r = "", i = 30, o = 0; o <= Jl; o++) {
            for (var s = Wr[o], d = o === Jl ? e : s, v = o + 1 + ". " + s; v.length < i; )
              v += " ";
            v += d + `
`, r += v;
          }
          y(`React has detected a change in the order of Hooks called by %s. This will lead to bugs and errors if not fixed. For more information, read the Rules of Hooks: https://reactjs.org/link/rules-of-hooks

   Previous render            Next render
   ------------------------------------------------------
%s   ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
`, t, r);
        }
      }
    }
    function sr() {
      throw Error(`Invalid hook call. Hooks can only be called inside of the body of a function component. This could happen for one of the following reasons:
1. You might have mismatching versions of React and the renderer (such as React DOM)
2. You might be breaking the Rules of Hooks
3. You might have more than one copy of React in the same app
See https://reactjs.org/link/invalid-hook-call for tips about how to debug and fix this problem.`);
    }
    function gy(e, t) {
      if (yy)
        return !1;
      if (t === null)
        return y("%s received a final argument during this render, but not during the previous render. Even though the final argument is optional, its type cannot change between renders.", X), !1;
      e.length !== t.length && y(`The final argument passed to %s changed size between renders. The order and size of this array must remain constant.

Previous: %s
Incoming: %s`, X, "[" + t.join(", ") + "]", "[" + e.join(", ") + "]");
      for (var r = 0; r < t.length && r < e.length; r++)
        if (!a(e[r], t[r]))
          return !1;
      return !0;
    }
    function Ys(e, t, r, i, o, s) {
      Xf = s, _t = t, Wr = e !== null ? e._debugHookTypes : null, Jl = -1, yy = e !== null && e.type !== t.type, t.memoizedState = null, t.updateQueue = null, t.lanes = W, e !== null && e.memoizedState !== null ? me.current = mS : Wr !== null ? me.current = hS : me.current = vS;
      var d = r(i, o);
      if (Kf) {
        var v = 0;
        do {
          if (Kf = !1, !(v < LR))
            throw Error("Too many re-renders. React limits the number of renders to prevent an infinite loop.");
          v += 1, yy = !1, Pn = null, bn = null, t.updateQueue = null, Jl = -1, me.current = yS, d = r(i, o);
        } while (Kf);
      }
      me.current = Hv, t._debugHookTypes = Wr;
      var E = Pn !== null && Pn.next !== null;
      if (Xf = W, _t = null, Pn = null, bn = null, X = null, Wr = null, Jl = -1, kv = !1, E)
        throw Error("Rendered fewer hooks than expected. This may be caused by an accidental early return statement.");
      return d;
    }
    function nS(e, t, r) {
      t.updateQueue = e.updateQueue, t.flags &= ~(xl | Ue), e.lanes = Hl(e.lanes, r);
    }
    function rS() {
      if (me.current = Hv, kv) {
        for (var e = _t.memoizedState; e !== null; ) {
          var t = e.queue;
          t !== null && (t.pending = null), e = e.next;
        }
        kv = !1;
      }
      Xf = W, _t = null, Pn = null, bn = null, Wr = null, Jl = -1, X = null, Fv = !1, Kf = !1;
    }
    function gu() {
      var e = {
        memoizedState: null,
        baseState: null,
        baseQueue: null,
        queue: null,
        next: null
      };
      return bn === null ? _t.memoizedState = bn = e : bn = bn.next = e, bn;
    }
    function Eu() {
      var e;
      if (Pn === null) {
        var t = _t.alternate;
        t !== null ? e = t.memoizedState : e = null;
      } else
        e = Pn.next;
      var r;
      if (bn === null ? r = _t.memoizedState : r = bn.next, r !== null)
        bn = r, r = bn.next, Pn = e;
      else {
        if (e === null)
          throw Error("Rendered more hooks than during the previous render.");
        Pn = e;
        var i = {
          memoizedState: Pn.memoizedState,
          baseState: Pn.baseState,
          baseQueue: Pn.baseQueue,
          queue: Pn.queue,
          next: null
        };
        bn === null ? _t.memoizedState = bn = i : bn = bn.next = i;
      }
      return bn;
    }
    function UR() {
      return {
        lastEffect: null
      };
    }
    function _v(e, t) {
      return typeof t == "function" ? t(e) : t;
    }
    function Ey(e, t, r) {
      var i = gu(), o;
      r !== void 0 ? o = r(t) : o = t, i.memoizedState = i.baseState = o;
      var s = i.queue = {
        pending: null,
        dispatch: null,
        lastRenderedReducer: e,
        lastRenderedState: o
      }, d = s.dispatch = My.bind(null, _t, s);
      return [i.memoizedState, d];
    }
    function Sy(e, t, r) {
      var i = Eu(), o = i.queue;
      if (o === null)
        throw Error("Should have a queue. This is likely a bug in React. Please file an issue.");
      o.lastRenderedReducer = e;
      var s = Pn, d = s.baseQueue, v = o.pending;
      if (v !== null) {
        if (d !== null) {
          var E = d.next, R = v.next;
          d.next = R, v.next = E;
        }
        s.baseQueue !== d && y("Internal error: Expected work-in-progress queue to be a clone. This is a bug in React."), s.baseQueue = d = v, o.pending = null;
      }
      if (d !== null) {
        var x = d.next, U = s.baseState, k = null, H = null, Q = null, se = x;
        do {
          var Me = se.lane;
          if (Wa(Xf, Me)) {
            if (Q !== null) {
              var je = {
                // This update is going to be committed so we never want uncommit
                // it. Using NoLane works because 0 is a subset of all bitmasks, so
                // this will never be skipped by the check above.
                lane: qt,
                action: se.action,
                eagerReducer: se.eagerReducer,
                eagerState: se.eagerState,
                next: null
              };
              Q = Q.next = je;
            }
            if (se.eagerReducer === e)
              U = se.eagerState;
            else {
              var ft = se.action;
              U = e(U, ft);
            }
          } else {
            var Xe = {
              lane: Me,
              action: se.action,
              eagerReducer: se.eagerReducer,
              eagerState: se.eagerState,
              next: null
            };
            Q === null ? (H = Q = Xe, k = U) : Q = Q.next = Xe, _t.lanes = dt(_t.lanes, Me), yg(Me);
          }
          se = se.next;
        } while (se !== null && se !== x);
        Q === null ? k = U : Q.next = H, a(U, i.memoizedState) || Yy(), i.memoizedState = U, i.baseState = k, i.baseQueue = Q, o.lastRenderedState = U;
      }
      var kt = o.dispatch;
      return [i.memoizedState, kt];
    }
    function Cy(e, t, r) {
      var i = Eu(), o = i.queue;
      if (o === null)
        throw Error("Should have a queue. This is likely a bug in React. Please file an issue.");
      o.lastRenderedReducer = e;
      var s = o.dispatch, d = o.pending, v = i.memoizedState;
      if (d !== null) {
        o.pending = null;
        var E = d.next, R = E;
        do {
          var x = R.action;
          v = e(v, x), R = R.next;
        } while (R !== E);
        a(v, i.memoizedState) || Yy(), i.memoizedState = v, i.baseQueue === null && (i.baseState = v), o.lastRenderedState = v;
      }
      return [v, s];
    }
    function aS(e, t, r) {
      MR(t);
      var i = t._getVersion, o = i(t._source), s = !1, d = NR(t);
      if (d !== null ? s = d === o : (s = Wa(Xf, e.mutableReadLanes), s && tS(t, o)), s) {
        var v = r(t._source);
        return typeof v == "function" && y("Mutable source should not return a function as the snapshot value. Functions may close over mutable values and cause tearing."), v;
      } else
        throw OR(t), Error("Cannot read from mutable source during the current render without tearing. This is a bug in React. Please file an issue.");
    }
    function iS(e, t, r, i) {
      var o = Hx();
      if (o === null)
        throw Error("Expected a work-in-progress root. This is a bug in React. Please file an issue.");
      var s = t._getVersion, d = s(t._source), v = me.current, E = v.useState(function() {
        return aS(o, t, r);
      }), R = E[0], x = E[1], U = R, k = bn, H = e.memoizedState, Q = H.refs, se = Q.getSnapshot, Me = H.source, Xe = H.subscribe, je = _t;
      if (e.memoizedState = {
        refs: Q,
        source: t,
        subscribe: i
      }, v.useEffect(function() {
        Q.getSnapshot = r, Q.setSnapshot = x;
        var kt = s(t._source);
        if (!a(d, kt)) {
          var j = r(t._source);
          if (typeof j == "function" && y("Mutable source should not return a function as the snapshot value. Functions may close over mutable values and cause tearing."), !a(U, j)) {
            x(j);
            var V = eo(je);
            gp(o, V);
          }
          sf(o, o.mutableReadLanes);
        }
      }, [r, t, i]), v.useEffect(function() {
        var kt = function() {
          var V = Q.getSnapshot, N = Q.setSnapshot;
          try {
            N(V(t._source));
            var ae = eo(je);
            gp(o, ae);
          } catch (pe) {
            N(function() {
              throw pe;
            });
          }
        }, j = i(t._source, kt);
        return typeof j != "function" && y("Mutable source subscribe function must return an unsubscribe function."), j;
      }, [t, i]), !a(se, r) || !a(Me, t) || !a(Xe, i)) {
        var ft = {
          pending: null,
          dispatch: null,
          lastRenderedReducer: _v,
          lastRenderedState: U
        };
        ft.dispatch = x = My.bind(null, _t, ft), k.queue = ft, k.baseQueue = null, U = aS(o, t, r), k.memoizedState = k.baseState = U;
      }
      return U;
    }
    function by(e, t, r) {
      var i = gu();
      return i.memoizedState = {
        refs: {
          getSnapshot: t,
          setSnapshot: null
        },
        source: e,
        subscribe: r
      }, iS(i, e, t, r);
    }
    function Dv(e, t, r) {
      var i = Eu();
      return iS(i, e, t, r);
    }
    function Su(e) {
      var t = gu();
      typeof e == "function" && (e = e()), t.memoizedState = t.baseState = e;
      var r = t.queue = {
        pending: null,
        dispatch: null,
        lastRenderedReducer: _v,
        lastRenderedState: e
      }, i = r.dispatch = My.bind(null, _t, r);
      return [t.memoizedState, i];
    }
    function Jf(e) {
      return Sy(_v);
    }
    function ed(e) {
      return Cy(_v);
    }
    function Ov(e, t, r, i) {
      var o = {
        tag: e,
        create: t,
        destroy: r,
        deps: i,
        // Circular
        next: null
      }, s = _t.updateQueue;
      if (s === null)
        s = UR(), _t.updateQueue = s, s.lastEffect = o.next = o;
      else {
        var d = s.lastEffect;
        if (d === null)
          s.lastEffect = o.next = o;
        else {
          var v = d.next;
          d.next = o, o.next = v, s.lastEffect = o;
        }
      }
      return o;
    }
    function Nv(e) {
      var t = gu(), r = {
        current: e
      };
      return Object.seal(r), t.memoizedState = r, r;
    }
    function qs(e) {
      var t = Eu();
      return t.memoizedState;
    }
    function Ty(e, t, r, i) {
      var o = gu(), s = i === void 0 ? null : i;
      _t.flags |= e, o.memoizedState = Ov($s | t, r, void 0, s);
    }
    function Ry(e, t, r, i) {
      var o = Eu(), s = i === void 0 ? null : i, d = void 0;
      if (Pn !== null) {
        var v = Pn.memoizedState;
        if (d = v.destroy, s !== null) {
          var E = v.deps;
          if (gy(s, E)) {
            Ov(t, r, d, s);
            return;
          }
        }
      }
      _t.flags |= e, o.memoizedState = Ov($s | t, r, d, s);
    }
    function Mv(e, t) {
      return typeof jest < "u" && SC(_t), Ty(Ue | xl, Qf, e, t);
    }
    function Qs(e, t) {
      return typeof jest < "u" && SC(_t), Ry(Ue | xl, Qf, e, t);
    }
    function xy(e, t) {
      return Ty(Ue, Ws, e, t);
    }
    function Lv(e, t) {
      return Ry(Ue, Ws, e, t);
    }
    function lS(e, t) {
      if (typeof t == "function") {
        var r = t, i = e();
        return r(i), function() {
          r(null);
        };
      } else if (t != null) {
        var o = t;
        o.hasOwnProperty("current") || y("Expected useImperativeHandle() first argument to either be a ref callback or React.createRef() object. Instead received: %s.", "an object with keys {" + Object.keys(o).join(", ") + "}");
        var s = e();
        return o.current = s, function() {
          o.current = null;
        };
      }
    }
    function wy(e, t, r) {
      typeof t != "function" && y("Expected useImperativeHandle() second argument to be a function that creates a handle. Instead received: %s.", t !== null ? typeof t : "null");
      var i = r != null ? r.concat([e]) : null;
      return Ty(Ue, Ws, lS.bind(null, t, e), i);
    }
    function Av(e, t, r) {
      typeof t != "function" && y("Expected useImperativeHandle() second argument to be a function that creates a handle. Instead received: %s.", t !== null ? typeof t : "null");
      var i = r != null ? r.concat([e]) : null;
      return Ry(Ue, Ws, lS.bind(null, t, e), i);
    }
    function zR(e, t) {
    }
    var Uv = zR;
    function ky(e, t) {
      var r = gu(), i = t === void 0 ? null : t;
      return r.memoizedState = [e, i], e;
    }
    function zv(e, t) {
      var r = Eu(), i = t === void 0 ? null : t, o = r.memoizedState;
      if (o !== null && i !== null) {
        var s = o[1];
        if (gy(i, s))
          return o[0];
      }
      return r.memoizedState = [e, i], e;
    }
    function _y(e, t) {
      var r = gu(), i = t === void 0 ? null : t, o = e();
      return r.memoizedState = [o, i], o;
    }
    function jv(e, t) {
      var r = Eu(), i = t === void 0 ? null : t, o = r.memoizedState;
      if (o !== null && i !== null) {
        var s = o[1];
        if (gy(i, s))
          return o[0];
      }
      var d = e();
      return r.memoizedState = [d, i], d;
    }
    function Dy(e) {
      var t = Su(e), r = t[0], i = t[1];
      return Mv(function() {
        var o = $r.transition;
        $r.transition = 1;
        try {
          i(e);
        } finally {
          $r.transition = o;
        }
      }, [e]), r;
    }
    function oS(e) {
      var t = Jf(), r = t[0], i = t[1];
      return Qs(function() {
        var o = $r.transition;
        $r.transition = 1;
        try {
          i(e);
        } finally {
          $r.transition = o;
        }
      }, [e]), r;
    }
    function uS(e) {
      var t = ed(), r = t[0], i = t[1];
      return Qs(function() {
        var o = $r.transition;
        $r.transition = 1;
        try {
          i(e);
        } finally {
          $r.transition = o;
        }
      }, [e]), r;
    }
    function jR(e, t) {
      var r = Hs();
      du(r < fu ? fu : r, function() {
        e(!0);
      }), du(r > $i ? $i : r, function() {
        var i = $r.transition;
        $r.transition = 1;
        try {
          e(!1), t();
        } finally {
          $r.transition = i;
        }
      });
    }
    function Oy() {
      var e = Su(!1), t = e[0], r = e[1], i = jR.bind(null, r);
      return Nv(i), [i, t];
    }
    function sS() {
      var e = Jf(), t = e[0], r = qs(), i = r.current;
      return [i, t];
    }
    function cS() {
      var e = ed(), t = e[0], r = qs(), i = r.current;
      return [i, t];
    }
    var Fv = !1;
    function FR() {
      return Fv;
    }
    function fS(e) {
      {
        var t = fe(e.type) || "Unknown";
        Sd() && !my[t] && (y("The object passed back from useOpaqueIdentifier is meant to be passed through to attributes only. Do not read the value directly."), my[t] = !0);
      }
    }
    function Ny() {
      var e = $T.bind(null, fS.bind(null, _t));
      if (dy()) {
        var t = !1, r = _t, i = function() {
          throw t || (t = !0, Fv = !0, s(e()), Fv = !1, fS(r)), Error("The object passed back from useOpaqueIdentifier is meant to be passed through to attributes only. Do not read the value directly.");
        }, o = YT(i), s = Su(o)[1];
        return (_t.mode & ur) === Vt && (_t.flags |= Ue | xl, Ov($s | Qf, function() {
          s(e());
        }, void 0, null)), o;
      } else {
        var d = e();
        return Su(d), d;
      }
    }
    function dS() {
      var e = Jf()[0];
      return e;
    }
    function pS() {
      var e = ed()[0];
      return e;
    }
    function My(e, t, r) {
      typeof arguments[3] == "function" && y("State updates from the useState() and useReducer() Hooks don't support the second callback argument. To execute a side effect after rendering, declare it in the component body with useEffect().");
      var i = br(), o = eo(e), s = {
        lane: o,
        action: r,
        eagerReducer: null,
        eagerState: null,
        next: null
      }, d = t.pending;
      d === null ? s.next = s : (s.next = d.next, d.next = s), t.pending = s;
      var v = e.alternate;
      if (e === _t || v !== null && v === _t)
        Kf = kv = !0;
      else {
        if (e.lanes === W && (v === null || v.lanes === W)) {
          var E = t.lastRenderedReducer;
          if (E !== null) {
            var R;
            R = me.current, me.current = ma;
            try {
              var x = t.lastRenderedState, U = E(x, r);
              if (s.eagerReducer = E, s.eagerState = U, a(U, x))
                return;
            } catch {
            } finally {
              me.current = R;
            }
          }
        }
        typeof jest < "u" && (EC(e), Cw(e)), Bn(e, o, i);
      }
    }
    var Hv = {
      readContext: fn,
      useCallback: sr,
      useContext: sr,
      useEffect: sr,
      useImperativeHandle: sr,
      useLayoutEffect: sr,
      useMemo: sr,
      useReducer: sr,
      useRef: sr,
      useState: sr,
      useDebugValue: sr,
      useDeferredValue: sr,
      useTransition: sr,
      useMutableSource: sr,
      useOpaqueIdentifier: sr,
      unstable_isNewReconciler: Rt
    }, vS = null, hS = null, mS = null, yS = null, ri = null, ma = null, Pv = null;
    {
      var Ly = function() {
        y("Context can only be read while React is rendering. In classes, you can read it in the render method or getDerivedStateFromProps. In function components, you can read it directly in the function body, but not inside Hooks like useReducer() or useMemo().");
      }, et = function() {
        y("Do not call Hooks inside useEffect(...), useMemo(...), or other built-in Hooks. You can only call Hooks at the top level of your React function. For more information, see https://reactjs.org/link/rules-of-hooks");
      };
      vS = {
        readContext: function(e, t) {
          return fn(e, t);
        },
        useCallback: function(e, t) {
          return X = "useCallback", wt(), Zf(t), ky(e, t);
        },
        useContext: function(e, t) {
          return X = "useContext", wt(), fn(e, t);
        },
        useEffect: function(e, t) {
          return X = "useEffect", wt(), Zf(t), Mv(e, t);
        },
        useImperativeHandle: function(e, t, r) {
          return X = "useImperativeHandle", wt(), Zf(r), wy(e, t, r);
        },
        useLayoutEffect: function(e, t) {
          return X = "useLayoutEffect", wt(), Zf(t), xy(e, t);
        },
        useMemo: function(e, t) {
          X = "useMemo", wt(), Zf(t);
          var r = me.current;
          me.current = ri;
          try {
            return _y(e, t);
          } finally {
            me.current = r;
          }
        },
        useReducer: function(e, t, r) {
          X = "useReducer", wt();
          var i = me.current;
          me.current = ri;
          try {
            return Ey(e, t, r);
          } finally {
            me.current = i;
          }
        },
        useRef: function(e) {
          return X = "useRef", wt(), Nv(e);
        },
        useState: function(e) {
          X = "useState", wt();
          var t = me.current;
          me.current = ri;
          try {
            return Su(e);
          } finally {
            me.current = t;
          }
        },
        useDebugValue: function(e, t) {
          return X = "useDebugValue", wt(), void 0;
        },
        useDeferredValue: function(e) {
          return X = "useDeferredValue", wt(), Dy(e);
        },
        useTransition: function() {
          return X = "useTransition", wt(), Oy();
        },
        useMutableSource: function(e, t, r) {
          return X = "useMutableSource", wt(), by(e, t, r);
        },
        useOpaqueIdentifier: function() {
          return X = "useOpaqueIdentifier", wt(), Ny();
        },
        unstable_isNewReconciler: Rt
      }, hS = {
        readContext: function(e, t) {
          return fn(e, t);
        },
        useCallback: function(e, t) {
          return X = "useCallback", Ee(), ky(e, t);
        },
        useContext: function(e, t) {
          return X = "useContext", Ee(), fn(e, t);
        },
        useEffect: function(e, t) {
          return X = "useEffect", Ee(), Mv(e, t);
        },
        useImperativeHandle: function(e, t, r) {
          return X = "useImperativeHandle", Ee(), wy(e, t, r);
        },
        useLayoutEffect: function(e, t) {
          return X = "useLayoutEffect", Ee(), xy(e, t);
        },
        useMemo: function(e, t) {
          X = "useMemo", Ee();
          var r = me.current;
          me.current = ri;
          try {
            return _y(e, t);
          } finally {
            me.current = r;
          }
        },
        useReducer: function(e, t, r) {
          X = "useReducer", Ee();
          var i = me.current;
          me.current = ri;
          try {
            return Ey(e, t, r);
          } finally {
            me.current = i;
          }
        },
        useRef: function(e) {
          return X = "useRef", Ee(), Nv(e);
        },
        useState: function(e) {
          X = "useState", Ee();
          var t = me.current;
          me.current = ri;
          try {
            return Su(e);
          } finally {
            me.current = t;
          }
        },
        useDebugValue: function(e, t) {
          return X = "useDebugValue", Ee(), void 0;
        },
        useDeferredValue: function(e) {
          return X = "useDeferredValue", Ee(), Dy(e);
        },
        useTransition: function() {
          return X = "useTransition", Ee(), Oy();
        },
        useMutableSource: function(e, t, r) {
          return X = "useMutableSource", Ee(), by(e, t, r);
        },
        useOpaqueIdentifier: function() {
          return X = "useOpaqueIdentifier", Ee(), Ny();
        },
        unstable_isNewReconciler: Rt
      }, mS = {
        readContext: function(e, t) {
          return fn(e, t);
        },
        useCallback: function(e, t) {
          return X = "useCallback", Ee(), zv(e, t);
        },
        useContext: function(e, t) {
          return X = "useContext", Ee(), fn(e, t);
        },
        useEffect: function(e, t) {
          return X = "useEffect", Ee(), Qs(e, t);
        },
        useImperativeHandle: function(e, t, r) {
          return X = "useImperativeHandle", Ee(), Av(e, t, r);
        },
        useLayoutEffect: function(e, t) {
          return X = "useLayoutEffect", Ee(), Lv(e, t);
        },
        useMemo: function(e, t) {
          X = "useMemo", Ee();
          var r = me.current;
          me.current = ma;
          try {
            return jv(e, t);
          } finally {
            me.current = r;
          }
        },
        useReducer: function(e, t, r) {
          X = "useReducer", Ee();
          var i = me.current;
          me.current = ma;
          try {
            return Sy(e, t, r);
          } finally {
            me.current = i;
          }
        },
        useRef: function(e) {
          return X = "useRef", Ee(), qs();
        },
        useState: function(e) {
          X = "useState", Ee();
          var t = me.current;
          me.current = ma;
          try {
            return Jf(e);
          } finally {
            me.current = t;
          }
        },
        useDebugValue: function(e, t) {
          return X = "useDebugValue", Ee(), Uv();
        },
        useDeferredValue: function(e) {
          return X = "useDeferredValue", Ee(), oS(e);
        },
        useTransition: function() {
          return X = "useTransition", Ee(), sS();
        },
        useMutableSource: function(e, t, r) {
          return X = "useMutableSource", Ee(), Dv(e, t, r);
        },
        useOpaqueIdentifier: function() {
          return X = "useOpaqueIdentifier", Ee(), dS();
        },
        unstable_isNewReconciler: Rt
      }, yS = {
        readContext: function(e, t) {
          return fn(e, t);
        },
        useCallback: function(e, t) {
          return X = "useCallback", Ee(), zv(e, t);
        },
        useContext: function(e, t) {
          return X = "useContext", Ee(), fn(e, t);
        },
        useEffect: function(e, t) {
          return X = "useEffect", Ee(), Qs(e, t);
        },
        useImperativeHandle: function(e, t, r) {
          return X = "useImperativeHandle", Ee(), Av(e, t, r);
        },
        useLayoutEffect: function(e, t) {
          return X = "useLayoutEffect", Ee(), Lv(e, t);
        },
        useMemo: function(e, t) {
          X = "useMemo", Ee();
          var r = me.current;
          me.current = Pv;
          try {
            return jv(e, t);
          } finally {
            me.current = r;
          }
        },
        useReducer: function(e, t, r) {
          X = "useReducer", Ee();
          var i = me.current;
          me.current = Pv;
          try {
            return Cy(e, t, r);
          } finally {
            me.current = i;
          }
        },
        useRef: function(e) {
          return X = "useRef", Ee(), qs();
        },
        useState: function(e) {
          X = "useState", Ee();
          var t = me.current;
          me.current = Pv;
          try {
            return ed(e);
          } finally {
            me.current = t;
          }
        },
        useDebugValue: function(e, t) {
          return X = "useDebugValue", Ee(), Uv();
        },
        useDeferredValue: function(e) {
          return X = "useDeferredValue", Ee(), uS(e);
        },
        useTransition: function() {
          return X = "useTransition", Ee(), cS();
        },
        useMutableSource: function(e, t, r) {
          return X = "useMutableSource", Ee(), Dv(e, t, r);
        },
        useOpaqueIdentifier: function() {
          return X = "useOpaqueIdentifier", Ee(), pS();
        },
        unstable_isNewReconciler: Rt
      }, ri = {
        readContext: function(e, t) {
          return Ly(), fn(e, t);
        },
        useCallback: function(e, t) {
          return X = "useCallback", et(), wt(), ky(e, t);
        },
        useContext: function(e, t) {
          return X = "useContext", et(), wt(), fn(e, t);
        },
        useEffect: function(e, t) {
          return X = "useEffect", et(), wt(), Mv(e, t);
        },
        useImperativeHandle: function(e, t, r) {
          return X = "useImperativeHandle", et(), wt(), wy(e, t, r);
        },
        useLayoutEffect: function(e, t) {
          return X = "useLayoutEffect", et(), wt(), xy(e, t);
        },
        useMemo: function(e, t) {
          X = "useMemo", et(), wt();
          var r = me.current;
          me.current = ri;
          try {
            return _y(e, t);
          } finally {
            me.current = r;
          }
        },
        useReducer: function(e, t, r) {
          X = "useReducer", et(), wt();
          var i = me.current;
          me.current = ri;
          try {
            return Ey(e, t, r);
          } finally {
            me.current = i;
          }
        },
        useRef: function(e) {
          return X = "useRef", et(), wt(), Nv(e);
        },
        useState: function(e) {
          X = "useState", et(), wt();
          var t = me.current;
          me.current = ri;
          try {
            return Su(e);
          } finally {
            me.current = t;
          }
        },
        useDebugValue: function(e, t) {
          return X = "useDebugValue", et(), wt(), void 0;
        },
        useDeferredValue: function(e) {
          return X = "useDeferredValue", et(), wt(), Dy(e);
        },
        useTransition: function() {
          return X = "useTransition", et(), wt(), Oy();
        },
        useMutableSource: function(e, t, r) {
          return X = "useMutableSource", et(), wt(), by(e, t, r);
        },
        useOpaqueIdentifier: function() {
          return X = "useOpaqueIdentifier", et(), wt(), Ny();
        },
        unstable_isNewReconciler: Rt
      }, ma = {
        readContext: function(e, t) {
          return Ly(), fn(e, t);
        },
        useCallback: function(e, t) {
          return X = "useCallback", et(), Ee(), zv(e, t);
        },
        useContext: function(e, t) {
          return X = "useContext", et(), Ee(), fn(e, t);
        },
        useEffect: function(e, t) {
          return X = "useEffect", et(), Ee(), Qs(e, t);
        },
        useImperativeHandle: function(e, t, r) {
          return X = "useImperativeHandle", et(), Ee(), Av(e, t, r);
        },
        useLayoutEffect: function(e, t) {
          return X = "useLayoutEffect", et(), Ee(), Lv(e, t);
        },
        useMemo: function(e, t) {
          X = "useMemo", et(), Ee();
          var r = me.current;
          me.current = ma;
          try {
            return jv(e, t);
          } finally {
            me.current = r;
          }
        },
        useReducer: function(e, t, r) {
          X = "useReducer", et(), Ee();
          var i = me.current;
          me.current = ma;
          try {
            return Sy(e, t, r);
          } finally {
            me.current = i;
          }
        },
        useRef: function(e) {
          return X = "useRef", et(), Ee(), qs();
        },
        useState: function(e) {
          X = "useState", et(), Ee();
          var t = me.current;
          me.current = ma;
          try {
            return Jf(e);
          } finally {
            me.current = t;
          }
        },
        useDebugValue: function(e, t) {
          return X = "useDebugValue", et(), Ee(), Uv();
        },
        useDeferredValue: function(e) {
          return X = "useDeferredValue", et(), Ee(), oS(e);
        },
        useTransition: function() {
          return X = "useTransition", et(), Ee(), sS();
        },
        useMutableSource: function(e, t, r) {
          return X = "useMutableSource", et(), Ee(), Dv(e, t, r);
        },
        useOpaqueIdentifier: function() {
          return X = "useOpaqueIdentifier", et(), Ee(), dS();
        },
        unstable_isNewReconciler: Rt
      }, Pv = {
        readContext: function(e, t) {
          return Ly(), fn(e, t);
        },
        useCallback: function(e, t) {
          return X = "useCallback", et(), Ee(), zv(e, t);
        },
        useContext: function(e, t) {
          return X = "useContext", et(), Ee(), fn(e, t);
        },
        useEffect: function(e, t) {
          return X = "useEffect", et(), Ee(), Qs(e, t);
        },
        useImperativeHandle: function(e, t, r) {
          return X = "useImperativeHandle", et(), Ee(), Av(e, t, r);
        },
        useLayoutEffect: function(e, t) {
          return X = "useLayoutEffect", et(), Ee(), Lv(e, t);
        },
        useMemo: function(e, t) {
          X = "useMemo", et(), Ee();
          var r = me.current;
          me.current = ma;
          try {
            return jv(e, t);
          } finally {
            me.current = r;
          }
        },
        useReducer: function(e, t, r) {
          X = "useReducer", et(), Ee();
          var i = me.current;
          me.current = ma;
          try {
            return Cy(e, t, r);
          } finally {
            me.current = i;
          }
        },
        useRef: function(e) {
          return X = "useRef", et(), Ee(), qs();
        },
        useState: function(e) {
          X = "useState", et(), Ee();
          var t = me.current;
          me.current = ma;
          try {
            return ed(e);
          } finally {
            me.current = t;
          }
        },
        useDebugValue: function(e, t) {
          return X = "useDebugValue", et(), Ee(), Uv();
        },
        useDeferredValue: function(e) {
          return X = "useDeferredValue", et(), Ee(), uS(e);
        },
        useTransition: function() {
          return X = "useTransition", et(), Ee(), cS();
        },
        useMutableSource: function(e, t, r) {
          return X = "useMutableSource", et(), Ee(), Dv(e, t, r);
        },
        useOpaqueIdentifier: function() {
          return X = "useOpaqueIdentifier", et(), Ee(), pS();
        },
        unstable_isNewReconciler: Rt
      };
    }
    var Bv = g.unstable_now, gS = 0, td = -1;
    function HR() {
      return gS;
    }
    function ES() {
      gS = Bv();
    }
    function Ay(e) {
      td = Bv(), e.actualStartTime < 0 && (e.actualStartTime = Bv());
    }
    function SS(e) {
      td = -1;
    }
    function Vv(e, t) {
      if (td >= 0) {
        var r = Bv() - td;
        e.actualDuration += r, t && (e.selfBaseDuration = r), td = -1;
      }
    }
    function Uy(e) {
      for (var t = e.child; t; )
        e.actualDuration += t.actualDuration, t = t.sibling;
    }
    var nd = b.ReactCurrentOwner, ai = !1, zy, rd, jy, Fy, Hy, Cu, Py, Iv;
    zy = {}, rd = {}, jy = {}, Fy = {}, Hy = {}, Cu = !1, Py = {}, Iv = {};
    function cr(e, t, r, i) {
      e === null ? t.child = qE(t, null, r, i) : t.child = Cv(t, e.child, r, i);
    }
    function PR(e, t, r, i) {
      t.child = Cv(t, e.child, null, i), t.child = Cv(t, null, r, i);
    }
    function CS(e, t, r, i, o) {
      if (t.type !== t.elementType) {
        var s = r.propTypes;
        s && da(
          s,
          i,
          // Resolved props
          "prop",
          fe(r)
        );
      }
      var d = r.render, v = t.ref, E;
      Bs(t, o);
      {
        if (nd.current = t, Vn(!0), E = Ys(e, t, d, i, v, o), t.mode & Gt) {
          Dr();
          try {
            E = Ys(e, t, d, i, v, o);
          } finally {
            Sn();
          }
        }
        Vn(!1);
      }
      return e !== null && !ai ? (nS(e, t, o), Yi(e, t, o)) : (t.flags |= On, cr(e, t, E, o), t.child);
    }
    function bS(e, t, r, i, o, s) {
      if (e === null) {
        var d = r.type;
        if (Lw(d) && r.compare === null && // SimpleMemoComponent codepath doesn't resolve outer props either.
        r.defaultProps === void 0) {
          var v = d;
          return v = nc(d), t.tag = Se, t.type = v, $y(t, d), TS(e, t, v, i, o, s);
        }
        {
          var E = d.propTypes;
          E && da(
            E,
            i,
            // Resolved props
            "prop",
            fe(d)
          );
        }
        var R = _g(r.type, null, i, t, t.mode, s);
        return R.ref = t.ref, R.return = t, t.child = R, R;
      }
      {
        var x = r.type, U = x.propTypes;
        U && da(
          U,
          i,
          // Resolved props
          "prop",
          fe(x)
        );
      }
      var k = e.child;
      if (!yn(o, s)) {
        var H = k.memoizedProps, Q = r.compare;
        if (Q = Q !== null ? Q : u, Q(H, i) && e.ref === t.ref)
          return Yi(e, t, s);
      }
      t.flags |= On;
      var se = wu(k, i);
      return se.ref = t.ref, se.return = t, t.child = se, se;
    }
    function TS(e, t, r, i, o, s) {
      if (t.type !== t.elementType) {
        var d = t.elementType;
        if (d.$$typeof === kr) {
          var v = d, E = v._payload, R = v._init;
          try {
            d = R(E);
          } catch {
            d = null;
          }
          var x = d && d.propTypes;
          x && da(
            x,
            i,
            // Resolved (SimpleMemoComponent has no defaultProps)
            "prop",
            fe(d)
          );
        }
      }
      if (e !== null) {
        var U = e.memoizedProps;
        if (u(U, i) && e.ref === t.ref && // Prevent bailout if the implementation changed due to hot reload.
        t.type === e.type)
          if (ai = !1, yn(s, o))
            (e.flags & Mo) !== Et && (ai = !0);
          else return t.lanes = e.lanes, Yi(e, t, s);
      }
      return Vy(e, t, r, i, s);
    }
    function By(e, t, r) {
      var i = t.pendingProps, o = i.children, s = e !== null ? e.memoizedState : null;
      if (i.mode === "hidden" || i.mode === "unstable-defer-without-hiding")
        if ((t.mode & pu) === Vt) {
          var d = {
            baseLanes: W
          };
          t.memoizedState = d, ih(t, r);
        } else if (yn(r, yr)) {
          var x = {
            baseLanes: W
          };
          t.memoizedState = x;
          var U = s !== null ? s.baseLanes : r;
          ih(t, U);
        } else {
          var v;
          if (s !== null) {
            var E = s.baseLanes;
            v = dt(E, r);
          } else
            v = r;
          fh(yr), t.lanes = t.childLanes = yr;
          var R = {
            baseLanes: v
          };
          return t.memoizedState = R, ih(t, v), null;
        }
      else {
        var k;
        s !== null ? (k = dt(s.baseLanes, r), t.memoizedState = null) : k = r, ih(t, k);
      }
      return cr(e, t, o, r), t.child;
    }
    var BR = By;
    function VR(e, t, r) {
      var i = t.pendingProps;
      return cr(e, t, i, r), t.child;
    }
    function IR(e, t, r) {
      var i = t.pendingProps.children;
      return cr(e, t, i, r), t.child;
    }
    function $R(e, t, r) {
      {
        t.flags |= Ue;
        var i = t.stateNode;
        i.effectDuration = 0, i.passiveEffectDuration = 0;
      }
      var o = t.pendingProps, s = o.children;
      return cr(e, t, s, r), t.child;
    }
    function RS(e, t) {
      var r = t.ref;
      (e === null && r !== null || e !== null && e.ref !== r) && (t.flags |= hn);
    }
    function Vy(e, t, r, i, o) {
      if (t.type !== t.elementType) {
        var s = r.propTypes;
        s && da(
          s,
          i,
          // Resolved props
          "prop",
          fe(r)
        );
      }
      var d;
      {
        var v = zs(t, r, !0);
        d = js(t, v);
      }
      var E;
      Bs(t, o);
      {
        if (nd.current = t, Vn(!0), E = Ys(e, t, r, i, d, o), t.mode & Gt) {
          Dr();
          try {
            E = Ys(e, t, r, i, d, o);
          } finally {
            Sn();
          }
        }
        Vn(!1);
      }
      return e !== null && !ai ? (nS(e, t, o), Yi(e, t, o)) : (t.flags |= On, cr(e, t, E, o), t.child);
    }
    function xS(e, t, r, i, o) {
      if (t.type !== t.elementType) {
        var s = r.propTypes;
        s && da(
          s,
          i,
          // Resolved props
          "prop",
          fe(r)
        );
      }
      var d;
      ei(r) ? (d = !0, nv(t)) : d = !1, Bs(t, o);
      var v = t.stateNode, E;
      v === null ? (e !== null && (e.alternate = null, t.alternate = null, t.flags |= Ye), IE(t, r, i), Zm(t, r, i, o), E = !0) : e === null ? E = ER(t, r, i, o) : E = SR(e, t, r, i, o);
      var R = Iy(e, t, r, E, d, o);
      {
        var x = t.stateNode;
        E && x.props !== i && (Cu || y("It looks like %s is reassigning its own `this.props` while rendering. This is not supported and can lead to confusing bugs.", fe(t.type) || "a component"), Cu = !0);
      }
      return R;
    }
    function Iy(e, t, r, i, o, s) {
      RS(e, t);
      var d = (t.flags & vt) !== Et;
      if (!i && !d)
        return o && cE(t, r, !1), Yi(e, t, s);
      var v = t.stateNode;
      nd.current = t;
      var E;
      if (d && typeof r.getDerivedStateFromError != "function")
        E = null, SS();
      else {
        if (Vn(!0), E = v.render(), t.mode & Gt) {
          Dr();
          try {
            v.render();
          } finally {
            Sn();
          }
        }
        Vn(!1);
      }
      return t.flags |= On, e !== null && d ? PR(e, t, E, s) : cr(e, t, E, s), t.memoizedState = v.state, o && cE(t, r, !0), t.child;
    }
    function wS(e) {
      var t = e.stateNode;
      t.pendingContext ? uE(e, t.pendingContext, t.pendingContext !== t.context) : t.context && uE(e, t.context, !1), ay(e, t.containerInfo);
    }
    function WR(e, t, r) {
      wS(t);
      var i = t.updateQueue;
      if (!(e !== null && i !== null))
        throw Error("If the root does not have an updateQueue, we should have already bailed out. This error is likely caused by a bug in React. Please file an issue.");
      var o = t.pendingProps, s = t.memoizedState, d = s !== null ? s.element : null;
      AE(e, t), Vf(t, o, null, r);
      var v = t.memoizedState, E = v.element;
      if (E === d)
        return fy(), Yi(e, t, r);
      var R = t.stateNode;
      if (R.hydrate && wR(t)) {
        {
          var x = R.mutableSourceEagerHydrationData;
          if (x != null)
            for (var U = 0; U < x.length; U += 2) {
              var k = x[U], H = x[U + 1];
              tS(k, H);
            }
        }
        var Q = qE(t, null, E, r);
        t.child = Q;
        for (var se = Q; se; )
          se.flags = se.flags & ~Ye | nr, se = se.sibling;
      } else
        cr(e, t, E, r), fy();
      return t.child;
    }
    function YR(e, t, r) {
      GE(t), e === null && cy(t);
      var i = t.type, o = t.pendingProps, s = e !== null ? e.memoizedProps : null, d = o.children, v = Tm(i, o);
      return v ? d = null : s !== null && Tm(i, s) && (t.flags |= vn), RS(e, t), cr(e, t, d, r), t.child;
    }
    function qR(e, t) {
      return e === null && cy(t), null;
    }
    function QR(e, t, r, i, o) {
      e !== null && (e.alternate = null, t.alternate = null, t.flags |= Ye);
      var s = t.pendingProps, d = r, v = d._payload, E = d._init, R = E(v);
      t.type = R;
      var x = t.tag = Aw(R), U = va(R, s), k;
      switch (x) {
        case A:
          return $y(t, R), t.type = R = nc(R), k = Vy(null, t, R, U, o), k;
        case L:
          return t.type = R = bg(R), k = xS(null, t, R, U, o), k;
        case ee:
          return t.type = R = Tg(R), k = CS(null, t, R, U, o), k;
        case le: {
          if (t.type !== t.elementType) {
            var H = R.propTypes;
            H && da(
              H,
              U,
              // Resolved for outer only
              "prop",
              fe(R)
            );
          }
          return k = bS(
            null,
            t,
            R,
            va(R.type, U),
            // The inner type can have defaults too
            i,
            o
          ), k;
        }
      }
      var Q = "";
      throw R !== null && typeof R == "object" && R.$$typeof === kr && (Q = " Did you wrap a component in React.lazy() more than once?"), Error("Element type is invalid. Received a promise that resolves to: " + R + ". Lazy element type must resolve to a class or function." + Q);
    }
    function GR(e, t, r, i, o) {
      e !== null && (e.alternate = null, t.alternate = null, t.flags |= Ye), t.tag = L;
      var s;
      return ei(r) ? (s = !0, nv(t)) : s = !1, Bs(t, o), IE(t, r, i), Zm(t, r, i, o), Iy(null, t, r, !0, s, o);
    }
    function XR(e, t, r, i) {
      e !== null && (e.alternate = null, t.alternate = null, t.flags |= Ye);
      var o = t.pendingProps, s;
      {
        var d = zs(t, r, !1);
        s = js(t, d);
      }
      Bs(t, i);
      var v;
      {
        if (r.prototype && typeof r.prototype.render == "function") {
          var E = fe(r) || "Unknown";
          zy[E] || (y("The <%s /> component appears to have a render method, but doesn't extend React.Component. This is likely to cause errors. Change %s to extend React.Component instead.", E, E), zy[E] = !0);
        }
        t.mode & Gt && pa.recordLegacyContextWarning(t, null), Vn(!0), nd.current = t, v = Ys(null, t, r, o, s, i), Vn(!1);
      }
      if (t.flags |= On, typeof v == "object" && v !== null && typeof v.render == "function" && v.$$typeof === void 0) {
        var R = fe(r) || "Unknown";
        rd[R] || (y("The <%s /> component appears to be a function component that returns a class instance. Change %s to a class that extends React.Component instead. If you can't use a class try assigning the prototype on the function as a workaround. `%s.prototype = React.Component.prototype`. Don't use an arrow function since it cannot be called with `new` by React.", R, R, R), rd[R] = !0);
      }
      if (
        // Run these checks in production only if the flag is off.
        // Eventually we'll delete this branch altogether.
        typeof v == "object" && v !== null && typeof v.render == "function" && v.$$typeof === void 0
      ) {
        {
          var x = fe(r) || "Unknown";
          rd[x] || (y("The <%s /> component appears to be a function component that returns a class instance. Change %s to a class that extends React.Component instead. If you can't use a class try assigning the prototype on the function as a workaround. `%s.prototype = React.Component.prototype`. Don't use an arrow function since it cannot be called with `new` by React.", x, x, x), rd[x] = !0);
        }
        t.tag = L, t.memoizedState = null, t.updateQueue = null;
        var U = !1;
        ei(r) ? (U = !0, nv(t)) : U = !1, t.memoizedState = v.state !== null && v.state !== void 0 ? v.state : null, Bm(t);
        var k = r.getDerivedStateFromProps;
        return typeof k == "function" && yv(t, r, k, o), VE(t, v), Zm(t, r, o, i), Iy(null, t, r, !0, U, i);
      } else {
        if (t.tag = A, t.mode & Gt) {
          Dr();
          try {
            v = Ys(null, t, r, o, s, i);
          } finally {
            Sn();
          }
        }
        return cr(null, t, v, i), $y(t, r), t.child;
      }
    }
    function $y(e, t) {
      {
        if (t && t.childContextTypes && y("%s(...): childContextTypes cannot be defined on a function component.", t.displayName || t.name || "Component"), e.ref !== null) {
          var r = "", i = fl();
          i && (r += `

Check the render method of \`` + i + "`.");
          var o = i || e._debugID || "", s = e._debugSource;
          s && (o = s.fileName + ":" + s.lineNumber), Hy[o] || (Hy[o] = !0, y("Function components cannot be given refs. Attempts to access this ref will fail. Did you mean to use React.forwardRef()?%s", r));
        }
        if (typeof t.getDerivedStateFromProps == "function") {
          var d = fe(t) || "Unknown";
          Fy[d] || (y("%s: Function components do not support getDerivedStateFromProps.", d), Fy[d] = !0);
        }
        if (typeof t.contextType == "object" && t.contextType !== null) {
          var v = fe(t) || "Unknown";
          jy[v] || (y("%s: Function components do not support contextType.", v), jy[v] = !0);
        }
      }
    }
    var $v = {
      dehydrated: null,
      retryLane: qt
    };
    function Wv(e) {
      return {
        baseLanes: e
      };
    }
    function kS(e, t) {
      return {
        baseLanes: dt(e.baseLanes, t)
      };
    }
    function KR(e, t, r, i) {
      if (t !== null) {
        var o = t.memoizedState;
        if (o === null)
          return !1;
      }
      return Rv(e, Yf);
    }
    function _S(e, t) {
      return Hl(e.childLanes, t);
    }
    function DS(e, t, r) {
      var i = t.pendingProps;
      Jw(t) && (t.flags |= vt);
      var o = ha.current, s = !1, d = (t.flags & vt) !== Et;
      if (d || KR(o, e) ? (s = !0, t.flags &= ~vt) : (e === null || e.memoizedState !== null) && i.fallback !== void 0 && i.unstable_avoidThisFallback !== !0 && (o = RR(o, oy)), o = qf(o), mu(t, o), e === null) {
        i.fallback !== void 0 && cy(t);
        var v = i.children, E = i.fallback;
        if (s) {
          var R = OS(t, v, E, r), x = t.child;
          return x.memoizedState = Wv(r), t.memoizedState = $v, R;
        } else if (typeof i.unstable_expectedLoadTime == "number") {
          var U = OS(t, v, E, r), k = t.child;
          return k.memoizedState = Wv(r), t.memoizedState = $v, t.lanes = Ia, fh(Ia), U;
        } else
          return ZR(t, v, r);
      } else {
        var H = e.memoizedState;
        if (H !== null)
          if (s) {
            var Q = i.fallback, se = i.children, Me = LS(e, t, se, Q, r), Xe = t.child, je = e.child.memoizedState;
            return Xe.memoizedState = je === null ? Wv(r) : kS(je, r), Xe.childLanes = _S(e, r), t.memoizedState = $v, Me;
          } else {
            var ft = i.children, kt = MS(e, t, ft, r);
            return t.memoizedState = null, kt;
          }
        else if (s) {
          var j = i.fallback, V = i.children, N = LS(e, t, V, j, r), ae = t.child, pe = e.child.memoizedState;
          return ae.memoizedState = pe === null ? Wv(r) : kS(pe, r), ae.childLanes = _S(e, r), t.memoizedState = $v, N;
        } else {
          var be = i.children, ct = MS(e, t, be, r);
          return t.memoizedState = null, ct;
        }
      }
    }
    function ZR(e, t, r) {
      var i = e.mode, o = {
        mode: "visible",
        children: t
      }, s = Og(o, i, r, null);
      return s.return = e, e.child = s, s;
    }
    function OS(e, t, r, i) {
      var o = e.mode, s = e.child, d = {
        mode: "hidden",
        children: t
      }, v, E;
      return (o & ur) === Vt && s !== null ? (v = s, v.childLanes = W, v.pendingProps = d, e.mode & Sr && (v.actualDuration = 0, v.actualStartTime = -1, v.selfBaseDuration = 0, v.treeBaseDuration = 0), E = ku(r, o, i, null)) : (v = Og(d, o, W, null), E = ku(r, o, i, null)), v.return = e, E.return = e, v.sibling = E, e.child = v, E;
    }
    function NS(e, t) {
      return wu(e, t);
    }
    function MS(e, t, r, i) {
      var o = e.child, s = o.sibling, d = NS(o, {
        mode: "visible",
        children: r
      });
      return (t.mode & ur) === Vt && (d.lanes = i), d.return = t, d.sibling = null, s !== null && (s.nextEffect = null, s.flags = Dt, t.firstEffect = t.lastEffect = s), t.child = d, d;
    }
    function LS(e, t, r, i, o) {
      var s = t.mode, d = e.child, v = d.sibling, E = {
        mode: "hidden",
        children: r
      }, R;
      if (
        // In legacy mode, we commit the primary tree as if it successfully
        // completed, even though it's in an inconsistent state.
        (s & ur) === Vt && // Make sure we're on the second pass, i.e. the primary child fragment was
        // already cloned. In legacy mode, the only case where this isn't true is
        // when DevTools forces us to display a fallback; we skip the first render
        // pass entirely and go straight to rendering the fallback. (In Concurrent
        // Mode, SuspenseList can also trigger this scenario, but this is a legacy-
        // only codepath.)
        t.child !== d
      ) {
        var x = t.child;
        R = x, R.childLanes = W, R.pendingProps = E, t.mode & Sr && (R.actualDuration = 0, R.actualStartTime = -1, R.selfBaseDuration = d.selfBaseDuration, R.treeBaseDuration = d.treeBaseDuration);
        var U = R.lastEffect;
        U !== null ? (t.firstEffect = R.firstEffect, t.lastEffect = U, U.nextEffect = null) : t.firstEffect = t.lastEffect = null;
      } else
        R = NS(d, E);
      var k;
      return v !== null ? k = wu(v, i) : (k = ku(i, s, o, null), k.flags |= Ye), k.return = t, R.return = t, R.sibling = k, t.child = R, k;
    }
    function AS(e, t) {
      e.lanes = dt(e.lanes, t);
      var r = e.alternate;
      r !== null && (r.lanes = dt(r.lanes, t)), NE(e.return, t);
    }
    function JR(e, t, r) {
      for (var i = t; i !== null; ) {
        if (i.tag === z) {
          var o = i.memoizedState;
          o !== null && AS(i, r);
        } else if (i.tag === it)
          AS(i, r);
        else if (i.child !== null) {
          i.child.return = i, i = i.child;
          continue;
        }
        if (i === e)
          return;
        for (; i.sibling === null; ) {
          if (i.return === null || i.return === e)
            return;
          i = i.return;
        }
        i.sibling.return = i.return, i = i.sibling;
      }
    }
    function ex(e) {
      for (var t = e, r = null; t !== null; ) {
        var i = t.alternate;
        i !== null && xv(i) === null && (r = t), t = t.sibling;
      }
      return r;
    }
    function tx(e) {
      if (e !== void 0 && e !== "forwards" && e !== "backwards" && e !== "together" && !Py[e])
        if (Py[e] = !0, typeof e == "string")
          switch (e.toLowerCase()) {
            case "together":
            case "forwards":
            case "backwards": {
              y('"%s" is not a valid value for revealOrder on <SuspenseList />. Use lowercase "%s" instead.', e, e.toLowerCase());
              break;
            }
            case "forward":
            case "backward": {
              y('"%s" is not a valid value for revealOrder on <SuspenseList />. React uses the -s suffix in the spelling. Use "%ss" instead.', e, e.toLowerCase());
              break;
            }
            default:
              y('"%s" is not a supported revealOrder on <SuspenseList />. Did you mean "together", "forwards" or "backwards"?', e);
              break;
          }
        else
          y('%s is not a supported value for revealOrder on <SuspenseList />. Did you mean "together", "forwards" or "backwards"?', e);
    }
    function nx(e, t) {
      e !== void 0 && !Iv[e] && (e !== "collapsed" && e !== "hidden" ? (Iv[e] = !0, y('"%s" is not a supported value for tail on <SuspenseList />. Did you mean "collapsed" or "hidden"?', e)) : t !== "forwards" && t !== "backwards" && (Iv[e] = !0, y('<SuspenseList tail="%s" /> is only valid if revealOrder is "forwards" or "backwards". Did you mean to specify revealOrder="forwards"?', e)));
    }
    function US(e, t) {
      {
        var r = Array.isArray(e), i = !r && typeof pr(e) == "function";
        if (r || i) {
          var o = r ? "array" : "iterable";
          return y("A nested %s was passed to row #%s in <SuspenseList />. Wrap it in an additional SuspenseList to configure its revealOrder: <SuspenseList revealOrder=...> ... <SuspenseList revealOrder=...>{%s}</SuspenseList> ... </SuspenseList>", o, t, o), !1;
        }
      }
      return !0;
    }
    function rx(e, t) {
      if ((t === "forwards" || t === "backwards") && e !== void 0 && e !== null && e !== !1)
        if (Array.isArray(e)) {
          for (var r = 0; r < e.length; r++)
            if (!US(e[r], r))
              return;
        } else {
          var i = pr(e);
          if (typeof i == "function") {
            var o = i.call(e);
            if (o)
              for (var s = o.next(), d = 0; !s.done; s = o.next()) {
                if (!US(s.value, d))
                  return;
                d++;
              }
          } else
            y('A single row was passed to a <SuspenseList revealOrder="%s" />. This is not useful since it needs multiple rows. Did you mean to pass multiple children or an array?', t);
        }
    }
    function Wy(e, t, r, i, o, s) {
      var d = e.memoizedState;
      d === null ? e.memoizedState = {
        isBackwards: t,
        rendering: null,
        renderingStartTime: 0,
        last: i,
        tail: r,
        tailMode: o,
        lastEffect: s
      } : (d.isBackwards = t, d.rendering = null, d.renderingStartTime = 0, d.last = i, d.tail = r, d.tailMode = o, d.lastEffect = s);
    }
    function zS(e, t, r) {
      var i = t.pendingProps, o = i.revealOrder, s = i.tail, d = i.children;
      tx(o), nx(s, o), rx(d, o), cr(e, t, d, r);
      var v = ha.current, E = Rv(v, Yf);
      if (E)
        v = uy(v, Yf), t.flags |= vt;
      else {
        var R = e !== null && (e.flags & vt) !== Et;
        R && JR(t, t.child, r), v = qf(v);
      }
      if (mu(t, v), (t.mode & ur) === Vt)
        t.memoizedState = null;
      else
        switch (o) {
          case "forwards": {
            var x = ex(t.child), U;
            x === null ? (U = t.child, t.child = null) : (U = x.sibling, x.sibling = null), Wy(
              t,
              !1,
              // isBackwards
              U,
              x,
              s,
              t.lastEffect
            );
            break;
          }
          case "backwards": {
            var k = null, H = t.child;
            for (t.child = null; H !== null; ) {
              var Q = H.alternate;
              if (Q !== null && xv(Q) === null) {
                t.child = H;
                break;
              }
              var se = H.sibling;
              H.sibling = k, k = H, H = se;
            }
            Wy(
              t,
              !0,
              // isBackwards
              k,
              null,
              // last
              s,
              t.lastEffect
            );
            break;
          }
          case "together": {
            Wy(
              t,
              !1,
              // isBackwards
              null,
              // tail
              null,
              // last
              void 0,
              t.lastEffect
            );
            break;
          }
          default:
            t.memoizedState = null;
        }
      return t.child;
    }
    function ax(e, t, r) {
      ay(t, t.stateNode.containerInfo);
      var i = t.pendingProps;
      return e === null ? t.child = Cv(t, null, i, r) : cr(e, t, i, r), t.child;
    }
    var jS = !1;
    function ix(e, t, r) {
      var i = t.type, o = i._context, s = t.pendingProps, d = t.memoizedProps, v = s.value;
      {
        "value" in s || jS || (jS = !0, y("The `value` prop is required for the `<Context.Provider>`. Did you misspell it or forget to pass it?"));
        var E = t.type.propTypes;
        E && da(E, s, "prop", "Context.Provider");
      }
      if (OE(t, v), d !== null) {
        var R = d.value, x = dR(o, v, R);
        if (x === 0) {
          if (d.children === s.children && !ev())
            return Yi(e, t, r);
        } else
          pR(t, o, x, r);
      }
      var U = s.children;
      return cr(e, t, U, r), t.child;
    }
    var FS = !1;
    function lx(e, t, r) {
      var i = t.type;
      i._context === void 0 ? i !== i.Consumer && (FS || (FS = !0, y("Rendering <Context> directly is not supported and will be removed in a future major release. Did you mean to render <Context.Consumer> instead?"))) : i = i._context;
      var o = t.pendingProps, s = o.children;
      typeof s != "function" && y("A context consumer was rendered with multiple children, or a child that isn't a function. A context consumer expects a single child that is a function. If you did pass a function, make sure there is no trailing or leading whitespace around it."), Bs(t, r);
      var d = fn(i, o.unstable_observedBits), v;
      return nd.current = t, Vn(!0), v = s(d), Vn(!1), t.flags |= On, cr(e, t, v, r), t.child;
    }
    function Yy() {
      ai = !0;
    }
    function Yi(e, t, r) {
      return e !== null && (t.dependencies = e.dependencies), SS(), yg(t.lanes), yn(r, t.childLanes) ? (CR(e, t), t.child) : null;
    }
    function ox(e, t, r) {
      {
        var i = t.return;
        if (i === null)
          throw new Error("Cannot swap the root fiber.");
        if (e.alternate = null, t.alternate = null, r.index = t.index, r.sibling = t.sibling, r.return = t.return, r.ref = t.ref, t === i.child)
          i.child = r;
        else {
          var o = i.child;
          if (o === null)
            throw new Error("Expected parent to have a child.");
          for (; o.sibling !== t; )
            if (o = o.sibling, o === null)
              throw new Error("Expected to find the previous sibling.");
          o.sibling = r;
        }
        var s = i.lastEffect;
        return s !== null ? (s.nextEffect = e, i.lastEffect = e) : i.firstEffect = i.lastEffect = e, e.nextEffect = null, e.flags = Dt, r.flags |= Ye, r;
      }
    }
    function HS(e, t, r) {
      var i = t.lanes;
      if (t._debugNeedsRemount && e !== null)
        return ox(e, t, _g(t.type, t.key, t.pendingProps, t._debugOwner || null, t.mode, t.lanes));
      if (e !== null) {
        var o = e.memoizedProps, s = t.pendingProps;
        if (o !== s || ev() || // Force a re-render if the implementation changed due to hot reload:
        t.type !== e.type)
          ai = !0;
        else if (yn(r, i))
          (e.flags & Mo) !== Et ? ai = !0 : ai = !1;
        else {
          switch (ai = !1, t.tag) {
            case B:
              wS(t), fy();
              break;
            case re:
              GE(t);
              break;
            case L: {
              var d = t.type;
              ei(d) && nv(t);
              break;
            }
            case Y:
              ay(t, t.stateNode.containerInfo);
              break;
            case we: {
              var v = t.memoizedProps.value;
              OE(t, v);
              break;
            }
            case ie:
              {
                var E = yn(r, t.childLanes);
                E && (t.flags |= Ue);
                var R = t.stateNode;
                R.effectDuration = 0, R.passiveEffectDuration = 0;
              }
              break;
            case z: {
              var x = t.memoizedState;
              if (x !== null) {
                var U = t.child, k = U.childLanes;
                if (yn(r, k))
                  return DS(e, t, r);
                mu(t, qf(ha.current));
                var H = Yi(e, t, r);
                return H !== null ? H.sibling : null;
              } else
                mu(t, qf(ha.current));
              break;
            }
            case it: {
              var Q = (e.flags & vt) !== Et, se = yn(r, t.childLanes);
              if (Q) {
                if (se)
                  return zS(e, t, r);
                t.flags |= vt;
              }
              var Me = t.memoizedState;
              if (Me !== null && (Me.rendering = null, Me.tail = null, Me.lastEffect = null), mu(t, ha.current), se)
                break;
              return null;
            }
            case st:
            case Be:
              return t.lanes = W, By(e, t, r);
          }
          return Yi(e, t, r);
        }
      } else
        ai = !1;
      switch (t.lanes = W, t.tag) {
        case I:
          return XR(e, t, t.type, r);
        case We: {
          var Xe = t.elementType;
          return QR(e, t, Xe, i, r);
        }
        case A: {
          var je = t.type, ft = t.pendingProps, kt = t.elementType === je ? ft : va(je, ft);
          return Vy(e, t, je, kt, r);
        }
        case L: {
          var j = t.type, V = t.pendingProps, N = t.elementType === j ? V : va(j, V);
          return xS(e, t, j, N, r);
        }
        case B:
          return WR(e, t, r);
        case re:
          return YR(e, t, r);
        case ue:
          return qR(e, t);
        case z:
          return DS(e, t, r);
        case Y:
          return ax(e, t, r);
        case ee: {
          var ae = t.type, pe = t.pendingProps, be = t.elementType === ae ? pe : va(ae, pe);
          return CS(e, t, ae, be, r);
        }
        case Te:
          return VR(e, t, r);
        case ce:
          return IR(e, t, r);
        case ie:
          return $R(e, t, r);
        case we:
          return ix(e, t, r);
        case _e:
          return lx(e, t, r);
        case le: {
          var ct = t.type, Mt = t.pendingProps, It = va(ct, Mt);
          if (t.type !== t.elementType) {
            var St = ct.propTypes;
            St && da(
              St,
              It,
              // Resolved for outer only
              "prop",
              fe(ct)
            );
          }
          return It = va(ct.type, It), bS(e, t, ct, It, i, r);
        }
        case Se:
          return TS(e, t, t.type, t.pendingProps, i, r);
        case Ae: {
          var dn = t.type, ht = t.pendingProps, $t = t.elementType === dn ? ht : va(dn, ht);
          return GR(e, t, dn, $t, r);
        }
        case it:
          return zS(e, t, r);
        case ot:
          break;
        case rt:
          break;
        case ut:
          break;
        case st:
          return By(e, t, r);
        case Be:
          return BR(e, t, r);
      }
      throw Error("Unknown unit of work tag (" + t.tag + "). This error is likely caused by a bug in React. Please file an issue.");
    }
    function Gs(e) {
      e.flags |= Ue;
    }
    function PS(e) {
      e.flags |= hn;
    }
    var BS, qy, VS, IS;
    BS = function(e, t, r, i) {
      for (var o = t.child; o !== null; ) {
        if (o.tag === re || o.tag === ue)
          oT(e, o.stateNode);
        else if (o.tag !== Y) {
          if (o.child !== null) {
            o.child.return = o, o = o.child;
            continue;
          }
        }
        if (o === t)
          return;
        for (; o.sibling === null; ) {
          if (o.return === null || o.return === t)
            return;
          o = o.return;
        }
        o.sibling.return = o.return, o = o.sibling;
      }
    }, qy = function(e) {
    }, VS = function(e, t, r, i, o) {
      var s = e.memoizedProps;
      if (s !== i) {
        var d = t.stateNode, v = iy(), E = sT(d, r, s, i, o, v);
        t.updateQueue = E, E && Gs(t);
      }
    }, IS = function(e, t, r, i) {
      r !== i && Gs(t);
    };
    function ad(e, t) {
      if (!dy())
        switch (e.tailMode) {
          case "hidden": {
            for (var r = e.tail, i = null; r !== null; )
              r.alternate !== null && (i = r), r = r.sibling;
            i === null ? e.tail = null : i.sibling = null;
            break;
          }
          case "collapsed": {
            for (var o = e.tail, s = null; o !== null; )
              o.alternate !== null && (s = o), o = o.sibling;
            s === null ? !t && e.tail !== null ? e.tail.sibling = null : e.tail = null : s.sibling = null;
            break;
          }
        }
    }
    function $S(e, t, r) {
      var i = t.pendingProps;
      switch (t.tag) {
        case I:
        case We:
        case Se:
        case A:
        case ee:
        case Te:
        case ce:
        case ie:
        case _e:
        case le:
          return null;
        case L: {
          var o = t.type;
          return ei(o) && tv(t), null;
        }
        case B: {
          Vs(t), Om(t), vy();
          var s = t.stateNode;
          if (s.pendingContext && (s.context = s.pendingContext, s.pendingContext = null), e === null || e.child === null) {
            var d = wv(t);
            d ? Gs(t) : s.hydrate || (t.flags |= Nr);
          }
          return qy(t), null;
        }
        case re: {
          ly(t);
          var v = QE(), E = t.type;
          if (e !== null && t.stateNode != null)
            VS(e, t, E, i, v), e.ref !== t.ref && PS(t);
          else {
            if (!i) {
              if (t.stateNode === null)
                throw Error("We must have new props for new mounts. This error is likely caused by a bug in React. Please file an issue.");
              return null;
            }
            var R = iy(), x = wv(t);
            if (x)
              kR(t, v, R) && Gs(t);
            else {
              var U = lT(E, i, v, R, t);
              BS(U, t, !1, !1), t.stateNode = U, uT(U, E, i, v) && Gs(t);
            }
            t.ref !== null && PS(t);
          }
          return null;
        }
        case ue: {
          var k = i;
          if (e && t.stateNode != null) {
            var H = e.memoizedProps;
            IS(e, t, H, k);
          } else {
            if (typeof k != "string" && t.stateNode === null)
              throw Error("We must have new props for new mounts. This error is likely caused by a bug in React. Please file an issue.");
            var Q = QE(), se = iy(), Me = wv(t);
            Me ? _R(t) && Gs(t) : t.stateNode = cT(k, Q, se, t);
          }
          return null;
        }
        case z: {
          Is(t);
          var Xe = t.memoizedState;
          if ((t.flags & vt) !== Et)
            return t.lanes = r, (t.mode & Sr) !== Vt && Uy(t), t;
          var je = Xe !== null, ft = !1;
          if (e === null)
            t.memoizedProps.fallback !== void 0 && wv(t);
          else {
            var kt = e.memoizedState;
            ft = kt !== null;
          }
          if (je && !ft && (t.mode & ur) !== Vt) {
            var j = e === null && t.memoizedProps.unstable_avoidThisFallback !== !0;
            j || Rv(ha.current, oy) ? qx() : Qx();
          }
          return (je || ft) && (t.flags |= Ue), null;
        }
        case Y:
          return Vs(t), qy(t), e === null && qT(t.stateNode.containerInfo), null;
        case we:
          return Fm(t), null;
        case Ae: {
          var V = t.type;
          return ei(V) && tv(t), null;
        }
        case it: {
          Is(t);
          var N = t.memoizedState;
          if (N === null)
            return null;
          var ae = (t.flags & vt) !== Et, pe = N.rendering;
          if (pe === null)
            if (ae)
              ad(N, !1);
            else {
              var be = Xx() && (e === null || (e.flags & vt) === Et);
              if (!be)
                for (var ct = t.child; ct !== null; ) {
                  var Mt = xv(ct);
                  if (Mt !== null) {
                    ae = !0, t.flags |= vt, ad(N, !1);
                    var It = Mt.updateQueue;
                    return It !== null && (t.updateQueue = It, t.flags |= Ue), N.lastEffect === null && (t.firstEffect = null), t.lastEffect = N.lastEffect, bR(t, r), mu(t, uy(ha.current, Yf)), t.child;
                  }
                  ct = ct.sibling;
                }
              N.tail !== null && Hn() > lC() && (t.flags |= vt, ae = !0, ad(N, !1), t.lanes = Ia, fh(Ia));
            }
          else {
            if (!ae) {
              var St = xv(pe);
              if (St !== null) {
                t.flags |= vt, ae = !0;
                var dn = St.updateQueue;
                if (dn !== null && (t.updateQueue = dn, t.flags |= Ue), ad(N, !0), N.tail === null && N.tailMode === "hidden" && !pe.alternate && !dy()) {
                  var ht = t.lastEffect = N.lastEffect;
                  return ht !== null && (ht.nextEffect = null), null;
                }
              } else // The time it took to render last row is greater than the remaining
              // time we have to render. So rendering one more row would likely
              // exceed it.
              Hn() * 2 - N.renderingStartTime > lC() && r !== yr && (t.flags |= vt, ae = !0, ad(N, !1), t.lanes = Ia, fh(Ia));
            }
            if (N.isBackwards)
              pe.sibling = t.child, t.child = pe;
            else {
              var $t = N.last;
              $t !== null ? $t.sibling = pe : t.child = pe, N.last = pe;
            }
          }
          if (N.tail !== null) {
            var Tn = N.tail;
            N.rendering = Tn, N.tail = Tn.sibling, N.lastEffect = t.lastEffect, N.renderingStartTime = Hn(), Tn.sibling = null;
            var en = ha.current;
            return ae ? en = uy(en, Yf) : en = qf(en), mu(t, en), Tn;
          }
          return null;
        }
        case ot:
          break;
        case rt:
          break;
        case ut:
          break;
        case st:
        case Be: {
          if (mg(t), e !== null) {
            var ui = t.memoizedState, tn = e.memoizedState, si = tn !== null, _u = ui !== null;
            si !== _u && i.mode !== "unstable-defer-without-hiding" && (t.flags |= Ue);
          }
          return null;
        }
      }
      throw Error("Unknown unit of work tag (" + t.tag + "). This error is likely caused by a bug in React. Please file an issue.");
    }
    function ux(e, t) {
      switch (e.tag) {
        case L: {
          var r = e.type;
          ei(r) && tv(e);
          var i = e.flags;
          return i & hr ? (e.flags = i & ~hr | vt, (e.mode & Sr) !== Vt && Uy(e), e) : null;
        }
        case B: {
          Vs(e), Om(e), vy();
          var o = e.flags;
          if ((o & vt) !== Et)
            throw Error("The root failed to unmount after an error. This is likely a bug in React. Please file an issue.");
          return e.flags = o & ~hr | vt, e;
        }
        case re:
          return ly(e), null;
        case z: {
          Is(e);
          var s = e.flags;
          return s & hr ? (e.flags = s & ~hr | vt, (e.mode & Sr) !== Vt && Uy(e), e) : null;
        }
        case it:
          return Is(e), null;
        case Y:
          return Vs(e), null;
        case we:
          return Fm(e), null;
        case st:
        case Be:
          return mg(e), null;
        default:
          return null;
      }
    }
    function WS(e) {
      switch (e.tag) {
        case L: {
          var t = e.type.childContextTypes;
          t != null && tv(e);
          break;
        }
        case B: {
          Vs(e), Om(e), vy();
          break;
        }
        case re: {
          ly(e);
          break;
        }
        case Y:
          Vs(e);
          break;
        case z:
          Is(e);
          break;
        case it:
          Is(e);
          break;
        case we:
          Fm(e);
          break;
        case st:
        case Be:
          mg(e);
          break;
      }
    }
    function Qy(e, t) {
      return {
        value: e,
        source: t,
        stack: Kr(t)
      };
    }
    function sx(e, t) {
      return !0;
    }
    function Gy(e, t) {
      try {
        var r = sx(e, t);
        if (r === !1)
          return;
        var i = t.value, o = t.source, s = t.stack, d = s !== null ? s : "";
        if (i != null && i._suppressLogging) {
          if (e.tag === L)
            return;
          console.error(i);
        }
        var v = o ? fe(o.type) : null, E = v ? "The above error occurred in the <" + v + "> component:" : "The above error occurred in one of your React components:", R, x = fe(e.type);
        x ? R = "React will try to recreate this component tree from scratch " + ("using the error boundary you provided, " + x + ".") : R = `Consider adding an error boundary to your tree to customize error handling behavior.
Visit https://reactjs.org/link/error-boundaries to learn more about error boundaries.`;
        var U = E + `
` + d + `

` + ("" + R);
        console.error(U);
      } catch (k) {
        setTimeout(function() {
          throw k;
        });
      }
    }
    var cx = typeof WeakMap == "function" ? WeakMap : Map;
    function YS(e, t, r) {
      var i = Gl(Nt, r);
      i.tag = Hm, i.payload = {
        element: null
      };
      var o = t.value;
      return i.callback = function() {
        cw(o), Gy(e, t);
      }, i;
    }
    function qS(e, t, r) {
      var i = Gl(Nt, r);
      i.tag = Hm;
      var o = e.type.getDerivedStateFromError;
      if (typeof o == "function") {
        var s = t.value;
        i.payload = function() {
          return Gy(e, t), o(s);
        };
      }
      var d = e.stateNode;
      return d !== null && typeof d.componentDidCatch == "function" ? i.callback = function() {
        kC(e), typeof o != "function" && (uw(this), Gy(e, t));
        var E = t.value, R = t.stack;
        this.componentDidCatch(E, {
          componentStack: R !== null ? R : ""
        }), typeof o != "function" && (yn(e.lanes, at) || y("%s: Error boundaries should implement getDerivedStateFromError(). In that method, return a state update to display an error message or fallback UI.", fe(e.type) || "Unknown"));
      } : i.callback = function() {
        kC(e);
      }, i;
    }
    function fx(e, t, r) {
      var i = e.pingCache, o;
      if (i === null ? (i = e.pingCache = new cx(), o = /* @__PURE__ */ new Set(), i.set(t, o)) : (o = i.get(t), o === void 0 && (o = /* @__PURE__ */ new Set(), i.set(t, o))), !o.has(r)) {
        o.add(r);
        var s = fw.bind(null, e, t, r);
        t.then(s, s);
      }
    }
    function dx(e, t, r, i, o) {
      if (r.flags |= No, r.firstEffect = r.lastEffect = null, i !== null && typeof i == "object" && typeof i.then == "function") {
        var s = i;
        if ((r.mode & ur) === Vt) {
          var d = r.alternate;
          d ? (r.updateQueue = d.updateQueue, r.memoizedState = d.memoizedState, r.lanes = d.lanes) : (r.updateQueue = null, r.memoizedState = null);
        }
        var v = Rv(ha.current, oy), E = t;
        do {
          if (E.tag === z && xR(E, v)) {
            var R = E.updateQueue;
            if (R === null) {
              var x = /* @__PURE__ */ new Set();
              x.add(s), E.updateQueue = x;
            } else
              R.add(s);
            if ((E.mode & ur) === Vt) {
              if (E.flags |= vt, r.flags |= Mo, r.flags &= ~(zc | No), r.tag === L) {
                var U = r.alternate;
                if (U === null)
                  r.tag = Ae;
                else {
                  var k = Gl(Nt, at);
                  k.tag = dv, Xl(r, k);
                }
              }
              r.lanes = dt(r.lanes, at);
              return;
            }
            fx(e, s, o), E.flags |= hr, E.lanes = o;
            return;
          }
          E = E.return;
        } while (E !== null);
        i = new Error((fe(r.type) || "A React component") + ` suspended while rendering, but no fallback UI was specified.

Add a <Suspense fallback=...> component higher in the tree to provide a loading indicator or placeholder to display.`);
      }
      Gx(), i = Qy(i, r);
      var H = t;
      do {
        switch (H.tag) {
          case B: {
            var Q = i;
            H.flags |= hr;
            var se = sn(o);
            H.lanes = dt(H.lanes, se);
            var Me = YS(H, Q, se);
            UE(H, Me);
            return;
          }
          case L:
            var Xe = i, je = H.type, ft = H.stateNode;
            if ((H.flags & vt) === Et && (typeof je.getDerivedStateFromError == "function" || ft !== null && typeof ft.componentDidCatch == "function" && !gg(ft))) {
              H.flags |= hr;
              var kt = sn(o);
              H.lanes = dt(H.lanes, kt);
              var j = qS(H, Xe, kt);
              UE(H, j);
              return;
            }
            break;
        }
        H = H.return;
      } while (H !== null);
    }
    var QS = null;
    QS = /* @__PURE__ */ new Set();
    var px = typeof WeakSet == "function" ? WeakSet : Set, vx = function(e, t) {
      t.props = e.memoizedProps, t.state = e.memoizedState, t.componentWillUnmount();
    };
    function hx(e, t) {
      if (_n(null, vx, null, e, t), In()) {
        var r = Dn();
        to(e, r);
      }
    }
    function GS(e) {
      var t = e.ref;
      if (t !== null)
        if (typeof t == "function") {
          if (_n(null, t, null, null), In()) {
            var r = Dn();
            to(e, r);
          }
        } else
          t.current = null;
    }
    function mx(e, t) {
      if (_n(null, t, null), In()) {
        var r = Dn();
        to(e, r);
      }
    }
    function yx(e, t) {
      switch (t.tag) {
        case A:
        case ee:
        case Se:
        case ut:
          return;
        case L: {
          if (t.flags & Nr && e !== null) {
            var r = e.memoizedProps, i = e.memoizedState, o = t.stateNode;
            t.type === t.elementType && !Cu && (o.props !== t.memoizedProps && y("Expected %s props to match memoized props before getSnapshotBeforeUpdate. This might either be because of a bug in React, or because a component reassigns its own `this.props`. Please file an issue.", fe(t.type) || "instance"), o.state !== t.memoizedState && y("Expected %s state to match memoized state before getSnapshotBeforeUpdate. This might either be because of a bug in React, or because a component reassigns its own `this.state`. Please file an issue.", fe(t.type) || "instance"));
            var s = o.getSnapshotBeforeUpdate(t.elementType === t.type ? r : va(t.type, r), i);
            {
              var d = QS;
              s === void 0 && !d.has(t.type) && (d.add(t.type), y("%s.getSnapshotBeforeUpdate(): A snapshot value (or null) must be returned. You have returned undefined.", fe(t.type)));
            }
            o.__reactInternalSnapshotBeforeUpdate = s;
          }
          return;
        }
        case B: {
          if (t.flags & Nr) {
            var v = t.stateNode;
            xm(v.containerInfo);
          }
          return;
        }
        case re:
        case ue:
        case Y:
        case Ae:
          return;
      }
      throw Error("This unit of work tag should not have side-effects. This error is likely caused by a bug in React. Please file an issue.");
    }
    function gx(e, t) {
      var r = t.updateQueue, i = r !== null ? r.lastEffect : null;
      if (i !== null) {
        var o = i.next, s = o;
        do {
          if ((s.tag & e) === e) {
            var d = s.destroy;
            s.destroy = void 0, d !== void 0 && d();
          }
          s = s.next;
        } while (s !== o);
      }
    }
    function Ex(e, t) {
      var r = t.updateQueue, i = r !== null ? r.lastEffect : null;
      if (i !== null) {
        var o = i.next, s = o;
        do {
          if ((s.tag & e) === e) {
            var d = s.create;
            s.destroy = d();
            {
              var v = s.destroy;
              if (v !== void 0 && typeof v != "function") {
                var E = void 0;
                v === null ? E = " You returned null. If your effect does not require clean up, return undefined (or nothing)." : typeof v.then == "function" ? E = `

It looks like you wrote useEffect(async () => ...) or returned a Promise. Instead, write the async function inside your effect and call it immediately:

useEffect(() => {
  async function fetchData() {
    // You can await here
    const response = await MyAPI.getData(someId);
    // ...
  }
  fetchData();
}, [someId]); // Or [] if effect doesn't need props or state

Learn more about data fetching with Hooks: https://reactjs.org/link/hooks-data-fetching` : E = " You returned: " + v, y("An effect function must not return anything besides a function, which is used for clean-up.%s", E);
              }
            }
          }
          s = s.next;
        } while (s !== o);
      }
    }
    function Sx(e) {
      var t = e.updateQueue, r = t !== null ? t.lastEffect : null;
      if (r !== null) {
        var i = r.next, o = i;
        do {
          var s = o, d = s.next, v = s.tag;
          (v & Qf) !== sy && (v & $s) !== sy && (hC(e, o), iw(e, o)), o = d;
        } while (o !== i);
      }
    }
    function Cx(e, t, r, i) {
      switch (r.tag) {
        case A:
        case ee:
        case Se:
        case ut: {
          Ex(Ws | $s, r), Sx(r);
          return;
        }
        case L: {
          var o = r.stateNode;
          if (r.flags & Ue)
            if (t === null)
              r.type === r.elementType && !Cu && (o.props !== r.memoizedProps && y("Expected %s props to match memoized props before componentDidMount. This might either be because of a bug in React, or because a component reassigns its own `this.props`. Please file an issue.", fe(r.type) || "instance"), o.state !== r.memoizedState && y("Expected %s state to match memoized state before componentDidMount. This might either be because of a bug in React, or because a component reassigns its own `this.state`. Please file an issue.", fe(r.type) || "instance")), o.componentDidMount();
            else {
              var s = r.elementType === r.type ? t.memoizedProps : va(r.type, t.memoizedProps), d = t.memoizedState;
              r.type === r.elementType && !Cu && (o.props !== r.memoizedProps && y("Expected %s props to match memoized props before componentDidUpdate. This might either be because of a bug in React, or because a component reassigns its own `this.props`. Please file an issue.", fe(r.type) || "instance"), o.state !== r.memoizedState && y("Expected %s state to match memoized state before componentDidUpdate. This might either be because of a bug in React, or because a component reassigns its own `this.state`. Please file an issue.", fe(r.type) || "instance")), o.componentDidUpdate(s, d, o.__reactInternalSnapshotBeforeUpdate);
            }
          var v = r.updateQueue;
          v !== null && (r.type === r.elementType && !Cu && (o.props !== r.memoizedProps && y("Expected %s props to match memoized props before processing the update queue. This might either be because of a bug in React, or because a component reassigns its own `this.props`. Please file an issue.", fe(r.type) || "instance"), o.state !== r.memoizedState && y("Expected %s state to match memoized state before processing the update queue. This might either be because of a bug in React, or because a component reassigns its own `this.state`. Please file an issue.", fe(r.type) || "instance")), jE(r, v, o));
          return;
        }
        case B: {
          var E = r.updateQueue;
          if (E !== null) {
            var R = null;
            if (r.child !== null)
              switch (r.child.tag) {
                case re:
                  R = r.child.stateNode;
                  break;
                case L:
                  R = r.child.stateNode;
                  break;
              }
            jE(r, E, R);
          }
          return;
        }
        case re: {
          var x = r.stateNode;
          if (t === null && r.flags & Ue) {
            var U = r.type, k = r.memoizedProps;
            dT(x, U, k);
          }
          return;
        }
        case ue:
          return;
        case Y:
          return;
        case ie: {
          {
            var H = r.memoizedProps;
            H.onCommit;
            var Q = H.onRender;
            r.stateNode.effectDuration;
            var se = HR();
            typeof Q == "function" && Q(r.memoizedProps.id, t === null ? "mount" : "update", r.actualDuration, r.treeBaseDuration, r.actualStartTime, se, e.memoizedInteractions);
          }
          return;
        }
        case z: {
          Dx(e, r);
          return;
        }
        case it:
        case Ae:
        case ot:
        case rt:
        case st:
        case Be:
          return;
      }
      throw Error("This unit of work tag should not have side-effects. This error is likely caused by a bug in React. Please file an issue.");
    }
    function XS(e, t) {
      for (var r = e; ; ) {
        if (r.tag === re) {
          var i = r.stateNode;
          t ? CT(i) : TT(r.stateNode, r.memoizedProps);
        } else if (r.tag === ue) {
          var o = r.stateNode;
          t ? bT(o) : RT(o, r.memoizedProps);
        } else if (!((r.tag === st || r.tag === Be) && r.memoizedState !== null && r !== e)) {
          if (r.child !== null) {
            r.child.return = r, r = r.child;
            continue;
          }
        }
        if (r === e)
          return;
        for (; r.sibling === null; ) {
          if (r.return === null || r.return === e)
            return;
          r = r.return;
        }
        r.sibling.return = r.return, r = r.sibling;
      }
    }
    function bx(e) {
      var t = e.ref;
      if (t !== null) {
        var r = e.stateNode, i;
        switch (e.tag) {
          case re:
            i = r;
            break;
          default:
            i = r;
        }
        typeof t == "function" ? t(i) : (t.hasOwnProperty("current") || y("Unexpected ref object provided for %s. Use either a ref-setter function or React.createRef().", fe(e.type)), t.current = i);
      }
    }
    function Tx(e) {
      var t = e.ref;
      t !== null && (typeof t == "function" ? t(null) : t.current = null);
    }
    function KS(e, t, r) {
      switch (eR(t), t.tag) {
        case A:
        case ee:
        case le:
        case Se:
        case ut: {
          var i = t.updateQueue;
          if (i !== null) {
            var o = i.lastEffect;
            if (o !== null) {
              var s = o.next, d = s;
              do {
                var v = d, E = v.destroy, R = v.tag;
                E !== void 0 && ((R & Qf) !== sy ? hC(t, d) : mx(t, E)), d = d.next;
              } while (d !== s);
            }
          }
          return;
        }
        case L: {
          GS(t);
          var x = t.stateNode;
          typeof x.componentWillUnmount == "function" && hx(t, x);
          return;
        }
        case re: {
          GS(t);
          return;
        }
        case Y: {
          tC(e, t);
          return;
        }
        case ot:
          return;
        case lt:
          return;
        case rt:
          return;
      }
    }
    function Rx(e, t, r) {
      for (var i = t; ; ) {
        if (KS(e, i), i.child !== null && // If we use mutation we drill down into portals using commitUnmount above.
        // If we don't use mutation we drill down into portals here instead.
        i.tag !== Y) {
          i.child.return = i, i = i.child;
          continue;
        }
        if (i === t)
          return;
        for (; i.sibling === null; ) {
          if (i.return === null || i.return === t)
            return;
          i = i.return;
        }
        i.sibling.return = i.return, i = i.sibling;
      }
    }
    function ZS(e) {
      e.alternate = null, e.child = null, e.dependencies = null, e.firstEffect = null, e.lastEffect = null, e.memoizedProps = null, e.memoizedState = null, e.pendingProps = null, e.return = null, e.updateQueue = null, e._debugOwner = null;
    }
    function xx(e) {
      for (var t = e.return; t !== null; ) {
        if (JS(t))
          return t;
        t = t.return;
      }
      throw Error("Expected to find a host parent. This error is likely caused by a bug in React. Please file an issue.");
    }
    function JS(e) {
      return e.tag === re || e.tag === B || e.tag === Y;
    }
    function wx(e) {
      var t = e;
      e: for (; ; ) {
        for (; t.sibling === null; ) {
          if (t.return === null || JS(t.return))
            return null;
          t = t.return;
        }
        for (t.sibling.return = t.return, t = t.sibling; t.tag !== re && t.tag !== ue && t.tag !== lt; ) {
          if (t.flags & Ye || t.child === null || t.tag === Y)
            continue e;
          t.child.return = t, t = t.child;
        }
        if (!(t.flags & Ye))
          return t.stateNode;
      }
    }
    function eC(e) {
      var t = xx(e), r, i, o = t.stateNode;
      switch (t.tag) {
        case re:
          r = o, i = !1;
          break;
        case B:
          r = o.containerInfo, i = !0;
          break;
        case Y:
          r = o.containerInfo, i = !0;
          break;
        case ot:
        default:
          throw Error("Invalid host parent fiber. This error is likely caused by a bug in React. Please file an issue.");
      }
      t.flags & vn && (K0(r), t.flags &= ~vn);
      var s = wx(e);
      i ? Xy(e, s, r) : Ky(e, s, r);
    }
    function Xy(e, t, r) {
      var i = e.tag, o = i === re || i === ue;
      if (o || Ke) {
        var s = o ? e.stateNode : e.stateNode.instance;
        t ? gT(r, s, t) : mT(r, s);
      } else if (i !== Y) {
        var d = e.child;
        if (d !== null) {
          Xy(d, t, r);
          for (var v = d.sibling; v !== null; )
            Xy(v, t, r), v = v.sibling;
        }
      }
    }
    function Ky(e, t, r) {
      var i = e.tag, o = i === re || i === ue;
      if (o || Ke) {
        var s = o ? e.stateNode : e.stateNode.instance;
        t ? yT(r, s, t) : hT(r, s);
      } else if (i !== Y) {
        var d = e.child;
        if (d !== null) {
          Ky(d, t, r);
          for (var v = d.sibling; v !== null; )
            Ky(v, t, r), v = v.sibling;
        }
      }
    }
    function tC(e, t, r) {
      for (var i = t, o = !1, s, d; ; ) {
        if (!o) {
          var v = i.return;
          e: for (; ; ) {
            if (v === null)
              throw Error("Expected to find a host parent. This error is likely caused by a bug in React. Please file an issue.");
            var E = v.stateNode;
            switch (v.tag) {
              case re:
                s = E, d = !1;
                break e;
              case B:
                s = E.containerInfo, d = !0;
                break e;
              case Y:
                s = E.containerInfo, d = !0;
                break e;
            }
            v = v.return;
          }
          o = !0;
        }
        if (i.tag === re || i.tag === ue)
          Rx(e, i), d ? ST(s, i.stateNode) : ET(s, i.stateNode);
        else if (i.tag === Y) {
          if (i.child !== null) {
            s = i.stateNode.containerInfo, d = !0, i.child.return = i, i = i.child;
            continue;
          }
        } else if (KS(e, i), i.child !== null) {
          i.child.return = i, i = i.child;
          continue;
        }
        if (i === t)
          return;
        for (; i.sibling === null; ) {
          if (i.return === null || i.return === t)
            return;
          i = i.return, i.tag === Y && (o = !1);
        }
        i.sibling.return = i.return, i = i.sibling;
      }
    }
    function kx(e, t, r) {
      tC(e, t);
      var i = t.alternate;
      ZS(t), i !== null && ZS(i);
    }
    function Zy(e, t) {
      switch (t.tag) {
        case A:
        case ee:
        case le:
        case Se:
        case ut: {
          gx(Ws | $s, t);
          return;
        }
        case L:
          return;
        case re: {
          var r = t.stateNode;
          if (r != null) {
            var i = t.memoizedProps, o = e !== null ? e.memoizedProps : i, s = t.type, d = t.updateQueue;
            t.updateQueue = null, d !== null && pT(r, d, s, o, i);
          }
          return;
        }
        case ue: {
          if (t.stateNode === null)
            throw Error("This should have a text node initialized. This error is likely caused by a bug in React. Please file an issue.");
          var v = t.stateNode, E = t.memoizedProps, R = e !== null ? e.memoizedProps : E;
          vT(v, R, E);
          return;
        }
        case B: {
          {
            var x = t.stateNode;
            x.hydrate && (x.hydrate = !1, MT(x.containerInfo));
          }
          return;
        }
        case ie:
          return;
        case z: {
          _x(t), nC(t);
          return;
        }
        case it: {
          nC(t);
          return;
        }
        case Ae:
          return;
        case ot:
          break;
        case rt:
          break;
        case st:
        case Be: {
          var U = t.memoizedState, k = U !== null;
          XS(t, k);
          return;
        }
      }
      throw Error("This unit of work tag should not have side-effects. This error is likely caused by a bug in React. Please file an issue.");
    }
    function _x(e) {
      var t = e.memoizedState;
      if (t !== null) {
        Yx();
        {
          var r = e.child;
          XS(r, !0);
        }
      }
    }
    function Dx(e, t) {
      var r = t.memoizedState;
      if (r === null) {
        var i = t.alternate;
        if (i !== null) {
          var o = i.memoizedState;
          if (o !== null) {
            var s = o.dehydrated;
            s !== null && LT(s);
          }
        }
      }
    }
    function nC(e) {
      var t = e.updateQueue;
      if (t !== null) {
        e.updateQueue = null;
        var r = e.stateNode;
        r === null && (r = e.stateNode = new px()), t.forEach(function(i) {
          var o = pw.bind(null, e, i);
          r.has(i) || (i.__reactDoNotTraceInteractions !== !0 && (o = h.unstable_wrap(o)), r.add(i), i.then(o, o));
        });
      }
    }
    function Ox(e, t) {
      if (e !== null) {
        var r = e.memoizedState;
        if (r === null || r.dehydrated !== null) {
          var i = t.memoizedState;
          return i !== null && i.dehydrated === null;
        }
      }
      return !1;
    }
    function Nx(e) {
      K0(e.stateNode);
    }
    if (typeof Symbol == "function" && Symbol.for) {
      var id = Symbol.for;
      id("selector.component"), id("selector.has_pseudo_class"), id("selector.role"), id("selector.test_id"), id("selector.text");
    }
    var Mx = [];
    function Lx() {
      Mx.forEach(function(e) {
        return e();
      });
    }
    var Ax = Math.ceil, Jy = b.ReactCurrentDispatcher, eg = b.ReactCurrentOwner, tg = b.IsSomeRendererActing, Xt = (
      /*             */
      0
    ), Yv = (
      /*               */
      1
    ), Ux = (
      /*                 */
      2
    ), ng = (
      /*         */
      4
    ), rg = (
      /*       */
      8
    ), Cr = (
      /*                */
      16
    ), ii = (
      /*                */
      32
    ), rC = (
      /*       */
      64
    ), qi = 0, qv = 1, Qv = 2, Gv = 3, Xv = 4, ag = 5, ze = Xt, Yn = null, Kt = null, qn = W, li = W, ig = ql(W), Ln = qi, Kv = null, bu = W, Zv = W, Tu = W, Jv = W, lg = null, og = 0, aC = 500, iC = 1 / 0, zx = 500;
    function Xs() {
      iC = Hn() + zx;
    }
    function lC() {
      return iC;
    }
    var Ce = null, eh = !1, ug = null, Ks = null, Qi = !1, Zs = null, ld = Am, sg = W, cg = [], fg = [], Gi = null, jx = 50, od = 0, dg = null, Fx = 50, th = 0, Ru = null, ud = Nt, Xi = W, nh = W, pg = !1, sd = null, rh = !1;
    function Hx() {
      return Yn;
    }
    function br() {
      return (ze & (Cr | ii)) !== Xt ? Hn() : (ud !== Nt || (ud = Hn()), ud);
    }
    function eo(e) {
      var t = e.mode;
      if ((t & ur) === Vt)
        return at;
      if ((t & pu) === Vt)
        return Hs() === Vr ? at : oa;
      Xi === W && (Xi = bu);
      var r = cR() !== sR;
      if (r)
        return nh !== W && (nh = lg !== null ? lg.pendingLanes : W), pp(Xi, nh);
      var i = Hs(), o;
      if (
        // TODO: Temporary. We're removing the concept of discrete updates.
        (ze & ng) !== Xt && i === fu
      )
        o = Fl(Nl, Xi);
      else {
        var s = tf(i);
        o = Fl(s, Xi);
      }
      return o;
    }
    function Px(e) {
      var t = e.mode;
      return (t & ur) === Vt ? at : (t & pu) === Vt ? Hs() === Vr ? at : oa : (Xi === W && (Xi = bu), af(Xi));
    }
    function Bn(e, t, r) {
      hw(), Ew(e);
      var i = ah(e, t);
      if (i === null)
        return yw(e), null;
      Pl(i, t, r), i === Yn && (Tu = dt(Tu, t), Ln === Xv && Js(i, qn));
      var o = Hs();
      t === at ? /* Check if we're inside unbatchedUpdates */ (ze & rg) !== Xt && // Check if we're not already rendering
      (ze & (Cr | ii)) === Xt ? (no(i, t), vg(i)) : (Yr(i, r), no(i, t), ze === Xt && (Xs(), ni())) : ((ze & ng) !== Xt && // Only updates at user-blocking priority or greater are considered
      // discrete, even inside a discrete event.
      (o === fu || o === Vr) && (Gi === null ? Gi = /* @__PURE__ */ new Set([i]) : Gi.add(i)), Yr(i, r), no(i, t)), lg = i;
    }
    function ah(e, t) {
      e.lanes = dt(e.lanes, t);
      var r = e.alternate;
      r !== null && (r.lanes = dt(r.lanes, t)), r === null && (e.flags & (Ye | nr)) !== Et && yC(e);
      for (var i = e, o = e.return; o !== null; )
        o.childLanes = dt(o.childLanes, t), r = o.alternate, r !== null ? r.childLanes = dt(r.childLanes, t) : (o.flags & (Ye | nr)) !== Et && yC(e), i = o, o = o.return;
      if (i.tag === B) {
        var s = i.stateNode;
        return s;
      } else
        return null;
    }
    function Yr(e, t) {
      var r = e.callbackNode;
      em(e, t);
      var i = qo(e, e === Yn ? qn : W), o = zn();
      if (i === W) {
        r !== null && (RE(r), e.callbackNode = null, e.callbackPriority = la);
        return;
      }
      if (r !== null) {
        var s = e.callbackPriority;
        if (s === o)
          return;
        RE(r);
      }
      var d;
      if (o === Pa)
        d = lR(vg.bind(null, e));
      else if (o === Vo)
        d = Ql(Vr, vg.bind(null, e));
      else {
        var v = ms(o);
        d = Ql(v, oC.bind(null, e));
      }
      e.callbackPriority = o, e.callbackNode = d;
    }
    function oC(e) {
      if (ud = Nt, Xi = W, nh = W, (ze & (Cr | ii)) !== Xt)
        throw Error("Should not already be working.");
      var t = e.callbackNode, r = oi();
      if (r && e.callbackNode !== t)
        return null;
      var i = qo(e, e === Yn ? qn : W);
      if (i === W)
        return null;
      var o = Zx(e, i);
      if (yn(bu, Tu))
        ec(e, W);
      else if (o !== qi) {
        if (o === Qv && (ze |= rC, e.hydrate && (e.hydrate = !1, xm(e.containerInfo)), i = ar(e), i !== W && (o = cd(e, i))), o === qv) {
          var s = Kv;
          throw ec(e, W), Js(e, i), Yr(e, Hn()), s;
        }
        var d = e.current.alternate;
        e.finishedWork = d, e.finishedLanes = i, Bx(e, o, i);
      }
      return Yr(e, Hn()), e.callbackNode === t ? oC.bind(null, e) : null;
    }
    function Bx(e, t, r) {
      switch (t) {
        case qi:
        case qv:
          throw Error("Root did not complete. This is a bug in React.");
        case Qv: {
          xu(e);
          break;
        }
        case Gv: {
          if (Js(e, r), rf(r) && // do not delay if we're inside an act() scope
          !Tw()) {
            var i = og + aC - Hn();
            if (i > 10) {
              var o = qo(e, W);
              if (o !== W)
                break;
              var s = e.suspendedLanes;
              if (!Wa(s, r)) {
                br(), of(e, s);
                break;
              }
              e.timeoutHandle = X0(xu.bind(null, e), i);
              break;
            }
          }
          xu(e);
          break;
        }
        case Xv: {
          if (Js(e, r), dp(r))
            break;
          {
            var d = Zh(e, r), v = d, E = Hn() - v, R = vw(E) - E;
            if (R > 10) {
              e.timeoutHandle = X0(xu.bind(null, e), R);
              break;
            }
          }
          xu(e);
          break;
        }
        case ag: {
          xu(e);
          break;
        }
        default:
          throw Error("Unknown root exit status.");
      }
    }
    function Js(e, t) {
      t = Hl(t, Jv), t = Hl(t, Tu), yp(e, t);
    }
    function vg(e) {
      if ((ze & (Cr | ii)) !== Xt)
        throw Error("Should not already be working.");
      oi();
      var t, r;
      if (e === Yn && yn(e.expiredLanes, qn) ? (t = qn, r = cd(e, t), yn(bu, Tu) && (t = qo(e, t), r = cd(e, t))) : (t = qo(e, W), r = cd(e, t)), e.tag !== Nm && r === Qv && (ze |= rC, e.hydrate && (e.hydrate = !1, xm(e.containerInfo)), t = ar(e), t !== W && (r = cd(e, t))), r === qv) {
        var i = Kv;
        throw ec(e, W), Js(e, t), Yr(e, Hn()), i;
      }
      var o = e.current.alternate;
      return e.finishedWork = o, e.finishedLanes = t, xu(e), Yr(e, Hn()), null;
    }
    function Vx() {
      if ((ze & (Yv | Cr | ii)) !== Xt) {
        (ze & Cr) !== Xt && y("unstable_flushDiscreteUpdates: Cannot flush updates when React is already rendering.");
        return;
      }
      Ix(), oi();
    }
    function Ix() {
      if (Gi !== null) {
        var e = Gi;
        Gi = null, e.forEach(function(t) {
          Qo(t), Yr(t, Hn());
        });
      }
      ni();
    }
    function uC(e, t) {
      var r = ze;
      ze |= Yv;
      try {
        return e(t);
      } finally {
        ze = r, ze === Xt && (Xs(), ni());
      }
    }
    function $x(e, t) {
      var r = ze;
      ze |= Ux;
      try {
        return e(t);
      } finally {
        ze = r, ze === Xt && (Xs(), ni());
      }
    }
    function Wx(e, t, r, i, o) {
      var s = ze;
      ze |= ng;
      try {
        return du(fu, e.bind(null, t, r, i, o));
      } finally {
        ze = s, ze === Xt && (Xs(), ni());
      }
    }
    function sC(e, t) {
      var r = ze;
      ze &= ~Yv, ze |= rg;
      try {
        return e(t);
      } finally {
        ze = r, ze === Xt && (Xs(), ni());
      }
    }
    function hg(e, t) {
      var r = ze;
      if ((r & (Cr | ii)) !== Xt)
        return y("flushSync was called from inside a lifecycle method. React cannot flush when React is already rendering. Consider moving this call to a scheduler task or micro task."), e(t);
      ze |= Yv;
      try {
        return e ? du(Vr, e.bind(null, t)) : void 0;
      } finally {
        ze = r, ni();
      }
    }
    function ih(e, t) {
      Fn(ig, li, e), li = dt(li, t), bu = dt(bu, t);
    }
    function mg(e) {
      li = ig.current, jn(ig, e);
    }
    function ec(e, t) {
      e.finishedWork = null, e.finishedLanes = W;
      var r = e.timeoutHandle;
      if (r !== Rm && (e.timeoutHandle = Rm, fT(r)), Kt !== null)
        for (var i = Kt.return; i !== null; )
          WS(i), i = i.return;
      Yn = e, Kt = wu(e.current, null), qn = li = bu = t, Ln = qi, Kv = null, Zv = W, Tu = W, Jv = W, Ru = null, pa.discardPendingWarnings();
    }
    function cC(e, t) {
      do {
        var r = Kt;
        try {
          if (fv(), rS(), An(), eg.current = null, r === null || r.return === null) {
            Ln = qv, Kv = t, Kt = null;
            return;
          }
          mt && r.mode & Sr && Vv(r, !0), dx(e, r.return, r, t, qn), vC(r);
        } catch (i) {
          t = i, Kt === r && r !== null ? (r = r.return, Kt = r) : r = Kt;
          continue;
        }
        return;
      } while (!0);
    }
    function fC() {
      var e = Jy.current;
      return Jy.current = Hv, e === null ? Hv : e;
    }
    function dC(e) {
      Jy.current = e;
    }
    function lh(e) {
      {
        var t = h.__interactionsRef.current;
        return h.__interactionsRef.current = e.memoizedInteractions, t;
      }
    }
    function oh(e) {
      h.__interactionsRef.current = e;
    }
    function Yx() {
      og = Hn();
    }
    function yg(e) {
      Zv = dt(e, Zv);
    }
    function qx() {
      Ln === qi && (Ln = Gv);
    }
    function Qx() {
      (Ln === qi || Ln === Gv) && (Ln = Xv), Yn !== null && (nf(Zv) || nf(Tu)) && Js(Yn, qn);
    }
    function Gx() {
      Ln !== ag && (Ln = Qv);
    }
    function Xx() {
      return Ln === qi;
    }
    function cd(e, t) {
      var r = ze;
      ze |= Cr;
      var i = fC();
      (Yn !== e || qn !== t) && (ec(e, t), TC(e, t));
      var o = lh(e);
      do
        try {
          Kx();
          break;
        } catch (s) {
          cC(e, s);
        }
      while (!0);
      if (fv(), oh(o), ze = r, dC(i), Kt !== null)
        throw Error("Cannot commit an incomplete root. This error is likely caused by a bug in React. Please file an issue.");
      return Yn = null, qn = W, Ln;
    }
    function Kx() {
      for (; Kt !== null; )
        pC(Kt);
    }
    function Zx(e, t) {
      var r = ze;
      ze |= Cr;
      var i = fC();
      (Yn !== e || qn !== t) && (Xs(), ec(e, t), TC(e, t));
      var o = lh(e);
      do
        try {
          Jx();
          break;
        } catch (s) {
          cC(e, s);
        }
      while (!0);
      return fv(), oh(o), dC(i), ze = r, Kt !== null ? qi : (Yn = null, qn = W, Ln);
    }
    function Jx() {
      for (; Kt !== null && !aR(); )
        pC(Kt);
    }
    function pC(e) {
      var t = e.alternate;
      nn(e);
      var r;
      (e.mode & Sr) !== Vt ? (Ay(e), r = Eg(t, e, li), Vv(e, !0)) : r = Eg(t, e, li), An(), e.memoizedProps = e.pendingProps, r === null ? vC(e) : Kt = r, eg.current = null;
    }
    function vC(e) {
      var t = e;
      do {
        var r = t.alternate, i = t.return;
        if ((t.flags & No) === Et) {
          nn(t);
          var o = void 0;
          if ((t.mode & Sr) === Vt ? o = $S(r, t, li) : (Ay(t), o = $S(r, t, li), Vv(t, !1)), An(), o !== null) {
            Kt = o;
            return;
          }
          if (ew(t), i !== null && // Do not append effects to parents if a sibling failed to complete
          (i.flags & No) === Et) {
            i.firstEffect === null && (i.firstEffect = t.firstEffect), t.lastEffect !== null && (i.lastEffect !== null && (i.lastEffect.nextEffect = t.firstEffect), i.lastEffect = t.lastEffect);
            var s = t.flags;
            s > On && (i.lastEffect !== null ? i.lastEffect.nextEffect = t : i.firstEffect = t, i.lastEffect = t);
          }
        } else {
          var d = ux(t);
          if (d !== null) {
            d.flags &= xi, Kt = d;
            return;
          }
          if ((t.mode & Sr) !== Vt) {
            Vv(t, !1);
            for (var v = t.actualDuration, E = t.child; E !== null; )
              v += E.actualDuration, E = E.sibling;
            t.actualDuration = v;
          }
          i !== null && (i.firstEffect = i.lastEffect = null, i.flags |= No);
        }
        var R = t.sibling;
        if (R !== null) {
          Kt = R;
          return;
        }
        t = i, Kt = t;
      } while (t !== null);
      Ln === qi && (Ln = ag);
    }
    function ew(e) {
      if (
        // TODO: Move this check out of the hot path by moving `resetChildLanes`
        // to switch statement in `completeWork`.
        !((e.tag === Be || e.tag === st) && e.memoizedState !== null && !yn(li, yr) && (e.mode & pu) !== W)
      ) {
        var t = W;
        if ((e.mode & Sr) !== Vt) {
          for (var r = e.actualDuration, i = e.selfBaseDuration, o = e.alternate === null || e.child !== e.alternate.child, s = e.child; s !== null; )
            t = dt(t, dt(s.lanes, s.childLanes)), o && (r += s.actualDuration), i += s.treeBaseDuration, s = s.sibling;
          var d = e.tag === z && e.memoizedState !== null;
          if (d) {
            var v = e.child;
            v !== null && (i -= v.treeBaseDuration);
          }
          e.actualDuration = r, e.treeBaseDuration = i;
        } else
          for (var E = e.child; E !== null; )
            t = dt(t, dt(E.lanes, E.childLanes)), E = E.sibling;
        e.childLanes = t;
      }
    }
    function xu(e) {
      var t = Hs();
      return du(Vr, tw.bind(null, e, t)), null;
    }
    function tw(e, t) {
      do
        oi();
      while (Zs !== null);
      if (mw(), (ze & (Cr | ii)) !== Xt)
        throw Error("Should not already be working.");
      var r = e.finishedWork, i = e.finishedLanes;
      if (r === null)
        return null;
      if (e.finishedWork = null, e.finishedLanes = W, r === e.current)
        throw Error("Cannot commit the same tree as before. This error is likely caused by a bug in React. Please file an issue.");
      e.callbackNode = null;
      var o = dt(r.lanes, r.childLanes);
      uf(e, o), Gi !== null && !nm(o) && Gi.has(e) && Gi.delete(e), e === Yn && (Yn = null, Kt = null, qn = W);
      var s;
      if (r.flags > On ? r.lastEffect !== null ? (r.lastEffect.nextEffect = r, s = r.firstEffect) : s = r : s = r.firstEffect, s !== null) {
        var d = ze;
        ze |= ii;
        var v = lh(e);
        eg.current = null, sd = aT(e.containerInfo), rh = !1, Ce = s;
        do
          if (_n(null, nw, null), In()) {
            if (Ce === null)
              throw Error("Should be working on an effect.");
            var E = Dn();
            to(Ce, E), Ce = Ce.nextEffect;
          }
        while (Ce !== null);
        sd = null, ES(), Ce = s;
        do
          if (_n(null, rw, null, e, t), In()) {
            if (Ce === null)
              throw Error("Should be working on an effect.");
            var R = Dn();
            to(Ce, R), Ce = Ce.nextEffect;
          }
        while (Ce !== null);
        iT(e.containerInfo), e.current = r, Ce = s;
        do
          if (_n(null, aw, null, e, i), In()) {
            if (Ce === null)
              throw Error("Should be working on an effect.");
            var x = Dn();
            to(Ce, x), Ce = Ce.nextEffect;
          }
        while (Ce !== null);
        Ce = null, iR(), oh(v), ze = d;
      } else
        e.current = r, ES();
      var U = Qi;
      if (Qi)
        Qi = !1, Zs = e, sg = i, ld = t;
      else
        for (Ce = s; Ce !== null; ) {
          var k = Ce.nextEffect;
          Ce.nextEffect = null, Ce.flags & Dt && xC(Ce), Ce = k;
        }
      if (o = e.pendingLanes, o !== W) {
        if (Ru !== null) {
          var H = Ru;
          Ru = null;
          for (var Q = 0; Q < H.length; Q++)
            bC(e, H[Q], e.memoizedInteractions);
        }
        no(e, o);
      } else
        Ks = null;
      if (U || RC(e, i), o === at ? e === dg ? od++ : (od = 0, dg = e) : od = 0, JT(r.stateNode, t), Lx(), Yr(e, Hn()), eh) {
        eh = !1;
        var se = ug;
        throw ug = null, se;
      }
      return (ze & rg) !== Xt || ni(), null;
    }
    function nw() {
      for (; Ce !== null; ) {
        var e = Ce.alternate;
        !rh && sd !== null && ((Ce.flags & Dt) !== Et ? lp(Ce, sd) && (rh = !0) : Ce.tag === z && Ox(e, Ce) && lp(Ce, sd) && (rh = !0));
        var t = Ce.flags;
        (t & Nr) !== Et && (nn(Ce), yx(e, Ce), An()), (t & xl) !== Et && (Qi || (Qi = !0, Ql($i, function() {
          return oi(), null;
        }))), Ce = Ce.nextEffect;
      }
    }
    function rw(e, t) {
      for (; Ce !== null; ) {
        nn(Ce);
        var r = Ce.flags;
        if (r & vn && Nx(Ce), r & hn) {
          var i = Ce.alternate;
          i !== null && Tx(i);
        }
        var o = r & (Ye | Ue | Dt | nr);
        switch (o) {
          case Ye: {
            eC(Ce), Ce.flags &= ~Ye;
            break;
          }
          case Aa: {
            eC(Ce), Ce.flags &= ~Ye;
            var s = Ce.alternate;
            Zy(s, Ce);
            break;
          }
          case nr: {
            Ce.flags &= ~nr;
            break;
          }
          case rp: {
            Ce.flags &= ~nr;
            var d = Ce.alternate;
            Zy(d, Ce);
            break;
          }
          case Ue: {
            var v = Ce.alternate;
            Zy(v, Ce);
            break;
          }
          case Dt: {
            kx(e, Ce);
            break;
          }
        }
        An(), Ce = Ce.nextEffect;
      }
    }
    function aw(e, t) {
      for (; Ce !== null; ) {
        nn(Ce);
        var r = Ce.flags;
        if (r & (Ue | Ua)) {
          var i = Ce.alternate;
          Cx(e, i, Ce);
        }
        r & hn && bx(Ce), An(), Ce = Ce.nextEffect;
      }
    }
    function oi() {
      if (ld !== Am) {
        var e = ld > $i ? $i : ld;
        return ld = Am, du(e, ow);
      }
      return !1;
    }
    function iw(e, t) {
      cg.push(t, e), Qi || (Qi = !0, Ql($i, function() {
        return oi(), null;
      }));
    }
    function hC(e, t) {
      fg.push(t, e);
      {
        e.flags |= wl;
        var r = e.alternate;
        r !== null && (r.flags |= wl);
      }
      Qi || (Qi = !0, Ql($i, function() {
        return oi(), null;
      }));
    }
    function lw(e) {
      var t = e.create;
      e.destroy = t();
    }
    function ow() {
      if (Zs === null)
        return !1;
      var e = Zs, t = sg;
      if (Zs = null, sg = W, (ze & (Cr | ii)) !== Xt)
        throw Error("Cannot flush passive effects while already rendering.");
      pg = !0;
      var r = ze;
      ze |= ii;
      var i = lh(e), o = fg;
      fg = [];
      for (var s = 0; s < o.length; s += 2) {
        var d = o[s], v = o[s + 1], E = d.destroy;
        d.destroy = void 0;
        {
          v.flags &= ~wl;
          var R = v.alternate;
          R !== null && (R.flags &= ~wl);
        }
        if (typeof E == "function") {
          if (nn(v), _n(null, E, null), In()) {
            if (v === null)
              throw Error("Should be working on an effect.");
            var x = Dn();
            to(v, x);
          }
          An();
        }
      }
      var U = cg;
      cg = [];
      for (var k = 0; k < U.length; k += 2) {
        var H = U[k], Q = U[k + 1];
        {
          if (nn(Q), _n(null, lw, null, H), In()) {
            if (Q === null)
              throw Error("Should be working on an effect.");
            var se = Dn();
            to(Q, se);
          }
          An();
        }
      }
      for (var Me = e.current.firstEffect; Me !== null; ) {
        var Xe = Me.nextEffect;
        Me.nextEffect = null, Me.flags & Dt && xC(Me), Me = Xe;
      }
      return oh(i), RC(e, t), pg = !1, ze = r, ni(), th = Zs === null ? 0 : th + 1, !0;
    }
    function gg(e) {
      return Ks !== null && Ks.has(e);
    }
    function uw(e) {
      Ks === null ? Ks = /* @__PURE__ */ new Set([e]) : Ks.add(e);
    }
    function sw(e) {
      eh || (eh = !0, ug = e);
    }
    var cw = sw;
    function mC(e, t, r) {
      var i = Qy(r, t), o = YS(e, i, at);
      Xl(e, o);
      var s = br(), d = ah(e, at);
      d !== null && (Pl(d, at, s), Yr(d, s), no(d, at));
    }
    function to(e, t) {
      if (e.tag === B) {
        mC(e, e, t);
        return;
      }
      for (var r = e.return; r !== null; ) {
        if (r.tag === B) {
          mC(r, e, t);
          return;
        } else if (r.tag === L) {
          var i = r.type, o = r.stateNode;
          if (typeof i.getDerivedStateFromError == "function" || typeof o.componentDidCatch == "function" && !gg(o)) {
            var s = Qy(t, e), d = qS(r, s, at);
            Xl(r, d);
            var v = br(), E = ah(r, at);
            if (E !== null)
              Pl(E, at, v), Yr(E, v), no(E, at);
            else if (typeof o.componentDidCatch == "function" && !gg(o))
              try {
                o.componentDidCatch(t, s);
              } catch {
              }
            return;
          }
        }
        r = r.return;
      }
    }
    function fw(e, t, r) {
      var i = e.pingCache;
      i !== null && i.delete(t);
      var o = br();
      of(e, r), Yn === e && Wa(qn, r) && (Ln === Xv || Ln === Gv && rf(qn) && Hn() - og < aC ? ec(e, W) : Jv = dt(Jv, r)), Yr(e, o), no(e, r);
    }
    function dw(e, t) {
      t === qt && (t = Px(e));
      var r = br(), i = ah(e, t);
      i !== null && (Pl(i, t, r), Yr(i, r), no(i, t));
    }
    function pw(e, t) {
      var r = qt, i;
      i = e.stateNode, i !== null && i.delete(t), dw(e, r);
    }
    function vw(e) {
      return e < 120 ? 120 : e < 480 ? 480 : e < 1080 ? 1080 : e < 1920 ? 1920 : e < 3e3 ? 3e3 : e < 4320 ? 4320 : Ax(e / 1960) * 1960;
    }
    function hw() {
      if (od > jx)
        throw od = 0, dg = null, Error("Maximum update depth exceeded. This can happen when a component repeatedly calls setState inside componentWillUpdate or componentDidUpdate. React limits the number of nested updates to prevent infinite loops.");
      th > Fx && (th = 0, y("Maximum update depth exceeded. This can happen when a component calls setState inside useEffect, but useEffect either doesn't have a dependency array, or one of the dependencies changes on every render."));
    }
    function mw() {
      pa.flushLegacyContextWarning(), pa.flushPendingUnsafeLifecycleWarnings();
    }
    var uh = null;
    function yC(e) {
      {
        if ((ze & Cr) !== Xt || !(e.mode & (ur | pu)))
          return;
        var t = e.tag;
        if (t !== I && t !== B && t !== L && t !== A && t !== ee && t !== le && t !== Se && t !== ut)
          return;
        var r = fe(e.type) || "ReactComponent";
        if (uh !== null) {
          if (uh.has(r))
            return;
          uh.add(r);
        } else
          uh = /* @__PURE__ */ new Set([r]);
        var i = xn;
        try {
          nn(e), y("Can't perform a React state update on a component that hasn't mounted yet. This indicates that you have a side-effect in your render function that asynchronously later calls tries to update the component. Move this work to useEffect instead.");
        } finally {
          i ? nn(e) : An();
        }
      }
    }
    var sh = null;
    function yw(e) {
      {
        var t = e.tag;
        if (t !== B && t !== L && t !== A && t !== ee && t !== le && t !== Se && t !== ut || (e.flags & wl) !== Et)
          return;
        var r = fe(e.type) || "ReactComponent";
        if (sh !== null) {
          if (sh.has(r))
            return;
          sh.add(r);
        } else
          sh = /* @__PURE__ */ new Set([r]);
        if (!pg) {
          var i = xn;
          try {
            nn(e), y("Can't perform a React state update on an unmounted component. This is a no-op, but it indicates a memory leak in your application. To fix, cancel all subscriptions and asynchronous tasks in %s.", t === L ? "the componentWillUnmount method" : "a useEffect cleanup function");
          } finally {
            i ? nn(e) : An();
          }
        }
      }
    }
    var Eg;
    {
      var gw = null;
      Eg = function(e, t, r) {
        var i = DC(gw, t);
        try {
          return HS(e, t, r);
        } catch (s) {
          if (s !== null && typeof s == "object" && typeof s.then == "function")
            throw s;
          if (fv(), rS(), WS(t), DC(t, i), t.mode & Sr && Ay(t), _n(null, HS, null, e, t, r), In()) {
            var o = Dn();
            throw o;
          } else
            throw s;
        }
      };
    }
    var gC = !1, Sg;
    Sg = /* @__PURE__ */ new Set();
    function Ew(e) {
      if (xa && (ze & Cr) !== Xt && !FR())
        switch (e.tag) {
          case A:
          case ee:
          case Se: {
            var t = Kt && fe(Kt.type) || "Unknown", r = t;
            if (!Sg.has(r)) {
              Sg.add(r);
              var i = fe(e.type) || "Unknown";
              y("Cannot update a component (`%s`) while rendering a different component (`%s`). To locate the bad setState() call inside `%s`, follow the stack trace as described in https://reactjs.org/link/setstate-in-render", i, t, t);
            }
            break;
          }
          case L: {
            gC || (y("Cannot update during an existing state transition (such as within `render`). Render methods should be a pure function of props and state."), gC = !0);
            break;
          }
        }
    }
    var ch = {
      current: !1
    };
    function EC(e) {
      if (tg.current === !0 && ch.current !== !0) {
        var t = xn;
        try {
          nn(e), y(`It looks like you're using the wrong act() around your test interactions.
Be sure to use the matching version of act() corresponding to your renderer:

// for react-dom:
import {act} from 'react-dom/test-utils';
// ...
act(() => ...);

// for react-test-renderer:
import TestRenderer from react-test-renderer';
const {act} = TestRenderer;
// ...
act(() => ...);`);
        } finally {
          t ? nn(e) : An();
        }
      }
    }
    function SC(e) {
      (e.mode & Gt) !== Vt && tg.current === !1 && ch.current === !1 && y(`An update to %s ran an effect, but was not wrapped in act(...).

When testing, code that causes React state updates should be wrapped into act(...):

act(() => {
  /* fire events that update state */
});
/* assert on the output */

This ensures that you're testing the behavior the user would see in the browser. Learn more at https://reactjs.org/link/wrap-tests-with-act`, fe(e.type));
    }
    function Sw(e) {
      if (ze === Xt && tg.current === !1 && ch.current === !1) {
        var t = xn;
        try {
          nn(e), y(`An update to %s inside a test was not wrapped in act(...).

When testing, code that causes React state updates should be wrapped into act(...):

act(() => {
  /* fire events that update state */
});
/* assert on the output */

This ensures that you're testing the behavior the user would see in the browser. Learn more at https://reactjs.org/link/wrap-tests-with-act`, fe(e.type));
        } finally {
          t ? nn(e) : An();
        }
      }
    }
    var Cw = Sw, CC = !1;
    function bw(e) {
      CC === !1 && g.unstable_flushAllWithoutAsserting === void 0 && (e.mode & ur || e.mode & pu) && (CC = !0, y(`In Concurrent or Sync modes, the "scheduler" module needs to be mocked to guarantee consistent behaviour across tests and browsers. For example, with jest: 
jest.mock('scheduler', () => require('scheduler/unstable_mock'));

For more info, visit https://reactjs.org/link/mock-scheduler`));
    }
    function Cg(e, t) {
      return t * 1e3 + e.interactionThreadID;
    }
    function fh(e) {
      Ru === null ? Ru = [e] : Ru.push(e);
    }
    function bC(e, t, r) {
      if (r.size > 0) {
        var i = e.pendingInteractionMap, o = i.get(t);
        o != null ? r.forEach(function(v) {
          o.has(v) || v.__count++, o.add(v);
        }) : (i.set(t, new Set(r)), r.forEach(function(v) {
          v.__count++;
        }));
        var s = h.__subscriberRef.current;
        if (s !== null) {
          var d = Cg(e, t);
          s.onWorkScheduled(r, d);
        }
      }
    }
    function no(e, t) {
      bC(e, t, h.__interactionsRef.current);
    }
    function TC(e, t) {
      var r = /* @__PURE__ */ new Set();
      if (e.pendingInteractionMap.forEach(function(s, d) {
        yn(t, d) && s.forEach(function(v) {
          return r.add(v);
        });
      }), e.memoizedInteractions = r, r.size > 0) {
        var i = h.__subscriberRef.current;
        if (i !== null) {
          var o = Cg(e, t);
          try {
            i.onWorkStarted(r, o);
          } catch (s) {
            Ql(Vr, function() {
              throw s;
            });
          }
        }
      }
    }
    function RC(e, t) {
      var r = e.pendingLanes, i;
      try {
        if (i = h.__subscriberRef.current, i !== null && e.memoizedInteractions.size > 0) {
          var o = Cg(e, t);
          i.onWorkStopped(e.memoizedInteractions, o);
        }
      } catch (d) {
        Ql(Vr, function() {
          throw d;
        });
      } finally {
        var s = e.pendingInteractionMap;
        s.forEach(function(d, v) {
          yn(r, v) || (s.delete(v), d.forEach(function(E) {
            if (E.__count--, i !== null && E.__count === 0)
              try {
                i.onInteractionScheduledWorkCompleted(E);
              } catch (R) {
                Ql(Vr, function() {
                  throw R;
                });
              }
          }));
        });
      }
    }
    function Tw() {
      return Rw > 0;
    }
    var Rw = 0;
    function xC(e) {
      e.sibling = null, e.stateNode = null;
    }
    var qr = null, tc = null, xw = function(e) {
      qr = e;
    };
    function nc(e) {
      {
        if (qr === null)
          return e;
        var t = qr(e);
        return t === void 0 ? e : t.current;
      }
    }
    function bg(e) {
      return nc(e);
    }
    function Tg(e) {
      {
        if (qr === null)
          return e;
        var t = qr(e);
        if (t === void 0) {
          if (e != null && typeof e.render == "function") {
            var r = nc(e.render);
            if (e.render !== r) {
              var i = {
                $$typeof: Xr,
                render: r
              };
              return e.displayName !== void 0 && (i.displayName = e.displayName), i;
            }
          }
          return e;
        }
        return t.current;
      }
    }
    function wC(e, t) {
      {
        if (qr === null)
          return !1;
        var r = e.elementType, i = t.type, o = !1, s = typeof i == "object" && i !== null ? i.$$typeof : null;
        switch (e.tag) {
          case L: {
            typeof i == "function" && (o = !0);
            break;
          }
          case A: {
            (typeof i == "function" || s === kr) && (o = !0);
            break;
          }
          case ee: {
            (s === Xr || s === kr) && (o = !0);
            break;
          }
          case le:
          case Se: {
            (s === vi || s === kr) && (o = !0);
            break;
          }
          default:
            return !1;
        }
        if (o) {
          var d = qr(r);
          if (d !== void 0 && d === qr(i))
            return !0;
        }
        return !1;
      }
    }
    function kC(e) {
      {
        if (qr === null || typeof WeakSet != "function")
          return;
        tc === null && (tc = /* @__PURE__ */ new WeakSet()), tc.add(e);
      }
    }
    var ww = function(e, t) {
      {
        if (qr === null)
          return;
        var r = t.staleFamilies, i = t.updatedFamilies;
        oi(), hg(function() {
          Rg(e.current, i, r);
        });
      }
    }, kw = function(e, t) {
      {
        if (e.context !== Er)
          return;
        oi(), hg(function() {
          fd(t, e, null, null);
        });
      }
    };
    function Rg(e, t, r) {
      {
        var i = e.alternate, o = e.child, s = e.sibling, d = e.tag, v = e.type, E = null;
        switch (d) {
          case A:
          case Se:
          case L:
            E = v;
            break;
          case ee:
            E = v.render;
            break;
        }
        if (qr === null)
          throw new Error("Expected resolveFamily to be set during hot reload.");
        var R = !1, x = !1;
        if (E !== null) {
          var U = qr(E);
          U !== void 0 && (r.has(U) ? x = !0 : t.has(U) && (d === L ? x = !0 : R = !0));
        }
        tc !== null && (tc.has(e) || i !== null && tc.has(i)) && (x = !0), x && (e._debugNeedsRemount = !0), (x || R) && Bn(e, at, Nt), o !== null && !x && Rg(o, t, r), s !== null && Rg(s, t, r);
      }
    }
    var _w = function(e, t) {
      {
        var r = /* @__PURE__ */ new Set(), i = new Set(t.map(function(o) {
          return o.current;
        }));
        return xg(e.current, i, r), r;
      }
    };
    function xg(e, t, r) {
      {
        var i = e.child, o = e.sibling, s = e.tag, d = e.type, v = null;
        switch (s) {
          case A:
          case Se:
          case L:
            v = d;
            break;
          case ee:
            v = d.render;
            break;
        }
        var E = !1;
        v !== null && t.has(v) && (E = !0), E ? Dw(e, r) : i !== null && xg(i, t, r), o !== null && xg(o, t, r);
      }
    }
    function Dw(e, t) {
      {
        var r = Ow(e, t);
        if (r)
          return;
        for (var i = e; ; ) {
          switch (i.tag) {
            case re:
              t.add(i.stateNode);
              return;
            case Y:
              t.add(i.stateNode.containerInfo);
              return;
            case B:
              t.add(i.stateNode.containerInfo);
              return;
          }
          if (i.return === null)
            throw new Error("Expected to reach root first.");
          i = i.return;
        }
      }
    }
    function Ow(e, t) {
      for (var r = e, i = !1; ; ) {
        if (r.tag === re)
          i = !0, t.add(r.stateNode);
        else if (r.child !== null) {
          r.child.return = r, r = r.child;
          continue;
        }
        if (r === e)
          return i;
        for (; r.sibling === null; ) {
          if (r.return === null || r.return === e)
            return i;
          r = r.return;
        }
        r.sibling.return = r.return, r = r.sibling;
      }
      return !1;
    }
    var wg;
    {
      wg = !1;
      try {
        var _C = Object.preventExtensions({});
      } catch {
        wg = !0;
      }
    }
    var Nw = 1;
    function Mw(e, t, r, i) {
      this.tag = e, this.key = r, this.elementType = null, this.type = null, this.stateNode = null, this.return = null, this.child = null, this.sibling = null, this.index = 0, this.ref = null, this.pendingProps = t, this.memoizedProps = null, this.updateQueue = null, this.memoizedState = null, this.dependencies = null, this.mode = i, this.flags = Et, this.nextEffect = null, this.firstEffect = null, this.lastEffect = null, this.lanes = W, this.childLanes = W, this.alternate = null, this.actualDuration = Number.NaN, this.actualStartTime = Number.NaN, this.selfBaseDuration = Number.NaN, this.treeBaseDuration = Number.NaN, this.actualDuration = 0, this.actualStartTime = -1, this.selfBaseDuration = 0, this.treeBaseDuration = 0, this._debugID = Nw++, this._debugSource = null, this._debugOwner = null, this._debugNeedsRemount = !1, this._debugHookTypes = null, !wg && typeof Object.preventExtensions == "function" && Object.preventExtensions(this);
    }
    var Tr = function(e, t, r, i) {
      return new Mw(e, t, r, i);
    };
    function kg(e) {
      var t = e.prototype;
      return !!(t && t.isReactComponent);
    }
    function Lw(e) {
      return typeof e == "function" && !kg(e) && e.defaultProps === void 0;
    }
    function Aw(e) {
      if (typeof e == "function")
        return kg(e) ? L : A;
      if (e != null) {
        var t = e.$$typeof;
        if (t === Xr)
          return ee;
        if (t === vi)
          return le;
      }
      return I;
    }
    function wu(e, t) {
      var r = e.alternate;
      r === null ? (r = Tr(e.tag, t, e.key, e.mode), r.elementType = e.elementType, r.type = e.type, r.stateNode = e.stateNode, r._debugID = e._debugID, r._debugSource = e._debugSource, r._debugOwner = e._debugOwner, r._debugHookTypes = e._debugHookTypes, r.alternate = e, e.alternate = r) : (r.pendingProps = t, r.type = e.type, r.flags = Et, r.nextEffect = null, r.firstEffect = null, r.lastEffect = null, r.actualDuration = 0, r.actualStartTime = -1), r.childLanes = e.childLanes, r.lanes = e.lanes, r.child = e.child, r.memoizedProps = e.memoizedProps, r.memoizedState = e.memoizedState, r.updateQueue = e.updateQueue;
      var i = e.dependencies;
      switch (r.dependencies = i === null ? null : {
        lanes: i.lanes,
        firstContext: i.firstContext
      }, r.sibling = e.sibling, r.index = e.index, r.ref = e.ref, r.selfBaseDuration = e.selfBaseDuration, r.treeBaseDuration = e.treeBaseDuration, r._debugNeedsRemount = e._debugNeedsRemount, r.tag) {
        case I:
        case A:
        case Se:
          r.type = nc(e.type);
          break;
        case L:
          r.type = bg(e.type);
          break;
        case ee:
          r.type = Tg(e.type);
          break;
      }
      return r;
    }
    function Uw(e, t) {
      e.flags &= Ye, e.nextEffect = null, e.firstEffect = null, e.lastEffect = null;
      var r = e.alternate;
      if (r === null)
        e.childLanes = W, e.lanes = t, e.child = null, e.memoizedProps = null, e.memoizedState = null, e.updateQueue = null, e.dependencies = null, e.stateNode = null, e.selfBaseDuration = 0, e.treeBaseDuration = 0;
      else {
        e.childLanes = r.childLanes, e.lanes = r.lanes, e.child = r.child, e.memoizedProps = r.memoizedProps, e.memoizedState = r.memoizedState, e.updateQueue = r.updateQueue, e.type = r.type;
        var i = r.dependencies;
        e.dependencies = i === null ? null : {
          lanes: i.lanes,
          firstContext: i.firstContext
        }, e.selfBaseDuration = r.selfBaseDuration, e.treeBaseDuration = r.treeBaseDuration;
      }
      return e;
    }
    function zw(e) {
      var t;
      return e === dE ? t = pu | ur | Gt : e === fE ? t = ur | Gt : t = Vt, XT && (t |= Sr), Tr(B, null, null, t);
    }
    function _g(e, t, r, i, o, s) {
      var d = I, v = e;
      if (typeof e == "function")
        kg(e) ? (d = L, v = bg(v)) : v = nc(v);
      else if (typeof e == "string")
        d = re;
      else
        e: switch (e) {
          case Gr:
            return ku(r.children, o, s, t);
          case Mu:
            d = ce, o |= oR;
            break;
          case sc:
            d = ce, o |= Gt;
            break;
          case pi:
            return jw(r, o, s, t);
          case fr:
            return Fw(r, o, s, t);
          case dr:
            return Hw(r, o, s, t);
          case co:
            return Og(r, o, s, t);
          case _r:
            return Pw(r, o, s, t);
          case Nu:
          default: {
            if (typeof e == "object" && e !== null)
              switch (e.$$typeof) {
                case al:
                  d = we;
                  break e;
                case il:
                  d = _e;
                  break e;
                case Xr:
                  d = ee, v = Tg(v);
                  break e;
                case vi:
                  d = le;
                  break e;
                case kr:
                  d = We, v = null;
                  break e;
                case uo:
                  d = ut;
                  break e;
              }
            var E = "";
            {
              (e === void 0 || typeof e == "object" && e !== null && Object.keys(e).length === 0) && (E += " You likely forgot to export your component from the file it's defined in, or you might have mixed up default and named imports.");
              var R = i ? fe(i.type) : null;
              R && (E += `

Check the render method of \`` + R + "`.");
            }
            throw Error("Element type is invalid: expected a string (for built-in components) or a class/function (for composite components) but got: " + (e == null ? e : typeof e) + "." + E);
          }
        }
      var x = Tr(d, r, t, o);
      return x.elementType = e, x.type = v, x.lanes = s, x._debugOwner = i, x;
    }
    function Dg(e, t, r) {
      var i = null;
      i = e._owner;
      var o = e.type, s = e.key, d = e.props, v = _g(o, s, d, i, t, r);
      return v._debugSource = e._source, v._debugOwner = e._owner, v;
    }
    function ku(e, t, r, i) {
      var o = Tr(Te, e, i, t);
      return o.lanes = r, o;
    }
    function jw(e, t, r, i) {
      typeof e.id != "string" && y('Profiler must specify an "id" as a prop');
      var o = Tr(ie, e, i, t | Sr);
      return o.elementType = pi, o.type = pi, o.lanes = r, o.stateNode = {
        effectDuration: 0,
        passiveEffectDuration: 0
      }, o;
    }
    function Fw(e, t, r, i) {
      var o = Tr(z, e, i, t);
      return o.type = fr, o.elementType = fr, o.lanes = r, o;
    }
    function Hw(e, t, r, i) {
      var o = Tr(it, e, i, t);
      return o.type = dr, o.elementType = dr, o.lanes = r, o;
    }
    function Og(e, t, r, i) {
      var o = Tr(st, e, i, t);
      return o.type = co, o.elementType = co, o.lanes = r, o;
    }
    function Pw(e, t, r, i) {
      var o = Tr(Be, e, i, t);
      return o.type = _r, o.elementType = _r, o.lanes = r, o;
    }
    function Ng(e, t, r) {
      var i = Tr(ue, e, null, t);
      return i.lanes = r, i;
    }
    function Bw() {
      var e = Tr(re, null, null, Vt);
      return e.elementType = "DELETED", e.type = "DELETED", e;
    }
    function Mg(e, t, r) {
      var i = e.children !== null ? e.children : [], o = Tr(Y, i, e.key, t);
      return o.lanes = r, o.stateNode = {
        containerInfo: e.containerInfo,
        pendingChildren: null,
        // Used by persistent updates
        implementation: e.implementation
      }, o;
    }
    function DC(e, t) {
      return e === null && (e = Tr(I, null, null, Vt)), e.tag = t.tag, e.key = t.key, e.elementType = t.elementType, e.type = t.type, e.stateNode = t.stateNode, e.return = t.return, e.child = t.child, e.sibling = t.sibling, e.index = t.index, e.ref = t.ref, e.pendingProps = t.pendingProps, e.memoizedProps = t.memoizedProps, e.updateQueue = t.updateQueue, e.memoizedState = t.memoizedState, e.dependencies = t.dependencies, e.mode = t.mode, e.flags = t.flags, e.nextEffect = t.nextEffect, e.firstEffect = t.firstEffect, e.lastEffect = t.lastEffect, e.lanes = t.lanes, e.childLanes = t.childLanes, e.alternate = t.alternate, e.actualDuration = t.actualDuration, e.actualStartTime = t.actualStartTime, e.selfBaseDuration = t.selfBaseDuration, e.treeBaseDuration = t.treeBaseDuration, e._debugID = t._debugID, e._debugSource = t._debugSource, e._debugOwner = t._debugOwner, e._debugNeedsRemount = t._debugNeedsRemount, e._debugHookTypes = t._debugHookTypes, e;
    }
    function Vw(e, t, r) {
      switch (this.tag = t, this.containerInfo = e, this.pendingChildren = null, this.current = null, this.pingCache = null, this.finishedWork = null, this.timeoutHandle = Rm, this.context = null, this.pendingContext = null, this.hydrate = r, this.callbackNode = null, this.callbackPriority = la, this.eventTimes = ys(W), this.expirationTimes = ys(Nt), this.pendingLanes = W, this.suspendedLanes = W, this.pingedLanes = W, this.expiredLanes = W, this.mutableReadLanes = W, this.finishedLanes = W, this.entangledLanes = W, this.entanglements = ys(W), this.mutableSourceEagerHydrationData = null, this.interactionThreadID = h.unstable_getThreadID(), this.memoizedInteractions = /* @__PURE__ */ new Set(), this.pendingInteractionMap = /* @__PURE__ */ new Map(), t) {
        case fE:
          this._debugRootType = "createBlockingRoot()";
          break;
        case dE:
          this._debugRootType = "createRoot()";
          break;
        case Nm:
          this._debugRootType = "createLegacyRoot()";
          break;
      }
    }
    function Iw(e, t, r, i) {
      var o = new Vw(e, t, r), s = zw(t);
      return o.current = s, s.stateNode = o, Bm(s), o;
    }
    function $w(e, t) {
      var r = t._getVersion, i = r(t._source);
      e.mutableSourceEagerHydrationData == null ? e.mutableSourceEagerHydrationData = [t, i] : e.mutableSourceEagerHydrationData.push(t, i);
    }
    function Ww(e, t, r) {
      var i = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : null;
      return {
        // This tag allow us to uniquely identify this as a React Portal
        $$typeof: Ut,
        key: i == null ? null : "" + i,
        children: e,
        containerInfo: t,
        implementation: r
      };
    }
    var Lg, Ag;
    Lg = !1, Ag = {};
    function Yw(e) {
      if (!e)
        return Er;
      var t = ta(e), r = GT(t);
      if (t.tag === L) {
        var i = t.type;
        if (ei(i))
          return sE(t, i, r);
      }
      return r;
    }
    function qw(e, t) {
      {
        var r = ta(e);
        if (r === void 0)
          throw typeof e.render == "function" ? Error("Unable to find node on an unmounted component.") : Error("Argument appears to not be a ReactComponent. Keys: " + Object.keys(e));
        var i = Hc(r);
        if (i === null)
          return null;
        if (i.mode & Gt) {
          var o = fe(r.type) || "Component";
          if (!Ag[o]) {
            Ag[o] = !0;
            var s = xn;
            try {
              nn(i), r.mode & Gt ? y("%s is deprecated in StrictMode. %s was passed an instance of %s which is inside StrictMode. Instead, add a ref directly to the element you want to reference. Learn more about using refs safely here: https://reactjs.org/link/strict-mode-find-node", t, t, o) : y("%s is deprecated in StrictMode. %s was passed an instance of %s which renders StrictMode children. Instead, add a ref directly to the element you want to reference. Learn more about using refs safely here: https://reactjs.org/link/strict-mode-find-node", t, t, o);
            } finally {
              s ? nn(s) : An();
            }
          }
        }
        return i.stateNode;
      }
    }
    function Qw(e, t, r, i) {
      return Iw(e, t, r);
    }
    function fd(e, t, r, i) {
      ZT(t, e);
      var o = t.current, s = br();
      typeof jest < "u" && (bw(o), EC(o));
      var d = eo(o), v = Yw(r);
      t.context === null ? t.context = v : t.pendingContext = v, xa && xn !== null && !Lg && (Lg = !0, y(`Render methods should be a pure function of props and state; triggering nested component updates from render is not allowed. If necessary, trigger nested updates in componentDidUpdate.

Check the render method of %s.`, fe(xn.type) || "Unknown"));
      var E = Gl(s, d);
      return E.payload = {
        element: e
      }, i = i === void 0 ? null : i, i !== null && (typeof i != "function" && y("render(...): Expected the last optional `callback` argument to be a function. Instead received: %s.", i), E.callback = i), Xl(o, E), Bn(o, d, s), d;
    }
    function Ug(e) {
      var t = e.current;
      if (!t.child)
        return null;
      switch (t.child.tag) {
        case re:
          return t.child.stateNode;
        default:
          return t.child.stateNode;
      }
    }
    function OC(e, t) {
      var r = e.memoizedState;
      r !== null && r.dehydrated !== null && (r.retryLane = sa(r.retryLane, t));
    }
    function zg(e, t) {
      OC(e, t);
      var r = e.alternate;
      r && OC(r, t);
    }
    function Gw(e) {
      if (e.tag === z) {
        var t = br(), r = Ai;
        Bn(e, r, t), zg(e, r);
      }
    }
    function Xw(e) {
      if (e.tag === z) {
        var t = br(), r = vs;
        Bn(e, r, t), zg(e, r);
      }
    }
    function Kw(e) {
      if (e.tag === z) {
        var t = br(), r = eo(e);
        Bn(e, r, t), zg(e, r);
      }
    }
    function Zw(e, t) {
      try {
        return t();
      } finally {
      }
    }
    function NC(e) {
      var t = Pc(e);
      return t === null ? null : t.tag === ot ? t.stateNode.instance : t.stateNode;
    }
    var MC = function(e) {
      return !1;
    };
    function Jw(e) {
      return MC(e);
    }
    var LC = null, AC = null, UC = null, zC = null, jC = null, FC = null, HC = null, PC = null;
    {
      var BC = function(e, t, r) {
        var i = t[r], o = Array.isArray(e) ? e.slice() : p({}, e);
        return r + 1 === t.length ? (Array.isArray(o) ? o.splice(i, 1) : delete o[i], o) : (o[i] = BC(e[i], t, r + 1), o);
      }, VC = function(e, t) {
        return BC(e, t, 0);
      }, IC = function(e, t, r, i) {
        var o = t[i], s = Array.isArray(e) ? e.slice() : p({}, e);
        if (i + 1 === t.length) {
          var d = r[i];
          s[d] = s[o], Array.isArray(s) ? s.splice(o, 1) : delete s[o];
        } else
          s[o] = IC(
            // $FlowFixMe number or string is fine here
            e[o],
            t,
            r,
            i + 1
          );
        return s;
      }, $C = function(e, t, r) {
        if (t.length !== r.length) {
          C("copyWithRename() expects paths of the same length");
          return;
        } else
          for (var i = 0; i < r.length - 1; i++)
            if (t[i] !== r[i]) {
              C("copyWithRename() expects paths to be the same except for the deepest key");
              return;
            }
        return IC(e, t, r, 0);
      }, WC = function(e, t, r, i) {
        if (r >= t.length)
          return i;
        var o = t[r], s = Array.isArray(e) ? e.slice() : p({}, e);
        return s[o] = WC(e[o], t, r + 1, i), s;
      }, YC = function(e, t, r) {
        return WC(e, t, 0, r);
      }, jg = function(e, t) {
        for (var r = e.memoizedState; r !== null && t > 0; )
          r = r.next, t--;
        return r;
      };
      LC = function(e, t, r, i) {
        var o = jg(e, t);
        if (o !== null) {
          var s = YC(o.memoizedState, r, i);
          o.memoizedState = s, o.baseState = s, e.memoizedProps = p({}, e.memoizedProps), Bn(e, at, Nt);
        }
      }, AC = function(e, t, r) {
        var i = jg(e, t);
        if (i !== null) {
          var o = VC(i.memoizedState, r);
          i.memoizedState = o, i.baseState = o, e.memoizedProps = p({}, e.memoizedProps), Bn(e, at, Nt);
        }
      }, UC = function(e, t, r, i) {
        var o = jg(e, t);
        if (o !== null) {
          var s = $C(o.memoizedState, r, i);
          o.memoizedState = s, o.baseState = s, e.memoizedProps = p({}, e.memoizedProps), Bn(e, at, Nt);
        }
      }, zC = function(e, t, r) {
        e.pendingProps = YC(e.memoizedProps, t, r), e.alternate && (e.alternate.pendingProps = e.pendingProps), Bn(e, at, Nt);
      }, jC = function(e, t) {
        e.pendingProps = VC(e.memoizedProps, t), e.alternate && (e.alternate.pendingProps = e.pendingProps), Bn(e, at, Nt);
      }, FC = function(e, t, r) {
        e.pendingProps = $C(e.memoizedProps, t, r), e.alternate && (e.alternate.pendingProps = e.pendingProps), Bn(e, at, Nt);
      }, HC = function(e) {
        Bn(e, at, Nt);
      }, PC = function(e) {
        MC = e;
      };
    }
    function ek(e) {
      var t = Hc(e);
      return t === null ? null : t.stateNode;
    }
    function tk(e) {
      return null;
    }
    function nk() {
      return xn;
    }
    function rk(e) {
      var t = e.findFiberByHostInstance, r = b.ReactCurrentDispatcher;
      return KT({
        bundleType: e.bundleType,
        version: e.version,
        rendererPackageName: e.rendererPackageName,
        rendererConfig: e.rendererConfig,
        overrideHookState: LC,
        overrideHookStateDeletePath: AC,
        overrideHookStateRenamePath: UC,
        overrideProps: zC,
        overridePropsDeletePath: jC,
        overridePropsRenamePath: FC,
        setSuspenseHandler: PC,
        scheduleUpdate: HC,
        currentDispatcherRef: r,
        findHostInstanceByFiber: ek,
        findFiberByHostInstance: t || tk,
        // React Refresh
        findHostInstancesForRefresh: _w,
        scheduleRefresh: ww,
        scheduleRoot: kw,
        setRefreshHandler: xw,
        // Enables DevTools to append owner stacks to error messages in DEV mode.
        getCurrentFiber: nk
      });
    }
    function Fg(e, t, r) {
      this._internalRoot = ak(e, t, r);
    }
    Fg.prototype.render = function(e) {
      var t = this._internalRoot;
      {
        typeof arguments[1] == "function" && y("render(...): does not support the second callback argument. To execute a side effect after rendering, declare it in a component body with useEffect().");
        var r = t.containerInfo;
        if (r.nodeType !== wn) {
          var i = NC(t.current);
          i && i.parentNode !== r && y("render(...): It looks like the React-rendered content of the root container was removed without using React. This is not supported and will cause errors. Instead, call root.unmount() to empty a root's container.");
        }
      }
      fd(e, t, null, null);
    }, Fg.prototype.unmount = function() {
      typeof arguments[0] == "function" && y("unmount(...): does not support a callback argument. To execute a side effect after rendering, declare it in a component body with useEffect().");
      var e = this._internalRoot, t = e.containerInfo;
      fd(null, e, null, function() {
        rE(t);
      });
    };
    function ak(e, t, r) {
      var i = r != null && r.hydrate === !0;
      r != null && r.hydrationOptions;
      var o = r != null && r.hydrationOptions != null && r.hydrationOptions.mutableSources || null, s = Qw(e, t, i);
      QT(s.current, e), e.nodeType;
      {
        var d = e.nodeType === wn ? e.parentNode : e;
        k0(d);
      }
      if (o)
        for (var v = 0; v < o.length; v++) {
          var E = o[v];
          $w(s, E);
        }
      return s;
    }
    function ik(e, t) {
      return new Fg(e, Nm, t);
    }
    function rc(e) {
      return !!(e && (e.nodeType === er || e.nodeType === Da || e.nodeType === Nd || e.nodeType === wn && e.nodeValue === " react-mount-point-unstable "));
    }
    var lk = b.ReactCurrentOwner, qC, QC = !1;
    qC = function(e) {
      if (e._reactRootContainer && e.nodeType !== wn) {
        var t = NC(e._reactRootContainer._internalRoot.current);
        t && t.parentNode !== e && y("render(...): It looks like the React-rendered content of this container was removed without using React. This is not supported and will cause errors. Instead, call ReactDOM.unmountComponentAtNode to empty a container.");
      }
      var r = !!e._reactRootContainer, i = dh(e), o = !!(i && Yl(i));
      o && !r && y("render(...): Replacing React-rendered children with a new root component. If you intended to update the children of this node, you should instead have the existing children update their state and render the new components instead of calling ReactDOM.render."), e.nodeType === er && e.tagName && e.tagName.toUpperCase() === "BODY" && y("render(): Rendering components directly into document.body is discouraged, since its children are often manipulated by third-party scripts and browser extensions. This may lead to subtle reconciliation issues. Try rendering into a container element created for your app.");
    };
    function dh(e) {
      return e ? e.nodeType === Da ? e.documentElement : e.firstChild : null;
    }
    function ok(e) {
      var t = dh(e);
      return !!(t && t.nodeType === er && t.hasAttribute(wr));
    }
    function uk(e, t) {
      var r = t || ok(e);
      if (!r)
        for (var i = !1, o; o = e.lastChild; )
          !i && o.nodeType === er && o.hasAttribute(wr) && (i = !0, y("render(): Target node has markup rendered by React, but there are unrelated nodes as well. This is most commonly caused by white-space inserted around server-rendered markup.")), e.removeChild(o);
      return r && !t && !QC && (QC = !0, C("render(): Calling ReactDOM.render() to hydrate server-rendered markup will stop working in React v18. Replace the ReactDOM.render() call with ReactDOM.hydrate() if you want React to attach to the server HTML.")), ik(e, r ? {
        hydrate: !0
      } : void 0);
    }
    function sk(e, t) {
      e !== null && typeof e != "function" && y("%s(...): Expected the last optional `callback` argument to be a function. Instead received: %s.", t, e);
    }
    function ph(e, t, r, i, o) {
      qC(r), sk(o === void 0 ? null : o, "render");
      var s = r._reactRootContainer, d;
      if (s) {
        if (d = s._internalRoot, typeof o == "function") {
          var E = o;
          o = function() {
            var R = Ug(d);
            E.call(R);
          };
        }
        fd(t, d, e, o);
      } else {
        if (s = r._reactRootContainer = uk(r, i), d = s._internalRoot, typeof o == "function") {
          var v = o;
          o = function() {
            var R = Ug(d);
            v.call(R);
          };
        }
        sC(function() {
          fd(t, d, e, o);
        });
      }
      return Ug(d);
    }
    function ck(e) {
      {
        var t = lk.current;
        if (t !== null && t.stateNode !== null) {
          var r = t.stateNode._warnedAboutRefsInRender;
          r || y("%s is accessing findDOMNode inside its render(). render() should be a pure function of props and state. It should never access something that requires stale data from the previous render, such as refs. Move this logic to componentDidMount and componentDidUpdate instead.", fe(t.type) || "A component"), t.stateNode._warnedAboutRefsInRender = !0;
        }
      }
      return e == null ? null : e.nodeType === er ? e : qw(e, "findDOMNode");
    }
    function fk(e, t, r) {
      if (!rc(t))
        throw Error("Target container is not a DOM element.");
      {
        var i = Xp(t) && t._reactRootContainer === void 0;
        i && y("You are calling ReactDOM.hydrate() on a container that was previously passed to ReactDOM.createRoot(). This is not supported. Did you mean to call createRoot(container, {hydrate: true}).render(element)?");
      }
      return ph(null, e, t, !0, r);
    }
    function dk(e, t, r) {
      if (!rc(t))
        throw Error("Target container is not a DOM element.");
      {
        var i = Xp(t) && t._reactRootContainer === void 0;
        i && y("You are calling ReactDOM.render() on a container that was previously passed to ReactDOM.createRoot(). This is not supported. Did you mean to call root.render(element)?");
      }
      return ph(null, e, t, !1, r);
    }
    function pk(e, t, r, i) {
      if (!rc(r))
        throw Error("Target container is not a DOM element.");
      if (!(e != null && np(e)))
        throw Error("parentComponent must be a valid React Component");
      return ph(e, t, r, !1, i);
    }
    function vk(e) {
      if (!rc(e))
        throw Error("unmountComponentAtNode(...): Target container is not a DOM element.");
      {
        var t = Xp(e) && e._reactRootContainer === void 0;
        t && y("You are calling ReactDOM.unmountComponentAtNode() on a container that was previously passed to ReactDOM.createRoot(). This is not supported. Did you mean to call root.unmount()?");
      }
      if (e._reactRootContainer) {
        {
          var r = dh(e), i = r && !Yl(r);
          i && y("unmountComponentAtNode(): The node you're attempting to unmount was rendered by another copy of React.");
        }
        return sC(function() {
          ph(null, null, e, !1, function() {
            e._reactRootContainer = null, rE(e);
          });
        }), !0;
      } else {
        {
          var o = dh(e), s = !!(o && Yl(o)), d = e.nodeType === er && rc(e.parentNode) && !!e.parentNode._reactRootContainer;
          s && y("unmountComponentAtNode(): The node you're attempting to unmount was rendered by React and is not a top-level container. %s", d ? "You may have accidentally passed in a React root node instead of its container." : "Instead, have the parent component update its state and rerender in order to remove this component.");
        }
        return !1;
      }
    }
    us(Gw), op(Xw), kl(Kw), wi(Zw);
    var GC = !1;
    (typeof Map != "function" || // $FlowIssue Flow incorrectly thinks Map has no prototype
    Map.prototype == null || typeof Map.prototype.forEach != "function" || typeof Set != "function" || // $FlowIssue Flow incorrectly thinks Set has no prototype
    Set.prototype == null || typeof Set.prototype.clear != "function" || typeof Set.prototype.forEach != "function") && y("React depends on Map and Set built-in types. Make sure that you load a polyfill in older browsers. https://reactjs.org/link/react-polyfills"), Oc(G1), ns(uC, Wx, Vx, $x);
    function XC(e, t) {
      var r = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : null;
      if (!rc(t))
        throw Error("Target container is not a DOM element.");
      return Ww(e, t, null, r);
    }
    function hk(e, t, r, i) {
      return pk(e, t, r, i);
    }
    function mk(e, t) {
      var r = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : null;
      return GC || (GC = !0, C('The ReactDOM.unstable_createPortal() alias has been deprecated, and will be removed in React 18+. Update your code to use ReactDOM.createPortal() instead. It has the exact same API, but without the "unstable_" prefix.')), XC(e, t, r);
    }
    var yk = {
      // Keep in sync with ReactTestUtils.js, and ReactTestUtilsAct.js.
      // This is an array for better minification.
      Events: [
        Yl,
        Us,
        Kp,
        Cl,
        Nc,
        oi,
        // TODO: This is related to `act`, not events. Move to separate key?
        ch
      ]
    }, gk = rk({
      findFiberByHostInstance: cu,
      bundleType: 1,
      version: wE,
      rendererPackageName: "react-dom"
    });
    if (!gk && Re && window.top === window.self && (navigator.userAgent.indexOf("Chrome") > -1 && navigator.userAgent.indexOf("Edge") === -1 || navigator.userAgent.indexOf("Firefox") > -1)) {
      var KC = window.location.protocol;
      /^(https?|file):$/.test(KC) && console.info("%cDownload the React DevTools for a better development experience: https://reactjs.org/link/react-devtools" + (KC === "file:" ? `
You might need to use a local HTTP server (instead of file://): https://reactjs.org/link/react-devtools-faq` : ""), "font-weight:bold");
    }
    xr.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED = yk, xr.createPortal = XC, xr.findDOMNode = ck, xr.flushSync = hg, xr.hydrate = fk, xr.render = dk, xr.unmountComponentAtNode = vk, xr.unstable_batchedUpdates = uC, xr.unstable_createPortal = mk, xr.unstable_renderSubtreeIntoContainer = hk, xr.version = wE;
  }()), xr;
}
function Zb() {
  if (!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__ > "u" || typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE != "function")) {
    if (true)
      throw new Error("^_^");
    // removed by dead control flow

  }
}
 false ? (0) : i0.exports = C_();
var b_ = i0.exports;
const lc = /* @__PURE__ */ s0(b_), Sb = {
  disabled: !1
};
var T_ =  true ? nt.oneOfType([nt.number, nt.shape({
  enter: nt.number,
  exit: nt.number,
  appear: nt.number
}).isRequired]) : 0;
 true && nt.oneOfType([nt.string, nt.shape({
  enter: nt.string,
  exit: nt.string,
  active: nt.string
}), nt.shape({
  enter: nt.string,
  enterDone: nt.string,
  enterActive: nt.string,
  exit: nt.string,
  exitDone: nt.string,
  exitActive: nt.string
})]);
const Jb = react__WEBPACK_IMPORTED_MODULE_1___default().createContext(null);
var R_ = function(p) {
  return p.scrollTop;
}, pd = "unmounted", ao = "exited", ga = "entering", Zi = "entered", vd = "exiting", el = /* @__PURE__ */ function(c) {
  Hk(p, c);
  function p(h, b) {
    var C;
    C = c.call(this, h, b) || this;
    var y = b, D = y && !y.isMounting ? h.enter : h.appear, A;
    return C.appearStatus = null, h.in ? D ? (A = ao, C.appearStatus = ga) : A = Zi : h.unmountOnExit || h.mountOnEnter ? A = pd : A = ao, C.state = {
      status: A
    }, C.nextCallback = null, C;
  }
  p.getDerivedStateFromProps = function(b, C) {
    var y = b.in;
    return y && C.status === pd ? {
      status: ao
    } : null;
  };
  var g = p.prototype;
  return g.componentDidMount = function() {
    this.updateStatus(!0, this.appearStatus);
  }, g.componentDidUpdate = function(b) {
    var C = null;
    if (b !== this.props) {
      var y = this.state.status;
      this.props.in ? y !== ga && y !== Zi && (C = ga) : (y === ga || y === Zi) && (C = vd);
    }
    this.updateStatus(!1, C);
  }, g.componentWillUnmount = function() {
    this.cancelNextCallback();
  }, g.getTimeouts = function() {
    var b = this.props.timeout, C, y, D;
    return C = y = D = b, b != null && typeof b != "number" && (C = b.exit, y = b.enter, D = b.appear !== void 0 ? b.appear : y), {
      exit: C,
      enter: y,
      appear: D
    };
  }, g.updateStatus = function(b, C) {
    if (b === void 0 && (b = !1), C !== null)
      if (this.cancelNextCallback(), C === ga) {
        if (this.props.unmountOnExit || this.props.mountOnEnter) {
          var y = this.props.nodeRef ? this.props.nodeRef.current : lc.findDOMNode(this);
          y && R_(y);
        }
        this.performEnter(b);
      } else
        this.performExit();
    else this.props.unmountOnExit && this.state.status === ao && this.setState({
      status: pd
    });
  }, g.performEnter = function(b) {
    var C = this, y = this.props.enter, D = this.context ? this.context.isMounting : b, A = this.props.nodeRef ? [D] : [lc.findDOMNode(this), D], L = A[0], I = A[1], B = this.getTimeouts(), Y = D ? B.appear : B.enter;
    if (!b && !y || Sb.disabled) {
      this.safeSetState({
        status: Zi
      }, function() {
        C.props.onEntered(L);
      });
      return;
    }
    this.props.onEnter(L, I), this.safeSetState({
      status: ga
    }, function() {
      C.props.onEntering(L, I), C.onTransitionEnd(Y, function() {
        C.safeSetState({
          status: Zi
        }, function() {
          C.props.onEntered(L, I);
        });
      });
    });
  }, g.performExit = function() {
    var b = this, C = this.props.exit, y = this.getTimeouts(), D = this.props.nodeRef ? void 0 : lc.findDOMNode(this);
    if (!C || Sb.disabled) {
      this.safeSetState({
        status: ao
      }, function() {
        b.props.onExited(D);
      });
      return;
    }
    this.props.onExit(D), this.safeSetState({
      status: vd
    }, function() {
      b.props.onExiting(D), b.onTransitionEnd(y.exit, function() {
        b.safeSetState({
          status: ao
        }, function() {
          b.props.onExited(D);
        });
      });
    });
  }, g.cancelNextCallback = function() {
    this.nextCallback !== null && (this.nextCallback.cancel(), this.nextCallback = null);
  }, g.safeSetState = function(b, C) {
    C = this.setNextCallback(C), this.setState(b, C);
  }, g.setNextCallback = function(b) {
    var C = this, y = !0;
    return this.nextCallback = function(D) {
      y && (y = !1, C.nextCallback = null, b(D));
    }, this.nextCallback.cancel = function() {
      y = !1;
    }, this.nextCallback;
  }, g.onTransitionEnd = function(b, C) {
    this.setNextCallback(C);
    var y = this.props.nodeRef ? this.props.nodeRef.current : lc.findDOMNode(this), D = b == null && !this.props.addEndListener;
    if (!y || D) {
      setTimeout(this.nextCallback, 0);
      return;
    }
    if (this.props.addEndListener) {
      var A = this.props.nodeRef ? [this.nextCallback] : [y, this.nextCallback], L = A[0], I = A[1];
      this.props.addEndListener(L, I);
    }
    b != null && setTimeout(this.nextCallback, b);
  }, g.render = function() {
    var b = this.state.status;
    if (b === pd)
      return null;
    var C = this.props, y = C.children;
    C.in, C.mountOnEnter, C.unmountOnExit, C.appear, C.enter, C.exit, C.timeout, C.addEndListener, C.onEnter, C.onEntering, C.onEntered, C.onExit, C.onExiting, C.onExited, C.nodeRef;
    var D = Fb(C, ["children", "in", "mountOnEnter", "unmountOnExit", "appear", "enter", "exit", "timeout", "addEndListener", "onEnter", "onEntering", "onEntered", "onExit", "onExiting", "onExited", "nodeRef"]);
    return (
      // allows for nested Transitions
      /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1___default().createElement(Jb.Provider, {
        value: null
      }, typeof y == "function" ? y(b, D) : react__WEBPACK_IMPORTED_MODULE_1___default().cloneElement(react__WEBPACK_IMPORTED_MODULE_1___default().Children.only(y), D))
    );
  }, p;
}((react__WEBPACK_IMPORTED_MODULE_1___default().Component));
el.contextType = Jb;
el.propTypes =  true ? {
  /**
   * A React reference to DOM element that need to transition:
   * https://stackoverflow.com/a/51127130/4671932
   *
   *   - When `nodeRef` prop is used, `node` is not passed to callback functions
   *      (e.g. `onEnter`) because user already has direct access to the node.
   *   - When changing `key` prop of `Transition` in a `TransitionGroup` a new
   *     `nodeRef` need to be provided to `Transition` with changed `key` prop
   *     (see
   *     [test/CSSTransition-test.js](https://github.com/reactjs/react-transition-group/blob/13435f897b3ab71f6e19d724f145596f5910581c/test/CSSTransition-test.js#L362-L437)).
   */
  nodeRef: nt.shape({
    current: typeof Element > "u" ? nt.any : function(c, p, g, h, b, C) {
      var y = c[p];
      return nt.instanceOf(y && "ownerDocument" in y ? y.ownerDocument.defaultView.Element : Element)(c, p, g, h, b, C);
    }
  }),
  /**
   * A `function` child can be used instead of a React element. This function is
   * called with the current transition status (`'entering'`, `'entered'`,
   * `'exiting'`, `'exited'`), which can be used to apply context
   * specific props to a component.
   *
   * ```jsx
   * <Transition in={this.state.in} timeout={150}>
   *   {state => (
   *     <MyComponent className={`fade fade-${state}`} />
   *   )}
   * </Transition>
   * ```
   */
  children: nt.oneOfType([nt.func.isRequired, nt.element.isRequired]).isRequired,
  /**
   * Show the component; triggers the enter or exit states
   */
  in: nt.bool,
  /**
   * By default the child component is mounted immediately along with
   * the parent `Transition` component. If you want to "lazy mount" the component on the
   * first `in={true}` you can set `mountOnEnter`. After the first enter transition the component will stay
   * mounted, even on "exited", unless you also specify `unmountOnExit`.
   */
  mountOnEnter: nt.bool,
  /**
   * By default the child component stays mounted after it reaches the `'exited'` state.
   * Set `unmountOnExit` if you'd prefer to unmount the component after it finishes exiting.
   */
  unmountOnExit: nt.bool,
  /**
   * By default the child component does not perform the enter transition when
   * it first mounts, regardless of the value of `in`. If you want this
   * behavior, set both `appear` and `in` to `true`.
   *
   * > **Note**: there are no special appear states like `appearing`/`appeared`, this prop
   * > only adds an additional enter transition. However, in the
   * > `<CSSTransition>` component that first enter transition does result in
   * > additional `.appear-*` classes, that way you can choose to style it
   * > differently.
   */
  appear: nt.bool,
  /**
   * Enable or disable enter transitions.
   */
  enter: nt.bool,
  /**
   * Enable or disable exit transitions.
   */
  exit: nt.bool,
  /**
   * The duration of the transition, in milliseconds.
   * Required unless `addEndListener` is provided.
   *
   * You may specify a single timeout for all transitions:
   *
   * ```jsx
   * timeout={500}
   * ```
   *
   * or individually:
   *
   * ```jsx
   * timeout={{
   *  appear: 500,
   *  enter: 300,
   *  exit: 500,
   * }}
   * ```
   *
   * - `appear` defaults to the value of `enter`
   * - `enter` defaults to `0`
   * - `exit` defaults to `0`
   *
   * @type {number | { enter?: number, exit?: number, appear?: number }}
   */
  timeout: function(p) {
    var g = T_;
    p.addEndListener || (g = g.isRequired);
    for (var h = arguments.length, b = new Array(h > 1 ? h - 1 : 0), C = 1; C < h; C++)
      b[C - 1] = arguments[C];
    return g.apply(void 0, [p].concat(b));
  },
  /**
   * Add a custom transition end trigger. Called with the transitioning
   * DOM node and a `done` callback. Allows for more fine grained transition end
   * logic. Timeouts are still used as a fallback if provided.
   *
   * **Note**: when `nodeRef` prop is passed, `node` is not passed.
   *
   * ```jsx
   * addEndListener={(node, done) => {
   *   // use the css transitionend event to mark the finish of a transition
   *   node.addEventListener('transitionend', done, false);
   * }}
   * ```
   */
  addEndListener: nt.func,
  /**
   * Callback fired before the "entering" status is applied. An extra parameter
   * `isAppearing` is supplied to indicate if the enter stage is occurring on the initial mount
   *
   * **Note**: when `nodeRef` prop is passed, `node` is not passed.
   *
   * @type Function(node: HtmlElement, isAppearing: bool) -> void
   */
  onEnter: nt.func,
  /**
   * Callback fired after the "entering" status is applied. An extra parameter
   * `isAppearing` is supplied to indicate if the enter stage is occurring on the initial mount
   *
   * **Note**: when `nodeRef` prop is passed, `node` is not passed.
   *
   * @type Function(node: HtmlElement, isAppearing: bool)
   */
  onEntering: nt.func,
  /**
   * Callback fired after the "entered" status is applied. An extra parameter
   * `isAppearing` is supplied to indicate if the enter stage is occurring on the initial mount
   *
   * **Note**: when `nodeRef` prop is passed, `node` is not passed.
   *
   * @type Function(node: HtmlElement, isAppearing: bool) -> void
   */
  onEntered: nt.func,
  /**
   * Callback fired before the "exiting" status is applied.
   *
   * **Note**: when `nodeRef` prop is passed, `node` is not passed.
   *
   * @type Function(node: HtmlElement) -> void
   */
  onExit: nt.func,
  /**
   * Callback fired after the "exiting" status is applied.
   *
   * **Note**: when `nodeRef` prop is passed, `node` is not passed.
   *
   * @type Function(node: HtmlElement) -> void
   */
  onExiting: nt.func,
  /**
   * Callback fired after the "exited" status is applied.
   *
   * **Note**: when `nodeRef` prop is passed, `node` is not passed
   *
   * @type Function(node: HtmlElement) -> void
   */
  onExited: nt.func
} : 0;
function ac() {
}
el.defaultProps = {
  in: !1,
  mountOnEnter: !1,
  unmountOnExit: !1,
  appear: !1,
  enter: !0,
  exit: !0,
  onEnter: ac,
  onEntering: ac,
  onEntered: ac,
  onExit: ac,
  onExiting: ac,
  onExited: ac
};
el.UNMOUNTED = pd;
el.EXITED = ao;
el.ENTERING = ga;
el.ENTERED = Zi;
el.EXITING = vd;
function x_(c) {
  return c.code === "Escape" || c.keyCode === 27;
}
function w_() {
  const c = react__WEBPACK_IMPORTED_MODULE_1__.version.split(".");
  return {
    major: +c[0],
    minor: +c[1],
    patch: +c[2]
  };
}
function uc(c) {
  if (!c || typeof c == "function")
    return null;
  const {
    major: p
  } = w_();
  return p >= 19 ? c.props.ref : c.ref;
}
const wh = !!(typeof window < "u" && window.document && window.document.createElement);
var l0 = !1, o0 = !1;
try {
  var Gg = {
    get passive() {
      return l0 = !0;
    },
    get once() {
      return o0 = l0 = !0;
    }
  };
  wh && (window.addEventListener("test", Gg, Gg), window.removeEventListener("test", Gg, !0));
} catch {
}
function k_(c, p, g, h) {
  if (h && typeof h != "boolean" && !o0) {
    var b = h.once, C = h.capture, y = g;
    !o0 && b && (y = g.__once || function D(A) {
      this.removeEventListener(p, D, C), g.call(this, A);
    }, g.__once = y), c.addEventListener(p, y, l0 ? h : C);
  }
  c.addEventListener(p, g, h);
}
function __(c, p, g, h) {
  var b = h && typeof h != "boolean" ? h.capture : h;
  c.removeEventListener(p, g, b), g.__once && c.removeEventListener(p, g.__once, b);
}
function Ch(c, p, g, h) {
  return k_(c, p, g, h), function() {
    __(c, p, g, h);
  };
}
function D_(c, p, g, h) {
  if (h === void 0 && (h = !0), c) {
    var b = document.createEvent("HTMLEvents");
    b.initEvent(p, g, h), c.dispatchEvent(b);
  }
}
function O_(c) {
  var p = Ji(c, "transitionDuration") || "", g = p.indexOf("ms") === -1 ? 1e3 : 1;
  return parseFloat(p) * g;
}
function N_(c, p, g) {
  g === void 0 && (g = 5);
  var h = !1, b = setTimeout(function() {
    h || D_(c, "transitionend", !0);
  }, p + g), C = Ch(c, "transitionend", function() {
    h = !0;
  }, {
    once: !0
  });
  return function() {
    clearTimeout(b), C();
  };
}
function M_(c, p, g, h) {
  g == null && (g = O_(c) || 0);
  var b = N_(c, g, h), C = Ch(c, "transitionend", p);
  return function() {
    b(), C();
  };
}
function Cb(c, p) {
  const g = Ji(c, p) || "", h = g.indexOf("ms") === -1 ? 1e3 : 1;
  return parseFloat(g) * h;
}
function y0(c, p) {
  const g = Cb(c, "transitionDuration"), h = Cb(c, "transitionDelay"), b = M_(c, (C) => {
    C.target === c && (b(), p(C));
  }, g + h);
}
function dd(...c) {
  return c.filter((p) => p != null).reduce((p, g) => {
    if (typeof g != "function")
      throw new Error("Invalid Argument Type, must only provide functions, undefined, or null.");
    return p === null ? g : function(...b) {
      p.apply(this, b), g.apply(this, b);
    };
  }, null);
}
function e1(c) {
  c.offsetHeight;
}
const bb = (c) => !c || typeof c == "function" ? c : (p) => {
  c.current = p;
};
function L_(c, p) {
  const g = bb(c), h = bb(p);
  return (b) => {
    g && g(b), h && h(b);
  };
}
function A_(c, p) {
  return (0,react__WEBPACK_IMPORTED_MODULE_1__.useMemo)(() => L_(c, p), [c, p]);
}
function U_(c) {
  return c && "setState" in c ? lc.findDOMNode(c) : c ?? null;
}
const kh = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1___default().forwardRef(({
  onEnter: c,
  onEntering: p,
  onEntered: g,
  onExit: h,
  onExiting: b,
  onExited: C,
  addEndListener: y,
  children: D,
  childRef: A,
  ...L
}, I) => {
  const B = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)(null), Y = A_(B, A), re = (le) => {
    Y(U_(le));
  }, ue = (le) => (Se) => {
    le && B.current && le(B.current, Se);
  }, Te = (0,react__WEBPACK_IMPORTED_MODULE_1__.useCallback)(ue(c), [c]), ce = (0,react__WEBPACK_IMPORTED_MODULE_1__.useCallback)(ue(p), [p]), _e = (0,react__WEBPACK_IMPORTED_MODULE_1__.useCallback)(ue(g), [g]), we = (0,react__WEBPACK_IMPORTED_MODULE_1__.useCallback)(ue(h), [h]), ee = (0,react__WEBPACK_IMPORTED_MODULE_1__.useCallback)(ue(b), [b]), ie = (0,react__WEBPACK_IMPORTED_MODULE_1__.useCallback)(ue(C), [C]), z = (0,react__WEBPACK_IMPORTED_MODULE_1__.useCallback)(ue(y), [y]);
  return /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(el, {
    ref: I,
    ...L,
    onEnter: Te,
    onEntered: _e,
    onEntering: ce,
    onExit: we,
    onExited: ie,
    onExiting: ee,
    addEndListener: z,
    nodeRef: B,
    children: typeof D == "function" ? (le, Se) => (
      // TODO: Types for RTG missing innerProps, so need to cast.
      D(le, {
        ...Se,
        ref: re
      })
    ) : /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1___default().cloneElement(D, {
      ref: re
    })
  });
});
kh.displayName = "TransitionWrapper";
const z_ = {
  height: ["marginTop", "marginBottom"],
  width: ["marginLeft", "marginRight"]
};
function j_(c, p) {
  const g = `offset${c[0].toUpperCase()}${c.slice(1)}`, h = p[g], b = z_[c];
  return h + // @ts-expect-error TODO
  parseInt(Ji(p, b[0]), 10) + // @ts-expect-error TODO
  parseInt(Ji(p, b[1]), 10);
}
const F_ = {
  [ao]: "collapse",
  [vd]: "collapsing",
  [ga]: "collapsing",
  [Zi]: "collapse show"
}, t1 = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1___default().forwardRef(({
  onEnter: c,
  onEntering: p,
  onEntered: g,
  onExit: h,
  onExiting: b,
  className: C,
  children: y,
  dimension: D = "height",
  in: A = !1,
  timeout: L = 300,
  mountOnEnter: I = !1,
  unmountOnExit: B = !1,
  appear: Y = !1,
  getDimensionValue: re = j_,
  ...ue
}, Te) => {
  const ce = typeof D == "function" ? D() : D, _e = (0,react__WEBPACK_IMPORTED_MODULE_1__.useMemo)(() => dd((le) => {
    le.style[ce] = "0";
  }, c), [ce, c]), we = (0,react__WEBPACK_IMPORTED_MODULE_1__.useMemo)(() => dd((le) => {
    const Se = `scroll${ce[0].toUpperCase()}${ce.slice(1)}`;
    le.style[ce] = `${le[Se]}px`;
  }, p), [ce, p]), ee = (0,react__WEBPACK_IMPORTED_MODULE_1__.useMemo)(() => dd((le) => {
    le.style[ce] = null;
  }, g), [ce, g]), ie = (0,react__WEBPACK_IMPORTED_MODULE_1__.useMemo)(() => dd((le) => {
    le.style[ce] = `${re(ce, le)}px`, e1(le);
  }, h), [h, re, ce]), z = (0,react__WEBPACK_IMPORTED_MODULE_1__.useMemo)(() => dd((le) => {
    le.style[ce] = null;
  }, b), [ce, b]);
  return /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(kh, {
    ref: Te,
    addEndListener: y0,
    ...ue,
    "aria-expanded": ue.role ? A : null,
    onEnter: _e,
    onEntering: we,
    onEntered: ee,
    onExit: ie,
    onExiting: z,
    childRef: uc(y),
    in: A,
    timeout: L,
    mountOnEnter: I,
    unmountOnExit: B,
    appear: Y,
    children: (le, Se) => /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1___default().cloneElement(y, {
      ...Se,
      className: yt(C, y.props.className, F_[le], ce === "width" && "collapse-horizontal")
    })
  });
});
t1.displayName = "Collapse";
const n1 = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef(({
  children: c,
  bsPrefix: p,
  ...g
}, h) => {
  p = Lt(p, "navbar-collapse");
  const b = (0,react__WEBPACK_IMPORTED_MODULE_1__.useContext)(oc);
  return /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(t1, {
    in: !!(b && b.expanded),
    ...g,
    children: /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("div", {
      ref: h,
      className: p,
      children: c
    })
  });
});
n1.displayName = "NavbarCollapse";
function H_(c) {
  const p = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)(c);
  return (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(() => {
    p.current = c;
  }, [c]), p;
}
function _h(c) {
  const p = H_(c);
  return (0,react__WEBPACK_IMPORTED_MODULE_1__.useCallback)(function(...g) {
    return p.current && p.current(...g);
  }, [p]);
}
const r1 = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef(({
  bsPrefix: c,
  className: p,
  children: g,
  label: h = "Toggle navigation",
  // Need to define the default "as" during prop destructuring to be compatible with styled-components github.com/react-bootstrap/react-bootstrap/issues/3595
  as: b = "button",
  onClick: C,
  ...y
}, D) => {
  c = Lt(c, "navbar-toggler");
  const {
    onToggle: A,
    expanded: L
  } = (0,react__WEBPACK_IMPORTED_MODULE_1__.useContext)(oc) || {}, I = _h((B) => {
    C && C(B), A && A();
  });
  return b === "button" && (y.type = "button"), /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(b, {
    ...y,
    ref: D,
    onClick: I,
    "aria-label": h,
    className: yt(p, c, !L && "collapsed"),
    children: g || /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("span", {
      className: `${c}-icon`
    })
  });
});
r1.displayName = "NavbarToggle";
const P_ = typeof __webpack_require__.g < "u" && // @ts-ignore
__webpack_require__.g.navigator && // @ts-ignore
__webpack_require__.g.navigator.product === "ReactNative", B_ = typeof document < "u", V_ = B_ || P_ ? react__WEBPACK_IMPORTED_MODULE_1__.useLayoutEffect : react__WEBPACK_IMPORTED_MODULE_1__.useEffect, u0 = /* @__PURE__ */ new WeakMap(), Tb = (c, p) => {
  if (!c || !p) return;
  const g = u0.get(p) || /* @__PURE__ */ new Map();
  u0.set(p, g);
  let h = g.get(c);
  return h || (h = p.matchMedia(c), h.refCount = 0, g.set(h.media, h)), h;
};
function I_(c, p = typeof window > "u" ? void 0 : window) {
  const g = Tb(c, p), [h, b] = (0,react__WEBPACK_IMPORTED_MODULE_1__.useState)(() => g ? g.matches : !1);
  return V_(() => {
    let C = Tb(c, p);
    if (!C)
      return b(!1);
    let y = u0.get(p);
    const D = () => {
      b(C.matches);
    };
    return C.refCount++, C.addListener(D), D(), () => {
      C.removeListener(D), C.refCount--, C.refCount <= 0 && (y == null || y.delete(C.media)), C = void 0;
    };
  }, [c]), h;
}
function $_(c) {
  const p = Object.keys(c);
  function g(D, A) {
    return D === A ? A : D ? `${D} and ${A}` : A;
  }
  function h(D) {
    return p[Math.min(p.indexOf(D) + 1, p.length - 1)];
  }
  function b(D) {
    const A = h(D);
    let L = c[A];
    return typeof L == "number" ? L = `${L - 0.2}px` : L = `calc(${L} - 0.2px)`, `(max-width: ${L})`;
  }
  function C(D) {
    let A = c[D];
    return typeof A == "number" && (A = `${A}px`), `(min-width: ${A})`;
  }
  function y(D, A, L) {
    let I;
    typeof D == "object" ? (I = D, L = A, A = !0) : (A = A || !0, I = {
      [D]: A
    });
    let B = (0,react__WEBPACK_IMPORTED_MODULE_1__.useMemo)(() => Object.entries(I).reduce((Y, [re, ue]) => ((ue === "up" || ue === !0) && (Y = g(Y, C(re))), (ue === "down" || ue === !0) && (Y = g(Y, b(re))), Y), ""), [JSON.stringify(I)]);
    return I_(B, L);
  }
  return y;
}
const W_ = $_({
  xs: 0,
  sm: 576,
  md: 768,
  lg: 992,
  xl: 1200,
  xxl: 1400
});
function Xg(c) {
  c === void 0 && (c = m0());
  try {
    var p = c.activeElement;
    return !p || !p.nodeName ? null : p;
  } catch {
    return c.body;
  }
}
function Rb(c, p) {
  if (c.contains) return c.contains(p);
  if (c.compareDocumentPosition) return c === p || !!(c.compareDocumentPosition(p) & 16);
}
function Y_(c) {
  const p = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)(c);
  return p.current = c, p;
}
function q_(c) {
  const p = Y_(c);
  (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(() => () => p.current(), []);
}
function Q_(c = document) {
  const p = c.defaultView;
  return Math.abs(p.innerWidth - c.documentElement.clientWidth);
}
const xb = xh("modal-open");
class g0 {
  constructor({
    ownerDocument: p,
    handleContainerOverflow: g = !0,
    isRTL: h = !1
  } = {}) {
    this.handleContainerOverflow = g, this.isRTL = h, this.modals = [], this.ownerDocument = p;
  }
  getScrollbarWidth() {
    return Q_(this.ownerDocument);
  }
  getElement() {
    return (this.ownerDocument || document).body;
  }
  setModalAttributes(p) {
  }
  removeModalAttributes(p) {
  }
  setContainerStyle(p) {
    const g = {
      overflow: "hidden"
    }, h = this.isRTL ? "paddingLeft" : "paddingRight", b = this.getElement();
    p.style = {
      overflow: b.style.overflow,
      [h]: b.style[h]
    }, p.scrollBarWidth && (g[h] = `${parseInt(Ji(b, h) || "0", 10) + p.scrollBarWidth}px`), b.setAttribute(xb, ""), Ji(b, g);
  }
  reset() {
    [...this.modals].forEach((p) => this.remove(p));
  }
  removeContainerStyle(p) {
    const g = this.getElement();
    g.removeAttribute(xb), Object.assign(g.style, p.style);
  }
  add(p) {
    let g = this.modals.indexOf(p);
    return g !== -1 || (g = this.modals.length, this.modals.push(p), this.setModalAttributes(p), g !== 0) || (this.state = {
      scrollBarWidth: this.getScrollbarWidth(),
      style: {}
    }, this.handleContainerOverflow && this.setContainerStyle(this.state)), g;
  }
  remove(p) {
    const g = this.modals.indexOf(p);
    g !== -1 && (this.modals.splice(g, 1), !this.modals.length && this.handleContainerOverflow && this.removeContainerStyle(this.state), this.removeModalAttributes(p));
  }
  isTopModal(p) {
    return !!this.modals.length && this.modals[this.modals.length - 1] === p;
  }
}
const a1 = /* @__PURE__ */ (0,react__WEBPACK_IMPORTED_MODULE_1__.createContext)(wh ? window : void 0);
a1.Provider;
function E0() {
  return (0,react__WEBPACK_IMPORTED_MODULE_1__.useContext)(a1);
}
const Kg = (c, p) => wh ? c == null ? (p || m0()).body : (typeof c == "function" && (c = c()), c && "current" in c && (c = c.current), c && ("nodeType" in c || c.getBoundingClientRect) ? c : null) : null;
function G_(c, p) {
  const g = E0(), [h, b] = (0,react__WEBPACK_IMPORTED_MODULE_1__.useState)(() => Kg(c, g == null ? void 0 : g.document));
  if (!h) {
    const C = Kg(c);
    C && b(C);
  }
  return (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(() => {
  }, [p, h]), (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(() => {
    const C = Kg(c);
    C !== h && b(C);
  }, [c, h]), h;
}
function X_({
  children: c,
  in: p,
  onExited: g,
  mountOnEnter: h,
  unmountOnExit: b
}) {
  const C = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)(null), y = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)(p), D = Ki(g);
  (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(() => {
    p ? y.current = !0 : D(C.current);
  }, [p, D]);
  const A = Rh(C, uc(c)), L = /* @__PURE__ */ (0,react__WEBPACK_IMPORTED_MODULE_1__.cloneElement)(c, {
    ref: A
  });
  return p ? L : b || !y.current && h ? null : L;
}
const K_ = ["onEnter", "onEntering", "onEntered", "onExit", "onExiting", "onExited", "addEndListener", "children"];
function Z_(c, p) {
  if (c == null) return {};
  var g = {};
  for (var h in c) if ({}.hasOwnProperty.call(c, h)) {
    if (p.indexOf(h) >= 0) continue;
    g[h] = c[h];
  }
  return g;
}
function J_(c) {
  let {
    onEnter: p,
    onEntering: g,
    onEntered: h,
    onExit: b,
    onExiting: C,
    onExited: y,
    addEndListener: D,
    children: A
  } = c, L = Z_(c, K_);
  const I = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)(null), B = Rh(I, uc(A)), Y = (ie) => (z) => {
    ie && I.current && ie(I.current, z);
  }, re = (0,react__WEBPACK_IMPORTED_MODULE_1__.useCallback)(Y(p), [p]), ue = (0,react__WEBPACK_IMPORTED_MODULE_1__.useCallback)(Y(g), [g]), Te = (0,react__WEBPACK_IMPORTED_MODULE_1__.useCallback)(Y(h), [h]), ce = (0,react__WEBPACK_IMPORTED_MODULE_1__.useCallback)(Y(b), [b]), _e = (0,react__WEBPACK_IMPORTED_MODULE_1__.useCallback)(Y(C), [C]), we = (0,react__WEBPACK_IMPORTED_MODULE_1__.useCallback)(Y(y), [y]), ee = (0,react__WEBPACK_IMPORTED_MODULE_1__.useCallback)(Y(D), [D]);
  return Object.assign({}, L, {
    nodeRef: I
  }, p && {
    onEnter: re
  }, g && {
    onEntering: ue
  }, h && {
    onEntered: Te
  }, b && {
    onExit: ce
  }, C && {
    onExiting: _e
  }, y && {
    onExited: we
  }, D && {
    addEndListener: ee
  }, {
    children: typeof A == "function" ? (ie, z) => (
      // TODO: Types for RTG missing innerProps, so need to cast.
      A(ie, Object.assign({}, z, {
        ref: B
      }))
    ) : /* @__PURE__ */ (0,react__WEBPACK_IMPORTED_MODULE_1__.cloneElement)(A, {
      ref: B
    })
  });
}
const eD = ["component"];
function tD(c, p) {
  if (c == null) return {};
  var g = {};
  for (var h in c) if ({}.hasOwnProperty.call(c, h)) {
    if (p.indexOf(h) >= 0) continue;
    g[h] = c[h];
  }
  return g;
}
const nD = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef((c, p) => {
  let {
    component: g
  } = c, h = tD(c, eD);
  const b = J_(h);
  return /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(g, Object.assign({
    ref: p
  }, b));
});
function rD({
  in: c,
  onTransition: p
}) {
  const g = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)(null), h = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)(!0), b = Ki(p);
  return fb(() => {
    if (!g.current)
      return;
    let C = !1;
    return b({
      in: c,
      element: g.current,
      initial: h.current,
      isStale: () => C
    }), () => {
      C = !0;
    };
  }, [c, b]), fb(() => (h.current = !1, () => {
    h.current = !0;
  }), []), g;
}
function aD({
  children: c,
  in: p,
  onExited: g,
  onEntered: h,
  transition: b
}) {
  const [C, y] = (0,react__WEBPACK_IMPORTED_MODULE_1__.useState)(!p);
  p && C && y(!1);
  const D = rD({
    in: !!p,
    onTransition: (L) => {
      const I = () => {
        L.isStale() || (L.in ? h == null || h(L.element, L.initial) : (y(!0), g == null || g(L.element)));
      };
      Promise.resolve(b(L)).then(I, (B) => {
        throw L.in || y(!0), B;
      });
    }
  }), A = Rh(D, uc(c));
  return C && !p ? null : /* @__PURE__ */ (0,react__WEBPACK_IMPORTED_MODULE_1__.cloneElement)(c, {
    ref: A
  });
}
function wb(c, p, g) {
  return c ? /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(nD, Object.assign({}, g, {
    component: c
  })) : p ? /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(aD, Object.assign({}, g, {
    transition: p
  })) : /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(X_, Object.assign({}, g));
}
const iD = ["show", "role", "className", "style", "children", "backdrop", "keyboard", "onBackdropClick", "onEscapeKeyDown", "transition", "runTransition", "backdropTransition", "runBackdropTransition", "autoFocus", "enforceFocus", "restoreFocus", "restoreFocusOptions", "renderDialog", "renderBackdrop", "manager", "container", "onShow", "onHide", "onExit", "onExited", "onExiting", "onEnter", "onEntering", "onEntered"];
function lD(c, p) {
  if (c == null) return {};
  var g = {};
  for (var h in c) if ({}.hasOwnProperty.call(c, h)) {
    if (p.indexOf(h) >= 0) continue;
    g[h] = c[h];
  }
  return g;
}
let Zg;
function oD(c) {
  return Zg || (Zg = new g0({
    ownerDocument: c == null ? void 0 : c.document
  })), Zg;
}
function uD(c) {
  const p = E0(), g = c || oD(p), h = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)({
    dialog: null,
    backdrop: null
  });
  return Object.assign(h.current, {
    add: () => g.add(h.current),
    remove: () => g.remove(h.current),
    isTopModal: () => g.isTopModal(h.current),
    setDialogRef: (0,react__WEBPACK_IMPORTED_MODULE_1__.useCallback)((b) => {
      h.current.dialog = b;
    }, []),
    setBackdropRef: (0,react__WEBPACK_IMPORTED_MODULE_1__.useCallback)((b) => {
      h.current.backdrop = b;
    }, [])
  });
}
const i1 = /* @__PURE__ */ (0,react__WEBPACK_IMPORTED_MODULE_1__.forwardRef)((c, p) => {
  let {
    show: g = !1,
    role: h = "dialog",
    className: b,
    style: C,
    children: y,
    backdrop: D = !0,
    keyboard: A = !0,
    onBackdropClick: L,
    onEscapeKeyDown: I,
    transition: B,
    runTransition: Y,
    backdropTransition: re,
    runBackdropTransition: ue,
    autoFocus: Te = !0,
    enforceFocus: ce = !0,
    restoreFocus: _e = !0,
    restoreFocusOptions: we,
    renderDialog: ee,
    renderBackdrop: ie = (tt) => /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("div", Object.assign({}, tt)),
    manager: z,
    container: le,
    onShow: Se,
    onHide: We = () => {
    },
    onExit: Ae,
    onExited: lt,
    onExiting: it,
    onEnter: ot,
    onEntering: rt,
    onEntered: ut
  } = c, st = lD(c, iD);
  const Be = E0(), mt = G_(le), Ke = uD(z), Rt = t_(), Z = n_(g), [F, te] = (0,react__WEBPACK_IMPORTED_MODULE_1__.useState)(!g), G = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)(null);
  (0,react__WEBPACK_IMPORTED_MODULE_1__.useImperativeHandle)(p, () => Ke, [Ke]), wh && !Z && g && (G.current = Xg(Be == null ? void 0 : Be.document)), g && F && te(!1);
  const oe = Ki(() => {
    if (Ke.add(), Fe.current = Ch(document, "keydown", xe), Ne.current = Ch(
      document,
      "focus",
      // the timeout is necessary b/c this will run before the new modal is mounted
      // and so steals focus from it
      () => setTimeout(Re),
      !0
    ), Se && Se(), Te) {
      var tt, wr;
      const Xn = Xg((tt = (wr = Ke.dialog) == null ? void 0 : wr.ownerDocument) != null ? tt : Be == null ? void 0 : Be.document);
      Ke.dialog && Xn && !Rb(Ke.dialog, Xn) && (G.current = Xn, Ke.dialog.focus());
    }
  }), ve = Ki(() => {
    if (Ke.remove(), Fe.current == null || Fe.current(), Ne.current == null || Ne.current(), _e) {
      var tt;
      (tt = G.current) == null || tt.focus == null || tt.focus(we), G.current = null;
    }
  });
  (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(() => {
    !g || !mt || oe();
  }, [
    g,
    mt,
    /* should never change: */
    oe
  ]), (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(() => {
    F && ve();
  }, [F, ve]), q_(() => {
    ve();
  });
  const Re = Ki(() => {
    if (!ce || !Rt() || !Ke.isTopModal())
      return;
    const tt = Xg(Be == null ? void 0 : Be.document);
    Ke.dialog && tt && !Rb(Ke.dialog, tt) && Ke.dialog.focus();
  }), Oe = Ki((tt) => {
    tt.target === tt.currentTarget && (L == null || L(tt), D === !0 && We());
  }), xe = Ki((tt) => {
    A && x_(tt) && Ke.isTopModal() && (I == null || I(tt), tt.defaultPrevented || We());
  }), Ne = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)(), Fe = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)(), Ze = (...tt) => {
    te(!0), lt == null || lt(...tt);
  };
  if (!mt)
    return null;
  const ne = Object.assign({
    role: h,
    ref: Ke.setDialogRef,
    // apparently only works on the dialog role element
    "aria-modal": h === "dialog" ? !0 : void 0
  }, st, {
    style: C,
    className: b,
    tabIndex: -1
  });
  let At = ee ? ee(ne) : /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("div", Object.assign({}, ne, {
    children: /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.cloneElement(y, {
      role: "document"
    })
  }));
  At = wb(B, Y, {
    unmountOnExit: !0,
    mountOnEnter: !0,
    appear: !0,
    in: !!g,
    onExit: Ae,
    onExiting: it,
    onExited: Ze,
    onEnter: ot,
    onEntering: rt,
    onEntered: ut,
    children: At
  });
  let Yt = null;
  return D && (Yt = ie({
    ref: Ke.setBackdropRef,
    onClick: Oe
  }), Yt = wb(re, ue, {
    in: !!g,
    appear: !0,
    mountOnEnter: !0,
    unmountOnExit: !0,
    children: Yt
  })), /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.Fragment, {
    children: /* @__PURE__ */ lc.createPortal(/* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsxs)(react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.Fragment, {
      children: [Yt, At]
    }), mt)
  });
});
i1.displayName = "Modal";
const sD = Object.assign(i1, {
  Manager: g0
}), cD = {
  [ga]: "show",
  [Zi]: "show"
}, l1 = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef(({
  className: c,
  children: p,
  transitionClasses: g = {},
  onEnter: h,
  ...b
}, C) => {
  const y = {
    in: !1,
    timeout: 300,
    mountOnEnter: !1,
    unmountOnExit: !1,
    appear: !1,
    ...b
  }, D = (0,react__WEBPACK_IMPORTED_MODULE_1__.useCallback)((A, L) => {
    e1(A), h == null || h(A, L);
  }, [h]);
  return /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(kh, {
    ref: C,
    addEndListener: y0,
    ...y,
    onEnter: D,
    childRef: uc(p),
    children: (A, L) => /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.cloneElement(p, {
      ...L,
      className: yt("fade", c, p.props.className, cD[A], g[A])
    })
  });
});
l1.displayName = "Fade";
const o1 = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef(({
  className: c,
  bsPrefix: p,
  as: g = "div",
  ...h
}, b) => (p = Lt(p, "offcanvas-body"), /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(g, {
  ref: b,
  className: yt(c, p),
  ...h
})));
o1.displayName = "OffcanvasBody";
const fD = {
  [ga]: "show",
  [Zi]: "show"
}, u1 = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef(({
  bsPrefix: c,
  className: p,
  children: g,
  in: h = !1,
  mountOnEnter: b = !1,
  unmountOnExit: C = !1,
  appear: y = !1,
  ...D
}, A) => (c = Lt(c, "offcanvas"), /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(kh, {
  ref: A,
  addEndListener: y0,
  in: h,
  mountOnEnter: b,
  unmountOnExit: C,
  appear: y,
  ...D,
  childRef: uc(g),
  children: (L, I) => /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.cloneElement(g, {
    ...I,
    className: yt(p, g.props.className, (L === ga || L === vd) && `${c}-toggling`, fD[L])
  })
})));
u1.displayName = "OffcanvasToggling";
const s1 = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.createContext({
  onHide() {
  }
}), dD = {
  /** An accessible label indicating the relevant information about the Close Button. */
  "aria-label": nt.string,
  /** A callback fired after the Close Button is clicked. */
  onClick: nt.func,
  /**
   * Render different color variant for the button.
   *
   * Omitting this will render the default dark color.
   */
  variant: nt.oneOf(["white"])
}, S0 = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef(({
  className: c,
  variant: p,
  "aria-label": g = "Close",
  ...h
}, b) => /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("button", {
  ref: b,
  type: "button",
  className: yt("btn-close", p && `btn-close-${p}`, c),
  "aria-label": g,
  ...h
}));
S0.displayName = "CloseButton";
S0.propTypes = dD;
const c1 = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef(({
  closeLabel: c = "Close",
  closeVariant: p,
  closeButton: g = !1,
  onHide: h,
  children: b,
  ...C
}, y) => {
  const D = (0,react__WEBPACK_IMPORTED_MODULE_1__.useContext)(s1), A = _h(() => {
    D == null || D.onHide(), h == null || h();
  });
  return /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsxs)("div", {
    ref: y,
    ...C,
    children: [b, g && /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(S0, {
      "aria-label": c,
      variant: p,
      onClick: A
    })]
  });
});
c1.displayName = "AbstractModalHeader";
const f1 = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef(({
  bsPrefix: c,
  className: p,
  closeLabel: g = "Close",
  closeButton: h = !1,
  ...b
}, C) => (c = Lt(c, "offcanvas-header"), /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(c1, {
  ref: C,
  ...b,
  className: yt(p, c),
  closeLabel: g,
  closeButton: h
})));
f1.displayName = "OffcanvasHeader";
const C0 = (c) => (
  // eslint-disable-next-line react/display-name
  /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef((p, g) => /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("div", {
    ...p,
    ref: g,
    className: yt(p.className, c)
  }))
), pD = C0("h5"), d1 = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef(({
  className: c,
  bsPrefix: p,
  as: g = pD,
  ...h
}, b) => (p = Lt(p, "offcanvas-title"), /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(g, {
  ref: b,
  className: yt(c, p),
  ...h
})));
d1.displayName = "OffcanvasTitle";
function vD(c, p) {
  return c.classList ? c.classList.contains(p) : (" " + (c.className.baseVal || c.className) + " ").indexOf(" " + p + " ") !== -1;
}
function hD(c, p) {
  c.classList ? c.classList.add(p) : vD(c, p) || (typeof c.className == "string" ? c.className = c.className + " " + p : c.setAttribute("class", (c.className && c.className.baseVal || "") + " " + p));
}
function kb(c, p) {
  return c.replace(new RegExp("(^|\\s)" + p + "(?:\\s|$)", "g"), "$1").replace(/\s+/g, " ").replace(/^\s*|\s*$/g, "");
}
function mD(c, p) {
  c.classList ? c.classList.remove(p) : typeof c.className == "string" ? c.className = kb(c.className, p) : c.setAttribute("class", kb(c.className && c.className.baseVal || "", p));
}
const ic = {
  FIXED_CONTENT: ".fixed-top, .fixed-bottom, .is-fixed, .sticky-top",
  STICKY_CONTENT: ".sticky-top",
  NAVBAR_TOGGLER: ".navbar-toggler"
};
class p1 extends g0 {
  adjustAndStore(p, g, h) {
    const b = g.style[p];
    g.dataset[p] = b, Ji(g, {
      [p]: `${parseFloat(Ji(g, p)) + h}px`
    });
  }
  restore(p, g) {
    const h = g.dataset[p];
    h !== void 0 && (delete g.dataset[p], Ji(g, {
      [p]: h
    }));
  }
  setContainerStyle(p) {
    super.setContainerStyle(p);
    const g = this.getElement();
    if (hD(g, "modal-open"), !p.scrollBarWidth) return;
    const h = this.isRTL ? "paddingLeft" : "paddingRight", b = this.isRTL ? "marginLeft" : "marginRight";
    Du(g, ic.FIXED_CONTENT).forEach((C) => this.adjustAndStore(h, C, p.scrollBarWidth)), Du(g, ic.STICKY_CONTENT).forEach((C) => this.adjustAndStore(b, C, -p.scrollBarWidth)), Du(g, ic.NAVBAR_TOGGLER).forEach((C) => this.adjustAndStore(b, C, p.scrollBarWidth));
  }
  removeContainerStyle(p) {
    super.removeContainerStyle(p);
    const g = this.getElement();
    mD(g, "modal-open");
    const h = this.isRTL ? "paddingLeft" : "paddingRight", b = this.isRTL ? "marginLeft" : "marginRight";
    Du(g, ic.FIXED_CONTENT).forEach((C) => this.restore(h, C)), Du(g, ic.STICKY_CONTENT).forEach((C) => this.restore(b, C)), Du(g, ic.NAVBAR_TOGGLER).forEach((C) => this.restore(b, C));
  }
}
let Jg;
function yD(c) {
  return Jg || (Jg = new p1(c)), Jg;
}
function gD(c) {
  return /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(u1, {
    ...c
  });
}
function ED(c) {
  return /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(l1, {
    ...c
  });
}
const v1 = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef(({
  bsPrefix: c,
  className: p,
  children: g,
  "aria-labelledby": h,
  placement: b = "start",
  responsive: C,
  /* BaseModal props */
  show: y = !1,
  backdrop: D = !0,
  keyboard: A = !0,
  scroll: L = !1,
  onEscapeKeyDown: I,
  onShow: B,
  onHide: Y,
  container: re,
  autoFocus: ue = !0,
  enforceFocus: Te = !0,
  restoreFocus: ce = !0,
  restoreFocusOptions: _e,
  onEntered: we,
  onExit: ee,
  onExiting: ie,
  onEnter: z,
  onEntering: le,
  onExited: Se,
  backdropClassName: We,
  manager: Ae,
  renderStaticNode: lt = !1,
  ...it
}, ot) => {
  const rt = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)();
  c = Lt(c, "offcanvas");
  const [ut, st] = (0,react__WEBPACK_IMPORTED_MODULE_1__.useState)(!1), Be = _h(Y), mt = W_(C || "xs", "up");
  (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(() => {
    st(C ? y && !mt : y);
  }, [y, C, mt]);
  const Ke = (0,react__WEBPACK_IMPORTED_MODULE_1__.useMemo)(() => ({
    onHide: Be
  }), [Be]);
  function Rt() {
    return Ae || (L ? (rt.current || (rt.current = new p1({
      handleContainerOverflow: !1
    })), rt.current) : yD());
  }
  const Z = (oe, ...ve) => {
    oe && (oe.style.visibility = "visible"), z == null || z(oe, ...ve);
  }, F = (oe, ...ve) => {
    oe && (oe.style.visibility = ""), Se == null || Se(...ve);
  }, te = (0,react__WEBPACK_IMPORTED_MODULE_1__.useCallback)((oe) => /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("div", {
    ...oe,
    className: yt(`${c}-backdrop`, We)
  }), [We, c]), G = (oe) => /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("div", {
    ...oe,
    ...it,
    className: yt(p, C ? `${c}-${C}` : c, `${c}-${b}`),
    "aria-labelledby": h,
    children: g
  });
  return /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsxs)(react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.Fragment, {
    children: [!ut && (C || lt) && G({}), /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(s1.Provider, {
      value: Ke,
      children: /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(sD, {
        show: ut,
        ref: ot,
        backdrop: D,
        container: re,
        keyboard: A,
        autoFocus: ue,
        enforceFocus: Te && !L,
        restoreFocus: ce,
        restoreFocusOptions: _e,
        onEscapeKeyDown: I,
        onShow: B,
        onHide: Be,
        onEnter: Z,
        onEntering: le,
        onEntered: we,
        onExit: ee,
        onExiting: ie,
        onExited: F,
        manager: Rt(),
        transition: gD,
        backdropTransition: ED,
        renderBackdrop: te,
        renderDialog: G
      })
    })]
  });
});
v1.displayName = "Offcanvas";
const SD = Object.assign(v1, {
  Body: o1,
  Header: f1,
  Title: d1
}), h1 = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef(({
  onHide: c,
  ...p
}, g) => {
  const h = (0,react__WEBPACK_IMPORTED_MODULE_1__.useContext)(oc), b = _h(() => {
    h == null || h.onToggle == null || h.onToggle(), c == null || c();
  });
  return /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(SD, {
    ref: g,
    show: !!(h != null && h.expanded),
    ...p,
    renderStaticNode: !0,
    onHide: b
  });
});
h1.displayName = "NavbarOffcanvas";
const m1 = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef(({
  className: c,
  bsPrefix: p,
  as: g = "span",
  ...h
}, b) => (p = Lt(p, "navbar-text"), /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(g, {
  ref: b,
  className: yt(c, p),
  ...h
})));
m1.displayName = "NavbarText";
const y1 = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef((c, p) => {
  const {
    bsPrefix: g,
    expand: h = !0,
    variant: b = "light",
    bg: C,
    fixed: y,
    sticky: D,
    className: A,
    // Need to define the default "as" during prop destructuring to be compatible with styled-components github.com/react-bootstrap/react-bootstrap/issues/3595
    as: L = "nav",
    expanded: I,
    onToggle: B,
    onSelect: Y,
    collapseOnSelect: re = !1,
    ...ue
  } = Hb(c, {
    expanded: "onToggle"
  }), Te = Lt(g, "navbar"), ce = (0,react__WEBPACK_IMPORTED_MODULE_1__.useCallback)((...ee) => {
    Y == null || Y(...ee), re && I && (B == null || B(!1));
  }, [Y, re, I, B]);
  ue.role === void 0 && L !== "nav" && (ue.role = "navigation");
  let _e = `${Te}-expand`;
  typeof h == "string" && (_e = `${_e}-${h}`);
  const we = (0,react__WEBPACK_IMPORTED_MODULE_1__.useMemo)(() => ({
    onToggle: () => B == null ? void 0 : B(!I),
    bsPrefix: Te,
    expanded: !!I,
    expand: h
  }), [Te, I, h, B]);
  return /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(oc.Provider, {
    value: we,
    children: /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(Sh.Provider, {
      value: ce,
      children: /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(L, {
        ref: p,
        ...ue,
        className: yt(A, Te, h && _e, b && `${Te}-${b}`, C && `bg-${C}`, D && `sticky-${D}`, y && `fixed-${y}`)
      })
    })
  });
});
y1.displayName = "Navbar";
const Eh = Object.assign(y1, {
  Brand: Xb,
  Collapse: n1,
  Offcanvas: h1,
  Text: m1,
  Toggle: r1
});
function CD() {
  return /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(Eh, { expand: "md", className: "bg-dark", variant: "dark", children: /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsxs)(jb, { fluid: !0, children: [
    /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(Eh.Brand, { title: "CLIMB Dashboard", children: "CLIMB Dashboard" }),
    /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(Eh.Toggle, { "aria-controls": "basic-navbar-nav" }),
    /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(Eh.Collapse, { id: "basic-navbar-nav", children: /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsxs)(hh, { className: "me-auto", children: [
      /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(
        hh.Link,
        {
          href: "https://docs.climb.ac.uk",
          target: "_blank",
          rel: "noopener noreferrer",
          children: "Documentation"
        }
      ),
      /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(
        hh.Link,
        {
          href: "mailto:support@climb.ac.uk",
          target: "_blank",
          rel: "noopener noreferrer",
          children: "Support"
        }
      ),
      /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(
        hh.Link,
        {
          href: "https://bryn.climb.ac.uk",
          target: "_blank",
          rel: "noopener noreferrer",
          children: "Bryn"
        }
      )
    ] }) })
  ] }) });
}
const b0 = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef(({
  className: c,
  bsPrefix: p,
  as: g = "div",
  ...h
}, b) => (p = Lt(p, "card-body"), /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(g, {
  ref: b,
  className: yt(c, p),
  ...h
})));
b0.displayName = "CardBody";
const g1 = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef(({
  className: c,
  bsPrefix: p,
  as: g = "div",
  ...h
}, b) => (p = Lt(p, "card-footer"), /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(g, {
  ref: b,
  className: yt(c, p),
  ...h
})));
g1.displayName = "CardFooter";
const E1 = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef(({
  bsPrefix: c,
  className: p,
  // Need to define the default "as" during prop destructuring to be compatible with styled-components github.com/react-bootstrap/react-bootstrap/issues/3595
  as: g = "div",
  ...h
}, b) => {
  const C = Lt(c, "card-header"), y = (0,react__WEBPACK_IMPORTED_MODULE_1__.useMemo)(() => ({
    cardHeaderBsPrefix: C
  }), [C]);
  return /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(h0.Provider, {
    value: y,
    children: /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(g, {
      ref: b,
      ...h,
      className: yt(p, C)
    })
  });
});
E1.displayName = "CardHeader";
const S1 = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef(
  // Need to define the default "as" during prop destructuring to be compatible with styled-components github.com/react-bootstrap/react-bootstrap/issues/3595
  ({
    bsPrefix: c,
    className: p,
    variant: g,
    as: h = "img",
    ...b
  }, C) => {
    const y = Lt(c, "card-img");
    return /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(h, {
      ref: C,
      className: yt(g ? `${y}-${g}` : y, p),
      ...b
    });
  }
);
S1.displayName = "CardImg";
const C1 = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef(({
  className: c,
  bsPrefix: p,
  as: g = "div",
  ...h
}, b) => (p = Lt(p, "card-img-overlay"), /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(g, {
  ref: b,
  className: yt(c, p),
  ...h
})));
C1.displayName = "CardImgOverlay";
const b1 = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef(({
  className: c,
  bsPrefix: p,
  as: g = "a",
  ...h
}, b) => (p = Lt(p, "card-link"), /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(g, {
  ref: b,
  className: yt(c, p),
  ...h
})));
b1.displayName = "CardLink";
const bD = C0("h6"), T1 = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef(({
  className: c,
  bsPrefix: p,
  as: g = bD,
  ...h
}, b) => (p = Lt(p, "card-subtitle"), /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(g, {
  ref: b,
  className: yt(c, p),
  ...h
})));
T1.displayName = "CardSubtitle";
const R1 = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef(({
  className: c,
  bsPrefix: p,
  as: g = "p",
  ...h
}, b) => (p = Lt(p, "card-text"), /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(g, {
  ref: b,
  className: yt(c, p),
  ...h
})));
R1.displayName = "CardText";
const TD = C0("h5"), x1 = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef(({
  className: c,
  bsPrefix: p,
  as: g = TD,
  ...h
}, b) => (p = Lt(p, "card-title"), /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(g, {
  ref: b,
  className: yt(c, p),
  ...h
})));
x1.displayName = "CardTitle";
const w1 = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef(({
  bsPrefix: c,
  className: p,
  bg: g,
  text: h,
  border: b,
  body: C = !1,
  children: y,
  // Need to define the default "as" during prop destructuring to be compatible with styled-components github.com/react-bootstrap/react-bootstrap/issues/3595
  as: D = "div",
  ...A
}, L) => {
  const I = Lt(c, "card");
  return /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(D, {
    ref: L,
    ...A,
    className: yt(p, I, g && `bg-${g}`, h && `text-${h}`, b && `border-${b}`),
    children: C ? /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(b0, {
      children: y
    }) : y
  });
});
w1.displayName = "Card";
const e0 = Object.assign(w1, {
  Img: S1,
  Title: x1,
  Subtitle: T1,
  Body: b0,
  Link: b1,
  Text: R1,
  Header: E1,
  Footer: g1,
  ImgOverlay: C1
});
function Dh({ title: c, children: p }) {
  return /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsxs)(e0, { className: "p-3 m-2", children: [
    /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(e0.Title, { children: c }),
    /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(e0.Body, { children: p })
  ] });
}
function RD({ handler: c }) {
  const [p, g] = (0,react__WEBPACK_IMPORTED_MODULE_1__.useState)(null), [h, b] = (0,react__WEBPACK_IMPORTED_MODULE_1__.useState)(!0), [C, y] = (0,react__WEBPACK_IMPORTED_MODULE_1__.useState)(null);
  return (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(() => {
    async function D() {
      try {
        b(!0);
        const A = await c();
        g(A);
      } catch (A) {
        console.error(A), y(A);
      } finally {
        b(!1);
      }
    }
    D();
  }, []), h ? /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("p", { children: "Loading..." }) : C ? /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("p", { children: "Error loading user info" }) : /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(Dh, { title: "User Information", children: /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsxs)("dl", { children: [
    /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("dt", { children: "User" }),
    /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("dd", { children: p == null ? void 0 : p.user }),
    /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("dt", { children: "Group" }),
    /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("dd", { children: p == null ? void 0 : p.group })
  ] }) });
}
function xD(c, p) {
  let g = 0;
  return react__WEBPACK_IMPORTED_MODULE_1__.Children.map(c, (h) => /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.isValidElement(h) ? p(h, g++) : h);
}
const _b = 1e3;
function wD(c, p, g) {
  const h = (c - p) / (g - p) * 100;
  return Math.round(h * _b) / _b;
}
function Db({
  min: c,
  now: p,
  max: g,
  label: h,
  visuallyHidden: b,
  striped: C,
  animated: y,
  className: D,
  style: A,
  variant: L,
  bsPrefix: I,
  ...B
}, Y) {
  return /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("div", {
    ref: Y,
    ...B,
    role: "progressbar",
    className: yt(D, `${I}-bar`, {
      [`bg-${L}`]: L,
      [`${I}-bar-animated`]: y,
      [`${I}-bar-striped`]: y || C
    }),
    style: {
      width: `${wD(p, c, g)}%`,
      ...A
    },
    "aria-valuenow": p,
    "aria-valuemin": c,
    "aria-valuemax": g,
    children: b ? /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("span", {
      className: "visually-hidden",
      children: h
    }) : h
  });
}
const bh = /* @__PURE__ */ react__WEBPACK_IMPORTED_MODULE_1__.forwardRef(({
  isChild: c = !1,
  ...p
}, g) => {
  const h = {
    min: 0,
    max: 100,
    animated: !1,
    visuallyHidden: !1,
    striped: !1,
    ...p
  };
  if (h.bsPrefix = Lt(h.bsPrefix, "progress"), c)
    return Db(h, g);
  const {
    min: b,
    now: C,
    max: y,
    label: D,
    visuallyHidden: A,
    striped: L,
    animated: I,
    bsPrefix: B,
    variant: Y,
    className: re,
    children: ue,
    ...Te
  } = h;
  return /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("div", {
    ref: g,
    ...Te,
    className: yt(re, B),
    children: ue ? xD(ue, (ce) => /* @__PURE__ */ (0,react__WEBPACK_IMPORTED_MODULE_1__.cloneElement)(ce, {
      isChild: !0
    })) : Db({
      min: b,
      now: C,
      max: y,
      label: D,
      visuallyHidden: A,
      striped: L,
      animated: I,
      bsPrefix: B,
      variant: Y
    }, g)
  });
});
bh.displayName = "ProgressBar";
function kD({ handler: c }) {
  const [p, g] = (0,react__WEBPACK_IMPORTED_MODULE_1__.useState)(null);
  return (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(() => {
    async function h() {
      try {
        const C = await c();
        g(C);
      } catch (C) {
        console.error(C);
      }
    }
    h();
    const b = setInterval(h, 5e3);
    return () => clearInterval(b);
  }, []), /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(Dh, { title: "Resources", children: /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsxs)("dl", { children: [
    /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("dt", { children: "CPUs" }),
    /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("dd", { children: (p == null ? void 0 : p.cpus) ?? "Loading..." }),
    /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("dt", { children: "Memory usage" }),
    /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("dd", { children: /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(
      bh,
      {
        now: (p == null ? void 0 : p.memory_now) ?? 0,
        max: (p == null ? void 0 : p.memory_max) ?? 1,
        label: `${(p == null ? void 0 : p.memory_now) ?? 0}%`
      }
    ) }),
    /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("dt", { children: "CPU usage" }),
    /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("dd", { children: /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(
      bh,
      {
        now: (p == null ? void 0 : p.cpu_now) ?? 0,
        max: (p == null ? void 0 : p.cpu_max) ?? 1,
        label: `${(p == null ? void 0 : p.cpu_now) ?? 0}%`
      }
    ) })
  ] }) });
}
function _D({ handler: c }) {
  const [p, g] = (0,react__WEBPACK_IMPORTED_MODULE_1__.useState)([]);
  return (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(() => {
    async function h() {
      try {
        const C = await c();
        g(C);
      } catch (C) {
        console.error(C);
      }
    }
    h();
    const b = setInterval(h, 5e3);
    return () => clearInterval(b);
  }, []), /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(Dh, { title: "Volumes", children: /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("dl", { children: p.map((h) => /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsxs)((react__WEBPACK_IMPORTED_MODULE_1___default().Fragment), { children: [
    /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("dt", { children: h.label }),
    /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("dd", { children: /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(
      bh,
      {
        now: h.data.used,
        max: h.data.total,
        label: `${100 * h.data.used / h.data.total}%`
      }
    ) })
  ] }, h.label)) }) });
}
function DD({ handler: c }) {
  const [p, g] = (0,react__WEBPACK_IMPORTED_MODULE_1__.useState)(null), [h, b] = (0,react__WEBPACK_IMPORTED_MODULE_1__.useState)(!0), [C, y] = (0,react__WEBPACK_IMPORTED_MODULE_1__.useState)(null);
  return (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(() => {
    async function D() {
      try {
        b(!0);
        const A = await c();
        g(A);
      } catch (A) {
        console.error(A), y(A);
      } finally {
        b(!1);
      }
    }
    D();
  }, []), h ? /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("p", { children: "Loading..." }) : C ? /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("p", { children: "Error loading user info" }) : /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(Dh, { title: "GPU", children: /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsxs)("dl", { children: [
    /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("dd", { children: "GPU" }),
    /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("dt", { children: p == null ? void 0 : p.name })
  ] }) });
}
function LD({
  userInfoHandler: c,
  resourcesHandler: p,
  volumesHandler: g,
  gpuHandler: h
}) {
  const [b, C] = (0,react__WEBPACK_IMPORTED_MODULE_1__.useState)(null);
  return (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(() => {
    h().then((y) => {
      C(y.available === !0);
    }).catch(() => {
      C(!1);
    });
  }, [h]), /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)("div", { className: "climb-jupyter onyx h-100", children: /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsxs)(zb, { gap: 2, children: [
    /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(CD, {}),
    /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(RD, { handler: c }),
    /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(kD, { handler: p }),
    /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(_D, { handler: g }),
    b && /* @__PURE__ */ (0,react_jsx_runtime__WEBPACK_IMPORTED_MODULE_0__.jsx)(DD, { handler: h })
  ] }) });
}



/***/ },

/***/ "./node_modules/react/cjs/react-jsx-runtime.development.js"
/*!*****************************************************************!*\
  !*** ./node_modules/react/cjs/react-jsx-runtime.development.js ***!
  \*****************************************************************/
(__unused_webpack_module, exports, __webpack_require__) {

/**
 * @license React
 * react-jsx-runtime.development.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */



if (true) {
  (function() {
'use strict';

var React = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");

// ATTENTION
// When adding new symbols to this file,
// Please consider also adding to 'react-devtools-shared/src/backend/ReactSymbols'
// The Symbol used to tag the ReactElement-like types.
var REACT_ELEMENT_TYPE = Symbol.for('react.element');
var REACT_PORTAL_TYPE = Symbol.for('react.portal');
var REACT_FRAGMENT_TYPE = Symbol.for('react.fragment');
var REACT_STRICT_MODE_TYPE = Symbol.for('react.strict_mode');
var REACT_PROFILER_TYPE = Symbol.for('react.profiler');
var REACT_PROVIDER_TYPE = Symbol.for('react.provider');
var REACT_CONTEXT_TYPE = Symbol.for('react.context');
var REACT_FORWARD_REF_TYPE = Symbol.for('react.forward_ref');
var REACT_SUSPENSE_TYPE = Symbol.for('react.suspense');
var REACT_SUSPENSE_LIST_TYPE = Symbol.for('react.suspense_list');
var REACT_MEMO_TYPE = Symbol.for('react.memo');
var REACT_LAZY_TYPE = Symbol.for('react.lazy');
var REACT_OFFSCREEN_TYPE = Symbol.for('react.offscreen');
var MAYBE_ITERATOR_SYMBOL = Symbol.iterator;
var FAUX_ITERATOR_SYMBOL = '@@iterator';
function getIteratorFn(maybeIterable) {
  if (maybeIterable === null || typeof maybeIterable !== 'object') {
    return null;
  }

  var maybeIterator = MAYBE_ITERATOR_SYMBOL && maybeIterable[MAYBE_ITERATOR_SYMBOL] || maybeIterable[FAUX_ITERATOR_SYMBOL];

  if (typeof maybeIterator === 'function') {
    return maybeIterator;
  }

  return null;
}

var ReactSharedInternals = React.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED;

function error(format) {
  {
    {
      for (var _len2 = arguments.length, args = new Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {
        args[_key2 - 1] = arguments[_key2];
      }

      printWarning('error', format, args);
    }
  }
}

function printWarning(level, format, args) {
  // When changing this logic, you might want to also
  // update consoleWithStackDev.www.js as well.
  {
    var ReactDebugCurrentFrame = ReactSharedInternals.ReactDebugCurrentFrame;
    var stack = ReactDebugCurrentFrame.getStackAddendum();

    if (stack !== '') {
      format += '%s';
      args = args.concat([stack]);
    } // eslint-disable-next-line react-internal/safe-string-coercion


    var argsWithFormat = args.map(function (item) {
      return String(item);
    }); // Careful: RN currently depends on this prefix

    argsWithFormat.unshift('Warning: ' + format); // We intentionally don't use spread (or .apply) directly because it
    // breaks IE9: https://github.com/facebook/react/issues/13610
    // eslint-disable-next-line react-internal/no-production-logging

    Function.prototype.apply.call(console[level], console, argsWithFormat);
  }
}

// -----------------------------------------------------------------------------

var enableScopeAPI = false; // Experimental Create Event Handle API.
var enableCacheElement = false;
var enableTransitionTracing = false; // No known bugs, but needs performance testing

var enableLegacyHidden = false; // Enables unstable_avoidThisFallback feature in Fiber
// stuff. Intended to enable React core members to more easily debug scheduling
// issues in DEV builds.

var enableDebugTracing = false; // Track which Fiber(s) schedule render work.

var REACT_MODULE_REFERENCE;

{
  REACT_MODULE_REFERENCE = Symbol.for('react.module.reference');
}

function isValidElementType(type) {
  if (typeof type === 'string' || typeof type === 'function') {
    return true;
  } // Note: typeof might be other than 'symbol' or 'number' (e.g. if it's a polyfill).


  if (type === REACT_FRAGMENT_TYPE || type === REACT_PROFILER_TYPE || enableDebugTracing  || type === REACT_STRICT_MODE_TYPE || type === REACT_SUSPENSE_TYPE || type === REACT_SUSPENSE_LIST_TYPE || enableLegacyHidden  || type === REACT_OFFSCREEN_TYPE || enableScopeAPI  || enableCacheElement  || enableTransitionTracing ) {
    return true;
  }

  if (typeof type === 'object' && type !== null) {
    if (type.$$typeof === REACT_LAZY_TYPE || type.$$typeof === REACT_MEMO_TYPE || type.$$typeof === REACT_PROVIDER_TYPE || type.$$typeof === REACT_CONTEXT_TYPE || type.$$typeof === REACT_FORWARD_REF_TYPE || // This needs to include all possible module reference object
    // types supported by any Flight configuration anywhere since
    // we don't know which Flight build this will end up being used
    // with.
    type.$$typeof === REACT_MODULE_REFERENCE || type.getModuleId !== undefined) {
      return true;
    }
  }

  return false;
}

function getWrappedName(outerType, innerType, wrapperName) {
  var displayName = outerType.displayName;

  if (displayName) {
    return displayName;
  }

  var functionName = innerType.displayName || innerType.name || '';
  return functionName !== '' ? wrapperName + "(" + functionName + ")" : wrapperName;
} // Keep in sync with react-reconciler/getComponentNameFromFiber


function getContextName(type) {
  return type.displayName || 'Context';
} // Note that the reconciler package should generally prefer to use getComponentNameFromFiber() instead.


function getComponentNameFromType(type) {
  if (type == null) {
    // Host root, text node or just invalid type.
    return null;
  }

  {
    if (typeof type.tag === 'number') {
      error('Received an unexpected object in getComponentNameFromType(). ' + 'This is likely a bug in React. Please file an issue.');
    }
  }

  if (typeof type === 'function') {
    return type.displayName || type.name || null;
  }

  if (typeof type === 'string') {
    return type;
  }

  switch (type) {
    case REACT_FRAGMENT_TYPE:
      return 'Fragment';

    case REACT_PORTAL_TYPE:
      return 'Portal';

    case REACT_PROFILER_TYPE:
      return 'Profiler';

    case REACT_STRICT_MODE_TYPE:
      return 'StrictMode';

    case REACT_SUSPENSE_TYPE:
      return 'Suspense';

    case REACT_SUSPENSE_LIST_TYPE:
      return 'SuspenseList';

  }

  if (typeof type === 'object') {
    switch (type.$$typeof) {
      case REACT_CONTEXT_TYPE:
        var context = type;
        return getContextName(context) + '.Consumer';

      case REACT_PROVIDER_TYPE:
        var provider = type;
        return getContextName(provider._context) + '.Provider';

      case REACT_FORWARD_REF_TYPE:
        return getWrappedName(type, type.render, 'ForwardRef');

      case REACT_MEMO_TYPE:
        var outerName = type.displayName || null;

        if (outerName !== null) {
          return outerName;
        }

        return getComponentNameFromType(type.type) || 'Memo';

      case REACT_LAZY_TYPE:
        {
          var lazyComponent = type;
          var payload = lazyComponent._payload;
          var init = lazyComponent._init;

          try {
            return getComponentNameFromType(init(payload));
          } catch (x) {
            return null;
          }
        }

      // eslint-disable-next-line no-fallthrough
    }
  }

  return null;
}

var assign = Object.assign;

// Helpers to patch console.logs to avoid logging during side-effect free
// replaying on render function. This currently only patches the object
// lazily which won't cover if the log function was extracted eagerly.
// We could also eagerly patch the method.
var disabledDepth = 0;
var prevLog;
var prevInfo;
var prevWarn;
var prevError;
var prevGroup;
var prevGroupCollapsed;
var prevGroupEnd;

function disabledLog() {}

disabledLog.__reactDisabledLog = true;
function disableLogs() {
  {
    if (disabledDepth === 0) {
      /* eslint-disable react-internal/no-production-logging */
      prevLog = console.log;
      prevInfo = console.info;
      prevWarn = console.warn;
      prevError = console.error;
      prevGroup = console.group;
      prevGroupCollapsed = console.groupCollapsed;
      prevGroupEnd = console.groupEnd; // https://github.com/facebook/react/issues/19099

      var props = {
        configurable: true,
        enumerable: true,
        value: disabledLog,
        writable: true
      }; // $FlowFixMe Flow thinks console is immutable.

      Object.defineProperties(console, {
        info: props,
        log: props,
        warn: props,
        error: props,
        group: props,
        groupCollapsed: props,
        groupEnd: props
      });
      /* eslint-enable react-internal/no-production-logging */
    }

    disabledDepth++;
  }
}
function reenableLogs() {
  {
    disabledDepth--;

    if (disabledDepth === 0) {
      /* eslint-disable react-internal/no-production-logging */
      var props = {
        configurable: true,
        enumerable: true,
        writable: true
      }; // $FlowFixMe Flow thinks console is immutable.

      Object.defineProperties(console, {
        log: assign({}, props, {
          value: prevLog
        }),
        info: assign({}, props, {
          value: prevInfo
        }),
        warn: assign({}, props, {
          value: prevWarn
        }),
        error: assign({}, props, {
          value: prevError
        }),
        group: assign({}, props, {
          value: prevGroup
        }),
        groupCollapsed: assign({}, props, {
          value: prevGroupCollapsed
        }),
        groupEnd: assign({}, props, {
          value: prevGroupEnd
        })
      });
      /* eslint-enable react-internal/no-production-logging */
    }

    if (disabledDepth < 0) {
      error('disabledDepth fell below zero. ' + 'This is a bug in React. Please file an issue.');
    }
  }
}

var ReactCurrentDispatcher = ReactSharedInternals.ReactCurrentDispatcher;
var prefix;
function describeBuiltInComponentFrame(name, source, ownerFn) {
  {
    if (prefix === undefined) {
      // Extract the VM specific prefix used by each line.
      try {
        throw Error();
      } catch (x) {
        var match = x.stack.trim().match(/\n( *(at )?)/);
        prefix = match && match[1] || '';
      }
    } // We use the prefix to ensure our stacks line up with native stack frames.


    return '\n' + prefix + name;
  }
}
var reentry = false;
var componentFrameCache;

{
  var PossiblyWeakMap = typeof WeakMap === 'function' ? WeakMap : Map;
  componentFrameCache = new PossiblyWeakMap();
}

function describeNativeComponentFrame(fn, construct) {
  // If something asked for a stack inside a fake render, it should get ignored.
  if ( !fn || reentry) {
    return '';
  }

  {
    var frame = componentFrameCache.get(fn);

    if (frame !== undefined) {
      return frame;
    }
  }

  var control;
  reentry = true;
  var previousPrepareStackTrace = Error.prepareStackTrace; // $FlowFixMe It does accept undefined.

  Error.prepareStackTrace = undefined;
  var previousDispatcher;

  {
    previousDispatcher = ReactCurrentDispatcher.current; // Set the dispatcher in DEV because this might be call in the render function
    // for warnings.

    ReactCurrentDispatcher.current = null;
    disableLogs();
  }

  try {
    // This should throw.
    if (construct) {
      // Something should be setting the props in the constructor.
      var Fake = function () {
        throw Error();
      }; // $FlowFixMe


      Object.defineProperty(Fake.prototype, 'props', {
        set: function () {
          // We use a throwing setter instead of frozen or non-writable props
          // because that won't throw in a non-strict mode function.
          throw Error();
        }
      });

      if (typeof Reflect === 'object' && Reflect.construct) {
        // We construct a different control for this case to include any extra
        // frames added by the construct call.
        try {
          Reflect.construct(Fake, []);
        } catch (x) {
          control = x;
        }

        Reflect.construct(fn, [], Fake);
      } else {
        try {
          Fake.call();
        } catch (x) {
          control = x;
        }

        fn.call(Fake.prototype);
      }
    } else {
      try {
        throw Error();
      } catch (x) {
        control = x;
      }

      fn();
    }
  } catch (sample) {
    // This is inlined manually because closure doesn't do it for us.
    if (sample && control && typeof sample.stack === 'string') {
      // This extracts the first frame from the sample that isn't also in the control.
      // Skipping one frame that we assume is the frame that calls the two.
      var sampleLines = sample.stack.split('\n');
      var controlLines = control.stack.split('\n');
      var s = sampleLines.length - 1;
      var c = controlLines.length - 1;

      while (s >= 1 && c >= 0 && sampleLines[s] !== controlLines[c]) {
        // We expect at least one stack frame to be shared.
        // Typically this will be the root most one. However, stack frames may be
        // cut off due to maximum stack limits. In this case, one maybe cut off
        // earlier than the other. We assume that the sample is longer or the same
        // and there for cut off earlier. So we should find the root most frame in
        // the sample somewhere in the control.
        c--;
      }

      for (; s >= 1 && c >= 0; s--, c--) {
        // Next we find the first one that isn't the same which should be the
        // frame that called our sample function and the control.
        if (sampleLines[s] !== controlLines[c]) {
          // In V8, the first line is describing the message but other VMs don't.
          // If we're about to return the first line, and the control is also on the same
          // line, that's a pretty good indicator that our sample threw at same line as
          // the control. I.e. before we entered the sample frame. So we ignore this result.
          // This can happen if you passed a class to function component, or non-function.
          if (s !== 1 || c !== 1) {
            do {
              s--;
              c--; // We may still have similar intermediate frames from the construct call.
              // The next one that isn't the same should be our match though.

              if (c < 0 || sampleLines[s] !== controlLines[c]) {
                // V8 adds a "new" prefix for native classes. Let's remove it to make it prettier.
                var _frame = '\n' + sampleLines[s].replace(' at new ', ' at '); // If our component frame is labeled "<anonymous>"
                // but we have a user-provided "displayName"
                // splice it in to make the stack more readable.


                if (fn.displayName && _frame.includes('<anonymous>')) {
                  _frame = _frame.replace('<anonymous>', fn.displayName);
                }

                {
                  if (typeof fn === 'function') {
                    componentFrameCache.set(fn, _frame);
                  }
                } // Return the line we found.


                return _frame;
              }
            } while (s >= 1 && c >= 0);
          }

          break;
        }
      }
    }
  } finally {
    reentry = false;

    {
      ReactCurrentDispatcher.current = previousDispatcher;
      reenableLogs();
    }

    Error.prepareStackTrace = previousPrepareStackTrace;
  } // Fallback to just using the name if we couldn't make it throw.


  var name = fn ? fn.displayName || fn.name : '';
  var syntheticFrame = name ? describeBuiltInComponentFrame(name) : '';

  {
    if (typeof fn === 'function') {
      componentFrameCache.set(fn, syntheticFrame);
    }
  }

  return syntheticFrame;
}
function describeFunctionComponentFrame(fn, source, ownerFn) {
  {
    return describeNativeComponentFrame(fn, false);
  }
}

function shouldConstruct(Component) {
  var prototype = Component.prototype;
  return !!(prototype && prototype.isReactComponent);
}

function describeUnknownElementTypeFrameInDEV(type, source, ownerFn) {

  if (type == null) {
    return '';
  }

  if (typeof type === 'function') {
    {
      return describeNativeComponentFrame(type, shouldConstruct(type));
    }
  }

  if (typeof type === 'string') {
    return describeBuiltInComponentFrame(type);
  }

  switch (type) {
    case REACT_SUSPENSE_TYPE:
      return describeBuiltInComponentFrame('Suspense');

    case REACT_SUSPENSE_LIST_TYPE:
      return describeBuiltInComponentFrame('SuspenseList');
  }

  if (typeof type === 'object') {
    switch (type.$$typeof) {
      case REACT_FORWARD_REF_TYPE:
        return describeFunctionComponentFrame(type.render);

      case REACT_MEMO_TYPE:
        // Memo may contain any component type so we recursively resolve it.
        return describeUnknownElementTypeFrameInDEV(type.type, source, ownerFn);

      case REACT_LAZY_TYPE:
        {
          var lazyComponent = type;
          var payload = lazyComponent._payload;
          var init = lazyComponent._init;

          try {
            // Lazy may contain any component type so we recursively resolve it.
            return describeUnknownElementTypeFrameInDEV(init(payload), source, ownerFn);
          } catch (x) {}
        }
    }
  }

  return '';
}

var hasOwnProperty = Object.prototype.hasOwnProperty;

var loggedTypeFailures = {};
var ReactDebugCurrentFrame = ReactSharedInternals.ReactDebugCurrentFrame;

function setCurrentlyValidatingElement(element) {
  {
    if (element) {
      var owner = element._owner;
      var stack = describeUnknownElementTypeFrameInDEV(element.type, element._source, owner ? owner.type : null);
      ReactDebugCurrentFrame.setExtraStackFrame(stack);
    } else {
      ReactDebugCurrentFrame.setExtraStackFrame(null);
    }
  }
}

function checkPropTypes(typeSpecs, values, location, componentName, element) {
  {
    // $FlowFixMe This is okay but Flow doesn't know it.
    var has = Function.call.bind(hasOwnProperty);

    for (var typeSpecName in typeSpecs) {
      if (has(typeSpecs, typeSpecName)) {
        var error$1 = void 0; // Prop type validation may throw. In case they do, we don't want to
        // fail the render phase where it didn't fail before. So we log it.
        // After these have been cleaned up, we'll let them throw.

        try {
          // This is intentionally an invariant that gets caught. It's the same
          // behavior as without this statement except with a better message.
          if (typeof typeSpecs[typeSpecName] !== 'function') {
            // eslint-disable-next-line react-internal/prod-error-codes
            var err = Error((componentName || 'React class') + ': ' + location + ' type `' + typeSpecName + '` is invalid; ' + 'it must be a function, usually from the `prop-types` package, but received `' + typeof typeSpecs[typeSpecName] + '`.' + 'This often happens because of typos such as `PropTypes.function` instead of `PropTypes.func`.');
            err.name = 'Invariant Violation';
            throw err;
          }

          error$1 = typeSpecs[typeSpecName](values, typeSpecName, componentName, location, null, 'SECRET_DO_NOT_PASS_THIS_OR_YOU_WILL_BE_FIRED');
        } catch (ex) {
          error$1 = ex;
        }

        if (error$1 && !(error$1 instanceof Error)) {
          setCurrentlyValidatingElement(element);

          error('%s: type specification of %s' + ' `%s` is invalid; the type checker ' + 'function must return `null` or an `Error` but returned a %s. ' + 'You may have forgotten to pass an argument to the type checker ' + 'creator (arrayOf, instanceOf, objectOf, oneOf, oneOfType, and ' + 'shape all require an argument).', componentName || 'React class', location, typeSpecName, typeof error$1);

          setCurrentlyValidatingElement(null);
        }

        if (error$1 instanceof Error && !(error$1.message in loggedTypeFailures)) {
          // Only monitor this failure once because there tends to be a lot of the
          // same error.
          loggedTypeFailures[error$1.message] = true;
          setCurrentlyValidatingElement(element);

          error('Failed %s type: %s', location, error$1.message);

          setCurrentlyValidatingElement(null);
        }
      }
    }
  }
}

var isArrayImpl = Array.isArray; // eslint-disable-next-line no-redeclare

function isArray(a) {
  return isArrayImpl(a);
}

/*
 * The `'' + value` pattern (used in in perf-sensitive code) throws for Symbol
 * and Temporal.* types. See https://github.com/facebook/react/pull/22064.
 *
 * The functions in this module will throw an easier-to-understand,
 * easier-to-debug exception with a clear errors message message explaining the
 * problem. (Instead of a confusing exception thrown inside the implementation
 * of the `value` object).
 */
// $FlowFixMe only called in DEV, so void return is not possible.
function typeName(value) {
  {
    // toStringTag is needed for namespaced types like Temporal.Instant
    var hasToStringTag = typeof Symbol === 'function' && Symbol.toStringTag;
    var type = hasToStringTag && value[Symbol.toStringTag] || value.constructor.name || 'Object';
    return type;
  }
} // $FlowFixMe only called in DEV, so void return is not possible.


function willCoercionThrow(value) {
  {
    try {
      testStringCoercion(value);
      return false;
    } catch (e) {
      return true;
    }
  }
}

function testStringCoercion(value) {
  // If you ended up here by following an exception call stack, here's what's
  // happened: you supplied an object or symbol value to React (as a prop, key,
  // DOM attribute, CSS property, string ref, etc.) and when React tried to
  // coerce it to a string using `'' + value`, an exception was thrown.
  //
  // The most common types that will cause this exception are `Symbol` instances
  // and Temporal objects like `Temporal.Instant`. But any object that has a
  // `valueOf` or `[Symbol.toPrimitive]` method that throws will also cause this
  // exception. (Library authors do this to prevent users from using built-in
  // numeric operators like `+` or comparison operators like `>=` because custom
  // methods are needed to perform accurate arithmetic or comparison.)
  //
  // To fix the problem, coerce this object or symbol value to a string before
  // passing it to React. The most reliable way is usually `String(value)`.
  //
  // To find which value is throwing, check the browser or debugger console.
  // Before this exception was thrown, there should be `console.error` output
  // that shows the type (Symbol, Temporal.PlainDate, etc.) that caused the
  // problem and how that type was used: key, atrribute, input value prop, etc.
  // In most cases, this console output also shows the component and its
  // ancestor components where the exception happened.
  //
  // eslint-disable-next-line react-internal/safe-string-coercion
  return '' + value;
}
function checkKeyStringCoercion(value) {
  {
    if (willCoercionThrow(value)) {
      error('The provided key is an unsupported type %s.' + ' This value must be coerced to a string before before using it here.', typeName(value));

      return testStringCoercion(value); // throw (to help callers find troubleshooting comments)
    }
  }
}

var ReactCurrentOwner = ReactSharedInternals.ReactCurrentOwner;
var RESERVED_PROPS = {
  key: true,
  ref: true,
  __self: true,
  __source: true
};
var specialPropKeyWarningShown;
var specialPropRefWarningShown;
var didWarnAboutStringRefs;

{
  didWarnAboutStringRefs = {};
}

function hasValidRef(config) {
  {
    if (hasOwnProperty.call(config, 'ref')) {
      var getter = Object.getOwnPropertyDescriptor(config, 'ref').get;

      if (getter && getter.isReactWarning) {
        return false;
      }
    }
  }

  return config.ref !== undefined;
}

function hasValidKey(config) {
  {
    if (hasOwnProperty.call(config, 'key')) {
      var getter = Object.getOwnPropertyDescriptor(config, 'key').get;

      if (getter && getter.isReactWarning) {
        return false;
      }
    }
  }

  return config.key !== undefined;
}

function warnIfStringRefCannotBeAutoConverted(config, self) {
  {
    if (typeof config.ref === 'string' && ReactCurrentOwner.current && self && ReactCurrentOwner.current.stateNode !== self) {
      var componentName = getComponentNameFromType(ReactCurrentOwner.current.type);

      if (!didWarnAboutStringRefs[componentName]) {
        error('Component "%s" contains the string ref "%s". ' + 'Support for string refs will be removed in a future major release. ' + 'This case cannot be automatically converted to an arrow function. ' + 'We ask you to manually fix this case by using useRef() or createRef() instead. ' + 'Learn more about using refs safely here: ' + 'https://reactjs.org/link/strict-mode-string-ref', getComponentNameFromType(ReactCurrentOwner.current.type), config.ref);

        didWarnAboutStringRefs[componentName] = true;
      }
    }
  }
}

function defineKeyPropWarningGetter(props, displayName) {
  {
    var warnAboutAccessingKey = function () {
      if (!specialPropKeyWarningShown) {
        specialPropKeyWarningShown = true;

        error('%s: `key` is not a prop. Trying to access it will result ' + 'in `undefined` being returned. If you need to access the same ' + 'value within the child component, you should pass it as a different ' + 'prop. (https://reactjs.org/link/special-props)', displayName);
      }
    };

    warnAboutAccessingKey.isReactWarning = true;
    Object.defineProperty(props, 'key', {
      get: warnAboutAccessingKey,
      configurable: true
    });
  }
}

function defineRefPropWarningGetter(props, displayName) {
  {
    var warnAboutAccessingRef = function () {
      if (!specialPropRefWarningShown) {
        specialPropRefWarningShown = true;

        error('%s: `ref` is not a prop. Trying to access it will result ' + 'in `undefined` being returned. If you need to access the same ' + 'value within the child component, you should pass it as a different ' + 'prop. (https://reactjs.org/link/special-props)', displayName);
      }
    };

    warnAboutAccessingRef.isReactWarning = true;
    Object.defineProperty(props, 'ref', {
      get: warnAboutAccessingRef,
      configurable: true
    });
  }
}
/**
 * Factory method to create a new React element. This no longer adheres to
 * the class pattern, so do not use new to call it. Also, instanceof check
 * will not work. Instead test $$typeof field against Symbol.for('react.element') to check
 * if something is a React Element.
 *
 * @param {*} type
 * @param {*} props
 * @param {*} key
 * @param {string|object} ref
 * @param {*} owner
 * @param {*} self A *temporary* helper to detect places where `this` is
 * different from the `owner` when React.createElement is called, so that we
 * can warn. We want to get rid of owner and replace string `ref`s with arrow
 * functions, and as long as `this` and owner are the same, there will be no
 * change in behavior.
 * @param {*} source An annotation object (added by a transpiler or otherwise)
 * indicating filename, line number, and/or other information.
 * @internal
 */


var ReactElement = function (type, key, ref, self, source, owner, props) {
  var element = {
    // This tag allows us to uniquely identify this as a React Element
    $$typeof: REACT_ELEMENT_TYPE,
    // Built-in properties that belong on the element
    type: type,
    key: key,
    ref: ref,
    props: props,
    // Record the component responsible for creating this element.
    _owner: owner
  };

  {
    // The validation flag is currently mutative. We put it on
    // an external backing store so that we can freeze the whole object.
    // This can be replaced with a WeakMap once they are implemented in
    // commonly used development environments.
    element._store = {}; // To make comparing ReactElements easier for testing purposes, we make
    // the validation flag non-enumerable (where possible, which should
    // include every environment we run tests in), so the test framework
    // ignores it.

    Object.defineProperty(element._store, 'validated', {
      configurable: false,
      enumerable: false,
      writable: true,
      value: false
    }); // self and source are DEV only properties.

    Object.defineProperty(element, '_self', {
      configurable: false,
      enumerable: false,
      writable: false,
      value: self
    }); // Two elements created in two different places should be considered
    // equal for testing purposes and therefore we hide it from enumeration.

    Object.defineProperty(element, '_source', {
      configurable: false,
      enumerable: false,
      writable: false,
      value: source
    });

    if (Object.freeze) {
      Object.freeze(element.props);
      Object.freeze(element);
    }
  }

  return element;
};
/**
 * https://github.com/reactjs/rfcs/pull/107
 * @param {*} type
 * @param {object} props
 * @param {string} key
 */

function jsxDEV(type, config, maybeKey, source, self) {
  {
    var propName; // Reserved names are extracted

    var props = {};
    var key = null;
    var ref = null; // Currently, key can be spread in as a prop. This causes a potential
    // issue if key is also explicitly declared (ie. <div {...props} key="Hi" />
    // or <div key="Hi" {...props} /> ). We want to deprecate key spread,
    // but as an intermediary step, we will use jsxDEV for everything except
    // <div {...props} key="Hi" />, because we aren't currently able to tell if
    // key is explicitly declared to be undefined or not.

    if (maybeKey !== undefined) {
      {
        checkKeyStringCoercion(maybeKey);
      }

      key = '' + maybeKey;
    }

    if (hasValidKey(config)) {
      {
        checkKeyStringCoercion(config.key);
      }

      key = '' + config.key;
    }

    if (hasValidRef(config)) {
      ref = config.ref;
      warnIfStringRefCannotBeAutoConverted(config, self);
    } // Remaining properties are added to a new props object


    for (propName in config) {
      if (hasOwnProperty.call(config, propName) && !RESERVED_PROPS.hasOwnProperty(propName)) {
        props[propName] = config[propName];
      }
    } // Resolve default props


    if (type && type.defaultProps) {
      var defaultProps = type.defaultProps;

      for (propName in defaultProps) {
        if (props[propName] === undefined) {
          props[propName] = defaultProps[propName];
        }
      }
    }

    if (key || ref) {
      var displayName = typeof type === 'function' ? type.displayName || type.name || 'Unknown' : type;

      if (key) {
        defineKeyPropWarningGetter(props, displayName);
      }

      if (ref) {
        defineRefPropWarningGetter(props, displayName);
      }
    }

    return ReactElement(type, key, ref, self, source, ReactCurrentOwner.current, props);
  }
}

var ReactCurrentOwner$1 = ReactSharedInternals.ReactCurrentOwner;
var ReactDebugCurrentFrame$1 = ReactSharedInternals.ReactDebugCurrentFrame;

function setCurrentlyValidatingElement$1(element) {
  {
    if (element) {
      var owner = element._owner;
      var stack = describeUnknownElementTypeFrameInDEV(element.type, element._source, owner ? owner.type : null);
      ReactDebugCurrentFrame$1.setExtraStackFrame(stack);
    } else {
      ReactDebugCurrentFrame$1.setExtraStackFrame(null);
    }
  }
}

var propTypesMisspellWarningShown;

{
  propTypesMisspellWarningShown = false;
}
/**
 * Verifies the object is a ReactElement.
 * See https://reactjs.org/docs/react-api.html#isvalidelement
 * @param {?object} object
 * @return {boolean} True if `object` is a ReactElement.
 * @final
 */


function isValidElement(object) {
  {
    return typeof object === 'object' && object !== null && object.$$typeof === REACT_ELEMENT_TYPE;
  }
}

function getDeclarationErrorAddendum() {
  {
    if (ReactCurrentOwner$1.current) {
      var name = getComponentNameFromType(ReactCurrentOwner$1.current.type);

      if (name) {
        return '\n\nCheck the render method of `' + name + '`.';
      }
    }

    return '';
  }
}

function getSourceInfoErrorAddendum(source) {
  {
    if (source !== undefined) {
      var fileName = source.fileName.replace(/^.*[\\\/]/, '');
      var lineNumber = source.lineNumber;
      return '\n\nCheck your code at ' + fileName + ':' + lineNumber + '.';
    }

    return '';
  }
}
/**
 * Warn if there's no key explicitly set on dynamic arrays of children or
 * object keys are not valid. This allows us to keep track of children between
 * updates.
 */


var ownerHasKeyUseWarning = {};

function getCurrentComponentErrorInfo(parentType) {
  {
    var info = getDeclarationErrorAddendum();

    if (!info) {
      var parentName = typeof parentType === 'string' ? parentType : parentType.displayName || parentType.name;

      if (parentName) {
        info = "\n\nCheck the top-level render call using <" + parentName + ">.";
      }
    }

    return info;
  }
}
/**
 * Warn if the element doesn't have an explicit key assigned to it.
 * This element is in an array. The array could grow and shrink or be
 * reordered. All children that haven't already been validated are required to
 * have a "key" property assigned to it. Error statuses are cached so a warning
 * will only be shown once.
 *
 * @internal
 * @param {ReactElement} element Element that requires a key.
 * @param {*} parentType element's parent's type.
 */


function validateExplicitKey(element, parentType) {
  {
    if (!element._store || element._store.validated || element.key != null) {
      return;
    }

    element._store.validated = true;
    var currentComponentErrorInfo = getCurrentComponentErrorInfo(parentType);

    if (ownerHasKeyUseWarning[currentComponentErrorInfo]) {
      return;
    }

    ownerHasKeyUseWarning[currentComponentErrorInfo] = true; // Usually the current owner is the offender, but if it accepts children as a
    // property, it may be the creator of the child that's responsible for
    // assigning it a key.

    var childOwner = '';

    if (element && element._owner && element._owner !== ReactCurrentOwner$1.current) {
      // Give the component that originally created this child.
      childOwner = " It was passed a child from " + getComponentNameFromType(element._owner.type) + ".";
    }

    setCurrentlyValidatingElement$1(element);

    error('Each child in a list should have a unique "key" prop.' + '%s%s See https://reactjs.org/link/warning-keys for more information.', currentComponentErrorInfo, childOwner);

    setCurrentlyValidatingElement$1(null);
  }
}
/**
 * Ensure that every element either is passed in a static location, in an
 * array with an explicit keys property defined, or in an object literal
 * with valid key property.
 *
 * @internal
 * @param {ReactNode} node Statically passed child of any type.
 * @param {*} parentType node's parent's type.
 */


function validateChildKeys(node, parentType) {
  {
    if (typeof node !== 'object') {
      return;
    }

    if (isArray(node)) {
      for (var i = 0; i < node.length; i++) {
        var child = node[i];

        if (isValidElement(child)) {
          validateExplicitKey(child, parentType);
        }
      }
    } else if (isValidElement(node)) {
      // This element was passed in a valid location.
      if (node._store) {
        node._store.validated = true;
      }
    } else if (node) {
      var iteratorFn = getIteratorFn(node);

      if (typeof iteratorFn === 'function') {
        // Entry iterators used to provide implicit keys,
        // but now we print a separate warning for them later.
        if (iteratorFn !== node.entries) {
          var iterator = iteratorFn.call(node);
          var step;

          while (!(step = iterator.next()).done) {
            if (isValidElement(step.value)) {
              validateExplicitKey(step.value, parentType);
            }
          }
        }
      }
    }
  }
}
/**
 * Given an element, validate that its props follow the propTypes definition,
 * provided by the type.
 *
 * @param {ReactElement} element
 */


function validatePropTypes(element) {
  {
    var type = element.type;

    if (type === null || type === undefined || typeof type === 'string') {
      return;
    }

    var propTypes;

    if (typeof type === 'function') {
      propTypes = type.propTypes;
    } else if (typeof type === 'object' && (type.$$typeof === REACT_FORWARD_REF_TYPE || // Note: Memo only checks outer props here.
    // Inner props are checked in the reconciler.
    type.$$typeof === REACT_MEMO_TYPE)) {
      propTypes = type.propTypes;
    } else {
      return;
    }

    if (propTypes) {
      // Intentionally inside to avoid triggering lazy initializers:
      var name = getComponentNameFromType(type);
      checkPropTypes(propTypes, element.props, 'prop', name, element);
    } else if (type.PropTypes !== undefined && !propTypesMisspellWarningShown) {
      propTypesMisspellWarningShown = true; // Intentionally inside to avoid triggering lazy initializers:

      var _name = getComponentNameFromType(type);

      error('Component %s declared `PropTypes` instead of `propTypes`. Did you misspell the property assignment?', _name || 'Unknown');
    }

    if (typeof type.getDefaultProps === 'function' && !type.getDefaultProps.isReactClassApproved) {
      error('getDefaultProps is only used on classic React.createClass ' + 'definitions. Use a static property named `defaultProps` instead.');
    }
  }
}
/**
 * Given a fragment, validate that it can only be provided with fragment props
 * @param {ReactElement} fragment
 */


function validateFragmentProps(fragment) {
  {
    var keys = Object.keys(fragment.props);

    for (var i = 0; i < keys.length; i++) {
      var key = keys[i];

      if (key !== 'children' && key !== 'key') {
        setCurrentlyValidatingElement$1(fragment);

        error('Invalid prop `%s` supplied to `React.Fragment`. ' + 'React.Fragment can only have `key` and `children` props.', key);

        setCurrentlyValidatingElement$1(null);
        break;
      }
    }

    if (fragment.ref !== null) {
      setCurrentlyValidatingElement$1(fragment);

      error('Invalid attribute `ref` supplied to `React.Fragment`.');

      setCurrentlyValidatingElement$1(null);
    }
  }
}

var didWarnAboutKeySpread = {};
function jsxWithValidation(type, props, key, isStaticChildren, source, self) {
  {
    var validType = isValidElementType(type); // We warn in this case but don't throw. We expect the element creation to
    // succeed and there will likely be errors in render.

    if (!validType) {
      var info = '';

      if (type === undefined || typeof type === 'object' && type !== null && Object.keys(type).length === 0) {
        info += ' You likely forgot to export your component from the file ' + "it's defined in, or you might have mixed up default and named imports.";
      }

      var sourceInfo = getSourceInfoErrorAddendum(source);

      if (sourceInfo) {
        info += sourceInfo;
      } else {
        info += getDeclarationErrorAddendum();
      }

      var typeString;

      if (type === null) {
        typeString = 'null';
      } else if (isArray(type)) {
        typeString = 'array';
      } else if (type !== undefined && type.$$typeof === REACT_ELEMENT_TYPE) {
        typeString = "<" + (getComponentNameFromType(type.type) || 'Unknown') + " />";
        info = ' Did you accidentally export a JSX literal instead of a component?';
      } else {
        typeString = typeof type;
      }

      error('React.jsx: type is invalid -- expected a string (for ' + 'built-in components) or a class/function (for composite ' + 'components) but got: %s.%s', typeString, info);
    }

    var element = jsxDEV(type, props, key, source, self); // The result can be nullish if a mock or a custom function is used.
    // TODO: Drop this when these are no longer allowed as the type argument.

    if (element == null) {
      return element;
    } // Skip key warning if the type isn't valid since our key validation logic
    // doesn't expect a non-string/function type and can throw confusing errors.
    // We don't want exception behavior to differ between dev and prod.
    // (Rendering will throw with a helpful message and as soon as the type is
    // fixed, the key warnings will appear.)


    if (validType) {
      var children = props.children;

      if (children !== undefined) {
        if (isStaticChildren) {
          if (isArray(children)) {
            for (var i = 0; i < children.length; i++) {
              validateChildKeys(children[i], type);
            }

            if (Object.freeze) {
              Object.freeze(children);
            }
          } else {
            error('React.jsx: Static children should always be an array. ' + 'You are likely explicitly calling React.jsxs or React.jsxDEV. ' + 'Use the Babel transform instead.');
          }
        } else {
          validateChildKeys(children, type);
        }
      }
    }

    {
      if (hasOwnProperty.call(props, 'key')) {
        var componentName = getComponentNameFromType(type);
        var keys = Object.keys(props).filter(function (k) {
          return k !== 'key';
        });
        var beforeExample = keys.length > 0 ? '{key: someKey, ' + keys.join(': ..., ') + ': ...}' : '{key: someKey}';

        if (!didWarnAboutKeySpread[componentName + beforeExample]) {
          var afterExample = keys.length > 0 ? '{' + keys.join(': ..., ') + ': ...}' : '{}';

          error('A props object containing a "key" prop is being spread into JSX:\n' + '  let props = %s;\n' + '  <%s {...props} />\n' + 'React keys must be passed directly to JSX without using spread:\n' + '  let props = %s;\n' + '  <%s key={someKey} {...props} />', beforeExample, componentName, afterExample, componentName);

          didWarnAboutKeySpread[componentName + beforeExample] = true;
        }
      }
    }

    if (type === REACT_FRAGMENT_TYPE) {
      validateFragmentProps(element);
    } else {
      validatePropTypes(element);
    }

    return element;
  }
} // These two functions exist to still get child warnings in dev
// even with the prod transform. This means that jsxDEV is purely
// opt-in behavior for better messages but that we won't stop
// giving you warnings if you use production apis.

function jsxWithValidationStatic(type, props, key) {
  {
    return jsxWithValidation(type, props, key, true);
  }
}
function jsxWithValidationDynamic(type, props, key) {
  {
    return jsxWithValidation(type, props, key, false);
  }
}

var jsx =  jsxWithValidationDynamic ; // we may want to special case jsxs internally to take advantage of static children.
// for now we can ship identical prod functions

var jsxs =  jsxWithValidationStatic ;

exports.Fragment = REACT_FRAGMENT_TYPE;
exports.jsx = jsx;
exports.jsxs = jsxs;
  })();
}


/***/ },

/***/ "./node_modules/react/jsx-runtime.js"
/*!*******************************************!*\
  !*** ./node_modules/react/jsx-runtime.js ***!
  \*******************************************/
(module, __unused_webpack_exports, __webpack_require__) {



if (false) // removed by dead control flow
{} else {
  module.exports = __webpack_require__(/*! ./cjs/react-jsx-runtime.development.js */ "./node_modules/react/cjs/react-jsx-runtime.development.js");
}


/***/ }

}]);
//# sourceMappingURL=vendors-node_modules_climb-dashboard-gui_dist_climb-dashboard-gui_js.f686d5c1f4542e4e5f48.js.map